(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 11.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[    660458,      11624]
NotebookOptionsPosition[    658513,      11554]
NotebookOutlinePosition[    658927,      11572]
CellTagsIndexPosition[    658884,      11569]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell[TextData[{
 "Basins of attraction in (\[Phi], ",
 Cell[BoxData[
  FormBox["v", TraditionalForm]]],
 ") space"
}], "Title",
 CellChangeTimes->{{3.701617365402061*^9, 3.7016173954719267`*^9}, {
  3.701617510283918*^9, 3.7016175130917788`*^9}, {3.701623589396885*^9, 
  3.7016236167302847`*^9}, {3.701623685255353*^9, 3.7016236925724*^9}, {
  3.701625112759225*^9, 3.701625120286673*^9}}],

Cell[CellGroupData[{

Cell["Main function(s)", "Chapter",
 CellChangeTimes->{{3.701623605034238*^9, 3.701623609305955*^9}, {
  3.701623714566551*^9, 3.701623716605515*^9}}],

Cell["\<\
Define function that generates phase plot of (\[Phi], v) with attractors and \
their basins of attraction.

Note: Decrease MaxRecursion in ContourPlot settings to get a lower-res plot \
quickly.
\
\>", "Text",
 CellChangeTimes->{{3.701617271907969*^9, 3.701617360665495*^9}, {
  3.701617400314217*^9, 3.70161741013551*^9}, {3.701618296007701*^9, 
  3.701618374571699*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"ClearAll", "[", 
   RowBox[{
   "vS", ",", "tMax", ",", "vMin", ",", "maxRec", ",", "Q", ",", "\[Alpha]", 
    ",", "\[Gamma]", ",", "endP", ",", "\[Phi]0", ",", "v0", ",", "\[Phi]", 
    ",", "v", ",", "vC", ",", "t", ",", "basinFunc", ",", "\[Phi]E", ",", 
    "vE", ",", "n0", ",", "p1", ",", "x", ",", "y", ",", "p2", ",", "n", ",", 
    "title"}], "]"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"plotBasins0", "[", 
   RowBox[{
    RowBox[{"vS_", "?", "NumericQ"}], ",", 
    RowBox[{"tMax_", "?", "NumericQ"}], ",", 
    RowBox[{"vMin_", "?", "NumericQ"}]}], "]"}], ":=", "\[IndentingNewLine]", 
  
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"Q", "=", "1.1"}], ",", 
      RowBox[{"\[Alpha]", "=", "4.6"}], ",", 
      RowBox[{"\[Gamma]", "=", "0.05"}], ",", "endP", ",", "basinFunc", ",", 
      "p1", ",", "p2", ",", "hLines", ",", "vLines", ",", "p3", ",", 
      "title"}], "}"}], ",", "\[IndentingNewLine]", "\[IndentingNewLine]", 
    RowBox[{"(*", " ", 
     RowBox[{"Map", " ", "initial", " ", "phase", " ", "point", " ", 
      RowBox[{"(", 
       RowBox[{"\[Phi]0", ",", "v0", ",", "vC0"}], ")"}], " ", "to", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"\[Phi]", "[", "tMax", "]"}], ",", 
        RowBox[{"v", "[", "tMax", "]"}]}], ")"}]}], " ", "*)"}], 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"endP", "[", 
       RowBox[{
        RowBox[{"\[Phi]0_", "?", "NumericQ"}], ",", 
        RowBox[{"v0_", "?", "NumericQ"}]}], "]"}], ":=", 
      RowBox[{"Module", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"\[Phi]", ",", "v", ",", "vC"}], "}"}], ",", 
        RowBox[{
         RowBox[{"Reap", "[", 
          RowBox[{"NDSolve", "[", 
           RowBox[{
            RowBox[{"{", "\[IndentingNewLine]", 
             RowBox[{
              RowBox[{
               RowBox[{"\[Phi]", "[", "0", "]"}], "\[Equal]", "\[Phi]0"}], 
              ",", 
              RowBox[{
               RowBox[{"v", "[", "0", "]"}], "\[Equal]", "v0"}], ",", 
              RowBox[{
               RowBox[{"vC", "[", "0", "]"}], "\[Equal]", "0"}], ",", 
              "\[IndentingNewLine]", 
              RowBox[{
               RowBox[{
                RowBox[{"\[Phi]", "'"}], "[", "t", "]"}], "\[Equal]", 
               RowBox[{"v", "[", "t", "]"}]}], ",", "\[IndentingNewLine]", 
              RowBox[{
               RowBox[{
                RowBox[{"v", "'"}], "[", "t", "]"}], "\[Equal]", 
               RowBox[{
                FractionBox["1", 
                 SuperscriptBox["Q", "2"]], 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{"1", "+", "\[Gamma]"}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{"vS", "-", 
                    RowBox[{"v", "[", "t", "]"}], "-", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    FractionBox["1", "2"], 
                    RowBox[{"\[Phi]", "[", "t", "]"}]}], "]"}]}], ")"}]}], 
                  "-", 
                  RowBox[{"vC", "[", "t", "]"}]}], ")"}]}]}], ",", 
              "\[IndentingNewLine]", 
              RowBox[{
               RowBox[{
                RowBox[{"vC", "'"}], "[", "t", "]"}], "\[Equal]", 
               RowBox[{
                FractionBox["\[Alpha]", 
                 SuperscriptBox["Q", "2"]], 
                RowBox[{"(", 
                 RowBox[{"vS", "-", 
                  RowBox[{"v", "[", "t", "]"}], "-", 
                  RowBox[{"vC", "[", "t", "]"}], "-", 
                  RowBox[{"Sin", "[", 
                   RowBox[{
                    FractionBox["1", "2"], 
                    RowBox[{"\[Phi]", "[", "t", "]"}]}], "]"}]}], ")"}]}]}]}],
              "}"}], ",", "\[IndentingNewLine]", 
            RowBox[{"{", "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"t", ",", "0", ",", "tMax"}], "}"}], ",", 
            "\[IndentingNewLine]", 
            RowBox[{"Method", "\[Rule]", 
             RowBox[{"{", 
              RowBox[{"\"\<EventLocator\>\"", ",", 
               RowBox[{"\"\<Event\>\"", "\[Rule]", 
                RowBox[{"(", 
                 RowBox[{"t", "\[Equal]", "tMax"}], ")"}]}], ",", 
               "\[IndentingNewLine]", 
               RowBox[{"\"\<EventAction\>\"", "\[RuleDelayed]", 
                RowBox[{"Sow", "[", 
                 RowBox[{"{", 
                  RowBox[{
                   RowBox[{"\[Phi]", "[", "t", "]"}], ",", 
                   RowBox[{"v", "[", "t", "]"}]}], "}"}], "]"}]}]}], 
              "}"}]}]}], "]"}], "]"}], "\[LeftDoubleBracket]", 
         RowBox[{
          RowBox[{"-", "1"}], ",", "1", ",", "1"}], 
         "\[RightDoubleBracket]"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
     "\[IndentingNewLine]", 
     RowBox[{"(*", " ", 
      RowBox[{
       RowBox[{
       "Check", " ", "if", " ", "point", " ", "flows", " ", "to", " ", "0", 
        " ", "or", " ", "1", " ", "state"}], ";", " ", 
       RowBox[{"return", " ", "appropriate", " ", "\"\<color\>\""}]}], " ", 
      "*)"}], "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"basinFunc", "[", 
       RowBox[{
        RowBox[{"\[Phi]0_", "?", "NumericQ"}], ",", 
        RowBox[{"v0_", "?", "NumericQ"}]}], "]"}], ":=", 
      RowBox[{"Module", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"\[Phi]E", ",", "vE", ",", "n0"}], "}"}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{
          RowBox[{"{", 
           RowBox[{"\[Phi]E", ",", "vE"}], "}"}], "=", 
          RowBox[{"endP", "[", 
           RowBox[{"\[Phi]0", ",", "v0"}], "]"}]}], ";", 
         "\[IndentingNewLine]", 
         RowBox[{"n0", "=", 
          RowBox[{"1", "-", 
           RowBox[{"2", 
            RowBox[{"Mod", "[", 
             RowBox[{
              RowBox[{"Round", "[", 
               FractionBox["\[Phi]E", 
                RowBox[{"4", "\[Pi]"}]], "]"}], ",", "2"}], "]"}]}]}]}], ";", 
         "\[IndentingNewLine]", 
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"Abs", "[", "vE", "]"}], "<", "vMin"}], ",", "n0", ",", 
           "0"}], "]"}]}]}], "]"}]}], ";", "\[IndentingNewLine]", 
     "\[IndentingNewLine]", 
     RowBox[{"(*", " ", 
      RowBox[{
      "Plot", " ", "stable", " ", "manifolds", " ", "of", " ", "0", " ", 
       "states"}], " ", "*)"}], "\[IndentingNewLine]", 
     RowBox[{"p1", "=", 
      RowBox[{"RegionPlot", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{"basinFunc", "[", 
            RowBox[{"x", ",", "y"}], "]"}], ">", "0.5"}], ",", 
          RowBox[{
           RowBox[{"basinFunc", "[", 
            RowBox[{"x", ",", "y"}], "]"}], "<", 
           RowBox[{"-", "0.5"}]}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"x", ",", 
          RowBox[{
           RowBox[{"-", "4"}], "\[Pi]"}], ",", 
          RowBox[{"4", "\[Pi]"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"y", ",", 
          RowBox[{"-", "2"}], ",", "2"}], "}"}], ",", 
        RowBox[{"PlotPoints", "\[Rule]", "50"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", "\[IndentingNewLine]", 
     RowBox[{"(*", " ", 
      RowBox[{
      "Comment", " ", "previous", " ", "line", " ", "and", " ", "uncomment", 
       " ", "this", " ", "one", " ", "to", " ", "modify", " ", "plot", " ", 
       "appearance"}], " ", "*)"}], "\[IndentingNewLine]", 
     RowBox[{"(*", " ", 
      RowBox[{
       RowBox[{"p1", "=", 
        RowBox[{"RegionPlot", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{"-", 
               SuperscriptBox["x", "2"]}], "+", 
              RowBox[{"10", 
               SuperscriptBox["y", "2"]}]}], ">", "0.5"}], ",", 
            RowBox[{
             RowBox[{
              RowBox[{"-", 
               SuperscriptBox["x", "2"]}], "+", 
              RowBox[{"10", 
               SuperscriptBox["y", "2"]}]}], "<", 
             RowBox[{"-", "0.5"}]}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"x", ",", 
            RowBox[{
             RowBox[{"-", "4"}], "\[Pi]"}], ",", 
            RowBox[{"4", "\[Pi]"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"y", ",", 
            RowBox[{"-", "2"}], ",", "2"}], "}"}]}], "]"}]}], ";"}], " ", 
      "*)"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
     RowBox[{"(*", " ", 
      RowBox[{"Plot", " ", "0", " ", "state", " ", "attractors"}], " ", 
      "*)"}], "\[IndentingNewLine]", 
     RowBox[{"p2", "=", 
      RowBox[{"ListPlot", "[", 
       RowBox[{
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{
             RowBox[{"2", 
              RowBox[{"ArcSin", "[", "vS", "]"}]}], "+", 
             RowBox[{"4", "n", " ", "\[Pi]"}]}], ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"n", ",", 
            RowBox[{"-", "1"}], ",", "1"}], "}"}]}], "]"}], ",", 
        RowBox[{"PlotStyle", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{"Black", ",", 
           RowBox[{"PointSize", "[", "0.018", "]"}]}], "}"}]}]}], "]"}]}], 
     ";", "\[IndentingNewLine]", "\[IndentingNewLine]", 
     RowBox[{"(*", " ", 
      RowBox[{"Plot", " ", "gridlines"}], " ", "*)"}], "\[IndentingNewLine]", 
     
     RowBox[{"hLines", "=", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"Line", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "4"}], "\[Pi]"}], ",", "n"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"4", "\[Pi]"}], ",", "n"}], "}"}]}], "}"}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"n", ",", 
          RowBox[{"-", "1"}], ",", "1"}], "}"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"vLines", "=", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"Line", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"2", "n", " ", "\[Pi]"}], ",", 
             RowBox[{"-", "2"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"2", "n", " ", "\[Pi]"}], ",", " ", "2"}], "}"}]}], 
          "}"}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"n", ",", 
          RowBox[{"-", "1"}], ",", "1"}], "}"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"p3", "=", 
      RowBox[{"Graphics", "[", 
       RowBox[{"{", 
        RowBox[{"Black", ",", 
         RowBox[{"Thickness", "[", "0.003", "]"}], ",", 
         RowBox[{"Join", "[", 
          RowBox[{"hLines", ",", "vLines"}], "]"}]}], "}"}], "]"}]}], ";", 
     "\[IndentingNewLine]", "\[IndentingNewLine]", 
     RowBox[{"title", "=", 
      RowBox[{
       RowBox[{
       "StringTemplate", "[", 
        "\"\<\!\(\*SubscriptBox[\(v\), \(s\)]\) = `a`,  \
\!\(\*SubscriptBox[\(v\), \(c\)]\) = 0\>\"", "]"}], "[", 
       RowBox[{"<|", 
        RowBox[{"\"\<a\>\"", "\[Rule]", "vS"}], "|>"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"Show", "[", 
      RowBox[{"p1", ",", "p2", ",", "p3", ",", 
       RowBox[{"Frame", "\[Rule]", "True"}], ",", 
       RowBox[{"FrameStyle", "\[Rule]", 
        RowBox[{"Thickness", "[", "0.004", "]"}]}], ",", 
       RowBox[{"PlotRangePadding", "\[Rule]", "0"}], ",", 
       RowBox[{"FrameTicks", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"Automatic", ",", "Automatic"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"Range", "[", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "4"}], "\[Pi]"}], ",", 
              RowBox[{"4", "\[Pi]"}], ",", 
              RowBox[{"2", "\[Pi]"}]}], "]"}], ",", "None"}], "}"}]}], 
         "}"}]}], ",", 
       RowBox[{"FrameTicksStyle", "\[Rule]", "Black"}], ",", 
       RowBox[{"LabelStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Black", ",", 
          RowBox[{"FontSize", "\[Rule]", "14"}]}], "}"}]}], ",", 
       RowBox[{"FrameLabel", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"\"\<v\>\"", ",", "\"\<\>\""}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"\"\<\[Phi]\>\"", ",", "title"}], "}"}]}], "}"}]}], ",", 
       RowBox[{"ImageSize", "\[Rule]", "Medium"}]}], "]"}]}]}], 
   "\[IndentingNewLine]", "]"}]}]}], "Input",
 CellChangeTimes->{{3.701616831290078*^9, 3.7016169164710703`*^9}, {
   3.701616948901993*^9, 3.7016169661637983`*^9}, {3.701617000883959*^9, 
   3.7016172598806353`*^9}, 3.701617530589541*^9, {3.7016177238311853`*^9, 
   3.701617727326652*^9}, {3.701617927447769*^9, 3.701617935246566*^9}, 
   3.701617971062707*^9, 3.701618026140562*^9, {3.701619588835003*^9, 
   3.701619719339616*^9}, {3.701619767641157*^9, 3.701619771755686*^9}, {
   3.70204139579523*^9, 3.702041402395287*^9}, {3.70204171009578*^9, 
   3.702041712602021*^9}, {3.7020417922913427`*^9, 3.702041792466456*^9}, {
   3.71050836514705*^9, 3.7105083770287247`*^9}, {3.710508604125107*^9, 
   3.7105087477368183`*^9}, {3.710508818066979*^9, 3.710508819041898*^9}, {
   3.710508859057659*^9, 3.710508884935256*^9}, 3.710508926206873*^9, {
   3.710509069904646*^9, 3.7105090784313383`*^9}, 3.710509183044546*^9, {
   3.710509254833254*^9, 3.7105093398925133`*^9}, {3.710509397810589*^9, 
   3.710509468463674*^9}, {3.7105095201433363`*^9, 3.710509525056185*^9}, {
   3.710521659946271*^9, 3.7105216814305477`*^9}, {3.71052173069954*^9, 
   3.710521740394382*^9}, {3.7105217903838778`*^9, 3.710521802984839*^9}, {
   3.710521978409327*^9, 3.710522082276393*^9}, {3.710522347585987*^9, 
   3.710522355344901*^9}, {3.710523634924687*^9, 3.710523695825746*^9}, {
   3.710524190104007*^9, 3.710524221664567*^9}, {3.710524318116907*^9, 
   3.710524328086734*^9}, {3.7105243766822233`*^9, 3.710524441846766*^9}, {
   3.710524475962582*^9, 3.710524503145587*^9}, 3.71052482733425*^9, 
   3.710524876555978*^9, {3.710524907624243*^9, 3.710524911694405*^9}, 
   3.71052494719786*^9, 3.710525013125198*^9, 3.710525044917922*^9, {
   3.71052521906102*^9, 3.7105252214512053`*^9}, {3.710525439027808*^9, 
   3.710525451969057*^9}, {3.710525656685484*^9, 3.710525684593836*^9}, 
   3.7105382651526613`*^9, {3.710542020320714*^9, 3.710542020941835*^9}, 
   3.7105421601714087`*^9, {3.7105422099372787`*^9, 3.710542216784234*^9}, {
   3.7105422504507713`*^9, 3.710542417388795*^9}, {3.710542450458741*^9, 
   3.710542565539653*^9}, {3.7105426536669083`*^9, 3.7105426775596933`*^9}, {
   3.7105429017672873`*^9, 3.71054290526338*^9}, {3.710542949529475*^9, 
   3.710543039878704*^9}, {3.710543092110879*^9, 3.710543191251333*^9}, {
   3.710543369653121*^9, 3.710543386743935*^9}, {3.710543769136091*^9, 
   3.71054377019109*^9}, {3.710559286807695*^9, 3.710559300293632*^9}, {
   3.710559874806834*^9, 3.710559875641068*^9}, {3.710560004401122*^9, 
   3.710560017539118*^9}, {3.71056018949837*^9, 3.710560484500944*^9}, {
   3.7105981177383623`*^9, 3.71059812095304*^9}, {3.7105986367961063`*^9, 
   3.7105986741309423`*^9}, 3.710598767191904*^9, {3.710598860051385*^9, 
   3.710598868025057*^9}, {3.710599438746784*^9, 3.7105994426253357`*^9}, {
   3.710599678177288*^9, 3.710599683199548*^9}, {3.710783172649878*^9, 
   3.710783177234622*^9}, 3.710784288005619*^9, {3.710786178104768*^9, 
   3.710786236228524*^9}, {3.71078643042894*^9, 3.710786549511305*^9}, {
   3.710786591319549*^9, 3.710786745714489*^9}, {3.717281651474772*^9, 
   3.717281661118525*^9}, {3.7172933413032312`*^9, 3.717293345802784*^9}, 
   3.7172956910851097`*^9, {3.7172967149533167`*^9, 3.71729671611812*^9}, 
   3.7172993381513653`*^9, 3.717300930188373*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "Plots for various values of source voltage ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["v", "s"], TraditionalForm]]],
 " (initial capacitor voltage ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["v", "c"], "=", "0"}], TraditionalForm]]],
 ")"
}], "Chapter",
 CellChangeTimes->{
  3.701617435715375*^9, {3.701617471381598*^9, 3.70161754037291*^9}, {
   3.701619790911727*^9, 3.701619832218857*^9}, {3.710608424066423*^9, 
   3.7106084272977457`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"plotBasins0", "[", 
  RowBox[{"0", ",", "400", ",", "0.05"}], "]"}]], "Input",
 CellChangeTimes->{{3.710543193920143*^9, 3.710543220939678*^9}, {
  3.710543786910775*^9, 3.710543787110448*^9}, {3.710559793461051*^9, 
  3.710559794569069*^9}, {3.710559851888933*^9, 3.710559856261856*^9}, {
  3.7105599589510107`*^9, 3.710559962716969*^9}, {3.710560112430778*^9, 
  3.7105601129269133`*^9}, {3.710598898919285*^9, 3.710598899109128*^9}, {
  3.710599521429411*^9, 3.71059953658687*^9}}],

Cell[BoxData[
 GraphicsBox[{GraphicsComplexBox[CompressedData["
1:eJztnfmbztX/+Achy9gzjG2MMcaShKk3pXOiUFKTpUWlshSmpJLtjSSGisiW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    "], {{
      {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
       Opacity[0.3], EdgeForm[None], 
       GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxVm3fYVsXRxs+e3RcsKEUQASMgKBasqFhQKSpiQTQW7Aio2LBgwYANQUBB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          "]], PolygonBox[CompressedData["
1:eJwtmHn8kFMWxt/73vsbLWjRlCKKChUVbUqrpF3SJklqLI0wxmQGnxRZJlmL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          "]]}]}, 
      {RGBColor[0.880722, 0.611041, 0.142051], AbsoluteThickness[1.6], 
       Opacity[0.3], EdgeForm[None], 
       GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNm3ncltP2xl/03HvvxzEdx5wh8+8YjyFjzjEcoWQ6IsJJyNRAMkRI5pko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          "]], 
         PolygonBox[CompressedData["
1:eJwtmHn8T1Uexr+W373nfO2JUdnHvmTLkmzZojJZIlsLyVrWikIpW0UT2VIm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          "]]}]}, {}, {}, {}, {}, {}}, {
      {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
       LineBox[CompressedData["
1:eJwt01dPVEEYBuABXEpiITZUWAyKihUrir2XRE3E3i5A7AoBg3/CfyJFQBMT
9cYOq6hgN0FNxAZ2wFt9TuDiyfvNOzPZ7Nk9eWWVJRVJIYR2konmFnpSQvjG
bWpt9Mo+fjOSP4QhIfyTZcRjISSsY0xmEq30uHuRHPulzt3iJnW6XF2WeYZz
aYw1T5cnZbv84cwTmUoB02jju77BmRM8sj4uH8v7ssneCvNKlrKcZTTql8hi
FrGYIi7pF8oJ7s6X4+UCmS07fMU4BXRyzdkd9koYygd6dV1yJ7sYxkf69J/k
bvYwnM/067/IvexjBF/ppsZn7pf5MjN6dpw353tO1907aD3F+oA8zCFu6Nt0
b83v6OSc9XvZJJupopo8tuq3s42r7iZ0r8yveUml9ZvouchGzlJBDqv0cbla
Nru7VuZar5HrWcdl/Ua5iQ1sYTNX9C3OtnKKib5Tve4nHfZnMot0nvJL/0zO
Zg4ZPOcFp90/wzgKrecxlwZ37ugemo/KB/KYrI/+y/aOyHJG0c9o/pLkXDJ3
zfcYEz1z66nR8+aClyLh98+g1Jwu00glNvAahJTB9+c/CaNkxA==
        "]], 
       LineBox[CompressedData["
1:eJwl1MVTlXEUxvEXxHHUle1OhLFRyu4WdKFjrJxBxRa7FbG7OxbG6J+gInZ3
g4pdS8fCxsLPb1x873Oec84v3veee+tmT+o/MSaKolQfObFR1EBcjHxx3fJR
FF8uivrERVEl1BH3pk/xBCV6DiNe32S1G7iOo3KJconifvoqI0Hcl77GK3zS
U4AEfdPVbuMWTsqNUm8oHkkb0FzMxTf+K6qjPj+CzqFfaKl1n2k1DEd2OAM/
5EtoVQzDUHzEd/kPtAqGIAtv8U3+oD1n4x0/i76nd+gZtTHisRiNRnLz0c0z
5NFf6qdRj1/AN0ZTdOST6G+1c+Ed84v5ZkhFJz6F/lG7gEb8Mj4N45yTTnPC
s4R74wF/RV9Tfa3EBViNXvwqWoyHaIfOcm1phGvWNOPXiNuHe6EL34HGhO9O
PZlfH+6ErgG+C43FTfVUflN4ZvRED5TDcWxFqfv9ws8wJ/wLDDZbv11hC/ag
Iv/SXoPUBmC/3oH0AH0h/1pc3jl7aRzdF+YCFbAbe8IshVh/v+DDWda9FJeJ
d9C/dCc9EfYK75bfTqfRDFqbRvbeJW5B71o/Qy6Tn05705m0UH52mLMwC8jF
XBTJ59H5mIeFWIB78ovpEizCMizFffln9nyObUh35m25uDAX6pMxBbUwFb3k
m+u5o+eJeHP47fFb6DF0D/PB31J/LN6ATH5j+P2F7x0p/A31R+K1yODX0Zr2
r4E24kn0qp4ytObH8xMxAS35lUiy7rL6XxwJ7wtN5C7x98XLwyzwK2h+uHeY
ff6i+j3xkjAn/FJ6GMloyJ9XLxIvDM/DL6KHwt6oz59VvysuxLwwZ+4Uh1Py
P/FGLsssJSEt+v//9Q+pVp8P
        "]], LineBox[CompressedData["
1:eJwl08dOlFEYBuAzIIhSxIY62LgJBcsVWBJZ2BXDBegVuLVgRcQCGEXp2BsW
mBmKZevGGk1UEDBR3FkxPicunrzf9875/xnmH8qq91TuToQQntHBOXIUb7JC
aJwSQhNnaOAsr/Wn5GnqqOckr/S18gRHOc4xXuoPyyPUsD47hEPyhf6gXGc/
INfKJhrJzgkhiwX6/ewjYc/12nPXLTM3mNfwnne6cl2ludnZJBc4T64+T//W
meXmZvMGPsZrdRW6TeZOZxex0dwhL8kirxWy0N5OGwX26V7Ll6X2VlqYap+m
T3GRvHgudgzbP3mvB849pIf73GNEf0fe5RZbnb0th/WrXNtmL5FlupvcYK69
KP4Nzqw0t5rHGGVct1pXZf7BBDv4The/KSbDTgbd7xFD8Rl67iX0+g1UyRr6
zHvdMyXTZOhngEGGSDr3xb2+MpM//OQX35jkL90kfbbLslTuko+971Oe8Nn7
jOvmx2fPPDrtaWbQHp8N2+h1frvsk6OuS8sMKQboZ0w/Er97Wljhfh90+fF+
5i5nullMsb0gfv74+exXWMKs+BvQz5ZzuKrbbF8qr3GdLfE7Tfz///kHaMty
gA==
        "]]}, 
      {RGBColor[0.880722, 0.611041, 0.142051], AbsoluteThickness[1.6], 
       LineBox[CompressedData["
1:eJwl0DlOQlEUgOGDCfggom7BFjRx6LVRGwfgicQxUQqHRiOOOOxFGmRDJias
QInoEvwSiy//Pefm3eJNNS/Ti0xEpKxnI9ZocEQyGrGXRLTyETt6pbt6rUN3
t3rHDQ/c82P/qE+0eeGZX/ucjhciut4o6pt+M82Y+cT9KStMmGfsJ7WnZ3bb
uqrnNJwP3Q28G+YMr3b7dp92JefE+di+yTJ58wEdd4vmJeaomWd1gXm+fD+i
ZUq85yLq/seHbmlfU61RpcImG9n/f/gHToIjxA==
        "]], LineBox[CompressedData["

1:eJwl1NVPV2EYB/DjFBGsWdiB3aKCvQne2InOCwMJGwG9cDOwA1uxuwPsjqmb
m3Pq5ubmnX+DhS3m550XH77v87zPOed3zu93SMzKH5dXIYqiRH9+V46iCTFR
lBMXRdPJZnyVKIqRlUgjlRTS9ZPlOHmSE3TiDaeJj4+iU7KqrGjubWwU5csC
8pho7zyl1DNTlyH688iljrqbvdpysHouc6il7hqu43xTrUusq+jH8klvvSxi
DetYy0f9VXI1K5jimJWyTH+5nKxeJifJi1zgPe9o6BqXZIJsQH3izH517Ga5
hU1MM3OVK5TxgeZmr8kmshlNqWb2p2MPykPsJ8fMAVmun23mprqjHB2+A+t9
8obsoNeeUeq97KGdOtleWzlSvZtdtFH31G8tR6h3UkwrdQ/9lnK4egfb+eHa
hb77Ioo5xBmucp8nvCTb3GvZzDGN6es8/ejDK+ctZxBrWMsqXlIQ7l2msSI8
f/XK8Nx5QZ46XqayNMyoC+USnjMvPHc5kEUsVy+W9X2GBJ5ar9N7Jr+xkFx1
bPh92e9l3ZtS6wV6JXK+fMys8BuVA8gPn0ldEK7JI2aoK8j+zKVQnStn85Ac
9R/PpZ/1/XDP6gfhvJxxnXOc5a+ZmrKL/Vv2Osvb8iMp4f1RH7Z/hDF0VffS
7yaPqo8xlqRwL/rd5XH1ifAe0iN8D/o95Z3wXob3WKbLZL0U7qrvhXvilP7M
8L7KXz5bdVmD63qZZr/pdbduYZ3IVnuZ6mFyG1nWWfrfzcWrq3JZL0Pvs16S
dSPrxmywN1U9VG4kw3qa/hdzc/yeMmL+///5B4B/izQ=
        "]], 
       LineBox[CompressedData["
1:eJwl1FdsjlEcx/FHtfZq1ahVat+4JPZobSIRmwuRiCBpQ4sGiQuj9iYR486V
vUfRGrW1Nq1Rat9ZpVb4nLj49vv//c558r4573naakrGyPRKURQl+/O8ShTl
xEVRx+pR1LVaFP2pGkWp5n7IleO5HiLz1BpRNIO/IB+L5TxOsB7D0+R0/oqL
WCJf4PrWY3m6nMnluIylcgEnWo/jGXIWf0NPVMFM3RWeg7327cMezJN7oRr2
y9k8ikfjpjnHcze4sVyTM+RFXIEiLJcLOcl6bZ4lL+YfuIsV8h1uYr0uZ8rL
+JA8BgdxAN31qfo6mG2+z831zZAYzoEvIR8XcB719ec4L5wxzuIMEvSn+DSO
4yROIF5/jFfwEV7OR8Pvwlk+8zH35rG6HPNhfsA9dGn8C4/CmcoPw7lxsj1N
zc94HT/ltSGHGQPwG6VItf85p3Er+1qYy3gTv+SNvBnJ+O4uxbhT/d2jWlzZ
M7GIwU7rfzEC3Tz3gTvzDu7EXbDLvNDeDtxObo/X5vm6FB4efmfzR/0nTA6/
ufxGv4Bbh/up28afuRxf0SZ8N67AN/zED7TVt+ZBnh2MgXgZ3gMMCucgvwrf
ARMwJOzTDw2fKb/FRAyTh6PM2jt5C0/i99hqzrbWklPk9fwCc3XNeCD6hzO2
VorxeIEN+nn65txSXsnF4V3QNQjPoE94h6xdxjj0lfuhxNoTrMIV/Wq+yg35
Oq/ha+FdwQ00kgu5CLdwB7fRWH+P7+MuHoa7hST9Yy7GIzxBCZroX7sDxShC
AXJxELuxHRvi/v/f+Qd7mqMO
        "]], LineBox[CompressedData["
1:eJwl0FtKQlEYBeD/PHQ0o4vd3oWuUPRaVBPIsFLQCjJwAAa9ORIjHxpJ06gB
BFZaOQDL+sKHj7XXch+QXWjclJtJRJR5zEQkacRdNmIwGfHFNW39U1Zy7nGs
n8m67YM+p3rRfiKv9B7vlPQje4GW84tcta+w7hy2hB/9lxFr9m/ZkUN5L1/p
UmLEG1XfnVNjw71NW+qcYYIH/VL25YXsyUP3Dthhj132//+/37blFk/eYJpn
hsxw621m5Rx55llgkSWWmUrHb/gHr/woSA==
        "]]}}}], {{}, {{}, 
     {GrayLevel[0], PointSize[0.018], AbsoluteThickness[1.6], 
      PointBox[{{-12.566370614359172`, 0.}, {0., 0.}, {12.566370614359172`, 
       0.}}]}, {}}, {}, {}, {{}, {}}}, 
   {GrayLevel[0], Thickness[0.003], 
    LineBox[NCache[{{(-4) Pi, -1}, {4 Pi, -1}}, {{-12.566370614359172`, -1}, {
       12.566370614359172`, -1}}]], 
    LineBox[NCache[{{(-4) Pi, 0}, {4 Pi, 0}}, {{-12.566370614359172`, 0}, {
       12.566370614359172`, 0}}]], 
    LineBox[NCache[{{(-4) Pi, 1}, {4 Pi, 1}}, {{-12.566370614359172`, 1}, {
       12.566370614359172`, 1}}]], 
    LineBox[NCache[{{(-2) Pi, -2}, {(-2) Pi, 
        2}}, {{-6.283185307179586, -2}, {-6.283185307179586, 2}}]], 
    LineBox[{{0, -2}, {0, 2}}], 
    LineBox[NCache[{{2 Pi, -2}, {2 Pi, 2}}, {{6.283185307179586, -2}, {
       6.283185307179586, 2}}]]}},
  AspectRatio->1,
  Axes->{False, False},
  AxesLabel->{None, None},
  AxesOrigin->{Automatic, Automatic},
  DisplayFunction->Identity,
  Frame->True,
  FrameLabel->{{
     FormBox["\"v\"", TraditionalForm], 
     FormBox["\"\"", TraditionalForm]}, {
     FormBox["\"\[Phi]\"", TraditionalForm], 
     FormBox[
     "\"\\!\\(\\*SubscriptBox[\\(v\\), \\(s\\)]\\) = 0,  \
\\!\\(\\*SubscriptBox[\\(v\\), \\(c\\)]\\) = 0\"", TraditionalForm]}},
  FrameStyle->Thickness[0.004],
  FrameTicks->{{Automatic, Automatic}, {{{
       NCache[(-4) Pi, -12.566370614359172`], 
       FormBox[
        RowBox[{
          RowBox[{"-", "4"}], " ", "\[Pi]"}], TraditionalForm]}, {
       NCache[(-2) Pi, -6.283185307179586], 
       FormBox[
        RowBox[{
          RowBox[{"-", "2"}], " ", "\[Pi]"}], TraditionalForm]}, {0, 
       FormBox["0", TraditionalForm]}, {
       NCache[2 Pi, 6.283185307179586], 
       FormBox[
        RowBox[{"2", " ", "\[Pi]"}], TraditionalForm]}, {
       NCache[4 Pi, 12.566370614359172`], 
       FormBox[
        RowBox[{"4", " ", "\[Pi]"}], TraditionalForm]}}, None}},
  FrameTicksStyle->GrayLevel[0],
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImageSize->Medium,
  LabelStyle->{
    GrayLevel[0], FontSize -> 14},
  Method->{
   "ScalingFunctions" -> None, "TransparentPolygonMesh" -> True, 
    "AxesInFront" -> True},
  PlotRange->
   NCache[{{(-4) Pi, 4 Pi}, {-2, 2}}, {{-12.566370614359172`, 
     12.566370614359172`}, {-2, 2}}],
  PlotRangeClipping->True,
  PlotRangePadding->0,
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.710599226401189*^9, 3.710599523433432*^9, 3.710599662930656*^9, 
   3.710599809009865*^9, 3.7106817871384897`*^9, 3.7107863581549397`*^9, {
   3.710786492489746*^9, 3.710786524668211*^9}, {3.71078659921262*^9, 
   3.7107866533850193`*^9}, 3.710786766172995*^9, 3.7107869121122417`*^9, 
   3.7172820163103037`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"plotBasins0", "[", 
  RowBox[{"0.6", ",", "400", ",", "0.05"}], "]"}]], "Input",
 CellChangeTimes->{{3.710599826286817*^9, 3.7105998263829107`*^9}, {
   3.7106820137416573`*^9, 3.7106820217062902`*^9}, 3.717282604687715*^9, 
   3.7172832996110477`*^9}],

Cell[BoxData[
 GraphicsBox[{GraphicsComplexBox[CompressedData["
1:eJxlm3lcTWn8xytbSaVFy23fb1mmyWQL5zEley5Dg0nIIJWdiOxJYawpsiQy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    "], {{
      {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
       Opacity[0.3], EdgeForm[None], 
       GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNmXe8V8URxXcuXaQISm+PIvBooSoCIoIigtJsKEZAQWxgjBo1FuyJXYNd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          "]], PolygonBox[CompressedData["
1:eJwtlnnQl2MUhs95fZavZAujhL7G1liHMVljaCGExm5sDYaYFgrtmkbRLkqI
qLQqKYq028oWk52iaCGt2ktc99zvH9f87vO+z/ss5znLr6plmxati4joBxVw
bkb8DF+jK+EG9HnwCnoG7Mvg/WEtegDM5t2NcDR6BDyPHgYdws8OZ2xNGIZ+
Aaby7kn4HD0Z3kKvgO/Qk2AReiHUDq/5LPo5aIeuCacy1ykwFD0NGvNuMXyC
7gnXoxvAS+h3YDf6UuiB/lV7Rlfn+43oTXA39ip4Ed0WrtDZ4TN0X5iLfg1e
R78H7aRhLHoFPIJ+FHqhF0Ij9F74HV0ftqHbQFf0aLgfvRYeC/voafQB7Gcd
ej0swf4GBqFvhnno9umzvR/e65GM3xLe8yTsi3Un6Tt8gN/1MBLdCTagW+lO
0T+FffEFfBz2yb3oJnx/aOnjC+RL+DC8x5Xow3j/T/gO66GroGN4jQfTa2ju
X2Aj+iKoFV5zJ3pP2vfdYRe6bVrLp+ejz2G+1DrYD/P7LywP+3AregcsC/vw
EvSn8BG6WziWesPgcEz9gT6E+TYrFqE19pa077vA2+in5AP0m/Auuj98qViE
PopFmKLYC4/tB0PC3zRFfwWL0L2hIXpT+uyKWc31TDrWNef29J61V51hTDpm
FCvj4EfdRTrXFsPZ7P2swrGoHByvWNGZ0RPgIfRvsAS9VGdAX8v42joH9nJ+
n4C/0N/CfPTj6b3OhpvQFyqmdXbFA99OS+dyde0Vu0c5VyW/jbBnpH1RQ3mr
3IC64Tl01w0YU1HeuWLpHnS1cEwNUW3g2XTs4eG9Tk7HtvZ8JvZdunPsveG7
V44ptxQDS9Fr4Ht0+3CsN8NuHI750wvXBNWCPVqz8JyaSzF7RuGYUCxojYOx
Tys8VjGivQ9P50pFGfu1eLY1nAPy9cnYu8M+V+6ciL0rnEMDsQ/CnhquSX/L
N9g70D/APuiuZW7+qTWwr8S+JnxHb6A7qwZJQ8H77umxa+Qj7KMK+057mpmu
YapdWvMk3p0Ao8J7qo8ewft64T2vRtfh2bawD2ugD4RW4RpYDV0JLcM1SLl1
LPb2cI5NT9co1SblxHG8O6ZwrdcYxWYn6BOOUeXyfem7ynJt9RD1Du3hdvTV
6do/D64rY0yxpT3th56S7gXqMXfIV+lcnQ+3oS9P+2pOuFZPgInhmt08HdOK
ZZ3pVtW3dO7MCsfOBzA3HEODNU7Pwj2jW/oO5HvdkXqTckq5pB61DL0ufbeq
gVeVOaNcaY69gN8uWfYO+TBd41TbtIbu+j9YGb5zxYpyUrmomJmj3ICq8J2q
1oyF8eGaMy7dE9QL9Gw0+haYGe5JPdM+lm/VQ0ale5h615jw3Mez5s7wGrPS
PVa9VTl6ROEeqt6pHvMyenO61uibXuk70V2o5nZI+1i+VQ9M/Zko7AudUb15
ZHpt9eiO6TvU3SlmtPfL0rVQZ+iLvhMWhGvuxHQNU+3SHetdi3St1hjF+qvp
2q6Y/x8MYzpj
          "]]}]}, 
      {RGBColor[0.880722, 0.611041, 0.142051], AbsoluteThickness[1.6], 
       Opacity[0.3], EdgeForm[None], 
       GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNmHUcVlUShvHOsVuR1TXRNVBwV127m7UJBSlBEAUp6QYJERGRRmwswkYB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          "]], 
         PolygonBox[CompressedData["
1:eJwtlXnQl1McxX8995v2bSokhWpEjW2kiEQhmslEhCbipRjJW7bklbFkbcHY
qpGSRkIl3qa/7KNI2yRNpY1KRdGmIi2f8577x/mdc+59nuf3PPd+7/meVlZ+
/f1FqVQaDULg513QJ5VK65j4B34b3wNejr8RPR+9DN0cXgD2gn34lnA15ieD
Xug1jNVAvwduwW/A74Yn4q+El+KHojeiN6P/A7vQFYydD3cA3dCXg0XMHYcv
R2+AN+HrwB+CaYz1h99ibDY8HT8ArsT3Ry9E/6RvAU3w88BIxrbjf4OH4c+C
5+I3wR3x9eCzwQPoT+G/mDsHboP/Fd6Crw43w38EBqP/ZqwpegYYiP8Dvxg+
BA6gW8Of6Z2Zvweez9ib6DfC91Zj7BPwAb4M/oKxl9Hjws86Auqj54IK5rfi
r0U/GH63Hfgx6NFgZeH/PML4bPwweBX+X/gF/CVwF5DQc8DD6LXM79Q64rvB
C/Ft0d9krT0/Gd8cLEbvBVdoL0EjrtmD/1brkDxXA/4BXMN8M/hU1RK4CX8K
PIhrnkMfSN6bzvBqMIuxcng8Y/vgJ/Ed4U5aGzAV3xceq5rQ/oDh+PX47+G+
+BbJ/1EXXQlG5Bp7H56C7w0/U/je6uHa0TO+BlfhG8MnJX/rE+Fa1DfvgeeB
Itd8K+Zag4PojWA945+DyDVaO1wzqpVD+B/hW/ErCtfkVPw7+J7wCPwU+Hbd
o1rHL4Jvw+8vvKcTwmuute6e92q8nll4z/RtK/Je6hs74MeCS7UW4NVwTamW
uuL3g37hvbkInIh+HVyGLuV3+z/XTs+cBZN0Zgpngs7yRPjuwmf6Mb1P+N3O
A6+Fa1S1qWd2RjfQM/EN8Bega4XXpurMhTNHWVMLngDOCJ991dh3yTWm2lqi
NWBuVj679eFzdZbD99YGk0E7fM3kNa+JXpecHdqzmXmN6uYz3T6cUcom3dMQ
vzn52XrnPvgbQNP8zV21VuAoegE4XmsNGiaPHdWZ1hmFRxWujY+Ts041crHO
IjiM/xLcrKwEJ+Q1bhR5zZKvUW0rc5W1qvEe4UxWFuudfgYz8UPgcYXf5ZXw
XuudlO3T85wyvkX4jHXKNb0NPBTe+51cMyhco6rNdvpmZRc4U3vN2HL4Xvwv
6NXgavQocGHyN5SFa1q13BYeiF+W/Cw949lwDar2dM+f4JFwFu7inpfQL4b/
S5n1qM5y+Gyq5nVWVXOqNZ3ZkejHw9miHnIn+i5wOnooYzvgr1QnYDf+aeae
Cs8pY4ajrwv/t645CJ7Hp+QzqCxTZimrlGnqddPy3qrn3YFfmvyt+k/1FvUU
9ZKqHoOvF872irxXK5N7pfZMWVUn3LuUWcrmIpx1ymhl+eHk7FKmKyvXJPdq
ZeaAcM9Rr2mVa0+NXXujGlR2rkrOSmWoeufa5OxSD1WvnpGcverZ6kW/J/dK
9aSW4R5S1TuSs+U+0D45Y4agB4d7vcbUC+ck17Z6onplZfJZUc9UL9yea009
Ub25cbg3qkerl29J7nXq6UvyN+rblJHHACMGHpA=
          
          "]]}]}, {}, {}, {}, {}, {}}, {
      {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
       LineBox[CompressedData["
1:eJwt0LFKgmEUBuBfszRwzRYH/7yC0rIivQInSZr7h6CCuhcHB/N2FCMxRy3N
LQ0s7Q56AoeH9z2Hs3xfGD3WHmJBEFSJ89/TZMgxsHihT4sTRxfyipy+lN98
EJoPeNJ/uGVG3q4tS7Is19yx4p5fKvR4pknR7Zmsk9XncsGUL244tj+XHSIa
HNqV5CV7eoZP/ZoJ++YjCryZ3zmly5gRr969y5AUSXbYJsHW5q/+AOwiJDc=

        "]], LineBox[CompressedData["
1:eJwt01dsjWEAx+GvtVu1JUZomlB7XKJ2qaJDj0RsYoQL1N57zyIILuy9994j
kUjE5taMhDurlOJ5ExdPfu//O6fJ+b5zmjIsPzYuLoqiD6Q6JOgIzYiPopE6
nI1s4CpXqO21TVpDa1GTe3YanxjNR0axhc304RpbqeP9ydTlvt2RQn7wjXy+
04GvhA/4hbHsZAeN/G1DXjmP4TPbqOdaX73OdurbDUjlgd2ZX/zmJ+MpohOt
vGeX3mAPWfZufUhX2tiT9SYHybEP6CO60daerrc4Qq59WB/Tnfb2bL3NHXqE
e3TtmM6hhPM8jde5OpCelLTn62vecIo8105qaS1DKRbaZ8I9Oufoc3pRzk6g
LCvs88Scz+kLVnKBLq7l6Ut6U95OIpEC+3K47nxJK+hafUsT56Y0pxkVqcQ7
r7XQodpSK1OF93ZVrcY65/Ws4WJ4zq7FdAirwv3bq3U5Z0m3c3UwS8MztJfp
Ek6H79HO1kEsCs/dXqzPeMrx8ExcO6F3WRB+f3aWPqGxc0Qcf+1ZHKWdnakD
mEGmPVOncYg0O0P7MyX8HuypOon9tLbTtR97ybb36QSKmcif8B2E37aPkEx1
Ev//X/4D9VJr9g==
        "]]}, 
      {RGBColor[0.880722, 0.611041, 0.142051], AbsoluteThickness[1.6], 
       LineBox[CompressedData["
1:eJwl00dsznEYwPGft4hYFw4Ss8TeHMTBgdiEpLpbq+apFSNB7VHzIiRKX1VF
NdWkVTsigtpVDhIOqAvhoPYe8fnH4ZPv8zzv+x7elZiTl5TbJITQQEoshGTq
GN00hDH04UBCCON0bDRTyGrGc9VjSbqKlZy1F7Lf/Fav0dtcpEV6U1N0AsnM
YD3n3A9GzB+0v/bjsHmm3tMsvavZWqyH9JsW6CTumDP1q27VLUwkg3Q2cyF6
HXHzFx2kAxlCS/tj7z2fAvYQp4xqLlFLIzWeu9RrljGNvVxx26cdWM5r+3Rd
wRtzhZ7WUdqO87SnF6/cy7VaR2qb6LOkLT156X5Cq3SEtuIMrZnKFF54bIlW
6mWek2tv0Dx9pi30OCfNPbQ7T83HtEKHazNqaE4iT9xLtVyHaYxTJNCNR+4l
WqZD9Y9W6V/tqr+1WEt1oT7UBbqYRRy1D9Yd7GQ7P9y66EXdpt91ltbpZN3F
bn7af3Gf2fZ6naMlmqMPdK7OZx5H7AN0I5vYwGe3ztH3oR/5xC1S3W5rmsa1
r65hLfm8d1unHelEo/0d17lBpVut1vu9ZJNFJhmkk0Zq7P//7h+c/nll
        "]], 
       LineBox[CompressedData["
1:eJwl0UsrRHEcx+HfjCmxcSnETnkJSAhlrfASZOOeDa/AEkOxsZDcksYlkoak
rCwRYlYupbDxCnhOFk+f7/+cU2c6Uz8w0T+eiohBsumIGQpsFkUMZyJudUhv
NPSAXzvPBqvOKe7sB3L2vZ6xzZpzhkf7mT37Sc/ZYd25mII9omOMMksjOde3
9EUbtJQjSmiimTf3JvVVL5J30O3cwrtdrqeU0UoFJ1TSThuHye/RKj7sHp1j
ngWydFDNIjV00cmx53e1lk+7V5dYpo4pvlzv02ku7W9+fOdrrsizn3x3VtL/
/8UfMZM4Tg==
        "]]}}}], {{}, {{}, 
     {GrayLevel[0], PointSize[0.018], AbsoluteThickness[1.6], 
      PointBox[{{-11.279368396772604`, 0.}, {1.2870022175865687`, 0.}, {
       13.853372831945741`, 0.}}]}, {}}, {}, {}, {{}, {}}}, 
   {GrayLevel[0], Thickness[0.003], 
    LineBox[NCache[{{(-4) Pi, -1}, {4 Pi, -1}}, {{-12.566370614359172`, -1}, {
       12.566370614359172`, -1}}]], 
    LineBox[NCache[{{(-4) Pi, 0}, {4 Pi, 0}}, {{-12.566370614359172`, 0}, {
       12.566370614359172`, 0}}]], 
    LineBox[NCache[{{(-4) Pi, 1}, {4 Pi, 1}}, {{-12.566370614359172`, 1}, {
       12.566370614359172`, 1}}]], 
    LineBox[NCache[{{(-2) Pi, -2}, {(-2) Pi, 
        2}}, {{-6.283185307179586, -2}, {-6.283185307179586, 2}}]], 
    LineBox[{{0, -2}, {0, 2}}], 
    LineBox[NCache[{{2 Pi, -2}, {2 Pi, 2}}, {{6.283185307179586, -2}, {
       6.283185307179586, 2}}]]}},
  AspectRatio->1,
  Axes->{False, False},
  AxesLabel->{None, None},
  AxesOrigin->{Automatic, Automatic},
  DisplayFunction->Identity,
  Frame->True,
  FrameLabel->{{
     FormBox["\"v\"", TraditionalForm], 
     FormBox["\"\"", TraditionalForm]}, {
     FormBox["\"\[Phi]\"", TraditionalForm], 
     FormBox[
     "\"\\!\\(\\*SubscriptBox[\\(v\\), \\(s\\)]\\) = 0.6,  \
\\!\\(\\*SubscriptBox[\\(v\\), \\(c\\)]\\) = 0\"", TraditionalForm]}},
  FrameStyle->Thickness[0.004],
  FrameTicks->{{Automatic, Automatic}, {{{
       NCache[(-4) Pi, -12.566370614359172`], 
       FormBox[
        RowBox[{
          RowBox[{"-", "4"}], " ", "\[Pi]"}], TraditionalForm]}, {
       NCache[(-2) Pi, -6.283185307179586], 
       FormBox[
        RowBox[{
          RowBox[{"-", "2"}], " ", "\[Pi]"}], TraditionalForm]}, {0, 
       FormBox["0", TraditionalForm]}, {
       NCache[2 Pi, 6.283185307179586], 
       FormBox[
        RowBox[{"2", " ", "\[Pi]"}], TraditionalForm]}, {
       NCache[4 Pi, 12.566370614359172`], 
       FormBox[
        RowBox[{"4", " ", "\[Pi]"}], TraditionalForm]}}, None}},
  FrameTicksStyle->GrayLevel[0],
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImageSize->Medium,
  LabelStyle->{
    GrayLevel[0], FontSize -> 14},
  Method->{
   "ScalingFunctions" -> None, "TransparentPolygonMesh" -> True, 
    "AxesInFront" -> True},
  PlotRange->
   NCache[{{(-4) Pi, 4 Pi}, {-2, 2}}, {{-12.566370614359172`, 
     12.566370614359172`}, {-2, 2}}],
  PlotRangeClipping->True,
  PlotRangePadding->0,
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.710599953390737*^9, 3.710681977736651*^9, 
  3.710682019473184*^9, 3.710682148794653*^9, 3.710787192304636*^9, 
  3.717283190562742*^9, 3.717283534812155*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"plotBasins0", "[", 
  RowBox[{"0.4", ",", "500", ",", "0.05"}], "]"}]], "Input",
 CellChangeTimes->{
  3.71059996879395*^9, {3.717284325337709*^9, 3.71728433450319*^9}, 
   3.717292411987026*^9}],

Cell[BoxData[
 GraphicsBox[{GraphicsComplexBox[CompressedData["
1:eJztnWVcV0nU+O1AUVQQRKTjZyfWqnMVO1GxXaw1sRsXYw0sXIu1C11bsWNX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    "], {{
      {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
       Opacity[0.3], EdgeForm[None], 
       GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNmwfcl9P7x+91vhmJslKkJTt7ZVQ2IYVKyF4RpZRRFNkrmxKVvULIVmTz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          "]], 
         PolygonBox[CompressedData["
1:eJwtmXf8j1Ubx+9xzk/2CNkjlBQlbdmjQomW1bCaSlpUSIR6eEIUDRo0raz0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          "]]}]}, 
      {RGBColor[0.880722, 0.611041, 0.142051], AbsoluteThickness[1.6], 
       Opacity[0.3], EdgeForm[None], 
       GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNm3fY1kTTxR8LdzabIKLYe0EUFBs2ROyvHRVQQAG7oCKCCoJd7N1PBTv2
3hV7eVUQFawoigUrNiwIFsT6nZ9nnsv3j71m7slms0l258ycyb3S/kd0Hzx/
U1PTwy2amhaQXDo3NT1ZNTUNTk1N/RpNTburdVfrq7Zb/N5bbdf43T+O91D7
tWxquqBuavqxaGpqo9ZLtv3VNtRYy+r30mqdpa8m2VbtTLUl1fZQn4my95Tc
R+082VZWGyB9AdnPkL6Y2uKFr7uXWkdday21r3T84LAxr2XUZ1/JQQ2fv3fM
fV31XUdtpvofEfM6QO1C/d4mxthC8iDJoWprqm8fyQPVJsn+ktoKhY/3iet1
ST4+RG3t0mMOVpscz26g2t/S/1JbWu0c/T5J7WS1/9NYqxeey4WS7Qqf20nj
rK/2rfq3k1xNbVnp65W+p2PV2kofFmN10Hnt1Y6TforacLVj4hrD4veosI1Q
OzXkyIbPYczD1U4LG+OvofGOlzxD7fw4n/POi2vw+2y1E2MOa6t/x8JjrCV5
Ovekdmn0477PUjshzrmdd672hvRzY66Me7HamdH3kpCcf1HDYzKfc3TecoXX
3egYmzHGhGSOY+N8rn9NjMvvK9QuiLldG8cZ48qwcZ3v9azfSB7vEbW71O5W
u1HtMrXLWc+F9RvUbgobY98ckvGu5h3HtW9Vuypst4VkXvfGuIzxuq75mtpG
GvvV5LG57mzpPyTP977oy3UejHEZb/nkeT7Ms42xeQbrFr5f5veA2i1xTmfZ
N1G7Q/q4GIPzHo1r3qP2eMyPa66h9TZB8lW1Z9QeimttWlj/r9qTavfHdZ6N
4zy/50Iy9pbqv4XaU9Ifi+twjfVlW6/wWnsqxuD+JkQ/5vJW8jUmqo2P8Th2
h87bU22K9M0kuxS+p12T5/WS2o7Sr5d9e/omz+lltXeSx3pFrWfyvCer7czz
V98d1G7B5xTuc6tkT7XXpXdPfhaT1DaX7WnJF3k/0rdWe0H6dpKvSb6v1kHP
cHf93q3wfd8Q7/5O/KTamw3vVfYB+2E/jb8fvkztPrV+au/J/pnsd0vvo9ZX
7QPZvlSbIfs9+r2X2gK61vxqq8jWWnJhtXWlF5INtXbSW0guqNZWeimZ1NaQ
XklmtQ7SP2dMtZXU3ld7T20fjd9Sx2v8r36PVJul6/+udpT0wTp+uNr+at/J
No93Jf3QwvM8gfUs+Yfa6dLnSP6lNkjHf5FsknxY7RC1L/T7ackj1X7l2aj/
bMk/WSeyDVH7SfoT+FG1H6W30rwWUlub9yPbUYXnsGxg0n7SF9XxRfCz+GS1
42Q/Vm0ifq/wHDbS8Q3VftTxYfo9v1qttoFsLSRbFcYlMAk8aC3ZUCvwf4FX
vRvGSPAHHFq48LmNwDFs4AiY2i/6gU/4ZDAMbANTwFHwEZ8HzoKZ4CR4CQaC
VWAZ8wCfDoxxD47fGyX7zeULY9OAuNZZ0p+XbWThuQyIc8Dz/jEnfO3A0Fcq
jK+HNYylYB7Ycb7GmVT4Ghsn4/cqahcl4ytY3iVwl3mer9+rqh3dMOYOiTlf
EHFBM7bh2/H/LwV+gmHEDuAwewVcBSfBMzATjATDwPOhce88S3AOXGsXOMmc
GWtU7DcwFkwFm4bF/uP64C6YdVTjX+zknPaBdYx5YswRrNo0GcvBdcY4N+6B
OZ0W558QfcG5NQtj7ekxj/PiHK5xfvyelYxJnQqfA56AKx3DXzLmOoVx94LG
v9h5cczr0vjNPEbHb/qBU+ACfndMXIt5gIEXNv7F1NFxPTALDNugMK6Af8vo
md3FOi98zpUxLmuWd008Qz/83A1xbXAMbHojMG10zOOm6NeMozfF9cArcGtO
MhZuXBjfwKvb4j6vifk14+utcc9j4xj4eXv8fkHnj1JLhfH21cBOrg0W4Zv5
DWaBYSsk4ys4t0lgC2OBk49GP+YHZjXjHxjWjIfIJxrGUDBkfFwHTGvGwMdi
LPAIXHou7uHBGI97Ghe/uwR+PhjzA7PAIfDx+bhWM+5yDLydGPMAE8EosAoc
nBx9wL5JMU7XwrhOn+sCM8G7h+I4mAr2vRT6VoXx74W4h/Fx7esDP4nxFgzM
+Vp6j8K4CJZ1S8bLboXxdsfAcTAWzAQ7b5S+U+DjXskYTOx4b2ATuNg3GUdZ
h3snxwRgar/k9QlW9g/cBB93CYx+p2Fs+1RyWsN42zdw5wHJAwtjWwo8/KZh
XAUzv+Id6PhBhfFsnOTBhfEJbAS/fm4Yg8E9cHpG4XgdH9QIvJ0pfWBhXAW/
wFhwFVx7SLYBhTGSNTIhnu/ByRgJpj4eeDu3YQwES+kPtoKTzAc8BKd/k350
Ml6CnWAxuM09Di2MwX9L71wav8ATYgfwd77CMQTYCE6PSMZm8PU5tWPUFiyM
0WA7z2S8fo8IzJsQOAP2gavg6EL0L4yvVWE8BmPB2ob0EwvjMeeDna1i74K1
4GyX0piOvwHHjg072A/mE380oj/nf4TfLnzO4jr3a/VbVPrHaksUxvLFQwef
waLVAms+kTy7MP4toXO/Sc5nyV3BY7C4a+njYA59iDmINzgfzAJzeKZcA3wm
ViJOIrZ5SfKswmOBpecWxt4XknEbPKZhA4vxj/eFL/lFfX5Wa6m2ZGmcBqPx
v2AeeLdxacwF34bFvTGvl5OxGux/WfKiwud8rnZxYXx6Re2SwrhHP/CcOIFr
fafzVyzs78E9rsn6pi/4CKYwBrnbDeHv8J2vFsY/jn+gMQ4rvE/AC/AFTPha
ckzh368XxjmwC9wDt8AscBUsBAenFMYnxrisMGaCYU+FH8QHflU432CMNwr3
Y6yFk/0Y/vE1ydGFx/2icH7LdWYyr8L535TAIjDsO8krC/tNcipw4vbws9jw
k29JXlXYf89Su7rw9aYW9rn0/SJ5bJ7T25LXFJ73Yqxztf8Q7xTOc8ADGuOB
BW9KXlH42t8XzrW47/alcw6wZxvJbQvjxNTk3+jvFPbj+PCl1X8ptdHgrWxj
C/vKOdxrYd+9qI7tXNh/gg1gBH5+8eTj+G5+4//x5zR8Oz58muTNMeYV6n95
sn9nvF1izEWSrwdWLFtaghfvyj4tOR9jfuAEGPGu5G2FfzNe77jWPOm/Jr/b
L2W7tHCctFzpcccmz23PmD/n9Io58xuc4f6+KZwz827/KIwnb0n/szCeTGV/
a7zl1R5I9uP4c3w4WNI31jbHwRhsYwO73mX/St5fhC9Qm1vYH6+k/iuqPZrs
Izg+L/w12PRD+Fkw6J+8CN+b/B74DR7NCTwAR5gXYz9W2Ne/r/ZIYaxifofG
3LgHbJ83jAf0xe+DM/gs5sK9DYkxGXtg6D9J3lv4nsGkw6P/B+y/4t887YiY
G8eOjL7c21HRHx+Nryb32aI0voADK0v/SfMbLv1DyaPjmXAMrGlEA2vAgo+J
4WP+09mLha/3O3iYvJZ/0+9nC+MQGEI+mOIc8IdnUMQx7Pgg1hExbxXngVur
knOrPZeML+SB5IAfSp5aGLtGhd46xhoV8wRvySfBh/OS8QB+FDwBd8gHGRu8
rGJeJ8bc6mQM43zwAxwhPwQTGAOMIgYgN/4+MAR8Ia/D95Ov4de7JvOSRwRu
gAXHhV8nrxkcvhxcgB+8JDmXOzp89ph4NvhN/Cc+ln3Ofn8nnhl78PTABzAF
v/prxIH4HzCKPBCMujQZk7g2PhpfPSZ8Kv72oRh/bJyLL8TH4vfwQ/ir18I/
EY+yp69J9kFcD59EfMm+x+/i28EO/CW8zyvhy/Gr48KfEafiH/CRxMf4B/w4
/hwffn2yPyJOZY8SI7JHb5L9xvQv33NHjLNH9GUc/NadMR98GT4NX3qLzrs5
Yln2FfuLePI24uH0Lx/EcfwSPgkbfukOcp9kbgg/d3s8h9/C9nbDPgOOCR/7
RLJfIL7EfxCDsk/xQ8TEs8JPcBxfgZ/AhxDrPpW8z4kv8VX4NGIwfMYvYcNX
ESvPDr+CLyKefDI5lsUPEAvAGeGTwD9wcGL4G8Zu9h/4E+JdfAIxKPEne5G9
TAyJLyFGxZ/gP4hH8RPsf/wAMS0+g9i0EevonVhL+Az4IHwAvoT4kn36e+H9
TB6Jf3qxsI/CD8E34YvYc+xf9iKcCPEce479QRzDHiEPIK5iH7AniIf+4c0L
r3n2H3EKMQprH/wB41mPYDvxAc+GvTu5cEz2TLKPezrW8pRYz6zNqbE+iR2I
Rdgr7AH2Anvon/dfGJPYQ8QQ7CNiWOLmNnHP3PuoeP+sE94/fgf/Q1xL7Ems
jN8iviOOxGewxtkXrOvhyfxdM3fHmuF9Emt/VjhWxveQL+F/8FWfFvZX4CIY
Nijuc3q8T2JDMB4fQyxDjMW+ZO8SM7F/ibOI1fAfxInEl/gt1tcPhdcYsQax
B/4DTPu5MJbjz4gd8Wn4LeJCfBcxy+x4hmA7+McexedRB8PvET8SU+IXWXfz
Cq+9Ss9hA7W/pP+t1iR9F/WfrzSfS3yxYHLMwb7m+HzRp6k0F8wxcGb+ZAzh
moslXzdJtkj2A1cmj/VWnFuEHZlCbxHXnBpzKJP9A/sgJ2MOz5R4ij2yUOQc
ezacg/B7qcI1OzCJddE64i/i6qsCbxkT/G2jtnfhZ8CzyPHciV/wRcRvnN8t
7qlN3FebGAedfdAq+R0uEbEPPnPV5NwbP0neBX84ImIk+vUvnGMuFXkmdbpl
1A5tWNL/ELAymQeEAwRv4ILgXTZJPob90+TYnGPocEZ3Nsz1cS4c4YphZwyw
a8XQ2yfzAB81nAcxZ7iF/ZO5ic8a5uFXTo4V4fa5t+nSV0vmItAHhA7Hcmgy
3wK3AM9Pvw+lLxn3zvPZN9nOuSvHteBAVo9z6U+9YPWY2+ExTziQC5J9Dr5n
WDJfgf/vGPoM6WsmcyYfN1wv4Bjx5JCwfyt9neRcHYyAB94ymQs+KPkY9g+j
D9wF8Qt2Ypj1kvkIsIOaBdf7pOF4Dzv7i9oH/cAU+GU4aPjnMyU7JWMEtQD0
BQrHcHAQLSU3S+7PfDZP/o3OHJkr/DLnrR/jbB3zHxrXoT9x1EFxb1wfW9ew
03erGJNcGs6avnsk83GTY62xruAjt03uc2T03TauRW64XXLdEJ+9fTI+EJvs
kBz77JbM/cHZEb/skhz7bBfjs1aJj3ZKjnHov3vyniV35Vywg9iTWBmMxbZb
9KF+1D7eNXPnHuAT4Ql7xHWbeUY4RPhB+EdsvZL1l8PWK+797uQ1Oj369A77
MzEu8+oT/TmX63SP6+If9kn2Laxr9tKnsacOCB15YOiDkvcM+6Vd6Owj9tOA
2I/YDgv7IWFHZ08cHucS08B//RD7ZXDYj4g+7B3W/pDQjwz929i/A+Na2IZG
H/YTewysPF7y2GTOjpxwZOyFY0PHTt/h0R/7cbF3Tkzm+/4I/aTof0yMz/4d
lTx/eEPugf7Eeycnn/NH2E6Mc0fGfH6L+x4VfcB48nNiWnjIM2JMjp8afZo5
Sp4ZsdXZyfkVfbET1xF3nJscZ1FHuijWPzUmfFDzdyIcYw9x/P+iDzUv6lLE
XxfHufSdHL/R5yZzLtQA4D3GsB8K13HIPYjFsHEv5BHol0UfOAu4BmL11UvX
QvgNLoFz8BnwG+AumHtaPJ8/o/8VYQdDyKPIoa6Oc8FHsPfq0OHJyVuI165L
5g7AAmL5G5JzCHz4tWGH36Bf98L5BHkHOQf8OfkJsRicOTkJx8kDyBHIG+DM
yTfIJeDMyTHIJYjfH0mO6TlGPtI74p07k3MScOmu5D2LvDt0Ysp7Ym5IuHtw
7f7QOY68L+zs2XtCJya9P/oQa8JNkHeMS9bBFOZHHkQOBM48GHb6PJRcQ4ef
GRc6Y/EMiTEeT95L3wcePRY6PDn5DPEpPAz9DijMvZMjEf8Swz6dnJew5/6b
bIMbJxYnPh0vOUHt5NDhBohzwCVynrmBI88mY9DImA/7Dj5hfJyLz78w1jZx
1vPJsRb8MLVh8v0Xk3+jI/kNd0w8TQ21OQ5CJ7aZGP3hlbFNCjucMHXi5rov
OvXinnFOj7DRb0D0fyWZS3gl7Jz7cDKWg+NgGPsM7pd9R+3teulvJnOp1zVc
E0SHU+X469EHG/3gW8dEP+qG8LnUvah5gflgP/kaNvjNZp6T38T2b4d9Ytj5
DQfK+G/EHKivUIcDo+Aa0eEBqMvwDcSMsMNFgjvkBhzD38JLTov+/8SeKWo/
7IPkvJZ45qPkfJGxp8U4n8T8iVumx7lgAX05Bx+7dujkmPTlHPJUMJy4Exxf
N2oT1B3Y1+QR+JAVog8xBfuF3IE4/8/os1fsUWJN9unKobMXqZPwLUKveIf4
TDjqP2Ic9t2XYed9UVP5Ovpj4xj8Clj2XjxDajaMSTwGt837Zo1QT6CmTxxO
HYXvIahfUGvhvuDBiOPpQ12d2sN30b9T1COofbCGqPtS86UOQA2dtdMx6j69
Yx19H++dsWfG+NhmhX2R+AaEmPD2GBMemLU4O9bqRsFJwj8g6c9e5hx06lzk
SfBxcHHDox994AqwLxV5FVxYc25FTtUy9gp7hmdPbkKusnSM90ucCzZwbreQ
80JvHTpjsx7gffYO+XvobUIHu8if4IPwjf9wo7F+4Aew948868//6ftn2L+I
eV4ffobvM3hXf8WcD4339lfoPL858TzJQ8lLWVNgH/kna5N6KzkPODIj7G/H
/uIYewTcWSC+dyJmo95MbNYudHIZ4jRqruQy5D0too7bNsZhfPq2iP6fxXym
xjicOzPe/+yYM7YixmR86sTEbEhiYuJh4uIyar3EfnxbRbyHJG8hZ+kQ59Kf
PKaKejN4Ry0ZLGPvoBOnkZMVUVPH1jL64B/gefEV4GDL//lGa6HgfsEDYqL+
gXet4lupIyvFqZVj+mMkj6ocUx8vOaJyTD+iVoyWzfdtLPl06b3eRfpzpffo
s5L9auPTYTpvbulY6BDpP5aOmw6SPrt0DnKX9EWyucZ7pbfJriccrTEGZXOg
Q6QPzOZUvpBsyo5tJpDfVb6nv2Trn80D9JHth9Jx2u3SF87mHTeUvmPUR7eS
7fnS/uNi2Zer/FwvlFym8po6TNftnc0hXcp1Kr/PMZIrVH5XK0o2std/O/U/
IjsW+lT2tbP5xcdZR9n8zfHqMyqbBxov+83Z3NYg2ffOwb3p3A2zcf996e9U
jouPU5+Ts3nP8yTPz+YfP9LxtbI5zunSO2T7mBukX1s577lJss6OYW6RvlA2
P823T3xnTPy5SenfR0dcih3+glh19Yhv+QaBb1nASWqL6HwXSvxLH2Ja4jJq
XcRpcGLo+0bsulzU3fCr5N74QOIfdHJpctLFotZJjY7+vGswAjt5LtftEHVN
+nHsrogZ2kQf5s29wL3w3WWHmCfz5fxX4n6pi7eNmg31lSp8M5zyP98zFLbz
Ls7T898rm7/BtmrYF5B932z++Hzp/bI5102lj8iOmeGnGZP3ApdOTHlAzKt9
zI25Mhe+PSPuWzXm9UCcQ39iWGJZnjExKeMQL9LoQ9zI814hnvlVetcrVfYH
r2su82f7/KS5HZhdI3mG9Z+djz4o/YHKce4kyRWzc8RHpC+Rnfu+zv7Izkcf
l75Udg79FHsnO999WfrkyrHwi5IvVI6pl9fx8ZXrgq01h0Ur49RC0n8JX9FG
+uK118tSkjeVznMWk/53rIc3dd5q2bnpSbJNqFw/mCj5fOVvUc9lDVbm99dR
388rc/lfSX5Z+fvHDyTXyOaE2mfvH95RW11r1dr1k9Ul16id5/Qr7RfwCWtm
7z323QeyD6zNK/cvvZ/Zy0tzL5VrL9MkzyydA76Nv8nOC2dK/6ZyDjxbck7l
vPcc9f2sct3iO8lvK3+vukG2j2Dt4RveDf9wNhhSea11zPZBIyIGWST22mDZ
l6ldf2op2ap2ztlXsnN27fBA6Ttl89wHS++WzX/vovF2qMw9TcOHhf9fXbaV
s2PaA9T/P9n8/QayTwwf21/2zbO5/E1ln1S61veqbH+Ujp1fk/5n7OtTwILK
cSjPb77sZ7iq9MWyY+k9NeYZ2fWe52RvWzmv2l72E7NrS1Mk182Ok0+S/SmN
vwjPTba3snn3rpIXZNdZb5KcW7mGsZn0Xyrb50muXzk/Gq0xtsyOYbaTnK92
3fRnHf+pcv22kvytcrx2uuSytb9NG6f+Ze0awwHZ+5A9eLpkJ/0+SfosyTez
6wL4YHwxPvl2/HNtTvtBHV+wdu2BfXxZ7OUm2RaqXLPdJ9s34Ze+1rmH166B
rB/rgfiU77vgSclDT9PxL0rXiPbSGAeU5hG/Z11l50pb844q8yx71N4/7J1P
Kq9X1uor0k/NrocNVp/9Stdkaum5Np58BB5W/h7lB+mzs2PARfAJtbmMwfjX
yrz0/hyvzb9wH/uUvpcPK6971vw3+MXsWs6ess8szYX+Bg5U5hB30bmnZOfp
Myr7CPzDjqzZ7Nr25bI9n13jvrT0u+e9j5F+YTaHdDP+rLRv7it5Ten86078
R+ka58WSm2bnFD9Wxmzw+h58Runaaqrsv/Bd37IGs+stl0r2ys4zrtbx6aXj
aq7zaVxrnM49LrtW2kL3NSa7fnm9ju+XzVnNkfwxO6bmv1kPZdeI5qnPkMo8
72my9ai9f9tKn1KZH+zKnq3Nibwr++/ZtaYdSj8XnskqXKcyz3iL9Fuza3hH
Md/KHE6S7brKnOuGGm+j2hzNsviQylznkuzXyhzr4tIfrsyHHi/9P7X3+3Dp
m9TmdGbp+EWl8flC2cZn19Xux+eVrt31lr1PbW7lLNneq8wrtlPfqZW5SHx2
n9J++xTpU0vX6w6SvkfpGubJ0t8oXbN9TXK7ytz9x6XfE+/oVPX5rHSdtgc4
Vpmr2av0++PdtSIWrZyPdsNvl67xnpWNPeDOPMnfsuth54LVtfmj9aR/F36s
vWwdanNsAyR7la5/LkBMWJn7HiQ5oHR9sofs92Tns5uBt6W/sdhf5+5c+hsO
vuXne0rycmq3fMtIHo1ts9J8At/XYycv53v7zUvb+J5zy9LfdHYNe/N/BDiX
sX/QdTfJ5nJL6c+UzlupK3eJ8TtV9pv4zDM1t12ya+NnS++eXdM+S/pu2bV0
/vuwaen/P+Cnu4YPP6P2fmYvbxFzI5Y7Jn6jM1d0vgdo/s6MuIIYl1gWbhO+
F14Y/pc6ON90kuPAH/B9DxzC2IhTyZfBHnwpXBT7ZPHAx84xT/rDnTL+W8E5
LBH3DhfC/cCH0Lgnakac1znuEV/MdyfkNfAcS8ZzxrZ02Jkrv+HeyXOWDPw9
Mnz93BhzrZgPc4Azgvv4DEzL/vZlkGzHVa65HCZ9eOXaymTWYWks2DLe/YIR
Y6DDdbwguUllPvBQ6UMr14BOI+7L5q1vkz6s9Pcx22fjKBg6kNiz9Hc5l+Mb
srmHe2S7IpsPPlKyU22+eKF4l3wb/LjsT2TX7IfKdm9prol5bRTz3DLeO+cQ
52Nn7nBMrNPBwTmxdrGxfteJd4RcN3R4DPYAHBTPsmM8z5GxT46Nd8i745uu
zWNvcIz1Q3/eOfb14z0S+5OP8O3TYrFuGJM8hlyl+Tg68QDx08ahbxb7d+0Y
r1OMyTpBZ75Da8fcxNtg1N2VcWpg6Ryb/PpXYkvwQvq+sv+dXV/fSvrb0rtp
zOvBsexvPm6Q3L4058za+TnWD7HkjRFPzpV8pPQ3BH9Jfp6dkz0mfVL2NyU/
ZceCxIEFOXXlevX8kkeU/iaUPGDJ2rkAfrRnti/9Q/L97G8gbsv2v/heYr1r
s+O9pyRHleZPnsnGA7CAfPrZ7Jz6ZtmWq10vgXt4JJt/gPN4Opv3GJv9LHgO
j2XjHBj3sGTP2rVg1t0GtdfeerXXLut2PjChNif3gGzb1a5fE/ddE7Hfo6Xf
Ac//I+l7ZOezH0pOz/62At6F+BvfAm4Tf4PdxIYXVI4PiX+vihh4C9m3qp0v
bilZZeeSp2fH0MTP20iuUvnbrgnEHrVrvbtLtqv8LRUcScfaPMlaxLyVubI7
WXe1eTDy3Suzc95usu1auy5CPNi9dkzIu/og3hfxy7a1Y5gTsmN35vx1dr5K
rvop66r09ymfSP+p9LcsxKSTIy5tr7n8kr3GwMkpgZX/ldyh9jdD30ifmf3d
x4zsfOMfDqF2XkGMwTt5tvJ7IUa7r3Kctmg2PwU3RQ4KDwVekLscEuuWZ3BJ
5ecA3u5dGnPvlf5J6e+I2QfMlXmuK7lO5Vrl2jzbyv+VX7MyRoKP8GprVcad
cdJ3rl1z2la2V0t/mwAHlivzYGD75pXx/aXSuRZ+ApzvUhnrJ+OLKv8HYGti
mco1zy0lt6j8H324MfI3sGNj5li57jqrNL8G1vQipq78zcE7su9a+Rup3SV7
VOZyWkvuUbn+8H7pGIg921v6bpW/6XyvdDxELNRXsl/lbxd2lOxe+jsH8s6d
IvfcR7J/5f/17ie5f+VvFw7m/VT+vqFn5bicOLl75b3EPtpe+uulv9e4W+/l
ruzv+sGrOjDrQGLVyv8DProyhoFfcKLDKvOiYNShlXFqTml+E24TjrOqrZ8k
2++lv1OA24APhd84VXJU5Xos3OqxlfnV+WvnMOQvt0iuULvOeqv0lWrXOG+T
vkrteu3IytgMLp9ROc8kx+ws+WLpb5QGg7mVa8jnSJ5ducZ7keSC2d9Y3M3e
yuaix8p+TeX/H19Rmd+E24TvvKwy51mo79WV+aWzJM+sXE8Gz++ojOmts7ld
eN3zJM+tXE/G98BF4n9uZN1m1whbZvOScJLkVbdWzq1aZXO48LfLcv3a/P1K
2XE/Mf+XpXNX8taepfkLuAu42Muz+dhTS3Ov8K59s3k6OLounFe7tn0X+F6b
h989O+4k5pxROr4ntj8pO2cjX4N7uDrbf75dOn8gd2CM0ZXHmVI6fyB32K40
DwIH0kLHh9eupexWmjeBM4FjXqc2z9xZ8pjsOurI0vw7GLRtduzOXt6mNHcD
zu5Zmq+Bq9k5O4YmfgaLrqyMR6eU5pHBu2ml8wdyh/WzOQgwaEfJY2vXp4fV
XgesgR2yY2vi6iGlOXrwcdfsuJyY/I7S2AAufFs6/yf3JyYm/qS+2SebS4VH
fat0rkWe9WRpjga8/n85AgL9
          "]], PolygonBox[CompressedData["
1:eJwtmXnYTlUXxh/Sc87Z50l9IkSJIpVKJaRUhMg8iwyhokIoElIoU0RCoYgM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          
          "]]}]}, {}, {}, {}, {}, {}}, {
      {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
       LineBox[CompressedData["
1:eJwt0UkuRFEUh/GjiqKUsZlI7cMGMBA11SSaqTLTJxL9VN+tQZMQTWxADCzA
EhDR96r8Xhh877vnf8+77757872DhWJFRBRxiRzqkccVatMRb5URs3zBZ1UR
KW7MRGRlH8Zz/M7z/Mk5/uYF/uISflCn7uP+pDZusEaG23Fk3Xv5A85xrC7I
SyhjCo/yaX7iau7hQ32fxgf8xa2ytmQ/yd4wiWvZLW6QVnfxrv497OBVts/N
8hY8q18wjlX1BK/xCU6xgU2sYxtbCD3dyTlhBgMOtVY8ylke4hquht8On4v/
1yKFO4/kHkYFTRrGuFNDB8rmlnkFixg2t8Qj6b87+wXNlz4o
        "]], 
       LineBox[CompressedData["
1:eJwl1EVvFlEUh/GpUqzUqQEtLU7CkhUWnCDFXUKC+weAYAvc3d1dEqS4O4Uv
AQtgg2wg8Dth8fCc/zn3zgwz923l1AXD5qckSdLZP7dTk6RQXYfUtCS5lZ4k
S7g0M0k+q59isfyJr2QkyWUMllNQYs0vnmI2GRnqcr1l/E1+hq/4guv21ein
o8ya37wUU82yuLneSv4pv8APfMcN+4brD1Sn4Kac8C2exjlm9dUNkIks1EMT
/Qxez2m8Lu7N2ZzKa+P/wGtineuk4658B6/UCf/lWh5hTWNUeMY0vdXqjegi
b+BRyEWlnGW+Sb0VXeUtPBr5qJIbmm9TN3LdndyQd/AYFMZ95F382ro3yEVf
+3J4DorN2sj7eahcgH5yPs/FAf3D6K53iMfHt0RbudD8iPoYeshHeUJ8D7ST
i82Pqws8QyHycVKeiGaoNb+NMtwzO6W3QN2CO9p/lvfLq3BGvY/vYKNztsIr
/YMO8d7s7Yo6s3f8Hm3VdfwRH1Br3dHYH88b90NH9aI4k+YV/IQreQQmxRni
R3ot+DGf0yvi89w09sSZ5VIUoxxlcY3YG/vQLHKsRcv4ZlwdNS7IrbgqvgFf
5NZ8iZ/zCzyLtfEdcFl/NZ/HBVThYPyO9NfwRVxCNV7a9zrOHq7G9+Jr8V3i
/rzQmgfxzHw/npMfxm+DT5t38P6b83y5BAPkUh6GE/rt5XKeJxehv9w03j/e
Is+1clFizTgcRLacE78l7JPzrGsd+9RjsQfd5L0822wWstFHrwnXYHe8M7mI
Z8qN0FtuzEOwXb9aLuAZcn30khvwYGzWbynn8XQ5Ez3lejwII/WXx9l3xjqh
vTNWkfz/u/YPyPR71w==
        "]], LineBox[CompressedData["
1:eJwl1MdOlVEUhuFfQRx5EQ4EBQUpigLG3jsKYpciVSSxmxjrUL0GxURHTjSx
JyiIXbGCYAHF3nuvzw6D97xrfWufs/+yoXdRTe7yblEU9fIRh53qXXwiJor2
xEZRLXbguH43J+AgDmA7jsnjeWBcFCWqc3pE0VHO4iOczf14CA/FIGRiMPrK
0zkDA5GGVCTIkzkF/XFYP4Djuc5eKfZKRpPsmj6JE3EFi63pE9ab9zE7pJ6s
XqGux6mAbJK1+9Q7cVK/lztlD7FU/4BvyybyBHSgRN7OLfLxPA73USy/x83y
sTwGd1Ekv8O35KN5FNqQpG8Nv4+b6jrrRoZ7ULdwob6Zb+hH8PDwG1gS7gup
7qef2SqsRCNOowHpZmnID9cWcuvz1Mnqd1ylzw/vC+/DM+YPvCZkZovCM8QC
nNEv5LMxXeej1tmY1T2K9vMm6zcgzl5Z3IOzuQA11sfqN/ruJnTKeuozkaM+
gxxrtoTnxJt5G7ZimH69+Q/1T3wPZ0Y/B9Vm38J5US/hc/oO9S/173Cm1H/4
H/7ivHkhX+CicLa4hC9yMV/ipeHccRlf5tJwjric07mSm7iCr3JV2J+rw9nj
ZXydl4fr5LWuYR1SkRHOaViDj+ZzUIB2s0/8Oeyt/hL24q/caO1cno954f3o
V5s9UT/F4/A3oc9Dqdkj/WRMQavsGT/HAPVUrremTf1CXaZ+ydMwHXfkr7hc
/ppnYGZ4J/I3XCF/y7mYhXvy2Vwpb4jp+n/xH289jb0=
        "]], 
       LineBox[CompressedData["
1:eJwl08dOlFEYgOEDo8aKFXXrRSgtUoaq4oadLr0A2gwWEKOJXQTsgg2wUIad
iri0o0vsxALS7I0b8Jm4ePN85/vPzwQmrNlWVVGZEkIY1oASSrfIiYTQODuE
ETbwLXczm/V8w518zV3M4g6+Yh1fcjszGecL1vI5Y8zgujnemxVChGMctqtJ
vmNOtUvRqLnarkrBuTL5ntaaMzxrUL3y7A65854H+Y4L3Fmo+cp1p8Zunnnc
fMCd/ZrrXG2fq0zzes/2qFHFdufcOa/TOqszKrI/xUme4ARPspCtHGczP7GF
UR7nGI9xlE0sYLbPLPBZSzjJj3ZHPcs3L7ZL04T5iN1hLXKudSdfWeY8zz6Y
y817zeXmHPMv9jm36Ke5lyW6pbjzNG+qWT3q1ib7e/7MMd//oO6b47yrB+aR
1BAe8pEe64mG9FTP9Nv7UZ/9h1v9vDreZkL9atWA7qhUq9wt42r+dTfh95th
Pzdzn2crPItyOQu5RTHPljovU5u7U85T9unOK1WU/O40bd/u+WdeYAkv8Qsv
8isvs5Qd/MYr/M5OlvEqf7CL13VNG5y72aMb6lOvNkb+/w/9Awcjcd4=
        "]], 
       LineBox[{366, 203, 1155, 886, 1159, 1158, 366}]}, 
      {RGBColor[0.880722, 0.611041, 0.142051], AbsoluteThickness[1.6], 
       LineBox[{2047, 1613, 2049, 2491, 2773, 2490, 2772, 2775, 2774, 2370, 
        2718, 2719, 2493, 3199, 2492, 1810, 1614, 2047}], 
       LineBox[CompressedData["
1:eJwl00lsTmEUh/G3FqXVYmdtbR5brVbnQemsbUKrSiwQXVhLCInEmFKEJtRU
VoStxFxKzWJoa4wxhJipqvrdWDx5zv+cc997c7/7jWpoLF8RE0LoRWlsCCUY
OTiEy/EhdGA/suNCeMxP0I1H6MEf9KELZ+w85NOczEnYjE34OjSE6fyJv+Az
WuU8u+PU4zEW5+UZ+qnYpt7C6fhhlsY/+RDPMpumvsRTuZ2z9DOxQ/1bbyim
YDJ60axfiPqEEDLsHUEbSvQyzDORjk55JhdzGl/lVL4SPRvP5gZn5Lr2r5yI
Dr0UnsMrvb9VWI8mtKANJ3AK7cj1foP9p8744JpOfoaP6kZnN/BJ+T0Pkuui
e2EA9XqteIcqZ9SgGm/leebLo331PrzGOvkNv0KN+TK5Vr0XL7BWfsnPcdy8
Chv1qrk5ei79pfI8PiZXYINcySPcdzh6zEqjZ+EWdKFY7uYSfhBl+0tcV6Xe
g3tYI9/nuygyXxydq96N21gt3+FryDNfJJeqd2HAuVnIxjAEsxjk2yvAdTs5
+jc4l8s4n29GZ/EtLuBynsVFKIx+w+g3RoX+Uef0R/eIvnXO4a3YadYnJyEZ
CdH3jcv6Cz1DER+2dyH6lrguei71dvyyNwETEY9JuKi/wE4BH7B/ECmYr5ej
14Rv9r5jNM7KcTwGtXbOyf32c6NvwveVOCSEuVyJCpSjLPb///sfV+OJWg==

        "]], LineBox[CompressedData["
1:eJwl1EdPVkEAheELSlPsBXs3ca3+CY1GQYkBQTpIB1Fs2BXsQY0Fo7Fi12hs
0bXubAsXLCwRK4mJ2Ht5Ji5e3jlnZu7lG+ZjdH51WlVMFEUT/GiMj6IG3O4W
RfuSoqiZp6IxOYqm8Gmk64vkh7xDno4meRqfwRx9idzGO+WZ2CjP4LPI0M+X
H/EuOQ2b5FQ+h/N4Ym6t7jEfQCZK5XRzT43TukfRLKSiXT6ILMyW09EHfZFp
/Vb7MvgicqyplDt4t5yNbXIWX0Kevkp+y3vkOONc7sI53JUvc4n5Cs//yuX8
hXua64UeKLHmIz7gLj6bb+divEcn7uCT/hkXoZt9yeiOj+Hzeu4HLuPicGb8
Ppw9l4QORXIBFyIX+cgLWT+PczAX2chCQThL7uQMfscJ3pfv/fGcx0d0e7kQ
iboCTuIrXG0u1r7XxhFe4a9ugPmB6I9yXT/uG7K1a7AaVda1uVvtKEz0TOsO
6xP5EB/FEdRZd0M32f4FPInruAUXzE2Ua8P9tDaeR3ELFunrERd6JOCa+euo
wEJzNfYfQ4rxWvPrMACD5OP6wVxp7XpdDA/kIbqhqJKH8QZdI1IwXG61bwQ3
yRvDszBSPqEfxZvkzRiM0fJJ/RjeIm8Nz8dY+ZR+HI/HG++KxQN0hDtqTZdw
D7krrhpvt+5buBfGNcbzjY+id/gM4bzRL3wXwnmFs0SMXGpNDX/nal6AWpTJ
C8M5hr8BFqMe5fqlvAxL0IDlqNCv5B+8gn/yKq7kOu8q9Xv9Mr4X7nn4DqAM
z/Fbf59f4CX+yKkJ1robt3ATF9GK/WiO//+/6R9fiJa1
        "]], 
       LineBox[CompressedData["
1:eJwl1NdXiHEcx/HHOVTK3lEhUrKdY++9V/4Df4B1Uppku5HNKdyYySaF0rL3
nlduyS3ueP2Oi3fv3+fz+z6j53mq/6o1WatbRVEU50d82yj6FhNFbeKj6KL1
kYQo6ovDOIRR7aLogn4kp8gHcQAj5Er9cE6W92Mfhsnn9UM5SW7tvHt5LQ/R
ZaKPXIo9GCRXmD9qfw3S5cHIQI283t5xcydwDLG6CfZyeDxv4HE8Fv3tl6MM
Y+TLjl2HXOtsc3dwGxt1V810s77MXfkK5+ovcRf5AncOz4Rz9JXcSa7gjnye
N+jPcQf5DLfns5ytP83t5FOcwDPcw0xMR548jaci1X68fDJcnyfqrji+LNwn
JslTMBm18mZ7980+QDNSdPd4kz4uWM43uxBpchMaMU++ZqbcfjHmy0W8gOu5
CX9iPS/89T0Uc2Kcd+SY7/Z+4DV+IdP5qvW/rXejBaPwBj8xOlzDeUvNNFuX
hnfDW1BovVVfheXWT53rGdKxQs4K++aey6mcwSt126yLgh33UjdAfsED+RVv
17/htHCf4bvit7xD/z6cX37HGfyBd+o/8Wd8xFd8wS59g5nG8KxR4JoluutY
ZP3QzKNwfiyWb+hLzC2xXoal6Cs/tt+Pn/AWM3XWd8O7Ce81fAPhG8Ss8F7M
XA+/E2bLc1Bg7obcnQfyXF2hdR7nO+6mrodcxT25mgv0t7iXXMOJ4XvnQn0t
9w5/A9yH67hIX89J4d44mRu4WN8S8/9/wz+aM4jd
        "]], LineBox[CompressedData["

1:eJwl0MkuQ2EYgOHPSnta0yVY1pxQFyJVxc4FcAEWFlJDW4kL4DaErQjRra2h
qHnotkjEI108ec/3nf9fnDO4tDKz3BURJda6I9L8kk9FJHqsGc3SQy999DPA
OudJRJ2jdMSp/tidkWKVHfv3TMQHL7zxSs3+SZ95YMLdR63aN3XcfKdjeq8V
+1sdNd/oiDZ02/5ah81XOqRbbDKf9W3k7HPmS501Fzhwb89ug6K5rHN6orve
tZyd9vypeV30rqoLWtFvvrig9X+ONofu7usUZWcnk86//QMM0TWv
        
        "]]}}}], {{}, {{}, 
     {GrayLevel[0], PointSize[0.018], AbsoluteThickness[1.6], 
      PointBox[{{-11.743336922224197`, 0.}, {0.8230336921349761, 0.}, {
       13.389404306494148`, 0.}}]}, {}}, {}, {}, {{}, {}}}, 
   {GrayLevel[0], Thickness[0.003], 
    LineBox[NCache[{{(-4) Pi, -1}, {4 Pi, -1}}, {{-12.566370614359172`, -1}, {
       12.566370614359172`, -1}}]], 
    LineBox[NCache[{{(-4) Pi, 0}, {4 Pi, 0}}, {{-12.566370614359172`, 0}, {
       12.566370614359172`, 0}}]], 
    LineBox[NCache[{{(-4) Pi, 1}, {4 Pi, 1}}, {{-12.566370614359172`, 1}, {
       12.566370614359172`, 1}}]], 
    LineBox[NCache[{{(-2) Pi, -2}, {(-2) Pi, 
        2}}, {{-6.283185307179586, -2}, {-6.283185307179586, 2}}]], 
    LineBox[{{0, -2}, {0, 2}}], 
    LineBox[NCache[{{2 Pi, -2}, {2 Pi, 2}}, {{6.283185307179586, -2}, {
       6.283185307179586, 2}}]]}},
  AspectRatio->1,
  Axes->{False, False},
  AxesLabel->{None, None},
  AxesOrigin->{Automatic, Automatic},
  DisplayFunction->Identity,
  Frame->True,
  FrameLabel->{{
     FormBox["\"v\"", TraditionalForm], 
     FormBox["\"\"", TraditionalForm]}, {
     FormBox["\"\[Phi]\"", TraditionalForm], 
     FormBox[
     "\"\\!\\(\\*SubscriptBox[\\(v\\), \\(s\\)]\\) = 0.4,  \
\\!\\(\\*SubscriptBox[\\(v\\), \\(c\\)]\\) = 0\"", TraditionalForm]}},
  FrameStyle->Thickness[0.004],
  FrameTicks->{{Automatic, Automatic}, {{{
       NCache[(-4) Pi, -12.566370614359172`], 
       FormBox[
        RowBox[{
          RowBox[{"-", "4"}], " ", "\[Pi]"}], TraditionalForm]}, {
       NCache[(-2) Pi, -6.283185307179586], 
       FormBox[
        RowBox[{
          RowBox[{"-", "2"}], " ", "\[Pi]"}], TraditionalForm]}, {0, 
       FormBox["0", TraditionalForm]}, {
       NCache[2 Pi, 6.283185307179586], 
       FormBox[
        RowBox[{"2", " ", "\[Pi]"}], TraditionalForm]}, {
       NCache[4 Pi, 12.566370614359172`], 
       FormBox[
        RowBox[{"4", " ", "\[Pi]"}], TraditionalForm]}}, None}},
  FrameTicksStyle->GrayLevel[0],
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImageSize->Medium,
  LabelStyle->{
    GrayLevel[0], FontSize -> 14},
  Method->{
   "ScalingFunctions" -> None, "TransparentPolygonMesh" -> True, 
    "AxesInFront" -> True},
  PlotRange->
   NCache[{{(-4) Pi, 4 Pi}, {-2, 2}}, {{-12.566370614359172`, 
     12.566370614359172`}, {-2, 2}}],
  PlotRangeClipping->True,
  PlotRangePadding->0,
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.7106000996086197`*^9, 3.7106822818975697`*^9, 
  3.7107873152928343`*^9, 3.717285005425458*^9, 
  3.717292983127149*^9},ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"plotBasins0", "[", 
  RowBox[{"0.9", ",", "400", ",", "0.05"}], "]"}]], "Input",
 CellChangeTimes->{
  3.710600204504321*^9, {3.7172902312516727`*^9, 3.717290231570056*^9}, 
   3.7172910129559317`*^9, {3.7172919933482847`*^9, 3.717291995282596*^9}}],

Cell[BoxData[
 GraphicsBox[{GraphicsComplexBox[CompressedData["
1:eJxlW3lYjNsfb1GSNlJqWrROg1BU5Mb7qoTQtS/JyFYR2Zfs69izxSVLutfO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    "], {{
      {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
       Opacity[0.3], EdgeForm[None], 
       GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNmHnUz2Uaxp+7phnJliVlfUXIFpmMIV6SaVdCliIxLRqhqCkVKltpkolU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          "]], PolygonBox[CompressedData["
1:eJwtlWmwjmUch++/IdnHkqyhIUXKLksTyu7YSyg6xhZxrElJjK2QJZ04WTLI
MuGQiiaTRFOaaaZphvHFB8Qgy1hGpEnXz+/5cM193ee87/Pez3+76wzP6zeh
SErpbSgKr0RKbeBVfAp0x6tDF/x1+BK/xzoKdsF+9kVgNL4b/oWd7LezNkn+
30XWIcmf+QdO8LfDrE/D33CM/UHWhvAXvMd+CWtZqIg/DC/gk6A1/pnQWWAA
3h9K4S9DAf4QdMTXwGP4FtiIb4J+eGN4CZ8AD+C3WHNhHPRkXxO642PhOvzO
/lvWqvoNvBJ0wDvDBrxaZJ4cm7PZWRSjbvzvP9aSyb+Zq3eB4fg0OAcz2M9n
fRCK43dYR8AbUIX9p7AOXw9zFBtYibeBYfjQcOz0zNtwnP0h1sZQHv8IVuPl
4Cm8EL5QnuAm/MH+AGut5LOOZD89O3MdvB70xqeqRvArqhMYoxiyP61zwUyY
yz5fZ8bbw4Us5or1s8m5ehHyknOWg/eCYYo9tAjnfFJWMyXwscox3hTG4+Og
Gf4OXFZc2U9MznndcE6VS535h3BMFcu9yWftzX58duYbWc3fr3XVKN433Asz
ss+eYX0r+TsjwjWu2n4TurB/POzK2VK8NHyC58Ng/BnohE+GazAo7OqpUviH
MAhvq5jjixQjvBUsC9eIakPPnMp+WvjdFZOZ+Lv6Dv6BwN8Px2o2/KhaCD9r
rmKGn2ctDQuVQ8UaZiXPgD/1ruHPKgY/4UfCZ1ONtg/XhGpBOZus2OkM2TOP
4r+Ec68eXo6vCMeiBKzEy0I7vADW4mvCvaUanxfuYfXuUlil2g17eZiFR7iW
9c5twzNKs0kzS7VeIfxs1XyrcA+tz2r2V/xS9qyv4Tf2V1krwT7orN4M92af
5FrLC9e2am4hvh0+V13D4vBM1CxUT36D7wvHVu/YPJwj5aYQPg7PTM1K9cjA
8Gf0P9XwgfCM02zbA5vwWtADf009hJ+En/Fu0FC9DFuTZ65qTe+kd1HNtQy/
s961A5xS3YZroxh8he8NzxLVYFV8gWZG8oytHO559fr9GazYh3tZNVMmXEOq
HdXAfPy78NmXw268Tzj3O2BbuCfVi4qhZpVirlgfSr4Lnoec5DtBd8UT4Vjr
ztC7twvPKsVgnXIb/i3lULO6Rjg2mtmabbXDs0Uzrmt4Bmr2jUy+G+rD5uQ7
Ygd+N3l2bkuelY3CZ9fMfFK5Dn9XPfqoaiGcG535EXwjDE3OmWKpO2JDckyV
qwbhZytnB/Hvw3ehztAxfGfprsqF58J3ku4iPfN/RU7g3Q==
          "]]}]}, 
      {RGBColor[0.880722, 0.611041, 0.142051], AbsoluteThickness[1.6], 
       Opacity[0.3], EdgeForm[None], 
       GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxFmHvc1+MZx5/ffVmIpNTS+bSQhJ5RmzBEqNbm2IaKxjogEmYjSRG1kVmY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          "]], PolygonBox[CompressedData["
1:eJwtlXnQjmUUxt/3PowtSSit+iwtlmlBJdn3nU/ZiyFLRUoRimTqQ6SsZStS
aVRf1ina+6fGH03baMoYtElGpbRj+l1z3X/85lznfd7nee7n3Nc5d8noyaV3
pUKhUAYVoHIUCj/xQ29oDJvJG0M79ED4FlaSlxHPhj7oi+EG9ACYhZ4NU9FH
i4VCK/RQGELeFcagCzAdPRI6oH8k/lz0Oy4nvwLq5d/WoFfDueStYAZ6HSxA
t4bv4TO4HrrBTK79R7wXpsBc8o5QP/mdvdG99M6i73kQfZo4LXnN48grwEz0
aFiKfhPWortADXQ36INuBm3QfxOP8LzuxAPwEb9tJlbROtD3wQT0d0WvrQH5
jXmNd6KPEk9ybRyxInmVcO1vhnboU8QLoSecRV4HmqMHwZPoJyDQE6Eq+jGY
hZ4NX0Ml8suIf/KO/cQPyTcRE5yBfhzmJD/jGNwT+VlwO/qO8NrGwnz0V9on
eEB7BAehU3JNPtfv+ubkGqu2jcjb5hpfib4KGqJ/43on9BH0cXR7rYH8UWiU
/J8ydGe4NHlPVOv7ySfnmn9DHCaPEWvCYPSg8No7wwb0erggueby9j7omD0+
nWvHibXgbhgf9oD2fgzMQe8llui98G/2oLynZ45Ef0q8BUbAbWGPy9uj8lr/
yc/WmtULh4jDk3uinPw1mJFroNoOJL8p11jeGEE+LHukLbpEe0beA55F9w33
2iLy59HPQRv0YngGfUn42kLoh94YvlYK76p3VSM9C+rJm2Evq6ffQb8V7t11
sCrcc+q1+fpu8lHhb68Nf8BF4V7tD5u0d7AUvQRah9+pd22AHWFPyAuryK9F
fww70E2hqL2WB5NrpN5SD6r31GN70L/Lg9xfTmwvr8MydC+YGl6z1jpJPYJ+
GuYl9+RyzRZ5Dv0IvI/+JLlXNxKXkU/RGtFz4RV0KfzK9ZXkK8IelPf0jGbk
L8MK9FNwjv6b722R3GvV4eHknnsJ3R+OFV0j3ds08rOhe7hmqlXf5N49M1wb
9fB76OHhWaw9XIyuBk2S31EzPMM0u/QNtdG/5Gc1z17bqpoke07eeVEzJdlD
V4dnkmZRh+RvnxDuDdXgS+KA8Nmgnv0re0B7Xxe+SD4jdDZohl0XnmGaXZoZ
WutOWJ285t3oITA4eeb2RJ8g1pF3k2dBl/BaNBPUez3C19SDe7PH5W317Fr0
D7lXdGY0JD+cvaGZpLPh1fBe6Yx4ITxzNWtVA+3N2HAva48WoReGZ6dm7DXh
matZq5lSC/12uFc0k05kj5bnbzgv7DF5SzNH3t4e9r48Pgk9LexVnXnb0FvC
s1F7pN5XT6uXNQPkdfWYekuebxGe2ZrVqukH6POhZbLn56EXhGe3zoSH5MXw
bNOZWzfcE+oFnfG70K+HZ+kaOJl8xups1Yy/Vb2b3Pt6h/bujfB/tYfq5Zbh
s1A9/T+ZCvln
          "]]}]}, {}, {}, {}, {}, {}}, {
      {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
       LineBox[CompressedData["
1:eJwl0D1SQjEUBtAHyIyAhVuwVwsc9kAnImzAQscfeI0CdkqFKKAbARRZACIL
EUFX4ch5Q3HmS3KTSXJ3TsJiNRYEQYEvkmQI2VYoc0yJLFOWav+8GT/yxD0j
3jmgQ4YmYz6ZccuPsz25RZcXnvmN3iGH7DFgnzx/an25S5s0d7wy4YM6DRb2
HskzTqM7zTdokiBO9OccDb45tDCXUTNCLqlwxQ3XXJDinE1aPFCLrXu3AkX7
J84=
        "]], LineBox[CompressedData["
1:eJwt0klQznEYwPE3WzNmZEQLpYUIHdSMEElkGS0OHVRka5lxIhzMWA/C3S5L
kn252qKcErKXna6WKIpsY3zMOHzm+87zPO/v9I8vWZW/MigQCDQQQn/WMd6w
nD9+z9MUXpJMPu/MG3Ugq1nBACpYy5p/j/JWNuh6LnGREHYRyk4GEcRmNrGR
CRSwgI/euKNhHKCS/ezjCr1pd3NbJzKEQjrN7ukwjrKdoVSTxjXq2MYRDnOV
vnT4712dzEKK+Gx2X6PIZiqvmEIxXfYPdTi5TOcNGRwjhhpiqWUGJxjBcUaS
RSs93lqiS5lNG7NYTglzeMJ3d6X6S8/rOM6RxAV+m5fpGObylB9mwXqD05xh
B2cZyzN+ulmm9TRwikROMpqZtPDNXT9N4AWjiCeTx3y1n695xPGIbrPFms5r
ppFDNA/4Yr9Ir3OQQ1QRySSa+eSmj4bznAgGk8pN3tv30svsZg9b2UsTt9jC
h//f/V+FXl/Y
        "]]}, 
      {RGBColor[0.880722, 0.611041, 0.142051], AbsoluteThickness[1.6], 
       LineBox[CompressedData["
1:eJwl01dsjWEYwPHvtGpFkCBqK7VqVoLYe9Ss4qLEqnlBe2HvvV3aapfaO67s
vWPPiA61LohVs/iJi1/+z/s+35eTnJwTlZSSkBwKgiCHTEMGn8KC4Gp4EHzW
rhrHbfNgHcJAPjoP0iSGUpazrGEM4xnHal549hZnzGX4YJ6s33WSftOW2oJK
3KAiPbhnd17ztLVuZwdbSWMbvXhgP1vnMIs/zrW0Jq/NbbU2u4hhN715aLdA
w5lPGA2oz1GOkEKIeRxgP2+8117rcZDDHKIPj+0W6xIWkZ8CPHGf6/vNI8Jc
hFgGkEmiZ5pynJOcoAT9ybJfqaVZQSSryP73vp6mGadoThfe25XUUhSnCVfI
cP+OzuZiXOa5cz9txE0a04miXOKZfV89xjKWs5TCNOQiTz3zloLm6xQiglgu
8Miuo3ZgIfkYyShGk8Be6rCHuuyjHXMJGMZwRhDPTqqTTg3a8MrnRGs1fpun
60xmcN+5p26iMhuJohUv7VJ1A1P44Zysm9lCFary0/1U/aXT9K520+6U4xx3
3OWw1jyBiYxlHespTwW+eOYr18y5Gkm230dW6P//8S/CSXgt
        "]], 
       LineBox[{612, 508, 602, 819, 860, 747, 875, 874, 873, 820, 949, 779, 
        910, 781, 909, 780, 748, 732, 911, 912, 880, 881, 749, 734, 854, 855, 
        824, 951, 953, 952, 856, 954, 955, 914, 785, 913, 786, 882, 915, 752, 
        790, 564, 528, 523, 516, 612}]}}}], {{}, {{}, 
     {GrayLevel[0], PointSize[0.018], AbsoluteThickness[1.6], 
      PointBox[{{-10.326831584361905`, 0.}, {2.2395390299972684`, 0.}, {
       14.80590964435644, 0.}}]}, {}}, {}, {}, {{}, {}}}, 
   {GrayLevel[0], Thickness[0.003], 
    LineBox[NCache[{{(-4) Pi, -1}, {4 Pi, -1}}, {{-12.566370614359172`, -1}, {
       12.566370614359172`, -1}}]], 
    LineBox[NCache[{{(-4) Pi, 0}, {4 Pi, 0}}, {{-12.566370614359172`, 0}, {
       12.566370614359172`, 0}}]], 
    LineBox[NCache[{{(-4) Pi, 1}, {4 Pi, 1}}, {{-12.566370614359172`, 1}, {
       12.566370614359172`, 1}}]], 
    LineBox[NCache[{{(-2) Pi, -2}, {(-2) Pi, 
        2}}, {{-6.283185307179586, -2}, {-6.283185307179586, 2}}]], 
    LineBox[{{0, -2}, {0, 2}}], 
    LineBox[NCache[{{2 Pi, -2}, {2 Pi, 2}}, {{6.283185307179586, -2}, {
       6.283185307179586, 2}}]]}},
  AspectRatio->1,
  Axes->{False, False},
  AxesLabel->{None, None},
  AxesOrigin->{Automatic, Automatic},
  DisplayFunction->Identity,
  Frame->True,
  FrameLabel->{{
     FormBox["\"v\"", TraditionalForm], 
     FormBox["\"\"", TraditionalForm]}, {
     FormBox["\"\[Phi]\"", TraditionalForm], 
     FormBox[
     "\"\\!\\(\\*SubscriptBox[\\(v\\), \\(s\\)]\\) = 0.9,  \
\\!\\(\\*SubscriptBox[\\(v\\), \\(c\\)]\\) = 0\"", TraditionalForm]}},
  FrameStyle->Thickness[0.004],
  FrameTicks->{{Automatic, Automatic}, {{{
       NCache[(-4) Pi, -12.566370614359172`], 
       FormBox[
        RowBox[{
          RowBox[{"-", "4"}], " ", "\[Pi]"}], TraditionalForm]}, {
       NCache[(-2) Pi, -6.283185307179586], 
       FormBox[
        RowBox[{
          RowBox[{"-", "2"}], " ", "\[Pi]"}], TraditionalForm]}, {0, 
       FormBox["0", TraditionalForm]}, {
       NCache[2 Pi, 6.283185307179586], 
       FormBox[
        RowBox[{"2", " ", "\[Pi]"}], TraditionalForm]}, {
       NCache[4 Pi, 12.566370614359172`], 
       FormBox[
        RowBox[{"4", " ", "\[Pi]"}], TraditionalForm]}}, None}},
  FrameTicksStyle->GrayLevel[0],
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImageSize->Medium,
  LabelStyle->{
    GrayLevel[0], FontSize -> 14},
  Method->{
   "ScalingFunctions" -> None, "TransparentPolygonMesh" -> True, 
    "AxesInFront" -> True},
  PlotRange->
   NCache[{{(-4) Pi, 4 Pi}, {-2, 2}}, {{-12.566370614359172`, 
     12.566370614359172`}, {-2, 2}}],
  PlotRangeClipping->True,
  PlotRangePadding->0,
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.710600340211226*^9, 3.7106824677809677`*^9, 
  3.710787448052081*^9, 3.717290987987389*^9, 3.717291946885146*^9, 
  3.717292342581213*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"plotBasins0", "[", 
  RowBox[{"0.5", ",", "400", ",", "0.05"}], "]"}]], "Input",
 CellChangeTimes->{{3.710600353409355*^9, 3.710600353801239*^9}, 
   3.717293355740464*^9}],

Cell[BoxData[
 GraphicsBox[{GraphicsComplexBox[CompressedData["
1:eJxknXdYFkfXhxU7IioiKihdEDWYKNYos4pijV2DNcYWNFY0BrsSI8ZYEmOJ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    "], {{
      {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
       Opacity[0.3], EdgeForm[None], 
       GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxMnXW4VUUbxW+dvvcC94Dd3d1idyt2txjYgoGBhYrdASZgC7ZigIiI3WJ3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          "]], PolygonBox[CompressedData["
1:eJwtnAnYTdX3xy+v9773cqdzzn3NFBmSsUwpKhmTVIY0CJEGiZSkZAghlaE5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          "]]}]}, 
      {RGBColor[0.880722, 0.611041, 0.142051], AbsoluteThickness[1.6], 
       Opacity[0.3], EdgeForm[None], 
       GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxMnXW4VUUbxbG79caJfc7hXuBeLnaL3YkBtthdiAmi2AEqgtjdYmOB3d3d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          "]], 
         PolygonBox[CompressedData["
1:eJwtnAnYjdXXxk9KJBWZvWd43zM953leGYsiKkkUKRoomVIiQ/MgVCohRabQ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          "]]}]}, {}, {}, {}, {}, {}}, {
      {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
       LineBox[CompressedData["
1:eJwt01lvjGEYxvFbi24zLTozLUXSSnBGqd0HsJY0cdBSEcSWaBNbSKwfQYJE
CQeWIBJEWge2Aw6Jr2AJaXWMNNppBeX3Jg7+uZ77eq77fp73nXcad3a3dU2I
iDcoQbJuQAtasQ/n0IPHeIuySRG/qyLWTI1Yi2tTIhozEU14VR3xGifTEevs
naLr6R/5jbQVG7AZmzDOH6+JyOp9qi9Dn9E+XiEVUateKNeMy87JqevwXGYR
75D5Pfx63nS84L/EYf5i+0doCx1xzlJ6VL2EHqPLaJG/gq7EcqzGKozyf7lD
lZkpVKLX3F5e3r3K1RWYK3vQrEvukFZXo0/uCbr48+x30/l0yMwx/T/xyH5n
1jPyBs0r0VeavEO5/fIXzZtjfcB6u9x3uaK+Per7erfyBnkDev/WRsyUnYUL
+mbTvXLbZPIyP/QN456+dl4/r1/fHfU79V26S36Gvt20gQ7IDCV3NfuW/TF6
mz7kfdF7w/omdshn5HPI4rO+gsyIfBHDuC43Sh/wO+W3OPNjcnd1e/L72W/j
ved9MjsvmzIrjfOe55u6gCtyV9Gh5zT/LM7gg76vZp2wPo4FZb4F32kzrad1
yMER4RWHUTENxod4aA1jw9hwfBgXlahAefK9YzJ89jERpf//K/8A17xpOQ==

        "]], LineBox[CompressedData["
1:eJwl13mcT/UeBvAzhhkVsyEhW2bqWma03ZY/Skr77VYoQokSIUsbrfay03Zx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        "]], LineBox[CompressedData["
1:eJwl1nmYTmUYx/GDSma3hhkzBrMYsq8zQ8wg25AthYoJ7WjfRWkhoZlCiz20
KxTqugpRZB9rthLaI6mrPX2eqz++1/fcv+e+n3POu5z3TS8e239MuSiKppeP
ouMxUdS8QhT9Gh9F2ypH0VasT4qiX9RbHDdOjKIJ1aLoIayTn5V/Ks+RPyhr
xOP5Z/km+RnezD3iougT/km9gT/GRnSXt7BPPpdWj6IU883VzXCFfWroH8wr
1Z87Xmymtp7jepP5qGyR7Ai/xHn2ydKbjSTrl5pN5Ex1N8eV9XXlZeoyx8+a
ibf+pf0SeJesVLaTn+FW9nuaSzANMzAdLeV17dGQHzcbmU1Tp6Kj/ePMd+DX
1A/ovx/56lh5Hr8qv092L3LVMfJsez1mr3MJUVTHegpayJ7Ss8P6VN7OMc5V
CUnhPeI4HDMXyxlmcs2UqA9bX2hmhWwBz8flzlVd3j7cl55aZg6pT+MUysJr
gFv1ZfIYHoexyLVPf3Nf2uc4juEfM631tcI0PU/hE31fWPscU9X19fQzN9/5
Wurrar0LRsiqVomiaqiMJPddhYfLkzhRncAJnMjXyOM5Xh3LcRzHV8tjOFZ9
IcdwJb5KXpErqc/jC3A+hsnLcwWcc43lOMJQeaHruoznudYWrrVA3RlPuo96
7mMKf6z+2/FRs831TJY9gY3yv+TNZHPN97XPET1/yg7xH3yY+8g/44PYhwPY
jyJ5e3sU8izzde3TTt0Wo+2fbH4Ur1GvDO8rRqpry6/l1fLlsrdRrK4lH8Gr
5G/JlmG4uqa8wDlmOkeac7Sx3hq9ZXv07EUZfte3m3vJ5+htqvdx8xv07grf
ETymTtfXU8+Lepro+U3dSc8Q2ULZhV7/f/V+KvuH/8as8PnSd6WeBXouMVdR
X089N8hektVWZ3pftshqOc5w/IK555Ft9np9i/R1MVsUrh83yy7Wl6a/MaeG
Pa33wCJzC7FNXx15I+vd5QtkDe03n7day5E3xE32Gu9ZOBvLMaeSdR6iZzAO
6x8Zvj88io8g1z4Hw/fA/DSc0HdEfRSjrU+XFTj3yfA8k10ne8M9TArfR2uF
1mZwKUrwqHyg3r1692EPis3s50N8GMMxAh3NTjZzCU/hiWb7m92hd4j17TyU
D6Kt69waXgtM0NvezDG9O9XDrL/imh40/7C1XGsTeRIewXh5X71L9C7FYvQ2
8xlywnNY3ctxE711zW7X+7KsSLbYvreYb2Yt3VpTrsfNeYy8JddXt+DWaIWx
8rbcDm3C9YTrxTh5PndAXrhvdMSt8s7cwD6dOIML+DZ5F85UF3IWd+Xb5Utc
Vx/Xly3b4XpfCc9o9JV1C58H+U75a7LXcVn4bZHnyHfJ3wi/fe79Te4u74Ey
+TJ1Y/lb3FPWC7vlb6svli8Pr52sCHvkK9RN5Cu5j6wv9srfUTeVvxvOLeuH
ffJV6mby1dxfNgD75WvU76Gf6xwoa+Q6D8jfD32ype73Dvd9ubXG1gbxFRiM
O+V99M7ROxcv4lIz83g/HwjP8PC6INlslpkUzuYbzfYy+5zeAuuzuZD3ISs8
F7gzKuuvrr8K1+Bic93MzdDfLnxPuD3vRQNzbcJnFv86PuH5cY5P8gBzX/M3
+Arf4VsMlOfZ7w773InbkWV+N1LM3qb+QN+H+EDfXeo68rt5rWxdWJPfo06V
38vrZR9hbfjtVqfJ7+f88H/Dvg+E50j4Hqo7YJBr+EH/j/gekXs9FX6D5T+F
3x31aS7PeeZOeE9y+YysgmyTPZ62Z0k4h7w0/K+ydhabrT2jzgj/YcL7E86p
Z6bjjuF5p+6Oa52rpte3Fi5CMmpjpLwOV3WelPAbzKk8Kvyv4erqNK7B6Txa
Xj/soa7HNbkBXxfe7wr//2/8Dy4lTjU=
        "]], LineBox[CompressedData["
1:eJwl1ne8j2UYx/GHQ9mUVUkSpYXMCNlbIZRxzGMrOxRKyiiUec6RvVfZe1Nk
RKFhZO8VQnb1vl/98Xl9zvW9rvv+Pc99nud3Ts4Wnd7qmCSKov5Jo+hBqihK
iImiYumiqGjaKPr40Sg6liGKPuK+2JkpiorId/BReR9Zb2xXF5Zv4yPyD2Uf
4Ad1IflWPizvJeuJLeqC8u/5D3kP2fv4Tt0gfRRt5k04pPeqa+muV1++UbYB
B+VF5d3kb8tPZ46id7iIrIusMHflPmmiqDMXUnfkgtwpXLP8PS6gbs/vogM+
lLfldmiFNmgd7kUexy3RDC3QHL3kTfkV+zTm/Nwk3KM8lvOpG3Feruf66mK9
61+HA+6hoV4DrFUXcB49rJvtXuqYq61fC/1kg82UsscgLslN9Ztgn3V7ccLc
QL0B2KMuFn531s21V2NzJaypY+ZT2TeysuqhZk/Kyvh5iJ8PWLcfxa3tb26e
uThr3zZTD4NkieYqmU/giuHs9NuF87fuFM6aqyCPD3uH60JJ+x3nM3pj5KPD
M6UuIR9oz/k+p609GujXR7zsVzO/YS9+wT6Mkf8c7g+78YbP+SnsJ9/FNdQ7
uTr/yKPkO7ia+ofwjGIbRsq38FZsxvfhucMI+UbehHXYgPUYLl8TfkdYidVY
ha/ky3kFlmAZluJL+SJejPlYiAUYFs6ev8UczMNcDJXP4tmYjpmYgSHyqTwN
kzAFk/GFfCJXdV/juQpP4M/lC53le87yvPM97ywr640Lz7fsnOx1Z36Wz+l9
LR+LM+pS8sHWL7C+g9lY/UaYIXsso2fAPlm5Xnjn9LuijDVHuTuu2OMarqKJ
dXOte8Z8LjyNBtbl5DnyJT7jA2tum70Ufud6OfRuqm+gnH2P6ffC3+qefIub
m11gfV6z+fASGlv7Ms+XL7PvR2b/MXvFbKzei3p9ZQ9k9/Gn/AXZ8/jWmvzJ
nCPi0BdbU3q2uZu5znjWnvHW5+YEPoM3XV8u9Ux7zMJdc8+p8yBRf7ast8++
J39eNla2jveE91Gvj94c/gbzsDd8F5nNbuYpPIkR4Z1CDZ+VTT3czxPM9rT2
ttkcspGyNbzL+kl6vfQm8hRMxm55e7OZzWRBJgyzJiuf5FMYgqHoYu0oa7ry
aN5mbTx3U4/hRCRgu7yNPVPZIzVS4jPrT6CKa02hftVcMVw3l0adFgP0i8ta
2O+GPJ1soGwFL7ZnCb04vde4JZfkJfLXuZW6FLfm0rxUXpbbqMtwWy7Hy+QV
uCLKozIqYbm8KldDFdRAdayQv8k18QZqoxZWyutwXbwVnv3w3GOVvH54lvEO
GqEhVssbcxPEohmaYo28RbgvNA/3Ee4Na+UtnUES9/6xM4i4Hx9HBWf4r+c0
v7lXcNVcUv2K8hhOhgLhs9zzNb3k6ofwibX90VReMFwDF+KF4RrMxYW/yfpL
zc6TlbffHZ+T28yzuKx/V30Pvc31QUN7PBfuk/OE5zX8rTPXDO/rLwrvQPhd
2Osv6x438wQu6l9X9zCz2MwsM0+GM7NPNn4K2TE7nJvZS2Y7mr3InfgIStvz
gvp330/7ccHc5fD+onN4XsN7aL8DejX5ICfY7w+upT7ER3AYifJjfBxHw98l
nAjfffLT4fsPp3AOZ/G1/AJfxHlcxiWMk1/hq/gTf+Eaxstv8E1cxy38jQny
O3wXt3Ef9zBR/g//iwdI4iwiTJLHcDIkxUNIHt5leYrwfLqvh8MzySnDey5P
zXXUqcLzyml4qjwdp0daPIIMmCbPyJnwKLIgM6aHc/A/304sivn/f8D/AL+Q
eyY=
        "]], LineBox[CompressedData["
1:eJwl1Xt0yGUcx/FHloWEnM6p/kr9RTcVKrrp4tZF6fpvzklmsyFUTNlmhtyL
cunmUlSKLm6xDUnZZmMbu2CGXOq/zimnc0iv7+mP9z6/7/v77Nnv+f2e37Pu
I/KG57ZJKRX70b5jSoMzUnr5qpQGdUqpb7eU/uySUh/ZG5nXpDSQ33hlSptc
F3VOaaT+K9jLLTRmEeZhAebjZ36OnItZeAezsYcvkTMxHTNQjJ/4QlmEt1GA
adjNT5VvYTLyMQW7+Dfkm5iI1zEJO/nX5ASMw1hrGi/L+bEyT50rc2WeLOPH
yDHqbJkjc2QpP1pmq7PkaDnbumehm2dwNf62/ix+VKyH78oN9Zy6yL/0XuVH
orN6CL/DnFtclxibpT8KldyKuHfzLIu1yOWygt9m7Hxjr5fnjZ2gt1TvOvW1
eNyc+4zb6nqecTnGZKOGWxPPy/jV8YzkYv33cKOx3fGPcav0VuIG9ZPmqvZ7
212/a1yefi7quI3xTsyxId6DXKG/HLcZeysuGjeV/0b/FvXNeNp8PeUFva/5
9eihHsbXmrPU9TJzjNcfhwZud+yDeIfxPM23Sx7my2WJujT2iyyTh/gdsXfU
22MvyVXmW4n7zX0fMrraT/yP+p/y/bl+aMsX8tv4T/h7uXtwGV/Ab+U/5u/m
+qINP43fwn/E9+F6I/GbuU24S/2std0pL1nPD9z3uEM9nO8l/+W/477F7epn
+HrrKHP9oXknxjtGC9dizHEcwTEcjeSb5RL30igXy9N+tyn6ejtdf2WeYnPk
Y5F+gfySmy5f9PfOxj7gq+I9y4x29pBvv1emtaDC9U3Og0pZhf2oRg0O4CBq
UYd6HMJhNKARTWjGERzFMbTgOFrRwd+b7F6m4CX3M0MWoij2EEowE+vd57B4
RrGX8L57bbXOD+SJeDbWe0ouVZ+Up/EbWvmz8hzO4A/8jhP8JPM+ZK7V5n5Q
rpFn8Jz7eEC9J84tXO69DlA/zz8s93K/oB3/iPoF/lH5GH6N8809ZOoNVA/C
Z+bcF+cdfwU/OL5/fM5XxFnIt+eHxjeMtXwlP4fvwD8R3yPW8VVxhvId+ae4
L7hy2Wg91XHm6u2PM1fWyCb+YJzD6gNyoayVzXx9fDeoQ0N8W7G/+A3eyxLk
Y0TG//8P/gNfSPEK
        "]]}, 
      {RGBColor[0.880722, 0.611041, 0.142051], AbsoluteThickness[1.6], 
       LineBox[CompressedData["
1:eJwl1nmU1mMYxvFnoqLFRE0iW1pM9uyEMs1MDSFLkSIioqOOynJkiVIhTXZa
JrsSlXDCsW8V7c1a0zpqtrRMzWKaZnye44/vud77uq/7fn7vvL/fO2+HoaNu
HJkQQhjSKISSpBCKsfL4EO7qEsJQrO8cwp8dQhju9f24D706hvBcpxAmIq9r
CLl4nF+FSuSoV5wawnJz3c8IYYJcipl1dv3Fu5KXrn5LvVV2iv4mugWbkcdf
JVdvVwMOIUP+JbmpWG332zKZXm+Tn0a30w28deYOPy2Ea+UPo33pK/pfO/Nl
utbsWpkU9avxXDOFyOGl8frJNzX3pDOb0MYosXuduWyZVJnXzV0vt8VcPq83
7yZ1C9mnzN3odXOvd5krR7bZPLl0uRnxWs1twwbe0XK3yreit9B39Oeg2lwV
nrZvAD9Rv0K9Dzn2ZZnPktuvrsQB/B3/nnZ2ku2MDuiIU7GFfwodYtdJ9A56
Mt3MP5Herj6BDqZz7f0YjU4PIQETXMMgfnv9j/iB1+C8Z/nH845DXfzcXNcc
1/ChzCH1B7SeFvOKnXOJ3KW4EBfjIuzkX0Dvtf98Oox+Zu5TNHdOM0x2znl6
3bBD/te2PjdUo9WxIXRFCgbhYWRiHn5BIaqQ2C6EZKRgEMZiGubiFxSiEhnt
Q+jifWQ6a7lryXJ2imvohSbeRypNRxr+1J8u9xd9mZ5m7lW6It5z9HW8hmT+
MfE9mDkf3VDr/V1Al9j5Nb4z87Ts93Q8XUjLZB5yz7Q2X4Vk+Xv17ou77RtO
F8mNlmmjH3jbzSxTF9Ev7J2v/6A6Ub9BvYW/VL2VLlZ/rD9C3VK/Pj4L/D/U
m+jn6vf171c31z+kbucajsPtzp6jN5hm0Xz5YXJN5coxi7dYPZvORJ7+Peom
emVYYNcM/t28xupadbbMb+ocOt17ycTA+HygkUxJ/Pua6R+fFQzAK+rV8nea
S9AvxnTeovi802p7q7BS5mfeqnhvqafqDVE3uJ8q1UneUz/7bsD1eF5/uexg
mTqZHfZO5i1UT4nff9hvbqnMj7xldJ56In+QutZMhfo3/g/q3+lc9Xj9geoa
/X3qNs7t47wM9MYT+j/J9pc5ILPduY/HZ0I9jj6G7/VvUlfob9N/hPep+lE6
Ft/q36Deq79VfzRvvnoMHYkl8ftLvVt/s35r15Dq7DS84G+eTkfJ9ZPZI7PL
dX5p5hv1V/TdeJ+YWxzvMTwg28PMCNqTlpspk0m0d4H+UXQhfSd+55lroW6J
y+K9bGaKM1upF8n0dUaJ+cv1hut1p1fiCpTyS+woxTzZq2W38fLtPMx8l/gM
YqJ9h6sL+I3jc4tk/p3xc9Nrqj4Cn9jRlX8XfxL/SN583jX2brf3DL2heqfT
u+mZtIh/Nr1HfRY9F+fg73iPuK6deNeOPnZs5OW6hhrfgcfItMZ45/yrrsV7
cm14A+16hn+Q9z4vw2yh2bZ6t+kl0XY4Fpv4Rc7YLbsH/2C2mb10Fn82Zqpn
4WazLc30p0fRgng/6JfJvqVfSt+mM3nrXecbXr8Z7x35I+Sb4UjkxvtEZof8
zvh/Bq/JFdMZ/Ovke7nm9XIb1VfH70X9nrzVvDV2F8kGuxLiPe69NqLXyF0l
syZ+huYK8KK5HrwVvFXmnlcvUb9Ae8sfNNuH1tGVMtlmNto9SX8DnRzfQ3ze
zearC1Atm2pmHC1UX27fFRitHoOx8TeLmVykydWoa+PnhJ9OdH1+D9X7XZTi
9SFah4Ooxb+oQTWqUIkD2I8K7MNe7MFu/INdKEcZSpP+/931HwPxrUU=
        "]], 
       LineBox[CompressedData["
1:eJwl1neciHUcB/DHnbLqRJxxIWTTkvZw7UV1aV2vloaSmZWGrJRxerWkaaat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        "]], 
       LineBox[CompressedData["
1:eJwl1vmbj2UUx/FHNUUosoxtypitmVFG2coyBqPFviaTMEhFtraJpJR2SzMM
FZJdtFDZl1D2vYX2+qG0/QVtep2rH97X5zmfc8793M92vt/00on9J1RJkuSF
i5JkcsMkGYKyxknSt1mS1Lw2SapkJkl1mtAatA//cnohI0mq0n9pNdqbfxn9
R5xC/6aX0l78i+klsQYuijXRk98yO0luQE5WkszIS5JsWiB+wvEV+qfTTeJv
cpLkazwuzlIzjU7FRrk/1H0ll8E/nm+b9HfeOd5v9Eta6Fxn6a/iz+gX+Byd
+Nlxflylb4w1a9Ms8WjHVdWPouvEG9SvR6n4Mv5Iupb/Fm8dRogv5Q+na/hr
eWtQIk7h77RuLdwlvhvDkKmuoz2cUfcpTuI0TqED/wT9Re9xep421X8Najre
TZuhzDrp9DHawno99F1Q/5eaf+mfNE8+N87veA9tjqfU59OZtJW+Afpqey4p
nnOteF60hfz12IuP8LzaAjqLPodn0Vbv3Xo76ylCJ9TTW0iH8ed5Ju31rFS7
V21duY5yN/NW8JbjI34HXnu8KW5on8voHv7NvJvwhrgBfyndzW/Ha4sl4lT+
YrqL34bXGq+L6/Nfozv5rXg34lVxPf4iuiPeP15LLBTX5VfS7fw69lkQ57bP
Bbz52BbvSdwXfjt+Ba8cW/m1+W15c13vXa77ejW1eM3plfQ6WsLPp1eIc2lN
mkeH8nPotchENrJwJ78ZzcA1SEdTDOGn0avRGDWs04TewW9Eq4sb0MtpQzqY
P8e+2tjfK/a7xX6ryaXKteLN5tVx7fsct8Yc8TzMRTu1Y/WPV/sA7o/96B1H
7+GXW7dYzza1R9Q2k7tPbrP4QzS17n75btgi7kq30vZq79f/YFy3nik0h94u
fxs+wcfx3qntQXfF+xDPHh31TtA7Tc/jeAzN9U6NPfIr7amvnkNqT6jNlyuL
2cU7yDuA4/xHeY9gvzjDPg/I947zinvFHmhndV3jPUnzDpuLZ8zH35HSSJ+4
Mr6bXO8Fzqr7Sc/PuEd/HV6xc5/jn+eN5S21t4V66sl1l6tLU1Efi/i3q/1B
7Qi139OR9DDy7e9b8Xcxl9QW6f1c7Y/iUvnF1i2P2SzXRa4arYHqqODfovZL
tV/hXMyfuD8xF6xbEnMJnfQl6gtpFTpHXzd9xRgov8g5JsfM1HPSGjPdu6dx
Wv6UOId/mg5S+wy/wDpn5M7wBvNe1T9F/7PxzcnNojfQ5+iD/Bfoi3geL+Ml
PBTvLp2L2XgF8/Awv4LORzkqsSCeJ39RfOfxTcccwGt4lL+ELsViLIuZgjL+
croiZg9WYWW8U/w1dC1W4y2sw1T+Bvo21uNdvINp/I10E96LWeO63o/3k/9h
fGfiD2I20c10On8rbSPeQrdjG57g76S7sAN7sBsz+EXuZRf0cy8XupcTeZnu
+WH3d3r04qT8kfid5B+lxzCDf53znJI7Ht8E+ltjQMx3/pPyLehTdJI1O6kr
RE/5+c4zLuaQ9fbq24eH1OWqP6bmYcd5jheoG6+uAy9T3D3mI+9eXrre7fom
qJ2Io2p2xFzGLepujd9cPZNi9tHJ9D59N8X8j9+GmFvWGh7zzVqr9HVR0xX7
5FfHb27MhXiHUd8a3eRSaTEdEe8/bRD7og3prXRkfG+0B25DL/REKb8P7Yve
6I9+GMUfSAdhABpZZzAdzR8Ss1h8B21C76Rj+CU0TTw05jXtbH8nXEthfHMx
13n74/9C/M9AEX9YzHn+x/H/grc+rpe/If47yA3HJ3Jvixu7H+/EvIjrwQH+
u+Im/PdiNsS+cZC/UZzG30RHx/5wiP+++Gr+BzG3eGNxmH9v7I+fbi8Vjf//
f/gfKzV5zQ==
        "]], LineBox[CompressedData["
1:eJwl1mW4VkUUhuENEhZh09LSCkgeUBSluxskpDuluxFQEAGRboMOE5ROERDp
7u4G77n88VzvXu9as/ae+WbmnDQN21ZqEyuKojKxoyhOsii6kDSKViaPolFp
o+hJpih6iod4jEcYyb9PH+AO7uEuRvBv08Lpo+gmLURv0eH8GzRGfI0WpNfp
MP4VehUXcRmXMJR/nl7AGZzDWQzhn6KncRwncQKD+UfpMRzCERzGIP4BehD7
sB//YiB/L/0Hf2MPdmMA/y+6C9uxEzvQn7+VbsMmbMFm9ONvoBuxDgXMaz3t
y/+T5hf/QfPRWhmiqCb2ZfFe7M4YRWvl1oR3izOl00e+BvaIq9O9tJi6sfrF
yxxF8REHRfSLS8fwJ2eNovpqD6ndo/YZfmwcFGfRc7SaSWrqqSkpXwLjeYnV
fKRPIlqUNpFvjFPGnQzfqC6hXAKcEGfTa5xxU/RqpK6MfGlM5KVQU1KP5LQE
bSnfAleNu4ID6orzk8lfFl9CDv0u0v1ySflJcE6cnb/F2OY4L25GL9Cy6mZ7
V1l15VAKZVAas/glwjfgYxRHMczkFw3zDGuGD/EBZvDfo+8jBoVRCNP5BWhB
5EV+5MM0/rs0D3IiN3JhKv9t+g6yIQey41t+VlrRnDPTCjQLncLPRMuLM4Z5
0LfoN/wMtKw4XZgXTU8n86dZ77bW4K41OBzWXC6tXBveHd5tHOKn4aXGdXFO
a7hVvjVuiG/hJiqoW6JnX3X90Bt19OtDF/N70drinrQW7Wx8J2zHNkS+pQt9
rNdTPEFlPVcaO8yY4RiCT4wdSlfwZxnTw5hn6XG1DeQGy33Gi8PL41t3eO6O
uOL4iIdqan82fpza8fgCTYz9kv7En6OmvzEv0VNqG8uNDfPiJeYlwkn+GN5o
vCjO51075fsigbgPTUhrqquDmJT2mntvgjtwERZjCZZiGZZjBVZiFVajp/eu
0KMX3aVfEe9orde4cAZoj3C2aJtw7ngL1G4I94Nv2um5d7gjPPeh6+jGcKcE
xXpsxqYAv64e9TBYn3nG/sYr6H1JPE8O+whnw3kSx/CT0SlhP4azxU8uLsRP
QaeGfY3z/JTiVBii73Rec99ygf8mLzWG8mfwW/Avhr3GS4th/Jn8lvxL/HS8
9BjOn8Vvxb/Mz8DLiBH8kWFf8meHPUzn0N/NYx5tK55L29H5dA1/IW0vXkC/
x3dYy6+lb20M0G+u3r/w8pvby56/UjMBp+VfERfgv0pfw9f8T/U7I/e6+A0M
1GMQmvInyjejk+ivelZXVwM95WerXcXLq99zYT5qRob7Uf558QthH6jrjYZ6
jJJrRD+nq42roq4quob1VLs03Ct6xfIcO+xndXXVHwv3uLhbWF+6TN1AuXpy
A2h9Oogu51dUWwntwm+ndg4vl573nM3y4e7BEfn74tz8B7S92or8SvoclXvI
e4QO/I6ozK8kX4VWpnP1rEqriqvQarQancevQauLq9MatCadz69Na4a/e2FO
4Z7BAn592iDMBQ3DXYGF/MbhfIf1QtPwG4Xfmt887Lvwm4T9FPZa2Af8NmG/
oHXYH2HP4Ad+R9oJHdAFnfEjv1u4c9AVPdAdi/jlzL88Wpn3VOs3Kdzp1uma
9UipJhUOhrMQ7nl+KXPa7I5Ilez//5X+A0HyhfY=
        "]], LineBox[CompressedData["

1:eJwl0cdKH1EYQPHP1zCIJPbeNRE0+Aq+gGDEjWLvbjR7YwPfwY0t0cT6t/eu
j+DaloDb/MDF4cx37tw7M8zHxvb6tqSIGEZNSsRackQtJ7Du+iE1YoM3sYUE
trGDXexhHwc4xBGOcYJ5vH2w9smeHHuwiQS2sK9v8FC65/Igr/OevsoD5t/c
z394V5/Ni5jOiKjif5kRfdZWrE1plVoF/uq9+rI+qZdrZXjVe/Rf+oReqpXg
Re/Wf+rjerFWhGe9S1/SC80F+JoWkc9P1hb1BeSZa/VcftTntTlkmWv0a2f+
QLZ5jHO4wX1nvufOffe4xi1ucKpf8hXO8d07XPCJfsaj5lMe4S/OqsZnzDi7
07kdaEYrWtCOOu/RxN8y3//zf98+W2M=
        "]]}}}], {{}, {{}, 
     {GrayLevel[0], PointSize[0.018], AbsoluteThickness[1.6], 
      PointBox[{{-11.519173063162574`, 0.}, {1.0471975511965979`, 0.}, {
       13.61356816555577, 0.}}]}, {}}, {}, {}, {{}, {}}}, 
   {GrayLevel[0], Thickness[0.003], 
    LineBox[NCache[{{(-4) Pi, -1}, {4 Pi, -1}}, {{-12.566370614359172`, -1}, {
       12.566370614359172`, -1}}]], 
    LineBox[NCache[{{(-4) Pi, 0}, {4 Pi, 0}}, {{-12.566370614359172`, 0}, {
       12.566370614359172`, 0}}]], 
    LineBox[NCache[{{(-4) Pi, 1}, {4 Pi, 1}}, {{-12.566370614359172`, 1}, {
       12.566370614359172`, 1}}]], 
    LineBox[NCache[{{(-2) Pi, -2}, {(-2) Pi, 
        2}}, {{-6.283185307179586, -2}, {-6.283185307179586, 2}}]], 
    LineBox[{{0, -2}, {0, 2}}], 
    LineBox[NCache[{{2 Pi, -2}, {2 Pi, 2}}, {{6.283185307179586, -2}, {
       6.283185307179586, 2}}]]}},
  AspectRatio->1,
  Axes->{False, False},
  AxesLabel->{None, None},
  AxesOrigin->{Automatic, Automatic},
  DisplayFunction->Identity,
  Frame->True,
  FrameLabel->{{
     FormBox["\"v\"", TraditionalForm], 
     FormBox["\"\"", TraditionalForm]}, {
     FormBox["\"\[Phi]\"", TraditionalForm], 
     FormBox[
     "\"\\!\\(\\*SubscriptBox[\\(v\\), \\(s\\)]\\) = 0.5,  \
\\!\\(\\*SubscriptBox[\\(v\\), \\(c\\)]\\) = 0\"", TraditionalForm]}},
  FrameStyle->Thickness[0.004],
  FrameTicks->{{Automatic, Automatic}, {{{
       NCache[(-4) Pi, -12.566370614359172`], 
       FormBox[
        RowBox[{
          RowBox[{"-", "4"}], " ", "\[Pi]"}], TraditionalForm]}, {
       NCache[(-2) Pi, -6.283185307179586], 
       FormBox[
        RowBox[{
          RowBox[{"-", "2"}], " ", "\[Pi]"}], TraditionalForm]}, {0, 
       FormBox["0", TraditionalForm]}, {
       NCache[2 Pi, 6.283185307179586], 
       FormBox[
        RowBox[{"2", " ", "\[Pi]"}], TraditionalForm]}, {
       NCache[4 Pi, 12.566370614359172`], 
       FormBox[
        RowBox[{"4", " ", "\[Pi]"}], TraditionalForm]}}, None}},
  FrameTicksStyle->GrayLevel[0],
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImageSize->Medium,
  LabelStyle->{
    GrayLevel[0], FontSize -> 14},
  Method->{
   "ScalingFunctions" -> None, "TransparentPolygonMesh" -> True, 
    "AxesInFront" -> True},
  PlotRange->
   NCache[{{(-4) Pi, 4 Pi}, {-2, 2}}, {{-12.566370614359172`, 
     12.566370614359172`}, {-2, 2}}],
  PlotRangeClipping->True,
  PlotRangePadding->0,
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.7106004905696507`*^9, 3.7106826075875483`*^9, 
  3.710787582915285*^9, 3.7172949321029263`*^9, 3.7172962919000797`*^9, 
  3.7172975631790323`*^9, 3.7172993579390078`*^9, 3.7173006045498447`*^9, 
  3.717302842998438*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["1 state attractor", "Title",
 CellChangeTimes->{{3.710703354220295*^9, 3.710703394153265*^9}, {
  3.717442345187336*^9, 3.7174423563446617`*^9}}],

Cell[CellGroupData[{

Cell[TextData[{
 Cell[BoxData[
  FormBox[
   RowBox[{"(", 
    RowBox[{"v", ",", 
     SubscriptBox["v", "c"]}]}], TraditionalForm]]],
 "): ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["V", "0"], "\[Rule]", "0"}], TraditionalForm]]],
 " limit"
}], "Chapter",
 CellChangeTimes->{{3.710703563186775*^9, 3.710703570961725*^9}, {
  3.710784327154557*^9, 3.710784366609646*^9}, {3.7173553879257317`*^9, 
  3.7173553931602*^9}}],

Cell[TextData[{
 "Define function that plots the 1 state attractor in ",
 Cell[BoxData[
  FormBox[
   RowBox[{"(", 
    RowBox[{"v", ",", 
     SubscriptBox["v", "c"]}], ")"}], TraditionalForm]]],
 " space for a given ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["v", "s"], TraditionalForm]]],
 " value."
}], "Text",
 CellChangeTimes->{{3.710703572705634*^9, 3.710703603640291*^9}, {
  3.710704006184936*^9, 3.71070401553522*^9}, {3.710705372231855*^9, 
  3.7107053769264307`*^9}, {3.710706106217256*^9, 3.710706120183467*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"ClearAll", "[", 
   RowBox[{
   "vS", ",", "tMax", ",", "col", ",", "Q", ",", "\[Alpha]", ",", "\[Gamma]", 
    ",", "\[Phi]E", ",", "vE", ",", "vCE", ",", "\[Phi]", ",", "v", ",", "vC",
     ",", "t", ",", "sol", ",", "endT", ",", "arrowPos"}], "]"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"plotAttractor1v", "[", 
   RowBox[{
    RowBox[{"vS_", "?", "NumericQ"}], ",", 
    RowBox[{"tMax_", "?", "NumericQ"}], ",", 
    RowBox[{"col_", "?", "ColorQ"}], ",", 
    RowBox[{"arrowPos_", "?", "NumericQ"}]}], "]"}], ":=", 
  "\[IndentingNewLine]", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"Q", "=", "1.1"}], ",", 
      RowBox[{"\[Alpha]", "=", "4.6"}], ",", 
      RowBox[{"\[Gamma]", "=", "0.05"}], ",", "\[Phi]E", ",", "vE", ",", 
      "vCE", ",", "\[Phi]", ",", "v", ",", "vC", ",", "sol", ",", "endT"}], 
     "}"}], ",", "\[IndentingNewLine]", "\[IndentingNewLine]", 
    RowBox[{"(*", " ", 
     RowBox[{"Map", " ", "initial", " ", "phase", " ", "point", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "2"}], "\[Pi]"}], ",", "2", ",", "0"}], ")"}], " ", 
      "to", " ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"\[Phi]E", ",", "vE", ",", "vCE"}], ")"}], "[", "tMax", 
       "]"}]}], " ", "*)"}], "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"{", 
       RowBox[{"\[Phi]E", ",", "vE", ",", "vCE"}], "}"}], "=", 
      RowBox[{
       RowBox[{"Reap", "[", 
        RowBox[{"NDSolve", "[", 
         RowBox[{
          RowBox[{"{", "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{
             RowBox[{"\[Phi]", "[", "0", "]"}], "\[Equal]", 
             RowBox[{
              RowBox[{"-", "2"}], "\[Pi]"}]}], ",", 
            RowBox[{
             RowBox[{"v", "[", "0", "]"}], "\[Equal]", "2"}], ",", 
            RowBox[{
             RowBox[{"vC", "[", "0", "]"}], "\[Equal]", "0"}], ",", 
            "\[IndentingNewLine]", 
            RowBox[{
             RowBox[{
              RowBox[{"\[Phi]", "'"}], "[", "t", "]"}], "\[Equal]", 
             RowBox[{"v", "[", "t", "]"}]}], ",", "\[IndentingNewLine]", 
            RowBox[{
             RowBox[{
              RowBox[{"v", "'"}], "[", "t", "]"}], "\[Equal]", 
             RowBox[{
              FractionBox["1", 
               SuperscriptBox["Q", "2"]], 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"1", "+", "\[Gamma]"}], ")"}], " ", 
                 RowBox[{"(", 
                  RowBox[{"vS", "-", 
                   RowBox[{"v", "[", "t", "]"}], "-", 
                   RowBox[{"Sin", "[", 
                    RowBox[{
                    FractionBox["1", "2"], 
                    RowBox[{"\[Phi]", "[", "t", "]"}]}], "]"}]}], ")"}]}], 
                "-", 
                RowBox[{"vC", "[", "t", "]"}]}], ")"}]}]}], ",", 
            "\[IndentingNewLine]", 
            RowBox[{
             RowBox[{
              RowBox[{"vC", "'"}], "[", "t", "]"}], "\[Equal]", 
             RowBox[{
              FractionBox["\[Alpha]", 
               SuperscriptBox["Q", "2"]], 
              RowBox[{"(", 
               RowBox[{"vS", "-", 
                RowBox[{"v", "[", "t", "]"}], "-", 
                RowBox[{"vC", "[", "t", "]"}], "-", 
                RowBox[{"Sin", "[", 
                 RowBox[{
                  FractionBox["1", "2"], 
                  RowBox[{"\[Phi]", "[", "t", "]"}]}], "]"}]}], ")"}]}]}]}], 
           "}"}], ",", "\[IndentingNewLine]", 
          RowBox[{"{", "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"t", ",", "0", ",", "tMax"}], "}"}], ",", 
          RowBox[{"Method", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{"\"\<EventLocator\>\"", ",", 
             RowBox[{"\"\<Event\>\"", "\[Rule]", 
              RowBox[{"(", 
               RowBox[{"t", "\[Equal]", "tMax"}], ")"}]}], ",", 
             "\[IndentingNewLine]", 
             RowBox[{"\"\<EventAction\>\"", "\[RuleDelayed]", 
              RowBox[{"Sow", "[", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"\[Phi]", "[", "t", "]"}], ",", 
                 RowBox[{"v", "[", "t", "]"}], ",", 
                 RowBox[{"vC", "[", "t", "]"}]}], "}"}], "]"}]}]}], "}"}]}]}],
          "]"}], "]"}], "\[LeftDoubleBracket]", 
       RowBox[{
        RowBox[{"-", "1"}], ",", "1", ",", "1"}], "\[RightDoubleBracket]"}]}],
      ";", "\[IndentingNewLine]", "\[IndentingNewLine]", 
     RowBox[{"(*", " ", 
      RowBox[{"Flow", " ", "to", " ", "1", " ", "state", " ", 
       RowBox[{"(", 
        RowBox[{
        "if", " ", "it", " ", "exists", " ", "at", " ", "given", " ", 
         SubscriptBox["v", "s"]}], ")"}], " ", "and", " ", "return", " ", 
       "subsequent", " ", "trajectory"}], " ", "*)"}], "\[IndentingNewLine]", 
     
     RowBox[{"sol", "=", 
      RowBox[{"NDSolve", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{"\[Phi]", "[", "0", "]"}], "\[Equal]", "\[Phi]E"}], ",", 
          RowBox[{
           RowBox[{"v", "[", "0", "]"}], "\[Equal]", "vE"}], ",", 
          RowBox[{
           RowBox[{"vC", "[", "0", "]"}], "\[Equal]", "vCE"}], ",", 
          "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{
            RowBox[{"\[Phi]", "'"}], "[", "t", "]"}], "\[Equal]", 
           RowBox[{"v", "[", "t", "]"}]}], ",", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{
            RowBox[{"v", "'"}], "[", "t", "]"}], "\[Equal]", 
           RowBox[{
            FractionBox["1", 
             SuperscriptBox["Q", "2"]], 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"(", 
                RowBox[{"1", "+", "\[Gamma]"}], ")"}], " ", 
               RowBox[{"(", 
                RowBox[{"vS", "-", 
                 RowBox[{"v", "[", "t", "]"}], "-", 
                 RowBox[{"Sin", "[", 
                  RowBox[{
                   FractionBox["1", "2"], 
                   RowBox[{"\[Phi]", "[", "t", "]"}]}], "]"}]}], ")"}]}], "-", 
              RowBox[{"vC", "[", "t", "]"}]}], ")"}]}]}], ",", 
          "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{
            RowBox[{"vC", "'"}], "[", "t", "]"}], "\[Equal]", 
           RowBox[{
            FractionBox["\[Alpha]", 
             SuperscriptBox["Q", "2"]], 
            RowBox[{"(", 
             RowBox[{"vS", "-", 
              RowBox[{"v", "[", "t", "]"}], "-", 
              RowBox[{"vC", "[", "t", "]"}], "-", 
              RowBox[{"Sin", "[", 
               RowBox[{
                FractionBox["1", "2"], 
                RowBox[{"\[Phi]", "[", "t", "]"}]}], "]"}]}], ")"}]}]}]}], 
         "}"}], ",", "\[IndentingNewLine]", 
        RowBox[{"{", 
         RowBox[{"\[Phi]", ",", "v", ",", "vC"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"t", ",", "0", ",", "200"}], "}"}], ",", 
        RowBox[{"Method", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{"\"\<EventLocator\>\"", ",", 
           RowBox[{"\"\<Event\>\"", "\[Rule]", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"\[Phi]", "[", "t", "]"}], "\[Equal]", 
              RowBox[{"\[Phi]E", "+", 
               RowBox[{"4", "\[Pi]"}]}]}], ")"}]}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{"\"\<EventAction\>\"", "\[RuleDelayed]", 
            RowBox[{"Throw", "[", 
             RowBox[{
              RowBox[{"endT", "=", "t"}], ",", "\"\<StopIntegration\>\""}], 
             "]"}]}]}], "}"}]}]}], "]"}]}], ";", "\[IndentingNewLine]", 
     "\[IndentingNewLine]", 
     RowBox[{"(*", " ", 
      RowBox[{"Return", " ", "1", " ", "state", " ", "attractor"}], " ", 
      "*)"}], "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"ParametricPlot", "[", 
       RowBox[{
        RowBox[{"Evaluate", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"vC", "[", "t", "]"}], ",", 
            RowBox[{"v", "[", "t", "]"}]}], "}"}], "/.", "sol"}], "]"}], ",", 
        
        RowBox[{"{", 
         RowBox[{"t", ",", "0", ",", "endT"}], "}"}], ",", 
        RowBox[{"PlotStyle", "\[Rule]", "col"}]}], "]"}], "/.", 
      RowBox[{
       RowBox[{"Line", "[", "x__", "]"}], "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Arrowheads", "[", 
          RowBox[{"{", 
           RowBox[{"{", 
            RowBox[{"Automatic", ",", "arrowPos"}], "}"}], "}"}], "]"}], ",", 
         
         RowBox[{"Arrow", "[", "x", "]"}]}], "}"}]}]}]}]}], "]"}]}]}], "Input",\

 CellChangeTimes->{{3.710703612185732*^9, 3.710703613146097*^9}, {
   3.710703645087953*^9, 3.7107038250095987`*^9}, {3.7107038651203623`*^9, 
   3.710703925800755*^9}, {3.710703966836862*^9, 3.7107039711892033`*^9}, {
   3.7107040284227467`*^9, 3.710704103911132*^9}, {3.710704178547552*^9, 
   3.710704218489841*^9}, {3.710704287232888*^9, 3.710704302735257*^9}, {
   3.710704453096983*^9, 3.710704469639659*^9}, {3.7107045058389473`*^9, 
   3.710704522036879*^9}, {3.7107046199149303`*^9, 3.710705014168984*^9}, {
   3.7107050627339163`*^9, 3.710705064581814*^9}, 3.710705380970055*^9, {
   3.71070553812418*^9, 3.710705545777363*^9}, {3.710705876236657*^9, 
   3.710705974584722*^9}, {3.710708729182864*^9, 3.710708734523841*^9}, 
   3.710708917711267*^9, {3.7107765702372723`*^9, 3.710776574826092*^9}, {
   3.710776616626152*^9, 3.7107766206742764`*^9}, {3.710776666008458*^9, 
   3.7107766985264397`*^9}, {3.710784842006604*^9, 3.710784866724958*^9}, {
   3.710786067923798*^9, 3.710786094881473*^9}, {3.717282083500925*^9, 
   3.717282090324587*^9}, 3.717355908889283*^9, {3.717442430121669*^9, 
   3.7174424533615294`*^9}, 3.717442503445665*^9}],

Cell[TextData[{
 "\nPlot 1 state attractors for a range of ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["v", "s"], TraditionalForm]],
  FormatType->"TraditionalForm"],
 " values:"
}], "Text",
 CellChangeTimes->{{3.7107061273757668`*^9, 3.710706150158072*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"cdata", "=", 
   RowBox[{"ColorData", "[", 
    RowBox[{"97", ",", "\"\<ColorList\>\""}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"vSvals", "=", 
   RowBox[{"{", 
    RowBox[{"0.6", ",", "0.8", ",", "1", ",", "1.25", ",", "1.5"}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"aPos", "=", 
   RowBox[{"{", 
    RowBox[{"0.21", ",", "0.4", ",", "0.46", ",", "0.13", ",", "0.3"}], 
    "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"p", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"plotAttractor1v", "[", 
      RowBox[{
       RowBox[{
       "vSvals", "\[LeftDoubleBracket]", "n", "\[RightDoubleBracket]"}], ",", 
       "6000", ",", 
       RowBox[{
       "cdata", "\[LeftDoubleBracket]", "n", "\[RightDoubleBracket]"}], ",", 
       RowBox[{
       "aPos", "\[LeftDoubleBracket]", "n", "\[RightDoubleBracket]"}]}], 
      "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"n", ",", "1", ",", "5"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"pos", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.88"}], ",", "0.28"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.91"}], ",", "0.58"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.84"}], ",", "0.83"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.85"}], ",", "1.12"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.8"}], ",", "1.41"}], "}"}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lbl", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"Graphics", "[", 
      RowBox[{"Text", "[", 
       RowBox[{
        RowBox[{"Style", "[", 
         RowBox[{
          RowBox[{
           RowBox[{
           "StringTemplate", "[", 
            "\"\<\!\(\*SubscriptBox[\(v\), \(s\)]\) = `a`\>\"", "]"}], "[", 
           RowBox[{"<|", 
            RowBox[{"\"\<a\>\"", "\[Rule]", 
             RowBox[{
             "vSvals", "\[LeftDoubleBracket]", "n", 
              "\[RightDoubleBracket]"}]}], "|>"}], "]"}], ",", 
          RowBox[{"FontSize", "\[Rule]", "14"}], ",", 
          RowBox[{"FontColor", "\[Rule]", 
           RowBox[{
           "cdata", "\[LeftDoubleBracket]", "n", 
            "\[RightDoubleBracket]"}]}]}], "]"}], ",", 
        RowBox[{
        "pos", "\[LeftDoubleBracket]", "n", "\[RightDoubleBracket]"}]}], 
       "]"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"n", ",", "1", ",", "5"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Show", "[", 
  RowBox[{
   RowBox[{"Join", "[", 
    RowBox[{"p", ",", "lbl"}], "]"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "1.2"}], ",", "1.2"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", "1.8"}], "}"}]}], "}"}]}], ",", 
   RowBox[{"AspectRatio", "\[Rule]", "Full"}], ",", 
   RowBox[{"Frame", "\[Rule]", "True"}], ",", 
   RowBox[{"FrameStyle", "\[Rule]", 
    RowBox[{"Thickness", "[", "0.003", "]"}]}], ",", 
   RowBox[{"PlotRangePadding", "\[Rule]", "0"}], ",", 
   RowBox[{"GridLines", "\[Rule]", "Automatic"}], ",", 
   RowBox[{"FrameTicks", "\[Rule]", "Automatic"}], ",", 
   RowBox[{"FrameTicksStyle", "\[Rule]", "Black"}], ",", 
   RowBox[{"LabelStyle", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"Black", ",", 
      RowBox[{"FontSize", "\[Rule]", "14"}]}], "}"}]}], ",", 
   RowBox[{"FrameLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"\"\<v\>\"", ",", "\"\<\>\""}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
       "\"\<\!\(\*SubscriptBox[\(v\), \(c\)]\)\>\"", ",", "\"\<\>\""}], 
       "}"}]}], "}"}]}], ",", 
   RowBox[{"ImageSize", "\[Rule]", "Medium"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.710706000759252*^9, 3.710706004644423*^9}, 
   3.710706037214898*^9, {3.710706143103284*^9, 3.710706259330122*^9}, {
   3.7107063065296593`*^9, 3.710706418595367*^9}, {3.7107064507159348`*^9, 
   3.710706726326672*^9}, {3.710707005876616*^9, 3.7107070822564*^9}, {
   3.7107071990043907`*^9, 3.710707224314292*^9}, {3.710707280705373*^9, 
   3.710707285672772*^9}, {3.710707329039289*^9, 3.710707352389803*^9}, {
   3.710707412748127*^9, 3.710707621553985*^9}, {3.710707658688671*^9, 
   3.710707738893084*^9}, {3.710707775188636*^9, 3.7107079329910517`*^9}, {
   3.710707983028253*^9, 3.7107081773001833`*^9}, {3.710708256281591*^9, 
   3.710708256855842*^9}, {3.710708837048049*^9, 3.710708848711232*^9}, {
   3.7107089322697077`*^9, 3.710709103158684*^9}, {3.710776721002119*^9, 
   3.71077672127882*^9}, {3.710776755477022*^9, 3.71077675607349*^9}, {
   3.710776786734151*^9, 3.710776807788189*^9}, {3.7107768476524143`*^9, 
   3.710777002594223*^9}, {3.717282160090372*^9, 3.717282214334758*^9}, {
   3.717282246253776*^9, 3.71728254034505*^9}, {3.717340072318059*^9, 
   3.717340078572639*^9}, 3.717355910744754*^9, {3.7174338912160673`*^9, 
   3.7174338961923122`*^9}, {3.7174346270671597`*^9, 
   3.7174346404667597`*^9}, {3.717441315532505*^9, 3.717441343083536*^9}, {
   3.7174417843455553`*^9, 3.7174417865131683`*^9}, {3.71744188304727*^9, 
   3.717441928499571*^9}, 3.717442073039645*^9, {3.717442464247237*^9, 
   3.717442644078425*^9}}],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    TagBox[
     {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], Opacity[
      1.], FaceForm[Opacity[0.3]], 
      {Arrowheads[{{Automatic, 0.21}}], ArrowBox[CompressedData["
1:eJwV2nc81P8fAHAaRHYpRUXJphAi9SIjIrJXyU5lywjt7EhoKpQdSloS9z57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        "]]}},
     Annotation[#, "Charting`Private`Tag$81444320#1"]& ]}, {{}, {}, 
    TagBox[
     {RGBColor[0.880722, 0.611041, 0.142051], AbsoluteThickness[1.6], Opacity[
      1.], FaceForm[Opacity[0.3]], 
      {Arrowheads[{{Automatic, 0.4}}], ArrowBox[CompressedData["
1:eJwV2nk0Vd8XAHChQQopQ1GhKPmiZMhQG6EQZaYMpWQsZUhoQIQmoQglRJOU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        "]]}},
     Annotation[#, "Charting`Private`Tag$81444444#1"]& ]}, {{}, {}, 
    TagBox[
     {RGBColor[0.560181, 0.691569, 0.194885], AbsoluteThickness[1.6], Opacity[
      1.], FaceForm[Opacity[0.3]], 
      {Arrowheads[{{Automatic, 0.46}}], ArrowBox[CompressedData["
1:eJwV2nk0lV0UB2AJzRlTSWaaPjNRyRYiUaSkCAnJVCRKkqEUEhpFKVGmNMiU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        "]]}},
     Annotation[#, "Charting`Private`Tag$81444568#1"]& ]}, {{}, {}, 
    TagBox[
     {RGBColor[0.922526, 0.385626, 0.209179], AbsoluteThickness[1.6], Opacity[
      1.], FaceForm[Opacity[0.3]], 
      {Arrowheads[{{Automatic, 0.13}}], ArrowBox[CompressedData["
1:eJwV2nk4VG0UAHBFSJQiKomKlCJEhXIQaaGIsiQtypIsrbJFSouULSJfIUul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        "]]}},
     Annotation[#, "Charting`Private`Tag$81444692#1"]& ]}, {{}, {}, 
    TagBox[
     {RGBColor[0.528488, 0.470624, 0.701351], AbsoluteThickness[1.6], Opacity[
      1.], FaceForm[Opacity[0.3]], 
      {Arrowheads[{{Automatic, 0.3}}], ArrowBox[CompressedData["
1:eJwd2Xc81P8fAPBsSUkRGWUmlFD2eBkZJZFklBGRokJLUlpoSFIqpWFEEaVE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        "]]}},
     Annotation[#, "Charting`Private`Tag$81444816#1"]& ]}, InsetBox[
    StyleBox["\<\"\\!\\(\\*SubscriptBox[\\(v\\), \\(s\\)]\\) = 0.6\"\>",
     StripOnInput->False,
     FontSize->14,
     FontColor->RGBColor[0.368417, 0.506779, 0.709798]], {-0.88, 0.28}], 
   InsetBox[
    StyleBox["\<\"\\!\\(\\*SubscriptBox[\\(v\\), \\(s\\)]\\) = 0.8\"\>",
     StripOnInput->False,
     FontSize->14,
     FontColor->RGBColor[0.880722, 0.611041, 0.142051]], {-0.91, 0.58}], 
   InsetBox[
    StyleBox["\<\"\\!\\(\\*SubscriptBox[\\(v\\), \\(s\\)]\\) = 1\"\>",
     StripOnInput->False,
     FontSize->14,
     FontColor->RGBColor[0.560181, 0.691569, 0.194885]], {-0.84, 0.83}], 
   InsetBox[
    StyleBox["\<\"\\!\\(\\*SubscriptBox[\\(v\\), \\(s\\)]\\) = 1.25\"\>",
     StripOnInput->False,
     FontSize->14,
     FontColor->RGBColor[0.922526, 0.385626, 0.209179]], {-0.85, 1.12}], 
   InsetBox[
    StyleBox["\<\"\\!\\(\\*SubscriptBox[\\(v\\), \\(s\\)]\\) = 1.5\"\>",
     StripOnInput->False,
     FontSize->14,
     FontColor->RGBColor[0.528488, 0.470624, 0.701351]], {-0.8, 1.41}]},
  AspectRatio->Full,
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0.12029394064697817`},
  DisplayFunction->Identity,
  Frame->True,
  FrameLabel->{{
     FormBox["\"v\"", TraditionalForm], 
     FormBox["\"\"", TraditionalForm]}, {
     FormBox[
     "\"\\!\\(\\*SubscriptBox[\\(v\\), \\(c\\)]\\)\"", TraditionalForm], 
     FormBox["\"\"", TraditionalForm]}},
  FrameStyle->Thickness[0.003],
  FrameTicks->Automatic,
  FrameTicksStyle->GrayLevel[0],
  GridLines->Automatic,
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImageSize->Medium,
  LabelStyle->{
    GrayLevel[0], FontSize -> 14},
  Method->{"ScalingFunctions" -> None},
  PlotRange->{{-1.2, 1.2}, {0, 1.8}},
  PlotRangeClipping->True,
  PlotRangePadding->0,
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{{3.7107767445100718`*^9, 3.710776759497746*^9}, {
   3.710776792670054*^9, 3.710776811992856*^9}, {3.710776851640917*^9, 
   3.710777006197586*^9}, {3.710784846943346*^9, 3.7107848712382393`*^9}, 
   3.710804356651207*^9, 3.7172821009985027`*^9, {3.717282163036861*^9, 
   3.717282216635345*^9}, {3.717282250955653*^9, 3.717282542218686*^9}, {
   3.717340074174336*^9, 3.717340080642988*^9}, 3.717355918238657*^9, 
   3.717356354101462*^9, 3.7174338981457233`*^9, {3.717434631138466*^9, 
   3.717434642696228*^9}, {3.717441317628764*^9, 3.717441344808694*^9}, 
   3.71744180184556*^9, {3.717441888454382*^9, 3.717441930810644*^9}, 
   3.717442083259508*^9, {3.717442478304658*^9, 3.717442646378222*^9}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 Cell[BoxData[
  FormBox[
   RowBox[{"(", 
    RowBox[{"\[Phi]", ",", "v"}]}], TraditionalForm]],
  FormatType->"TraditionalForm"],
 "): ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["V", "0"], "\[Rule]", "0"}], TraditionalForm]]],
 " limit"
}], "Chapter",
 CellChangeTimes->{{3.710703563186775*^9, 3.710703570961725*^9}, {
  3.710784327154557*^9, 3.710784366609646*^9}, {3.7173553879257317`*^9, 
  3.7173554049345703`*^9}, {3.717355871594673*^9, 3.717355871594757*^9}}],

Cell[TextData[{
 "Define function that plots the 1 state attractor in ",
 Cell[BoxData[
  FormBox[
   RowBox[{"(", 
    RowBox[{"\[Phi]", ",", "v"}], ")"}], TraditionalForm]]],
 " space for a given ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["v", "s"], TraditionalForm]]],
 " value."
}], "Text",
 CellChangeTimes->{{3.710703572705634*^9, 3.710703603640291*^9}, {
  3.710704006184936*^9, 3.71070401553522*^9}, {3.710705372231855*^9, 
  3.7107053769264307`*^9}, {3.710706106217256*^9, 3.710706120183467*^9}, {
  3.717355407934894*^9, 3.717355409590053*^9}, {3.717355874337154*^9, 
  3.717355874963213*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"ClearAll", "[", 
   RowBox[{
   "vS", ",", "tMax", ",", "col", ",", "Q", ",", "\[Alpha]", ",", "\[Gamma]", 
    ",", "\[Phi]E", ",", "\[Phi]Em", ",", "vE", ",", "vCE", ",", "\[Phi]", 
    ",", "v", ",", "vC", ",", "t", ",", "sol", ",", "endT", ",", "arrowPos"}],
    "]"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"plotAttractor1\[Phi]", "[", 
   RowBox[{
    RowBox[{"vS_", "?", "NumericQ"}], ",", 
    RowBox[{"tMax_", "?", "NumericQ"}], ",", 
    RowBox[{"col_", "?", "ColorQ"}], ",", 
    RowBox[{"arrowPos_", "?", "NumericQ"}]}], "]"}], ":=", 
  "\[IndentingNewLine]", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"Q", "=", "1.1"}], ",", 
      RowBox[{"\[Alpha]", "=", "4.6"}], ",", 
      RowBox[{"\[Gamma]", "=", "0.05"}], ",", "\[Phi]E", ",", "\[Phi]Em", ",",
       "vE", ",", "vCE", ",", "\[Phi]", ",", "v", ",", "vC", ",", "sol", ",", 
      "endT"}], "}"}], ",", "\[IndentingNewLine]", "\[IndentingNewLine]", 
    RowBox[{"(*", " ", 
     RowBox[{"Map", " ", "initial", " ", "phase", " ", "point", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "2"}], "\[Pi]"}], ",", "2", ",", "0"}], ")"}], " ", 
      "to", " ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"\[Phi]E", ",", "vE", ",", "vCE"}], ")"}], "[", "tMax", 
       "]"}]}], " ", "*)"}], "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"{", 
       RowBox[{"\[Phi]E", ",", "vE", ",", "vCE"}], "}"}], "=", 
      RowBox[{
       RowBox[{"Reap", "[", 
        RowBox[{"NDSolve", "[", 
         RowBox[{
          RowBox[{"{", "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{
             RowBox[{"\[Phi]", "[", "0", "]"}], "\[Equal]", 
             RowBox[{
              RowBox[{"-", "2"}], "\[Pi]"}]}], ",", 
            RowBox[{
             RowBox[{"v", "[", "0", "]"}], "\[Equal]", "2"}], ",", 
            RowBox[{
             RowBox[{"vC", "[", "0", "]"}], "\[Equal]", "0"}], ",", 
            "\[IndentingNewLine]", 
            RowBox[{
             RowBox[{
              RowBox[{"\[Phi]", "'"}], "[", "t", "]"}], "\[Equal]", 
             RowBox[{"v", "[", "t", "]"}]}], ",", "\[IndentingNewLine]", 
            RowBox[{
             RowBox[{
              RowBox[{"v", "'"}], "[", "t", "]"}], "\[Equal]", 
             RowBox[{
              FractionBox["1", 
               SuperscriptBox["Q", "2"]], 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"1", "+", "\[Gamma]"}], ")"}], " ", 
                 RowBox[{"(", 
                  RowBox[{"vS", "-", 
                   RowBox[{"v", "[", "t", "]"}], "-", 
                   RowBox[{"Sin", "[", 
                    RowBox[{
                    FractionBox["1", "2"], 
                    RowBox[{"\[Phi]", "[", "t", "]"}]}], "]"}]}], ")"}]}], 
                "-", 
                RowBox[{"vC", "[", "t", "]"}]}], ")"}]}]}], ",", 
            "\[IndentingNewLine]", 
            RowBox[{
             RowBox[{
              RowBox[{"vC", "'"}], "[", "t", "]"}], "\[Equal]", 
             RowBox[{
              FractionBox["\[Alpha]", 
               SuperscriptBox["Q", "2"]], 
              RowBox[{"(", 
               RowBox[{"vS", "-", 
                RowBox[{"v", "[", "t", "]"}], "-", 
                RowBox[{"vC", "[", "t", "]"}], "-", 
                RowBox[{"Sin", "[", 
                 RowBox[{
                  FractionBox["1", "2"], 
                  RowBox[{"\[Phi]", "[", "t", "]"}]}], "]"}]}], ")"}]}]}]}], 
           "}"}], ",", "\[IndentingNewLine]", 
          RowBox[{"{", "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"t", ",", "0", ",", "tMax"}], "}"}], ",", 
          RowBox[{"Method", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{"\"\<EventLocator\>\"", ",", 
             RowBox[{"\"\<Event\>\"", "\[Rule]", 
              RowBox[{"(", 
               RowBox[{"t", "\[Equal]", "tMax"}], ")"}]}], ",", 
             "\[IndentingNewLine]", 
             RowBox[{"\"\<EventAction\>\"", "\[RuleDelayed]", 
              RowBox[{"Sow", "[", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"\[Phi]", "[", "t", "]"}], ",", 
                 RowBox[{"v", "[", "t", "]"}], ",", 
                 RowBox[{"vC", "[", "t", "]"}]}], "}"}], "]"}]}]}], "}"}]}]}],
          "]"}], "]"}], "\[LeftDoubleBracket]", 
       RowBox[{
        RowBox[{"-", "1"}], ",", "1", ",", "1"}], "\[RightDoubleBracket]"}]}],
      ";", "\[IndentingNewLine]", "\[IndentingNewLine]", 
     RowBox[{"(*", " ", 
      RowBox[{"Flow", " ", "to", " ", "1", " ", "state", " ", 
       RowBox[{"(", 
        RowBox[{
        "if", " ", "it", " ", "exists", " ", "at", " ", "given", " ", 
         SubscriptBox["v", "s"]}], ")"}], " ", "and", " ", "return", " ", 
       "subsequent", " ", "trajectory"}], " ", "*)"}], "\[IndentingNewLine]", 
     
     RowBox[{"\[Phi]Em", "=", 
      RowBox[{
       RowBox[{"Mod", "[", 
        RowBox[{"\[Phi]E", ",", 
         RowBox[{"4", "\[Pi]"}]}], "]"}], "-", 
       RowBox[{"4", "\[Pi]"}]}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"sol", "=", 
      RowBox[{"NDSolve", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{"\[Phi]", "[", "0", "]"}], "\[Equal]", "\[Phi]Em"}], ",", 
          RowBox[{
           RowBox[{"v", "[", "0", "]"}], "\[Equal]", "vE"}], ",", 
          RowBox[{
           RowBox[{"vC", "[", "0", "]"}], "\[Equal]", "vCE"}], ",", 
          "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{
            RowBox[{"\[Phi]", "'"}], "[", "t", "]"}], "\[Equal]", 
           RowBox[{"v", "[", "t", "]"}]}], ",", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{
            RowBox[{"v", "'"}], "[", "t", "]"}], "\[Equal]", 
           RowBox[{
            FractionBox["1", 
             SuperscriptBox["Q", "2"]], 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"(", 
                RowBox[{"1", "+", "\[Gamma]"}], ")"}], " ", 
               RowBox[{"(", 
                RowBox[{"vS", "-", 
                 RowBox[{"v", "[", "t", "]"}], "-", 
                 RowBox[{"Sin", "[", 
                  RowBox[{
                   FractionBox["1", "2"], 
                   RowBox[{"\[Phi]", "[", "t", "]"}]}], "]"}]}], ")"}]}], "-", 
              RowBox[{"vC", "[", "t", "]"}]}], ")"}]}]}], ",", 
          "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{
            RowBox[{"vC", "'"}], "[", "t", "]"}], "\[Equal]", 
           RowBox[{
            FractionBox["\[Alpha]", 
             SuperscriptBox["Q", "2"]], 
            RowBox[{"(", 
             RowBox[{"vS", "-", 
              RowBox[{"v", "[", "t", "]"}], "-", 
              RowBox[{"vC", "[", "t", "]"}], "-", 
              RowBox[{"Sin", "[", 
               RowBox[{
                FractionBox["1", "2"], 
                RowBox[{"\[Phi]", "[", "t", "]"}]}], "]"}]}], ")"}]}]}]}], 
         "}"}], ",", "\[IndentingNewLine]", 
        RowBox[{"{", 
         RowBox[{"\[Phi]", ",", "v", ",", "vC"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"t", ",", "0", ",", "200"}], "}"}], ",", 
        RowBox[{"Method", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{"\"\<EventLocator\>\"", ",", 
           RowBox[{"\"\<Event\>\"", "\[Rule]", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"\[Phi]", "[", "t", "]"}], "\[Equal]", 
              RowBox[{"\[Phi]Em", "+", 
               RowBox[{"16", "\[Pi]"}]}]}], ")"}]}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{"\"\<EventAction\>\"", "\[RuleDelayed]", 
            RowBox[{"Throw", "[", 
             RowBox[{
              RowBox[{"endT", "=", "t"}], ",", "\"\<StopIntegration\>\""}], 
             "]"}]}]}], "}"}]}]}], "]"}]}], ";", "\[IndentingNewLine]", 
     "\[IndentingNewLine]", 
     RowBox[{"(*", " ", 
      RowBox[{"Return", " ", "1", " ", "state", " ", "attractor"}], " ", 
      "*)"}], "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"ParametricPlot", "[", 
       RowBox[{
        RowBox[{"Evaluate", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"\[Phi]", "[", "t", "]"}], ",", 
            RowBox[{"v", "[", "t", "]"}]}], "}"}], "/.", "sol"}], "]"}], ",", 
        
        RowBox[{"{", 
         RowBox[{"t", ",", "0", ",", "endT"}], "}"}], ",", 
        RowBox[{"PlotStyle", "\[Rule]", "col"}]}], "]"}], "/.", 
      RowBox[{
       RowBox[{"Line", "[", "x__", "]"}], "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Arrowheads", "[", 
          RowBox[{"{", 
           RowBox[{"{", 
            RowBox[{"Automatic", ",", "arrowPos"}], "}"}], "}"}], "]"}], ",", 
         
         RowBox[{"Arrow", "[", "x", "]"}]}], "}"}]}]}]}]}], "]"}]}]}], "Input",\

 CellChangeTimes->{{3.710703612185732*^9, 3.710703613146097*^9}, {
   3.710703645087953*^9, 3.7107038250095987`*^9}, {3.7107038651203623`*^9, 
   3.710703925800755*^9}, {3.710703966836862*^9, 3.7107039711892033`*^9}, {
   3.7107040284227467`*^9, 3.710704103911132*^9}, {3.710704178547552*^9, 
   3.710704218489841*^9}, {3.710704287232888*^9, 3.710704302735257*^9}, {
   3.710704453096983*^9, 3.710704469639659*^9}, {3.7107045058389473`*^9, 
   3.710704522036879*^9}, {3.7107046199149303`*^9, 3.710705014168984*^9}, {
   3.7107050627339163`*^9, 3.710705064581814*^9}, 3.710705380970055*^9, {
   3.71070553812418*^9, 3.710705545777363*^9}, {3.710705876236657*^9, 
   3.710705974584722*^9}, {3.710708729182864*^9, 3.710708734523841*^9}, 
   3.710708917711267*^9, {3.7107765702372723`*^9, 3.710776574826092*^9}, {
   3.710776616626152*^9, 3.7107766206742764`*^9}, {3.710776666008458*^9, 
   3.7107766985264397`*^9}, {3.710784842006604*^9, 3.710784866724958*^9}, {
   3.710786067923798*^9, 3.710786094881473*^9}, {3.717282083500925*^9, 
   3.717282090324587*^9}, {3.717355468814692*^9, 3.717355483758181*^9}, {
   3.717355535860203*^9, 3.717355540611265*^9}, {3.7173556696380253`*^9, 
   3.717355671100561*^9}, {3.717355712122838*^9, 3.717355726928789*^9}, 
   3.717355783527965*^9, {3.7173558883679028`*^9, 3.717355973334732*^9}, 
   3.717356043773108*^9, {3.717356221638586*^9, 3.717356358548705*^9}, {
   3.717433585046125*^9, 3.717433691073043*^9}, {3.717433793078725*^9, 
   3.717433797141006*^9}, 3.717433832523905*^9, {3.717434059939434*^9, 
   3.71743419880486*^9}, {3.717434263187112*^9, 3.71743428409692*^9}, {
   3.717434328888208*^9, 3.717434442603376*^9}, {3.717434504521278*^9, 
   3.717434530185054*^9}}],

Cell[TextData[{
 "\nPlot 1 state attractors for a range of ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["v", "s"], TraditionalForm]]],
 " values:"
}], "Text",
 CellChangeTimes->{{3.7107061273757668`*^9, 3.710706150158072*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"cdata", "=", 
   RowBox[{"ColorData", "[", 
    RowBox[{"97", ",", "\"\<ColorList\>\""}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"vSvals", "=", 
   RowBox[{"{", 
    RowBox[{"0.6", ",", "0.8", ",", "1", ",", "1.25", ",", "1.5"}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"aPos", "=", 
   RowBox[{"{", 
    RowBox[{"0.33", ",", "0.525", ",", "0.49", ",", "0.29", ",", "0.36"}], 
    "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"p", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"plotAttractor1\[Phi]", "[", 
      RowBox[{
       RowBox[{
       "vSvals", "\[LeftDoubleBracket]", "n", "\[RightDoubleBracket]"}], ",", 
       "4001.8", ",", 
       RowBox[{
       "cdata", "\[LeftDoubleBracket]", "n", "\[RightDoubleBracket]"}], ",", 
       RowBox[{
       "aPos", "\[LeftDoubleBracket]", "n", "\[RightDoubleBracket]"}]}], 
      "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"n", ",", "1", ",", "5"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"pos", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"4.5", ",", "0.35"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"4.2", ",", "0.64"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"4.1", ",", "0.84"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3.9", ",", "1.17"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3.9", ",", "1.41"}], "}"}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lbl", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"Graphics", "[", 
      RowBox[{"Text", "[", 
       RowBox[{
        RowBox[{"Style", "[", 
         RowBox[{
          RowBox[{
           RowBox[{
           "StringTemplate", "[", 
            "\"\<\!\(\*SubscriptBox[\(v\), \(s\)]\) = `a`\>\"", "]"}], "[", 
           RowBox[{"<|", 
            RowBox[{"\"\<a\>\"", "\[Rule]", 
             RowBox[{
             "vSvals", "\[LeftDoubleBracket]", "n", 
              "\[RightDoubleBracket]"}]}], "|>"}], "]"}], ",", 
          RowBox[{"FontSize", "\[Rule]", "14"}], ",", 
          RowBox[{"FontColor", "\[Rule]", 
           RowBox[{
           "cdata", "\[LeftDoubleBracket]", "n", 
            "\[RightDoubleBracket]"}]}]}], "]"}], ",", 
        RowBox[{
        "pos", "\[LeftDoubleBracket]", "n", "\[RightDoubleBracket]"}]}], 
       "]"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"n", ",", "1", ",", "5"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Show", "[", 
  RowBox[{
   RowBox[{"Join", "[", 
    RowBox[{"p", ",", "lbl"}], "]"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"0", ",", 
        RowBox[{"8", "\[Pi]"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", "1.8"}], "}"}]}], "}"}]}], ",", 
   RowBox[{"AspectRatio", "\[Rule]", "Full"}], ",", 
   RowBox[{"Frame", "\[Rule]", "True"}], ",", 
   RowBox[{"FrameStyle", "\[Rule]", 
    RowBox[{"Thickness", "[", "0.003", "]"}]}], ",", 
   RowBox[{"PlotRangePadding", "\[Rule]", "0"}], ",", 
   RowBox[{"FrameTicks", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"Automatic", ",", "Automatic"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", 
          RowBox[{"8", "\[Pi]"}], ",", 
          RowBox[{"2", "\[Pi]"}]}], "]"}], ",", "None"}], "}"}]}], "}"}]}], 
   ",", 
   RowBox[{"GridLines", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"Range", "[", 
       RowBox[{"0", ",", 
        RowBox[{"8", "\[Pi]"}], ",", 
        RowBox[{"2", "\[Pi]"}]}], "]"}], ",", "Automatic"}], "}"}]}], ",", 
   RowBox[{"FrameTicksStyle", "\[Rule]", "Black"}], ",", 
   RowBox[{"LabelStyle", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"Black", ",", 
      RowBox[{"FontSize", "\[Rule]", "14"}]}], "}"}]}], ",", 
   RowBox[{"FrameLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"\"\<v\>\"", ",", "\"\<\>\""}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"\"\<\[Phi]\>\"", ",", "\"\<\>\""}], "}"}]}], "}"}]}], ",", 
   RowBox[{"ImageSize", "\[Rule]", "Medium"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.717433729040492*^9, 3.717433755996726*^9}, {
  3.717433807731358*^9, 3.7174338743693943`*^9}, {3.7174345361912317`*^9, 
  3.717434574892231*^9}, {3.717441118942371*^9, 3.717441279501512*^9}, {
  3.71744135965873*^9, 3.717441447446579*^9}, {3.717441487749619*^9, 
  3.717441717492236*^9}, {3.717441769690042*^9, 3.717441774073914*^9}, {
  3.717441816632433*^9, 3.7174418314882507`*^9}, {3.717441936396121*^9, 
  3.7174420233918133`*^9}, {3.717442089538162*^9, 3.71744211247666*^9}, {
  3.7174421428673897`*^9, 3.7174421560026293`*^9}, {3.71744219064924*^9, 
  3.717442224136559*^9}, {3.717442292053636*^9, 3.7174422926760406`*^9}, {
  3.717443774442528*^9, 3.7174438205183353`*^9}}],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    TagBox[
     {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], Opacity[
      1.], FaceForm[Opacity[0.3]], 
      {Arrowheads[{{Automatic, 0.33}}], ArrowBox[CompressedData["
1:eJwV13c8lW8bAHAqO5tEyi5lHrId10UOZZVQQikpKVGhIoVCRMmISiWJNBAZ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        "]]}},
     Annotation[#, "Charting`Private`Tag$81484891#1"]& ]}, {{}, {}, 
    TagBox[
     {RGBColor[0.880722, 0.611041, 0.142051], AbsoluteThickness[1.6], Opacity[
      1.], FaceForm[Opacity[0.3]], 
      {Arrowheads[{{Automatic, 0.525}}], ArrowBox[CompressedData["
1:eJwUmnk8lN8Xxy0RslOE7PuSfTfOGVLalBbtlkopElK0yFLaVJZQCi1U1hJS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        "]]}},
     Annotation[#, "Charting`Private`Tag$81485015#1"]& ]}, {{}, {}, 
    TagBox[
     {RGBColor[0.560181, 0.691569, 0.194885], AbsoluteThickness[1.6], Opacity[
      1.], FaceForm[Opacity[0.3]], 
      {Arrowheads[{{Automatic, 0.49}}], ArrowBox[CompressedData["
1:eJwVnHc4lV8cwI3sPSN7hTKuPa/zvUZFaNstWQ1RMlooFFJS8YtQkpVRtCTx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        "]]}},
     Annotation[#, "Charting`Private`Tag$81485139#1"]& ]}, {{}, {}, 
    TagBox[
     {RGBColor[0.922526, 0.385626, 0.209179], AbsoluteThickness[1.6], Opacity[
      1.], FaceForm[Opacity[0.3]], 
      {Arrowheads[{{Automatic, 0.29}}], ArrowBox[CompressedData["
1:eJwVnHk4FW0UwG1lXyJK9p2yXPt2ec/lWqJQiShbqFCECikVooVSWiRLIVJJ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        "]]}},
     Annotation[#, "Charting`Private`Tag$81485263#1"]& ]}, {{}, {}, 
    TagBox[
     {RGBColor[0.528488, 0.470624, 0.701351], AbsoluteThickness[1.6], Opacity[
      1.], FaceForm[Opacity[0.3]], 
      {Arrowheads[{{Automatic, 0.36}}], ArrowBox[CompressedData["
1:eJwdnHk4lG8XgO37lj1b9iVh7NuM5wxjSTuytkkiQlGRNVsikkLSSlmKkoqk
ZKiQkiWFFhKpFJF3mJnI9/y+v7rua97lec85z3nPPU2p7Y5wC+Ti4ODQ5eHg
+O9PUpu6uFybBJ3I6iqiarFQZOwM0X9fgm7z9rYXWs1CvuIdB3OvSdBpqh2y
5kYsNHr+rwP7mASdZ1ORgoA1C5U8vjBZYStB38D7U3jtehbSHir/17NLnD7q
u/uo8kEWuu8QJPuVIk7/4bj7Ys5hFiqdeK08pyBOb1nyZ8wdZaGPGZ4mS/1i
9Lh0yY+lKSz07FcR0ekiRp9UjEs5fpaFQvc/PehjJEr/01i4tOEeC03o2+tL
iYjSKaH8LOkHLMQ0O9zU/l2Efu+c5fGeRhZy1lhdrVYqQk+5foeh2cpCfutu
HiqWFqGf3EzLhB4W+gni9Wtmhenrtm2JuvGGhRbKJNwau4TpLkYZxnwDLHSu
rvBT+3Fhur0qT2/xJxbqnDJWvs0Uojc+ndM3nGShvG0e4spvhej7M6RdTadY
aIar5GtGrRC9gVFxSn+GhYJPZ6dvCRGiu/avtWYwWEjQNCW9/oMg3c64emSS
g43Om/Hl8DUI0hl+7hwZ3GwkMWQg6J4vSNfg7a2S4WMj7VNyN0bXC9K/vRrw
ERJmI7WC0DMDTQL0pY0Kupuk2cinxSFG6JwAXbCtSKRalo3cePImrA8I0G8I
sBOZ8mw0YMb35JS6AD2Tr/LxTmU2Empq8b7/l5+etd80IHYVG12mdw6/6+en
m1Yx16epsZGz4h0JqQx++p3Os9cDtfDx48nTa3bx09+aX/hN1sFcUa1Is+an
HxXvtOLWYyOBawqdIT/56BBXfnLbGjaSaktKjH3GRzfYZXL0twEbvb8U8T3j
Eh+dY1ZizUEjNjoqauNwcRMffXHX1Rtgwkb5I1lB13T56Oe5HX1PmbLRcXpU
ZSUnH50xe+xSpxkbjSj8XVX9npe+yoUezDBnIxMfne+37vHStdUjasUs2Uh8
4p/C7WxeuvxF1n5ZKxyfsyf6qgN56VYPXp0WsWYj7z+JVuVyvPR7dXZTT23Y
yGD5omLJDA892+yKXLotG2W9vvKr+AUP/cedhJNmZDZ6mDr6/GwpD131xzi1
DzOn/eOWk3E89IwLI6Y7KGzELDnDTvHgoV843eo7iHnHqcmsowY89ANZxnfB
jo1KFTflRPDx0O28Jy3OYS7QW6cUOMJNL4yv/voBs2DRPjffBm66YKzlIzHE
Rt1O5q6b8rjpWm9c7xthzllvo0IL4aY7UW932WF+myj1w8qBm342oZyXjHkX
2/e5gRI33bgwe5sO5poHlV3qDC66h8xoHwdmx5p8JfnXXHRSuua+Dny/a0P1
r0QruOjsiIFViZg3GFUwuY9x0Sd2xi6oYT51cqmR7c1F/2g/OHMPP09uqoPh
H2MuulZbsLgZ5nCnv/snhbjogmMPvUpxPLi5K/LGxjjp9cU+r//h+Gl/76j/
9JiTvm36bfRazNWaY/ODBZx03ZHH3ik43qHfove/Deeku4ZfPHwD54Pv/ZLx
G2dO+mEz/TdPcL7uTN/x71PlpPfGHoxpxfnMMSgNftvHQbcq3dyUj/M9+Dbw
0FAVB33XeG54AK6HSIOd7iNpHHQ43pGliuvFR5E9N2PBQW/efFhnL4mNVks/
+rEozkHPUvnWOG3IRnZN181l+5abK5+8Hw3E9aj2c9+a7RbLzYO0zSqqq9nI
L+plht7yUnPh45gnz9Xx+jM2ZuTVLzVrP2FOTqiyUcvTnV3/wpaaa7aKOrNU
2Og0r3Xvj4+LzX5nTJ/NKuD9G3+RxPfob3PQxTIPU0k2cteK/nAx8m/zrlGe
9BFxNhLdq77CZvXf5oiASN8EURxvny+PT5xnNzeYyJifEmAjw20jgXExrGaX
4erjfP9YqFxgvsGVxGrO0Zh9RP2L+4nJlh6178zmDfEZGhFMFlpx8c7Xb17M
Zt4+9bdX/7AQ9/LSswHLhea8mw+X/SdYqOnDk8q9LKL5xDc7nfCXLERvr6l5
Wks037rAvfldOwvd+mj+dHUI0bzDr0rA5BkLeTqNnJP7MNc8ZxWZ8+wxCwk0
BN+OaPrTPPDm3xXvWyy07b6Fs0XaTPNIUEW1ezYLRah0DX41/9585d/guJc9
Cy1afkvcXv2tWYQQU0qisNBc3IGS3+rfmn2e9T++ZMVCWsuKsnskJpr7KnfW
tBiyECPnw9Mzv8aapeYksioU8PvgQdsDb4+RZpNCI2neWSbKvvP0fPDUq+bg
T0La74uYqBS+/N15og+ZcQkvpn9YQM7UmlyfcgY6zlG9cR+aR/oJzwYqxxgo
Nsjg1xvreaTNd6vlu+o8Or2u/LiD2Ty6rnr8ns2FeZTPr80w1ptHj9DNC7q5
C0gjITtrg9Q8qqf0J1sfYqEjHq9O5HxnIPnxzpSrpkvITu6b37lzDHTPVE9J
PWIJdUf1qjefYaBGn5KAwpuYo8/VTuUw0OV5E2cvtX+IKR3juTONgW7OyB4m
iy2jdTLspYKDDNTE/5jeF8kBb24N2PpuYKCZmW6gO3LBV2+hPalCDHTQni9s
TSAXhLfG59P48PUFI1zOpHFBgKOXtjgXA91qSnZc95QLynMpZ+ksAtXQ8r9G
ATd0pLeeLfhBoKrn9a7V1jwwqlbZJ/6SQD4lQSqN3jygq+mCQtsJ5KS05URr
NA9U9yXk9zwlkLeklO/TOh4gzBkyDx8TqC/7e8FxY17w3zFH5qohkI57yFVV
XT6Qbm9+GVtAoE3q/0aGnfjg84Edk9FnCIT0L1YUBfLBx7ZSr6RcAgkG7BVZ
LuUD3qN7zW5lEkg7Lmy4SJkfDiujtPREAnU+jBE3J/ND0TftG2/jCDRkXknr
8uWHNWq/aKSjBFpVSrBmz/HDxQcn53gOEah3L/9aMUkBWHP5a8maEAKd2T3j
lk0SAL+L8fM9QQQ6Utc3zLdJAMqrb48lBRJIZJfg49mTArBT0a1waReByDm3
117lFYQEpQ9NMd4Eemp3RpVHUxBqs9qsIz3x+oqeMvfYC4LF46F9RzwIFL/f
ako5SRCEzv6avbyZQJLLJyvCmYJwaWls9sBaAgWj6LeGskIg6ftYr8OZQLme
Cxd+mQrB6cYv7XpOBJqj9xv5RwhBz/7nSMSBQJwHWhTlc4RAs3ZAOYdKoKRb
/p9e3RSCG8NjIfJAoB7PcRXShBBo9AX7bqQQaNYjsmmYWxjiH+RxsGwJdMGN
O+KkmjBM8lgp37YhkHHOZZeRbcJA075Kt7QiUH7ieGrkG2EIyb3zqcOUQH6s
3mCpWWFYLXd/T7sJgYJu9X24KyYCc+8FwnuMCVQb1nhjaq0IvIrxE+EiEUil
J1ojM0gEprnvX1tthK+3cT5YI10EUsqFW7cbEuhbJ1+BB10EJiqEzo2tIZCw
b2rxz08icJimuskC85aD+TeS/4rA8wyrvLP6BPLcWNMru1IUmLuEdvxdTaCH
hmvVqyxEwaR5fX0Y5v7igZt2HqIwN3C/eFIPs1h/bO9BUVgf+Ew4EvNbp4cl
AbmicDO7VZAHMzRwGjGqRWHf5rn8q7oEShjUMTneKQrf7xbfcsZMKJU3yn4X
hdT6RXeWDoEk/s4PlPOKwfnt20/UYRb9nX/eQkMMtM5yrIvH/FFhUawNxGAG
RC5uwHxjbaXz1h1iIMKzI04Pc26ItPt4nBj8HO74Lo65Yv8jiDovBktvVo1z
YBZG8qpcD8Sg9qt52KI2Xn9PGUdevxhEyw6ncuHPlVaMzK76Iwb04J86Upij
5RF3jbg49N1a7WOI+VGhHc3OQBwa5VTkPDBftvR41uUqDgENq/zTMKtemz+z
PVgc+A5mWjRjtk++2DyVLg4f1OsKefDzcsY+9km8Jg6KNYvHPDDvMO86IN4i
Dv/mHxK3MXv6OUqXDItD0wenWSkcv+cdxe6mi+LA08I+nIo5YpfyqjERCWBU
TicvYXa52TFbrSgB2t/YUik4P0sPhF5TrSWAi1H7/CbOpx5N7JuIiwQIZPOP
bcT5fnLbKX7QUwL4BF4mL2E+VmNkc/CQBHhQZu1icb1s03WJtEuVAIPaMV8X
XE+/KnY6ipyRAF4fwTlVXG+XTew/3KiRgNGtWnmzuB5jzJ91xzZJgO678vxB
XK9FivsC17+UgO6xkdr/6nnVpEDO7IQEfP85b/rMnECUl0/jaCoroInHx0AX
7weF2/E6imtWQE/B7X4vvF9e9XKV/7FeAc/Pt544Tcb96CrZ7PrWFfDlyIC4
MiLQcd0Ke8mcFfCBkhFYSiPQsx8zxjPFK0Al6T5FAe9fvq8BWt2VK8DwbrDk
Bby/k929jU8/w9c/a1D5wJVAn0mHM1ctrgB6/X7ati0Esvr9MC8mVBJ6zoUv
bMb95rzOuZJ9RyUhZexIiNduAm0v0pDbliEJf4fUa/buIdCHF5vXOV6TBD+R
71euBON6XVx9TO+DJJwNeUCPPYjX77DNy26dFGRkGU70peH9WmN42sVHCvLE
m17tySBQWaXwKY8gKXDfxOO6jPvrmbrtMwdTpSC/+tnCBtx/R8xX/2l9JAWV
799e3lJMoA2KrUuta6RBsNX531QtgVzP5+irkKVhl3xwqGsdrs9rRh/i1knD
3ff0gjsNBHIIXP5oFyINjVcH+Iqb8fp2pZmOV0gDp/KJU5+7cL8a+bXtroYM
CH3Q9zX/RaBI91IiW1kWrjZktdKNGMhuw+OvjgayuJ6U22lmDGTNf9iUiyIL
7hyGQb1WDDR11O1f2jZZcBZNW89jz0DKm1O471+QhQoVq5BuDwYSVezSb1KQ
g69CkaIzcQy0Wq5OtkxRHmqFpA/97Waga6s/traslge6D7Gs+JaBIGdmadRa
HtxIT9Pt3zMQi8PM2MBbHj7sZTqVjDOQRuiOf9P58pA7bCZ7ncVAarSQCxri
K0E3NGi5VhPPBR+JT/v4FCDGy8UoKXEeKYf6XRDiVAIeNUGlQfICSvPeqvtG
QgnuxiWF9NovIFmPX0+vqCpBQvO9ny9dFlDWsRE9R1CCEwrnVz/zWEAmi5ee
0pOUYGI5V6p5/wJq+p2YFbesBMufBntfXFxAP9mFY/84VeDRfmV2+uIC4tM2
PrVWUgVErnvcOcLFROPtuVCkrgI3TifEBQowEeNfcz3VQQUcI7XGydJMNH20
s/lZmgr8VnTk79Fnoldnvj/MFFgFPV2SpyJ8mUil7mBykqAqjC1utOm+z0TC
P9axz0uqgo+vBsezRibqKUy9Vq+oCh22Wjvu0ploUfx1wryBKqy1DdgU94qJ
0hc8hE67qUKw7+V/D8eYSFxRT1v3oiqw7RKdOyVYaGtQ0L49ZapQ+dNirbMs
CyVKJN8pva0Kt7viCh8pYr8VkaBotajCW/JscqY29n+3R3+oE/j6Ujyl9bb4
+Ktb6t+R1CBszrvUYg8Ltb+SLzS2UYOzby4dldvHQqlaLeiUgxrssT3lPxXG
Qo02nZ/Xe6pBh0jgYHQ0C+25mDQ+HKcGDqlct7izWOiCdoumW7saTNOWOoaq
WehStkBpe48arJd/NPX3Dgs5TFSV2r1Xg/x2W+kVdSx0nhynYDylBhwfH/yS
amIhuSZnPx0pdXjC+BIT84qFZJc473vsVAeB2Mhz176z0N2prDRysDo4X4k9
eecnC8VNGO/UOqgOaUaZ1+9Ms9BLMXs1doo6qBUMz2QSLHRIf9i3plwdKHe6
6ZeXWWh8j/jy5Rp1UKxLK7PnYqNaHpPM3AZ1uPWaY8UQDxuJmH8lR3Wqw8FO
R+NPgmz08dnIJdq0OrybuV8PUti/duyetllQB/eU8bEjMv/5k9yyMYcGwO8m
0StybGT65dUGdUkNqA36pfBckY2c5jhSFBU1YGaN32gr9vvDK7/vltHUgHaJ
ln13sd/LNpnLCVtowFRC5fG9Gmz0iNH9mQ9pwP6p0H+rsd+r2Rx14HbRAMdO
MseoNvbf3vHmJR8N4Em+EqmG/WgzKVGAlaABGYmf2v5gfw/b9luUdVwDjp46
62hvzEZaPepprFwNWNvuT6Rgnxekbr39t0QDTnZ1Nw1gXztxTtZ76aYGcOma
tf3EPuf0XWXH8j0N2PHc+v2MBRvFCGSF8LRpQKVLGvdr7IMhZ4r28ndrwHHd
w8Ll2Bd7K9fdFBrUAOPPp7gisE9aKkeSxEY14OvWrC+62Dc1Wt7PrZjUgE8R
qmVvMCvs9fgtM6cBntJCtAjsq5237ygrLGoAfWLTw7+YZx83HVXh1YTVm0Y5
jmK/VVRC/9TFNOH6bX+5b//xKmaZjpwmBKYeYjliP+6Qrw5do4o/X9d0rQAz
w0/F1VhPE4rTRyTfYY6zlSRbmGhCYk2iAz/27wPOm8m2tppgLZxioodZSrrE
EWia8HSqc9gWsxG71c1xgyZs75B1QZjTzQ/tcPXE16/TCDfF/IYzKmDTTk2w
6qnZLI95sDhhm0ewJtSbHP09he/nQXaj+RzUhMcLFNf7mN2bamR2xGqCblnz
rlDMl3T9X+5O1QTBIyOmUpj1HqzZFZSN1ydysK0KP1/6/v7XoQWa8DrsqKI5
Zvv1CpIHLmsC5cqSeQ2Oz8JPkWnzSk14037ziwjmjP2krL+1mqB1TOKuN47v
g+KBEfojTZh15688g/MxbLzze/pzTVBTn+5oxPlKUja+5NqtCSnyw4q9OJ/2
d2oWxIY04UNhX+Vb7PcNfbaphb80QUntwekbuB4MJkQrfOY1YVDn8t8YXC/r
K2U8lTi0wKw6mm6B/b56/JTtVSkt6Gv0jk/Afp/a/G+Pv7IW3B+PyeLD9Vgr
nb2spqMFghUrVRKx37sKzYaV2GiBYd8yrzWu3/6iFrNdNC04dcMzMl6XjeSu
VLupbNQCv8u38m/jeoddO2KL/LVgnxmv1Qj2f46tPW2pJ7SgMGPuQRT2e6Rt
kk8+owU75qWyDeXZaOXDuXTighZkGckXDeL9mTL3ssm/Rgt6FNeXsSXYKHMy
s5f0Tgt+Ry/WxfCx0dZTbOkvI1pQsULlQA03G73Ma1135ocW3Nt2j/cdBxsF
dDrE/V7UAo7LLUpzbBaqVpy2vaihDeF0vRMRuN88vP88imagDds946p0cD8a
tf4Q8dNCG1wj5kJ6vrHQjkNfLpm7akMAj4g28ZmF2E3vzRoPaEP1Wu0zGX0s
1FTPP+sVqw3HWgNy2l+zUOfBLzQiVRtGFP25WJ0s5H3G9bLuOW0I5V3dR3rK
QpYj0ylJTfjzJxu9Fu6y0Mm8ovOjgjrQ+Fau8W8uC1VUGg5aS+nAOcH7V6JP
spCK83DYaSUd8Gv/fPjbcRay2tSebWWkA6Jf9I5cS2Ahzixv1UMeOmBIGww/
HcJCYgMHhQsu68DdRy98t9mzkP9Fl7EAY10wT+gqqptkInVNhegkG1240ZRo
NjfORKqxHtNFDrpQO2RopTfCRMwpt/jnW3Vhwf6zaNIbJnJOUn7FE6sL2dsN
xd89YqJDnI6KCq260OHg6+t2konMajRd8zbrQUTb2w1Z2kwkuXLw5StvPUj8
de9wtioT2dWL2vP56wGXv5RItgIT/TOKFIg6qAftqY6sVDEmUuK0/WZ6Rg8E
lso4fOcXUM/Nb/5ub/TAjLu7/sHzBXTrpeunZffVEPJoM//fgAVkT7x9q71J
Hw641YQYX59Hk0LHb6V76YOcrvOX0UvzqO18JOnLTn0oKwwuLTw3j2RGjezy
D+hDNqe2v+jJeZRxba7yY54+UBcr400i51Gc2L0tHP364FqUfCWCOo92PQ5a
V+K5Brqc3MbW43mnXNRg7cMda2C6MOZP7TAD5R6PN+/euwZUYr1+Kw8xUH4a
5zhxZA0c1ZNkCr1moLAfN0d1zq2BxUlVLdsGBtqQG95qOLAGtLpIy5ynGMhq
zUrX/q0G4Hc4RPs0YqA92T/y9bYbgES7/zpky0AyaWcDEvYYwHnZPP55Czz/
SQidU40ygFph732xhgz062Xp1a2nDQAFHnk1osxAZg4BxfGdBiBQkham+Y9A
B65c3fOo1wA2eOkLbmETiHRGY5g5aACD00ea0+cJJGCiPxnxzQA+XV19nv83
9h8+87qNPIaw4ZphW9hnAvlQWed6KYawReRL24tnBHr57VPVIs0Q9up+t4xr
IVCHy+xF7fWGoMU3t9r8CYF0Dx9Sj/Y1hIbib9WtDwh05/QNUeFoQ1DZ6d1A
qyJQYrUUJ+cdQ0g5l+P74yyeh5W+rVd8YAhlQV+9tPIIVKnWW2b2xBBsGqa1
Qk5hv/kqfnLPK0MYJh90FMPzeKh7d8zD74bA73uGuyWRQBcDfc7aqBnB3bb5
J29Csd+fVPj+SdcIHE2TnkfsI1Cj74TPMZIR1PyrCJENItD72LjrrcgI+F80
X03F/jCVc8iRssMIjLLaVIZ9sD/K6v4ZCjSCuI0fjnV74XlecODD4TAjuJ4h
fPnlVrz+dsqRqngjqLZ5IDOO/cTXW8JK7IIR5FgXuRZif9FBIZSyUiNIjmO9
++SCfcaS86rtTSOI+S1pTsK+k7VJLWfvQyOQFLobwXAg0IOJ9lV/6UbAnTS0
Odge++KxiVW5HUZQ2LooMgF4/g9oi6kbMIK6i/6ruOwI9OZT5ZDziBGU3G84
ehX7V46Tc8PQhBF0+VEerMV+ZrPEv/yXgc9fu/jlsRWBjOiBZ5SFSKBadM9Q
24xAFwrH/oyLkmD76299itj/bg7mq1evIAFiSgQpYT88X9KyYL2SBAEDUXvs
sE/e4d9awqFMgtFjLj07sW/u+eOq3q5KgpBVRsbZ2Edpu8/eddclgbLBwbe8
BgQKluBsW7mGBAdveSm4Y3+t0uV/OGJEgsyRKK8q7LuZ6F5OmSkJWOtO5ohh
Tvwh6RRqSQKvuICmeOzHzx6YjpNsSTDN1/qNgf25HKmHzNuR4OLmraKxmKns
n0OP7Elwk7nfUBDzFqsr5slOJPibY7/uGvbzM66uSU6uJDh8RXyPC+aW5L8N
whtJsPRI9CgT+36xYct4zxYSREceybqHeajkBk/hVhJ0bkktOorZZs1TBT8f
Egx9D7vmijk8QVFPdTsJAnP3VGljnn7cbPx1Fwn8Mu3uiGJ213xicXMPCRKN
qmqXtQnU/kfTJiIYf17tU/Pf9xeHg7jszPaTIHk1q5IHH3+iZQ+NFUGChH6r
y3KY9cF305MoEnzqbz9ljjlDfXZXajQJjDy3xu7APOZtGecSRwJSVvauM5iT
va2viiaRgOzXC72Yq9x5+vpSSFCs5qqgiJ9XSnJP0vHjJEgSvOEc/l88qFwU
mywSnBi24X+F+Zhoj8h0Ds7XYyNvMxw/s5InMyV5JKhqemBdgZlHt3lyawGO
9z+uKk2cD87nrYuC50kQFkKtqsZsqZ93IPIqCf4khHp8xPkbOG3zTvs6CVpV
G9ipON+s59f9PlSQILROVN8C14NN5dEuWg0JGr2SNBtxvcj6Pm1i3SWBvOXs
5ElcT1PjJ9/eridBS5WcRTCuN59Wt9SVT/D9zTI8ANej2Nhq5e4WErjestAk
43pdvmY5kfacBGnPnx60x/Usf+qa6OwrElyaUE0KtyAQ19+PERU9JIhjOtrm
WxLoxpZlgR39JBi7OhX2DO+H4p83vr38QIIrQ7KGNLxfxAX4jVNHSJCtw6w/
i/fTeZeFBpsxvL7udbemKAQy5LbNvjlJghf9/EN0vB87Ng8czmGRgC8g9fuY
E4GkB91/OC2RQElDr+g43u/NohU3OTiNISQj9qop7gdT98NUDgsYg1LgQE31
BgK9m0lb9pczBlrQoSgF3E8s6l/IqigaA6Vj41lx3G9kbPhPvlcxhrdv9v8R
w/3o5Z/5PA9tY2gV+bprzXYCNXhIbtxgbgyifdP5o4EEWhl0NVnE2hjCq987
6wbjfv5DVe0V2Rjg5y3FoyEE2q4cWrWeZgw397XJWEcQaPF7j6q7uzG0u93v
Nz5KoPQtyvrRB42h1CJ9N1cugZzkJeWXDhmDSnf1YD3ux2k5e+JTY4yhaS/r
Q1Q+gaI28NbmJRnD1vg9MfzFuB+Icc/dyzEGtyHPtPwy3I+EPymtuGkM51iT
4VT8PuiZ2T9nOWYMEzI3Rp4wCKRlMne6e8IYXFpMTsayCMSuG+sLmjQGfmKr
gN0SgVbkrl9bPGsM24tOen/kYaD2OxQtfg4TuNl3J+awNAOlRos1cyqbgEyC
T7ukOQPtPpm8OdXLBLZoLl97FMdAskIju5L9TED9Usfx58cYqG1dpv+xnSYw
+lrXfiCdgee1C9bJQSawx/OCkORpBnLdjsJORZtAyW2G+9h1Bnp9RkR+8JwJ
CIo98fvWje+/hfuc8ZAJrOfcncuhP48SleurbXaawsks8VNas/Ood/tyh3mA
KThOf/qjuzCPXA+kzxgHmUL4yGSj4dI8Eqpf2G0QYQqn6vcrUQUXkF9r5zAp
yRSoQx8vJaotoFUGt2NCrpiCi0nnGhe3BTQ9/DT7xmdTkLkh8XHf/QXEleGX
2TZuCnblew1ONi6gE+uEC8e/m8K1R5T2Kjq+XqTNiMasKegdfBE0+WoBpU68
0K/hNIMWaw5v368LaH2m/xGmuhmIe9KCfskw0eLBAmn3vWYQrM29UvwwE0Xc
e6EYH2IGcd6Bis9jmcjU0UyxPNwMdrm9mj1yjInWx9YvLx4xg98OFyq68Hzn
3nHWtT7DDIzfiUjSSplIIHF0jecNMxA6feiC7WsmYhXf8Tx1ywy2TJp6l+B5
0Yb2JaS91gxEj5AVOIeYSOH49o3kRjPoa31sfXuMidiD68ZJL80g4ZB24yMm
E92bv+tKmzKD+szfoVlqLCR1eX1B1qwZUHvvf0/RZiGBtoIHvQz8PGV5F6P0
WajxL3fi7n9m8L1aw5JizkJHhd1+5oibg05Wu1q4CwuNJ5VxC5uYg1NzG9Uw
jIUuBbNVdliYg5ZhMuelgyw0phbJrrUxhw6pjzZcR1hIc3nNTz8Hcyi44ltT
k8hCwXy+6Q0e5jD4ZuneWTyPB1boyp+NNoegsPXh+2pYiDt12X1zvDnc/TC9
Pv0eCzW4VW8WSzYHm6BLYvkPWGhid3tKdpY5pI9N0TObWSiHQk3Lu2QO29va
z/VhP3gnGpLsUWoOIycj7VOwP2w+6K4vX2EOX3c1f9F4x0KT62djS+6YA+Mb
8yz5Ewu51bQ0P3pqDqpzDdX0SRbKXacwlNphDsPZzMXFKRYyU3ybub7LHJSj
CkNWz+L7d8WVj7wzh1Z3d0vvBRaieCYnikzi83+d+7LIxUZdo2yeoWlzyPLs
DW7mZaO841tFyufMYW/Ry3WRAthHfUhnqEvm4NDp31UpykZPV4nrJkpYgHmy
WYKnHBuJFz4O2ChjAZP+fwvPr8S+v/+pwCoFC5AdEwl+pYh93u1BSouGBdSc
JU1yqLLRUvipLWd1LQCVjsdwYf/7wlOQEGhgAUHSbUfnNNhI4Rj3qJClBSjs
iM65poP9ss5ZctjWArrS2Um79dioyikivxYsYHTAtExCn41up/5J9HG1AJNk
xiYbQzbWR6lRg00WEKGY/7AO+6qMWUkGl4cFaG+UVVE1ZqOx4wcLqrdbwK2k
D2Ut2Hevb902n7zbAuTy6u4xsQ97y4jlegVZwNLH6FwVCzYSrPTdZrAfP19f
vqEp9umW3zJ+3Afxer8kHrfAvq14VvLE0GELOF87nq2LfXyXrtLnmlgL2MpT
ZC2IfV1GenHn8SQL+P0jO30Qc1NzHM/2NAu4LdS4rxD7/VD+nk7TTAsYEJMd
scf+P7WYdFvoFI7X5XPDnzDzO5y7NXrGAjoDrP2DKGx00/fAs4ZzFnBl2Nx/
BPPR4Ne/cy9agJ/d9/f/fX+y//KhNUElFuB08nNnMeYEQ+1ou3ILuN5122AY
c7lr+SuZKgt4Ijq2LI7YSHnaYkdxjQXQutilhpg5vz6eU7lvAR3JJQQF852U
/KxrDfj+K9T/z6KlCqq6TRYgP1hZ8t/xYVrVtdUtFhB8ImDpv+tp/y4jG7dZ
wMF3Sfxf8P1Oj+55UtdpAT8O69OvY+YYcTSz6baADIV8HW/MNXvLLjx5YwHH
npPtFvHzKDM+z9oPWoCdeDFfHmaZvV5m7R8tIEujP1UWc++5oF3rRi3g2T6p
h9k4PrnBB6K6v1qAy9pjN+ZwPLPre0LcJy0gSs/Bex3mf35Si75zFrAya3Tp
Fc5PocOD08MLFqCkPrM0j/N39Kjlsv+iBdQWdb1egZnLb8fOYF5L6Lgc8ncl
zr/sq651PwUtYeLXngB+czbSk6niDxezBPa1a/e/4vrJves6FilnCdnD9UaH
cX05//66RChawkd/01BtEhttuVb86YiqJe5H3rUduD59//J+OapnCed+3Un+
jOv3k4jMg3hbS+Bda2i3Q4uN3Hlb7i4iS4hQuDZchPeDb43GzniaJdiO3Pr0
TI2N1KlEc+wGS4hSGdOeVWYjf71ev6idlnCm+bDHRRk2StInnZsJsIR1peIe
AVI4/g6BEWHBlpCfRV6ltIKN6u0SfwUetIS93y67B4iwEfOI9LstqZZwX343
nyvuB2+PBd9/mWEJckfMtUuWWWi+xkPJMdsS+up9CicXWSjsfVGSRYEleAuK
3fXA/USbaecuVWEJGtXBzIyfLBSud8r4XqcliMcQUfG9LPR7oHs8tdsSnE/c
aqnvYqHVhae/uPdbwtTsrfQvL1ioVuzd3dlPliCiq/JDrBX3t+67fpqzluB2
4XjEk1oWuvkn8XSAnBXcLLeLzz/FQsJX1O7rKFnBkd0LU0QmC+kLd7ImVa3g
Y2LyR5d0fP6516Phq60gyPHko5dxLBT38cfXUIoVINeb4dRgFurWHBu0CrCC
Y6LJl0QQC/moSspMB1lB76Uz7+qs8fvlheeW0v1W8Mfq+ZCHGQtx9Xu28h+x
An6az8AhPRZS6tRxbzthBVtOMKdAioWWR23uSdy2gpA1nmP6X5noH9nlQ/eC
FXAJvP68O5WJItH5a+sXraA0ps7WKIGJzDouunRwWAOfhkra/BEmmhYz0nos
aA0XXAujjoQwkcpm3RWFitbAtXvNKNrCRPvK7wpKImtYEl0IWqnCRE9fNJ/V
TreG98ti1eN1+H0vklL4QNQGqmttTB2/zqOyvU/9rq6wgccCv39uGJlHBz5s
VDohYwNDMbVBPkPzyGJkfZ6Hsg002xgvxXTNo3sBkT6ja2wgo0Dy18e6efTR
PnKkc50NlGT96l6bMY9uRA7u/nLCBsLrlOkUg3nk5feutSrbBvbTLio815lH
8Rc5zA6dtgGHdWl5W9TnkbLc+g1cRTYQJBAvEys3j3bkGB2WqrABmxA3XWGu
edRRMrVf6Dnm/i+nbAYZ6Pa1CXE3DluY/BL52jCTgew91s5u5LEFRqJpnXga
AyU+yPzsKmAL5fFwgZnIQEqRF6aRhC38ftF98cshBjomNPtHRdUWbLbZMOX9
Gcia9Xq+FtmCw8GazQq2DLTZ/mrYVQdbOODH6ZNswUCN8bbCp5xt4f6DjNWz
xgwUVLCpZe8mW4hY0PH8qctATMFfTmI7baEq3JlznRwDrSFHkywTbSFgkPco
Hc+vlrxPPsin2AIcP8xomCWQZvarDla6LYirirxvnCJQUAop4mGOLVjP2y+/
/0qgMt9EFdIlW/hE/LmS845AdSXrChcf2cL53FKhpw8JtJT90uRNsy3sfHD9
xdZ6AoWN1xrceGoLjmevhPy5S6A1TmxH95e2oGTwJmxtNYFWSVHMrr63BdpL
Pe2IK3je74mrVGHZwsu3svsvZxAoYf+FTVWLtsDLPhPOmY79pKk31ZKDDHaB
lG1hKdi3u6vOb+Qnw2mx3wK7ErBvVLmVR8uQYeMZQenaKAKNPIkY5VhJhjjZ
yfd+BwnEeCNWn6lEBre/jBvi2B/uGEmbFGuQQeh7QdgZ7BcXHfhK6o3J4HP9
11ee3QTy/czbTzYnQ3uZqwtzJ4G8L8rearUiw8eN+14S2F/kBeleXYgMMToB
doK+BJp7l/JoeAMZBodLVa+6EejjpN+63VvI8Pi3V9/HzQQix8/lfPUgA++L
DQ/VNxFoXX+r8U8/MkivlTfqXEegJ6cvqc7tI8OhQcu5DEcCoac6UYfCyBAc
PZkhRsP+k2KVzjhABot5nd2X7Ql06KrP9Hw0GdDegOkhRKArJ0pdouPIMK2/
61q6Hfart5+DFxLx9eWdr9tg/xNVuMW5kE6Grrdvcuk2BJp5HZlwJJMM+z4f
Tcizxr6959JzRjYZTqQKNYVivwz/dLpl7ixez4EJSzL20bA9hgVTJWRw6C6i
bMA++/6Pa0loGRkuf8v8FGxMoLwrDcd/VJIhtTxuMAf770a+5bHxGjKMde4Y
m8O+nHNeaufue2QYEtzEMMMs3jf7cKSeDD8XlfYmYb/mCcySed9EBs+MXXtJ
2L8fqaSu9GohA5X383wh9vNRoafc/c/wetI2fefDbOD14+3mDjJk6JnZHsM+
72lckNf1kgxyK6VmuDCLtwdauXaT4Un0Qf5cPezfTuyXbX1kkA3pT9bErPxn
doPDOzIopDTtfKpLoBiLqebmIRw/Df+SUMwKqnmnV38iwwDXpUaV/35Pkv3b
o+AzGfa2/Rx6r4PjJ35ajGOcDPy+fstXMLfYsZ+EfCPD6hus1eGYqbfqgt5O
ksH2Sv82x/8+/71WCKbJcEOHna+FOafYrvLmLBlGDWLeiGGepyo6yDBwfV7a
Js+Jue9O0MckJq4f7YqA/75/iV9VfXjyLxmiT3HW/ff7kmczERJbl3E8owVF
/ju//pDN7WYuCjhU7AjWxOz/98zm1XwUkB29+sIBc28/BytfkAL3fkQY7ccs
u0X4xrIIBY6mh56/hNmKbr07RIICL2JM+Qcxu0RKab+VogDPiaCY/76PcX+w
ah7JUSAruuJXEOZBuYk3NxUoEOkWGdD0X3yKpugyKhQ4Mjj/QRHH93Lu4yfH
1Cgwdzpw63+/J+lxG3r9U5MCL3V/v57D/PCszJpWfQoI3pRp/o3zVfyYGm9g
RAHSlJRZHM7vJ/6340UmFDB9+rtMHNfD0nZX3gPWFBib40xwx/Wyn21F/0Cm
QMP27Z+5cD1dO1d+3hko0P6snPwIM9f2FbdXOVPgpPTSeydcj9Ev5H6ddKUA
pfW4ggKu183NNRuZGyigtrCwYR5zR3d5Rq8HBWKPZZ18YUqge4bi/nbeFJg8
r3uWbob70yXFwCo/Clz3L8mkmxPo6D+DufTdFNjYeYn8wZJAb4Ktjs0FUuC2
ejWDgffPCctZiv8+CijpvC5ciffbs0dHtlAOUMB6JigrjkygVIoYNzOBAs+L
i/luUgn0k9aGgpIpAJah3cIOBBJJs3r4Lo0C01eSDx7B+799r3Nw/UkKOGZc
strrTKADP2c+x5ynQGaGf37NBpzPTWezhOsowHk4JPybH4GY9jcSOxsowH/h
hA7HDgJtMA17l/mYAiu5Tylp7CJQ8o+sBsFnFOiYLqnK2EOgU+yDcWJvKCD8
svh7ZxiBorh9LhnMUqBTQ1jGAvdb7vFN1XMEBT6ucz09k0YgbY9qciOTAlHb
C5fv437tf3HquwuHHSzMi5T75RAo26G6dL+4HRT5/IxfdZ5AZ5U7DbsN7EBn
I59OPH4fjLdkGFw2toNnMVG2b+rwfjeI6Awzt4NQj99jpvh94rvt2Vcxih3s
sPV/u4KO78969MZ7vR3w9u+ORq8JdEm7Tlw01A7ceuRE/H4RaM+p971cN+yg
7+ebR15G+H146xlnebUdnI7UuJxmykBh27p/rL1jB3e9zn5psGQgK0vHb2cf
2IEPvWe/JTBQyNKGRlKbHVi3HIs7uYWBkj0N+k+N2YG2SaFoxmEG6hWPEPuq
gsDEtCQsuZWBXoW3XzErQmDt/cWiKWwepYxvsgn2BJC7q1+WJ4zno8XHVkne
AJze3nolK5holcBgU6EvQHJYxO7bcky0vsPar30HwFyaemKLBhMd25X20TAI
wKU9Wbvdlok4spebZGMAdvpKW1uEMlFrScF552IAt+Ek9+42JpLlXvsu/CJA
HEXT2+8VE1V/ljtVeBnAKmGv82gvE6Xp9ez/Vgq4H9Xue/+RifRSlQdOVQH0
Ly14J/5hov5rPUNzjwG0wsz7DyrheXcs+9OKzwAy87tVjEPwvJrqtZr8BUAy
pYhSGc5CaTpKg3vHARJXuo3IRLFQ6TByb/oOoMmYs+vH86npZMKd8FmAtPHV
ye+zWcjEIMrxCxcVApLXS8xXs5C4lbitJC8V8OtxoeMOC+lE5qTa81PhpGNd
y+n7LHQswVfwujAVVrjplvx7xEKPb3t3hUhTofywxNjmThZa3FXixadNBbEf
Q1aPxvG8e0ST11aXCs+YxLbebyxkkxDKiFhNBdmyl8z3kyw03Dt1/r0hFcZX
pTp3zLBQV9eO/ruWVBC0WxIXxPP/yLPzR39YUyHdtbCl4R8LFR94761KpkLj
yboNfpxstFFthH4KqHB8/bma//4+NuG4jFz4Wip46m27IynBRv0HL+4vX0eF
vT/+rveSZKNfU9xzwxuosP/EE5tT0mxkXfU4Z7MbFdqff+3qk8d+OV97JdOD
CrMme7d+VsA+97X7U6snFcruUf+MKLFRvnjXkLkfFTbeOUyqU2WjlOa1BRHb
qXCfb6IuSx37803dmBs7qZD6wm2lmyYbORWb1yjvwfHIlXCp12EjqT+X6Pxh
VLA59uhHnwEbue0b/h0ZQYUmK9FIdyM2eh42RB0+SAULieKfrdjnEuxqnOuO
UEGFfi0pHPtfDe9upupRKnQ7th+7acZGvOHxz7PjcLxgnPoW+2JwfuLtPceo
YODdMDxvyUaxDsbtPSlUeJk3WzGFfbO7bJRBTqfCZLmwyBvspz/MGFY3MqiQ
z2rjrLBho+t1PadksvDz34o/tg/7rMn3t4zkbCp4HZpOVsD+OzMUuH/6FF7f
pWCORsyUotEZ3zwqLMVYzjtjXz5CupncfpYKSt4V259hZtWoKpsVUoH7JI+x
EfZvsnB5y9UiKjw6/CTkBOYdk+fDRC9QIbTQnb8Hs4WK36rYS7j+ast5+LDf
txxyeTtxhQpZ+Vd2rcbMfkTPcS/F9SKkvfK/7weGW9Sd6depsHtUbc1//54i
fWPX8poKKlQ9ijtngPnhtEr9+RtUiN3k4SuMuczhSDBfNRV6KFxHBvD9clnG
MlG3qRAvIPkrD/Pjx3caR+5QYYOxxBMbzAett3itv0cFGZvMqV78PF8UI380
1FEhs1Aw3guzn3JkhFYDFUy1c0Jf4ni82Vz7La+RCqM70ugGmI/6nd787zEV
xtarHUvE8Uz8ElEZ0ozPXyyoacLxlj55Z+pdCxVUY6U9fuJ8hLDvqjg8owKz
93UkP2apkQHrmjYqbLontEIS5y9nNJmi+IIK7hPj5sI4v/r8zIU/XVQYaU23
eIHr4UtFTtWOHir8vflN479/bwObbamdfVQQEpN8RDXB/q0fJVIygPPr8Eno
MK63Lo7XdiLv8eci1kMErseXpNH10R9xvVhaxwesYaMLCR8Z60ep8ON2zEFR
PTZSOFGc82CMCsXEro8uuJ4XtzWx1SbwfsxO2xClha9vsLBxfpIKecuXEwvU
2Gin4rt7Fwkq6AZ97pdYyUbbCJeXvAu4fi5s0GqTZSO1nLaqcBYVGjpKlkLw
frw3MtCC/uH+8JPjTKo4G92lKMuP8NsD6Jvt/sPDRsYGWi7KQvYwNVDp4cnF
RgWUfxQ/EXuoV+CNrV5moVy13UfeSdjDxnu0MiM2Cy1sn2K+WGkPkv4TqWen
WcjpzEbadX176KPPiI/1sxD/miinYQN7aCh4ui2ql4XMikwX5Uj4fnfrNBe6
WOh3oHFilpk9PJNISR5qY6GCld1PQin2sFcpXVqkgYWSfritV9lkD9GFIh52
RSyUKdoi7L4FX4/e/mpFPgs19Z0Nz3C3hzfuV9zf57LQg5v1Cr+97CHpyxTL
NQMfL6Ex93CXPShqX7x16zAL7RAuHiZH2kOEz8X4vM0sFLbXZX423x52rZ4K
KllmokZXuOp8zh4KftV7fWQx0X7Kp+aL5+1B7OjWTjGCiey2dW9zvGwPni/k
B3y/MxHR+XEht8IeXuc+/XW2h4lsH03ICTXaw0zusOGtK0x0JoH5OWfYHtzv
r7qdb81Ev9/YNz7RcoB3V14kPNqzgFrO2j0f03EAqRdRJvo7FpBYmqqFwGoH
SK+8M3LBawFdeMpau8nQAdq22V895rqARL4WUt5ZOEC0VqOIH2kBbdMYim53
dgD6b7drYYvzaC//ilGrfQ7wooku87pwHoW/tRZZF+oAW9fx3M8/PY9mIiPK
toU5QKJZxeOdWdjvH97USDzoAPuKbUK5E+eR/XFtv8ajDnDsvl5XauA8ekJb
qSyf5QAm7dUG8eb4eqmGmftvOsDzx+f7PwwxEI/UepZrtQNcp4W+fdDPQLPP
JVi6tx1A129q5Hw3Aw0cu3hjrNYB+q1ZzgeeM5Dmw8pP7g8dIHj96d6gWgb6
pJQhrNrhAE2Ux13ZWfj8UiI19KsDFLRENP6jMtALp6p/5G8OoFhzyOAehYEE
Zi8qiv1wAG2q5ooIawaqy2m1q/nlAB/yn25YIjFQzUkF8tScA2Txr807pMpA
I60vyry5aGDwyD/2LQcDKVKHpmZVaPCLMl2f347ns89zbiOqNFAc2LV/+SmB
bLyDA16p08CIbTkbheet/GzOrDJtGpzwfpIei+ex00ZX+D0MabBLI7/oXxWB
7A8I5pdSaGA+/3z82xkCDe0IUT6JaLAmM+Hin1wCOfQt74qi0sB4NuA4P54H
mwIKFRwcaWBHnOPZjOdFnlz5yJH1NBi9ctV0WzyBjHk7Tohso4F0S93uwGDM
wqt0Z7fTgK5hHy6zl0B8D/ny3u6kgdKZY3+6AwiUnhv69FIADVrHz0ftwX5e
ubP7uX4oDf4VrHok7EUgR9LcK7EwGuwtFZ8W30ogt5nostlwGmy5Q7mv4o59
oer06/pIGoju8+bbhn385LsUJRRLg4khL0lPFwK9jjHrVI2ngepGYaMaJzy/
03W3cCXSYN0JP0IS+/m6a13Tz5JpoFfulMLG8/ul8Bj+8lQaNNRd2JQIBEq5
47t0PJ0G/PrfX4tgP/eSa0lzyaTB+RfnJ9fi+X9Dvr283kkaTG1MzWJiP5iL
ns8WzKHBipK4sVrs4+ulZ5Q7T+N4lF9rp2G/ABth9toiGoxPzGT8xP6tyHg8
KFhMA7PvL2M5ML98GnvtxQUaHJk70aOCfcad5Mex9goNmg+dqIw2wj4kr5Iv
UEIDSl7jmrvYjxwqDOQ6SmkQy3Fbbh77lOrWw9NO5TToHOjRLMa+dXfFJhpf
JQ2obDEXNvYxtk9D9vMbNJi+d6g/APP0WHJHWhUN+nwzO99hf0sPjGc63KLB
DK1/tTvm+vwYZe4aGjh1fGQMYt+L1nG2ar1Dg0Gb1WuCMSsNNaxNvksDGRX7
1xyYV76+7Ab38ecFYR9LsU/ulel0X66jwXa+Z54bMVdfFd745AENkkg7KdyY
C/zN7BMe4vPfep9uwb76Yq2MMfkRDdj3OzdlYv7jmqT49zENBPJex/libvB0
4Gp8QgP51YnS//0+oW2HyUQMnQY81LmVKzFv2aPcYdmK67MHZfNhlil5Wzn/
lAaXK1eHLmH/vruon1n3nAYPi3fW/8cBbrP7DrXTwH1vdhg/Pn5Pwvw60xd4
v73ccVrhv99XeIuQ/nTSQCQzTcUSM5nOLVf7iga1O6vktmPOPHWL88BrXP9i
yXHZmMWuvJ8x7MHP63lv7XPMnp/9vk714vos+5jMj5+3dRXX5+o3NHh/0lnD
HfP1N5dGQ9/i/N4wM6jEbHhgeXL1AA1yDL9e5sPxLNi3sPhjENePa3F0OGYh
M0/5G+9poL2moH4E87RIVrjOMA0Muf33DON89XBzVE2M4OfddL83FOfXpFiF
KBvF+RjXL+XC9bDHtKBG8ysNGgXfBa3H9SJSla0xPkEDfdIt32XM5V9CK659
p4Fa1FzVf/69M071i/ov3E/iZQM3Y//22lJQ/GWKBhJD5zp1cX3a95L2lv6m
gUlVd6YQrl+/n/I26nN4PYJJ4pPYv7nnuGhfCBrkke/3fcP+vWS0aU/pPA3c
9mz5MY39u5Rw+anOxvkKBKGV2Ldv9551H/uLj6/cvIKM90/Hqbi315ZocOa+
Y2Aw3l8oxU9Pi9MRNldM/fqI999Gi3c6egKO4FCzn2puTyBdb7HLo4KOIDT2
xfQC9u/NHiKmxcKOILqwyCeE9/uM887HwuKO0Jym7syF+4P83RD/GRlHkOat
mN62kUCrrEa/3JBzhOcfWioENxPoA9+qzICVjkDfNmjYvIVAse6/nQaUHOHN
L51LNNyPBNraLtI1HGFWwupOwzYCvXvh5xOn5Qg1B91yq7Cv+3VUgYUOvr41
WbsC+/pO76gz1asdweP09YgG7OtPz3t4XTB2hLZ+UHTAvk7ekySUghxBqrv+
DSMJ+3Yex0tEdQTVhoKySOzvX7VnW5bsHeG66t6FBezvWwY4PWOdHOHhqTAh
pSzc30sF9Y9scITBVT9jX+QT6E2Vl+5RP0do+tJwoQ73e+mU9V610Y7wS4Ca
WjNCIIP5m+8uHcXxa5N+lzSG15e+/05WnCP4SlEDfb4RaKtT3JHAJEdYNegu
q/ubQLs6TfesynAEQi6z3WQZ92d7h2NlhY6w4ni/FwO/r9aUsXw46h2h0H7q
10QIA+m0FzxkPXCEZT3rmy8jGOjP34XsuYeOoJSuvrHhEAMVv+M8873JEeYc
82VvJDKQpQrSG3zuCBt3XiJ9O8NAnks0nddvHUE9JutXx2MGEl1lx1w57whT
Dyo86mTm0dTvJuBgOkJr8RQhqziPDg3/Wp5gOUJPN19jguo88mPyjtctOUKD
gUmkr/48Enw3t9GH1wnclOjvNlLnUdS/GOEH0k4Q+CBVSCZ8HkWqlt/oMXUC
W841XBc65xHX16qdJ6OcYMEq+rvmyQUULXRA5fVhJzh3SHD5d94CapxVT1sR
4wQyO3aJPSpaQELLBrTieCfQffrq+ObyBZRzuLTgXroTbPznOXGoZQEZCPza
x1vkBNS130VTF/C8xJd8SLPJCTjv9gRX+jNRidHS87hmJ3But8rUC2aio3p8
D960OEHNUNXrsnAmCu8bPJze5gSh3y5p5sYxUeGqs94z3U5w8tKhBNUCJjpy
YNBk7IsT/ByoKl7ZzkRXKT9taV+dQAccq627mKhlo+aHsm9OUN9luM7tDRP1
0QWGQn454f5Zlbl/hIkU7iQ1/WU4Qchc0RFYYKKvn1N2+zOdoOz5oV2qS0xk
Sd93rp3tBFHnazIXuFjoyIuUWwXLTjB07v5clhgLMeQ4c5Y4neHdEf9RJ2kW
OuExxQzkcQazsUPBrJUsdDzbb+Y1nzMYD5zdWbqKhdz6d0ZaCTqDT/XuS//9
fxP/A1K0buE=
        "]]}},
     Annotation[#, "Charting`Private`Tag$81485387#1"]& ]}, InsetBox[
    StyleBox["\<\"\\!\\(\\*SubscriptBox[\\(v\\), \\(s\\)]\\) = 0.6\"\>",
     StripOnInput->False,
     FontSize->14,
     FontColor->RGBColor[0.368417, 0.506779, 0.709798]], {4.5, 0.35}], 
   InsetBox[
    StyleBox["\<\"\\!\\(\\*SubscriptBox[\\(v\\), \\(s\\)]\\) = 0.8\"\>",
     StripOnInput->False,
     FontSize->14,
     FontColor->RGBColor[0.880722, 0.611041, 0.142051]], {4.2, 0.64}], 
   InsetBox[
    StyleBox["\<\"\\!\\(\\*SubscriptBox[\\(v\\), \\(s\\)]\\) = 1\"\>",
     StripOnInput->False,
     FontSize->14,
     FontColor->RGBColor[0.560181, 0.691569, 0.194885]], {4.1, 0.84}], 
   InsetBox[
    StyleBox["\<\"\\!\\(\\*SubscriptBox[\\(v\\), \\(s\\)]\\) = 1.25\"\>",
     StripOnInput->False,
     FontSize->14,
     FontColor->RGBColor[0.922526, 0.385626, 0.209179]], {3.9, 1.17}], 
   InsetBox[
    StyleBox["\<\"\\!\\(\\*SubscriptBox[\\(v\\), \\(s\\)]\\) = 1.5\"\>",
     StripOnInput->False,
     FontSize->14,
     FontColor->RGBColor[0.528488, 0.470624, 0.701351]], {3.9, 1.41}]},
  AspectRatio->Full,
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0.12029381178379213`},
  DisplayFunction->Identity,
  Frame->True,
  FrameLabel->{{
     FormBox["\"v\"", TraditionalForm], 
     FormBox["\"\"", TraditionalForm]}, {
     FormBox["\"\[Phi]\"", TraditionalForm], 
     FormBox["\"\"", TraditionalForm]}},
  FrameStyle->Thickness[0.003],
  FrameTicks->{{Automatic, Automatic}, {{{0, 
       FormBox["0", TraditionalForm]}, {
       NCache[2 Pi, 6.283185307179586], 
       FormBox[
        RowBox[{"2", " ", "\[Pi]"}], TraditionalForm]}, {
       NCache[4 Pi, 12.566370614359172`], 
       FormBox[
        RowBox[{"4", " ", "\[Pi]"}], TraditionalForm]}, {
       NCache[6 Pi, 18.84955592153876], 
       FormBox[
        RowBox[{"6", " ", "\[Pi]"}], TraditionalForm]}, {
       NCache[8 Pi, 25.132741228718345`], 
       FormBox[
        RowBox[{"8", " ", "\[Pi]"}], TraditionalForm]}}, None}},
  FrameTicksStyle->GrayLevel[0],
  GridLines->
   NCache[{{0, 2 Pi, 4 Pi, 6 Pi, 8 Pi}, Automatic}, {{
     0, 6.283185307179586, 12.566370614359172`, 18.84955592153876, 
      25.132741228718345`}, Automatic}],
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImageSize->Medium,
  LabelStyle->{
    GrayLevel[0], FontSize -> 14},
  Method->{"ScalingFunctions" -> None},
  PlotRange->
   NCache[{{0, 8 Pi}, {0, 1.8}}, {{0, 25.132741228718345`}, {0, 1.8}}],
  PlotRangeClipping->True,
  PlotRangePadding->0,
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{{3.717433773296947*^9, 3.717433811200652*^9}, 
   3.717433842368272*^9, 3.7174338768097067`*^9, {3.717434094091977*^9, 
   3.7174341834967203`*^9}, {3.717434269700963*^9, 3.717434288192966*^9}, {
   3.71743435274162*^9, 3.717434447517768*^9}, {3.717434554743972*^9, 
   3.717434576868005*^9}, {3.717441121085411*^9, 3.717441281778709*^9}, {
   3.717441363477622*^9, 3.717441449490122*^9}, {3.7174414927645206`*^9, 
   3.7174417198292217`*^9}, {3.717441771735805*^9, 3.717441776151491*^9}, {
   3.717441818792039*^9, 3.717441834296788*^9}, {3.717441941687922*^9, 
   3.717442025676672*^9}, {3.717442092354024*^9, 3.717442115093585*^9}, {
   3.717442146053355*^9, 3.717442159320788*^9}, {3.717442196786564*^9, 
   3.717442226757389*^9}, 3.717442295079501*^9, {3.717443787087429*^9, 
   3.717443822621784*^9}}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
WindowSize->{1020, 1287},
WindowMargins->{{24, Automatic}, {Automatic, 0}},
PrintingCopies->1,
PrintingPageRange->{1, Automatic},
FrontEndVersion->"11.0 for Mac OS X x86 (32-bit, 64-bit Kernel) (September \
21, 2016)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[580, 22, 390, 9, 93, "Title"],
Cell[CellGroupData[{
Cell[995, 35, 150, 2, 65, "Chapter"],
Cell[1148, 39, 382, 10, 87, "Text"],
Cell[1533, 51, 15979, 374, 961, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[17549, 430, 479, 15, 111, "Chapter"],
Cell[CellGroupData[{
Cell[18053, 449, 508, 8, 32, "Input"],
Cell[18564, 459, 49954, 856, 377, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[68555, 1320, 276, 5, 32, "Input"],
Cell[68834, 1327, 28952, 508, 377, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[97823, 1840, 219, 5, 32, "Input"],
Cell[98045, 1847, 74989, 1269, 377, 61236, 1042, "CachedBoxData", "BoxData", \
"Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[173071, 3121, 273, 5, 32, "Input"],
Cell[173347, 3128, 24477, 432, 377, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[197861, 3565, 196, 4, 32, "Input"],
Cell[198060, 3571, 253058, 4189, 377, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[451179, 7767, 151, 2, 92, "Title"],
Cell[CellGroupData[{
Cell[451355, 7773, 435, 15, 66, "Chapter"],
Cell[451793, 7790, 527, 15, 32, "Text"],
Cell[452323, 7807, 9857, 237, 674, "Input"],
Cell[462183, 8046, 259, 8, 51, "Text"],
Cell[CellGroupData[{
Cell[462467, 8058, 5360, 136, 264, "Input"],
Cell[467830, 8196, 60545, 1023, 447, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[528424, 9225, 498, 15, 66, "Chapter"],
Cell[528925, 9242, 605, 16, 32, "Text"],
Cell[529533, 9260, 10684, 251, 695, "Input"],
Cell[540220, 9513, 226, 7, 51, "Text"],
Cell[CellGroupData[{
Cell[540471, 9524, 4932, 135, 264, "Input"],
Cell[545406, 9661, 113067, 1888, 447, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

