(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 11.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[    688346,      12025]
NotebookOptionsPosition[    686397,      11955]
NotebookOutlinePosition[    686812,      11973]
CellTagsIndexPosition[    686769,      11970]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell[TextData[{
 "Basins of attraction in (\[Phi], ",
 Cell[BoxData[
  FormBox["v", TraditionalForm]]],
 ") space"
}], "Title",
 CellChangeTimes->{{3.701617365402061*^9, 3.7016173954719267`*^9}, {
  3.701617510283918*^9, 3.7016175130917788`*^9}, {3.701623589396885*^9, 
  3.7016236167302847`*^9}, {3.701623685255353*^9, 3.7016236925724*^9}, {
  3.701625112759225*^9, 3.701625120286673*^9}}],

Cell[CellGroupData[{

Cell["Main function(s)", "Chapter",
 CellChangeTimes->{{3.701623605034238*^9, 3.701623609305955*^9}, {
  3.701623714566551*^9, 3.701623716605515*^9}}],

Cell["\<\
Define function that generates phase plot of (\[Phi], v) with attractors and \
their basins of attraction.

Note: Specify MaxRecursion in RegionPlot settings to get a lower-res plot \
quickly.
\
\>", "Text",
 CellChangeTimes->{{3.701617271907969*^9, 3.701617360665495*^9}, {
  3.701617400314217*^9, 3.70161741013551*^9}, {3.701618296007701*^9, 
  3.701618374571699*^9}, {3.717280982489702*^9, 3.7172810068867273`*^9}, {
  3.722649376732252*^9, 3.722649377265223*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"ClearAll", "[", 
   RowBox[{
   "vS", ",", "tMax", ",", "vMin", ",", "maxRec", ",", "Q", ",", "\[Alpha]", 
    ",", "\[Gamma]", ",", "endP", ",", "\[Phi]0", ",", "v0", ",", "\[Phi]", 
    ",", "v", ",", "vC", ",", "t", ",", "basinFunc", ",", "\[Phi]E", ",", 
    "vE", ",", "n0", ",", "p1", ",", "x", ",", "y", ",", "p2", ",", "n", ",", 
    "title"}], "]"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"plotBasins0", "[", 
   RowBox[{
    RowBox[{"vS_", "?", "NumericQ"}], ",", 
    RowBox[{"tMax_", "?", "NumericQ"}], ",", 
    RowBox[{"vMin_", "?", "NumericQ"}]}], "]"}], ":=", "\[IndentingNewLine]", 
  
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"Q", "=", "1.1"}], ",", 
      RowBox[{"\[Alpha]", "=", "4.6"}], ",", 
      RowBox[{"\[Gamma]", "=", "0.05"}], ",", "endP", ",", "basinFunc", ",", 
      "p1", ",", "p2", ",", "hLines", ",", "vLines", ",", "p3", ",", 
      "title"}], "}"}], ",", "\[IndentingNewLine]", "\[IndentingNewLine]", 
    RowBox[{"(*", " ", 
     RowBox[{"Map", " ", "initial", " ", "phase", " ", "point", " ", 
      RowBox[{"(", 
       RowBox[{"\[Phi]0", ",", "v0", ",", "vC0"}], ")"}], " ", "to", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"\[Phi]", "[", "tMax", "]"}], ",", 
        RowBox[{"v", "[", "tMax", "]"}]}], ")"}]}], " ", "*)"}], 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"endP", "[", 
       RowBox[{
        RowBox[{"\[Phi]0_", "?", "NumericQ"}], ",", 
        RowBox[{"v0_", "?", "NumericQ"}]}], "]"}], ":=", 
      RowBox[{"Module", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"\[Phi]", ",", "v", ",", "vC"}], "}"}], ",", 
        RowBox[{
         RowBox[{"Reap", "[", 
          RowBox[{"NDSolve", "[", 
           RowBox[{
            RowBox[{"{", "\[IndentingNewLine]", 
             RowBox[{
              RowBox[{
               RowBox[{"\[Phi]", "[", "0", "]"}], "\[Equal]", "\[Phi]0"}], 
              ",", 
              RowBox[{
               RowBox[{"v", "[", "0", "]"}], "\[Equal]", "v0"}], ",", 
              RowBox[{
               RowBox[{"vC", "[", "0", "]"}], "\[Equal]", "0"}], ",", 
              "\[IndentingNewLine]", 
              RowBox[{
               RowBox[{
                RowBox[{"\[Phi]", "'"}], "[", "t", "]"}], "\[Equal]", 
               RowBox[{"v", "[", "t", "]"}]}], ",", "\[IndentingNewLine]", 
              RowBox[{
               RowBox[{
                RowBox[{"v", "'"}], "[", "t", "]"}], "\[Equal]", 
               RowBox[{
                FractionBox["1", 
                 SuperscriptBox["Q", "2"]], 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{"1", "+", "\[Gamma]"}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{"vS", "-", 
                    RowBox[{"v", "[", "t", "]"}], "-", 
                    RowBox[{"Sin", "[", 
                    RowBox[{"\[Phi]", "[", "t", "]"}], "]"}]}], ")"}]}], "-", 
                  
                  RowBox[{"vC", "[", "t", "]"}]}], ")"}]}]}], ",", 
              "\[IndentingNewLine]", 
              RowBox[{
               RowBox[{
                RowBox[{"vC", "'"}], "[", "t", "]"}], "\[Equal]", 
               RowBox[{
                FractionBox["\[Alpha]", 
                 SuperscriptBox["Q", "2"]], 
                RowBox[{"(", 
                 RowBox[{"vS", "-", 
                  RowBox[{"v", "[", "t", "]"}], "-", 
                  RowBox[{"vC", "[", "t", "]"}], "-", 
                  RowBox[{"Sin", "[", 
                   RowBox[{"\[Phi]", "[", "t", "]"}], "]"}]}], ")"}]}]}]}], 
             "}"}], ",", "\[IndentingNewLine]", 
            RowBox[{"{", "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"t", ",", "0", ",", "tMax"}], "}"}], ",", 
            "\[IndentingNewLine]", 
            RowBox[{"Method", "\[Rule]", 
             RowBox[{"{", 
              RowBox[{"\"\<EventLocator\>\"", ",", 
               RowBox[{"\"\<Event\>\"", "\[Rule]", 
                RowBox[{"(", 
                 RowBox[{"t", "\[Equal]", "tMax"}], ")"}]}], ",", 
               "\[IndentingNewLine]", 
               RowBox[{"\"\<EventAction\>\"", "\[RuleDelayed]", 
                RowBox[{"Sow", "[", 
                 RowBox[{"{", 
                  RowBox[{
                   RowBox[{"\[Phi]", "[", "t", "]"}], ",", 
                   RowBox[{"v", "[", "t", "]"}]}], "}"}], "]"}]}]}], 
              "}"}]}]}], "]"}], "]"}], "\[LeftDoubleBracket]", 
         RowBox[{
          RowBox[{"-", "1"}], ",", "1", ",", "1"}], 
         "\[RightDoubleBracket]"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
     "\[IndentingNewLine]", 
     RowBox[{"(*", " ", 
      RowBox[{
       RowBox[{
       "Check", " ", "if", " ", "point", " ", "flows", " ", "to", " ", "0", 
        " ", "or", " ", "1", " ", "state"}], ";", " ", 
       RowBox[{"return", " ", "appropriate", " ", "\"\<color\>\""}]}], " ", 
      "*)"}], "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"basinFunc", "[", 
       RowBox[{
        RowBox[{"\[Phi]0_", "?", "NumericQ"}], ",", 
        RowBox[{"v0_", "?", "NumericQ"}]}], "]"}], ":=", 
      RowBox[{"Module", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"\[Phi]E", ",", "vE", ",", "n0"}], "}"}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{
          RowBox[{"{", 
           RowBox[{"\[Phi]E", ",", "vE"}], "}"}], "=", 
          RowBox[{"endP", "[", 
           RowBox[{"\[Phi]0", ",", "v0"}], "]"}]}], ";", 
         "\[IndentingNewLine]", 
         RowBox[{"n0", "=", 
          RowBox[{"1", "-", 
           RowBox[{"2", 
            RowBox[{"Mod", "[", 
             RowBox[{
              RowBox[{"Round", "[", 
               FractionBox["\[Phi]E", 
                RowBox[{"2", "\[Pi]"}]], "]"}], ",", "2"}], "]"}]}]}]}], ";", 
         "\[IndentingNewLine]", 
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"Abs", "[", "vE", "]"}], "<", "vMin"}], ",", "n0", ",", 
           "0"}], "]"}]}]}], "]"}]}], ";", "\[IndentingNewLine]", 
     "\[IndentingNewLine]", 
     RowBox[{"(*", " ", 
      RowBox[{
      "Plot", " ", "stable", " ", "manifolds", " ", "of", " ", "0", " ", 
       "states"}], " ", "*)"}], "\[IndentingNewLine]", 
     RowBox[{"p1", "=", 
      RowBox[{"RegionPlot", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{"basinFunc", "[", 
            RowBox[{"x", ",", "y"}], "]"}], ">", "0.5"}], ",", 
          RowBox[{
           RowBox[{"basinFunc", "[", 
            RowBox[{"x", ",", "y"}], "]"}], "<", 
           RowBox[{"-", "0.5"}]}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"x", ",", 
          RowBox[{
           RowBox[{"-", "2"}], "\[Pi]"}], ",", 
          RowBox[{"2", "\[Pi]"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"y", ",", 
          RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
        RowBox[{"PlotPoints", "\[Rule]", "40"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", "\[IndentingNewLine]", 
     RowBox[{"(*", " ", 
      RowBox[{"Plot", " ", "0", " ", "state", " ", "attractors"}], " ", 
      "*)"}], "\[IndentingNewLine]", 
     RowBox[{"p2", "=", 
      RowBox[{"ListPlot", "[", 
       RowBox[{
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{
             RowBox[{"ArcSin", "[", "vS", "]"}], "+", 
             RowBox[{"2", "n", " ", "\[Pi]"}]}], ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"n", ",", 
            RowBox[{"-", "1"}], ",", "1"}], "}"}]}], "]"}], ",", 
        RowBox[{"PlotStyle", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{"Black", ",", 
           RowBox[{"PointSize", "[", "0.018", "]"}]}], "}"}]}]}], "]"}]}], 
     ";", "\[IndentingNewLine]", "\[IndentingNewLine]", 
     RowBox[{"(*", " ", 
      RowBox[{"Plot", " ", "gridlines"}], " ", "*)"}], "\[IndentingNewLine]", 
     
     RowBox[{"hLines", "=", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"Line", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "2"}], "\[Pi]"}], ",", "n"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"2", "\[Pi]"}], ",", "n"}], "}"}]}], "}"}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"n", ",", 
          RowBox[{"-", "1"}], ",", "1"}], "}"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"vLines", "=", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"Line", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"n", " ", "\[Pi]"}], ",", 
             RowBox[{"-", "2"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"n", " ", "\[Pi]"}], ",", " ", "2"}], "}"}]}], "}"}], 
         "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"n", ",", 
          RowBox[{"-", "1"}], ",", "1"}], "}"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"p3", "=", 
      RowBox[{"Graphics", "[", 
       RowBox[{"{", 
        RowBox[{"Black", ",", 
         RowBox[{"Thickness", "[", "0.003", "]"}], ",", 
         RowBox[{"Join", "[", 
          RowBox[{"hLines", ",", "vLines"}], "]"}]}], "}"}], "]"}]}], ";", 
     "\[IndentingNewLine]", "\[IndentingNewLine]", 
     RowBox[{"title", "=", 
      RowBox[{
       RowBox[{
       "StringTemplate", "[", 
        "\"\<\!\(\*SubscriptBox[\(v\), \(s\)]\) = `a`,  \
\!\(\*SubscriptBox[\(v\), \(c\)]\) = 0\>\"", "]"}], "[", 
       RowBox[{"<|", 
        RowBox[{"\"\<a\>\"", "\[Rule]", "vS"}], "|>"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"Show", "[", 
      RowBox[{"p1", ",", "p2", ",", "p3", ",", 
       RowBox[{"Frame", "\[Rule]", "True"}], ",", 
       RowBox[{"FrameStyle", "\[Rule]", 
        RowBox[{"Thickness", "[", "0.004", "]"}]}], ",", 
       RowBox[{"PlotRangePadding", "\[Rule]", "0"}], ",", 
       RowBox[{"FrameTicks", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"Automatic", ",", "Automatic"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"Range", "[", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "2"}], "\[Pi]"}], ",", 
              RowBox[{"2", "\[Pi]"}], ",", "\[Pi]"}], "]"}], ",", "None"}], 
           "}"}]}], "}"}]}], ",", 
       RowBox[{"FrameTicksStyle", "\[Rule]", "Black"}], ",", 
       RowBox[{"LabelStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Black", ",", 
          RowBox[{"FontSize", "\[Rule]", "14"}]}], "}"}]}], ",", 
       RowBox[{"FrameLabel", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"\"\<v\>\"", ",", "\"\<\>\""}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"\"\<\[Phi]\>\"", ",", "title"}], "}"}]}], "}"}]}], ",", 
       RowBox[{"ImageSize", "\[Rule]", "Medium"}]}], "]"}]}]}], 
   "\[IndentingNewLine]", "]"}]}]}], "Input",
 CellChangeTimes->{{3.701616831290078*^9, 3.7016169164710703`*^9}, {
   3.701616948901993*^9, 3.7016169661637983`*^9}, {3.701617000883959*^9, 
   3.7016172598806353`*^9}, 3.701617530589541*^9, {3.7016177238311853`*^9, 
   3.701617727326652*^9}, {3.701617927447769*^9, 3.701617935246566*^9}, 
   3.701617971062707*^9, 3.701618026140562*^9, {3.701619588835003*^9, 
   3.701619719339616*^9}, {3.701619767641157*^9, 3.701619771755686*^9}, {
   3.70204139579523*^9, 3.702041402395287*^9}, {3.70204171009578*^9, 
   3.702041712602021*^9}, {3.7020417922913427`*^9, 3.702041792466456*^9}, {
   3.71050836514705*^9, 3.7105083770287247`*^9}, {3.710508604125107*^9, 
   3.7105087477368183`*^9}, {3.710508818066979*^9, 3.710508819041898*^9}, {
   3.710508859057659*^9, 3.710508884935256*^9}, 3.710508926206873*^9, {
   3.710509069904646*^9, 3.7105090784313383`*^9}, 3.710509183044546*^9, {
   3.710509254833254*^9, 3.7105093398925133`*^9}, {3.710509397810589*^9, 
   3.710509468463674*^9}, {3.7105095201433363`*^9, 3.710509525056185*^9}, {
   3.710521659946271*^9, 3.7105216814305477`*^9}, {3.71052173069954*^9, 
   3.710521740394382*^9}, {3.7105217903838778`*^9, 3.710521802984839*^9}, {
   3.710521978409327*^9, 3.710522082276393*^9}, {3.710522347585987*^9, 
   3.710522355344901*^9}, {3.710523634924687*^9, 3.710523695825746*^9}, {
   3.710524190104007*^9, 3.710524221664567*^9}, {3.710524318116907*^9, 
   3.710524328086734*^9}, {3.7105243766822233`*^9, 3.710524441846766*^9}, {
   3.710524475962582*^9, 3.710524503145587*^9}, 3.71052482733425*^9, 
   3.710524876555978*^9, {3.710524907624243*^9, 3.710524911694405*^9}, 
   3.71052494719786*^9, 3.710525013125198*^9, 3.710525044917922*^9, {
   3.71052521906102*^9, 3.7105252214512053`*^9}, {3.710525439027808*^9, 
   3.710525451969057*^9}, {3.710525656685484*^9, 3.710525684593836*^9}, 
   3.7105382651526613`*^9, {3.710542020320714*^9, 3.710542020941835*^9}, 
   3.7105421601714087`*^9, {3.7105422099372787`*^9, 3.710542216784234*^9}, {
   3.7105422504507713`*^9, 3.710542417388795*^9}, {3.710542450458741*^9, 
   3.710542565539653*^9}, {3.7105426536669083`*^9, 3.7105426775596933`*^9}, {
   3.7105429017672873`*^9, 3.71054290526338*^9}, {3.710542949529475*^9, 
   3.710543039878704*^9}, {3.710543092110879*^9, 3.710543191251333*^9}, {
   3.710543369653121*^9, 3.710543386743935*^9}, {3.710543769136091*^9, 
   3.71054377019109*^9}, {3.710559286807695*^9, 3.710559300293632*^9}, {
   3.710559874806834*^9, 3.710559875641068*^9}, {3.710560004401122*^9, 
   3.710560017539118*^9}, {3.71056018949837*^9, 3.710560484500944*^9}, {
   3.7105981177383623`*^9, 3.71059812095304*^9}, {3.7105986367961063`*^9, 
   3.7105986741309423`*^9}, 3.710598767191904*^9, {3.710598860051385*^9, 
   3.710598868025057*^9}, {3.710599438746784*^9, 3.7105994426253357`*^9}, {
   3.710599678177288*^9, 3.710599683199548*^9}, {3.7172800158118973`*^9, 
   3.717280051887767*^9}, {3.7172801645901012`*^9, 3.717280165602796*^9}, {
   3.717280223154845*^9, 3.7172802302424717`*^9}, {3.71728027103231*^9, 
   3.7172802918684893`*^9}, {3.7172803373729486`*^9, 3.717280343486486*^9}, 
   3.717280389499937*^9, 3.717280442810063*^9, {3.717280619235106*^9, 
   3.717280736332333*^9}, {3.717280796971384*^9, 3.717280832088307*^9}, {
   3.717280966134192*^9, 3.7172809765797367`*^9}, {3.717370198107017*^9, 
   3.7173701991774893`*^9}, {3.71737770946075*^9, 3.717377712644412*^9}, {
   3.7173806463597927`*^9, 3.717380652390786*^9}, 3.717423437229248*^9, 
   3.7174287077020893`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "Plots for various values of source voltage ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["v", "s"], TraditionalForm]]],
 " (initial capacitor voltage ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["v", "c"], "=", "0"}], TraditionalForm]]],
 ")"
}], "Chapter",
 CellChangeTimes->{
  3.701617435715375*^9, {3.701617471381598*^9, 3.70161754037291*^9}, {
   3.701619790911727*^9, 3.701619832218857*^9}, {3.710608424066423*^9, 
   3.7106084272977457`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"plotBasins0", "[", 
  RowBox[{"0", ",", "400", ",", "0.05"}], "]"}]], "Input",
 CellChangeTimes->{{3.710543193920143*^9, 3.710543220939678*^9}, {
   3.710543786910775*^9, 3.710543787110448*^9}, {3.710559793461051*^9, 
   3.710559794569069*^9}, {3.710559851888933*^9, 3.710559856261856*^9}, {
   3.7105599589510107`*^9, 3.710559962716969*^9}, {3.710560112430778*^9, 
   3.7105601129269133`*^9}, {3.710598898919285*^9, 3.710598899109128*^9}, {
   3.710599521429411*^9, 3.71059953658687*^9}, 3.717280177620079*^9, 
   3.717280928716217*^9, 3.717281003856843*^9, 3.717281089389228*^9, 
   3.717281371170541*^9, 3.71736730391859*^9}],

Cell[BoxData[
 GraphicsBox[{GraphicsComplexBox[CompressedData["
1:eJztnPl7zsfex2NfIglBQo7qYov1UaW6aGc0tNWiaWgpTpSuTlCnjiBFUzSW
HrW3qqq2OlpK2mpV5XS+HERstUdRa3JXiISoPZon5/7cr8l1jeu5nn8gfnG9
rrlz3+/vzHyW+cx35t6Bb8W9VjYoKKhD5aCg//5f9H1U1x/HRHhn/j0mvago
3/xnV49hIzJrWp6U/c85bdrUsPzRzQ/+fqJuiOX6zf5c/9IvlSwvf2lY2QMT
y1ruF75l7oJ/3DRw5um4bveZfMu5Hdsfj2h20PIhYQU/uvBUk1v31vUmv370
yurFuQa9MHph9MLohdELoxdGL/yn/J6GA3pc9lqGPdIwPibH6oPRB6MPRh+M
Phh9cIr8vYY3yfdbRi+MXpj+3bduXlxIdrbZKeNh+UV5fstL5fc1/BfRZ3m2
6LeMPhh9MPpg5sPIl68lp6WctvMBRi+MXhi9MHph9MLohdELoxdG30Phq+Iz
Y49bfTD6YPTB6IPRB6MPRh+MPpj5Of6VQRvazcm0+mD0weiD0QejD0YfjD4Y
fTDzc+faxnXmZO6x+mD0weiD0QejD0YfjD4YfTD6YPQ1r7YtJ6vdZqsPRh+M
Phh9MPpg9MHog9EHY9/Xf6o6LaXgK6sPRh+MPhh9MPpg9MHog9EHow9GX5qw
Qh+MPhh9MPpg9MHog9EHow9GH4y+etKfVh+MPhh9MPpg9MHog9EHow/Gf2+W
+Wb1weiD0QejD0YfjD4YfTD6YPTB6EsSe7X6YPTB6IPRB6MPRh+MPhh9MPGv
tfgzqw9GH4w+GH0w+mD0weiD0QcTn4eLv7f6YPTB6IPRB6MPRh+MPhh9MPpg
8ondEi+tXhi9MHph9MLohdELoxdGL0y+01TyCasPRh+MPpj5CWPfMP4bJv7B
xGeYfAIm33HYmyj5mtULMz9h9MHog9EHow9GH4w+GH2wk/8qJ/+18wFGL4xe
GL0wemH0wuiF0Qvf5f++SO9Bv73k2XwXzvLrvWJgn5+zLdeTv9fwSX97bX3E
78/P2fyU9gP+5y0ytDM/4T3+9jCd7Pcnv9t8jXb00n5Kfs8y+uEv/P0Xbnmf
fL/lPv7fr2r5tP/7KlgO8v/bmtbQHw+y7PPSTn/QTn9t9/vnkzae007/uJ//
zf98R8wy0av5e/qHdvqvif/vD9j+op3xh2nn8zxfjr/9J9NLnl+f9vN2m1/B
tPN5+muHsIL3yefVCfl+TTv+inb6/27RY/mg6FW75fkU7fgX2hnPrdI/6rj0
n6Id+4Fp5/PMl3uk/+38HyPjqRhv2o/J+CqY+cXn0Q/z/DDPc0jmr6I/aWd8
YMYfZr7AzD8Y+4J5Pn6P/oDpj7Zij/b5YZ4P5vlh/BWMHpj44voP1tM8j7ve
x56ILzDjDzOfYOKfa6+sP+kf2tFLO/pYf9H/MPbGeojxgrEn8n/GF8Y+yCeZ
HzDzh/yJ+QIz38lnGD+Y8SN+E1+Yr/QH7cQP5gv2DuM/YPwvTPyAGS/mF/OP
+IdeNz4yX1b4n6/A9E+LaRYz+oLJvxU99439tTU8z6/vtin/2pLeBVHnTIus
/GFfjaqjvwwpM2lxms+2t/bnA7+akc0//e3U5OoaHpGyotzj6cE6xa833awd
+taJ5MGhXkv/7+9WH30+7tkJR2t44/36jqkof/9cU3DosGrlqjSO9K4NaF1/
dEi22uF/ni0K3jepc5OtybW8r6sP3xi1/bz9exi91d6sNTshOh/2AmzjFXyP
/L35Rv7e7JXv1/A1+X1zS37fhIg+DfP3U0W/mSvPp+Fv5fn1Y/L8ZpT0jzdS
+keNkv7zoqX/1CzpXwWj/wvpf+svYD4fJOOlLsp4ev1kPNUSGW8FMx8YT5j+
SvfbwwlbLzwmbPMp5vf/wcbpf+P0vyJ+u9/P54nfzni536cdf2O/H3+C/4Gp
1+FfyQdgvg/7oR2mHX9BO0w7/oZ2mHb8Fe0w7fg/8gHWF/Bmv/2X87Av/KGM
w+o0/DPcwd8/VbyF/r+fb+2J8fuu5sD1DVvV1I69e8wP5hO8Vj5vmflrOTC/
YfwBjL34/L9/wvqPA/7nP2ifn3rTZL9/LOMl+ddv+yyTX/H9e/yf92x/UH8J
+uG//rOi18b/+bWWya8YH/oLfw0/LP2nIzb4+88+30b5PRs/yLdsfTfAG2W8
tGvvO+V5rf2SP+HPjkv/2HyP+AITX9CDP+D5+TzM5+lf2mHaic+0w7Rjv7TD
tNNf6GF8YPwhzPjD+E+Y+Qnjn2HiF4x/hvEXMPGdeAqzvmV+40/Jr4iPxCfm
M/kUTHyCidcw8Q8m37L2FYiX9vOB/AvGnmHs3bUv8inmB/kP8498B3t38xni
LfroL/4+bv3e/IyEsza+kG/gT/EvxBP8M/kO/pnxf1G+z9ov608Y/43/4/PM
P9ZvjBdMvrOo6vSu0WtO2XyY34fxv8wn4jvxA38Ns5/B/OT70ct6jPGBGb9a
4o9sfko99rZ/PlXUtGPvrM+YDzDz5W3xj9YfUa98X/ylpp35jv0yP2Hm7zM/
9P8+Nv6MHU/WczD1tJ5+fecUnye/tt8XYOYXerFHnp98Fv8Jox97JP+mHWb+
YZ/kO8QL8i/8P/6c9QXjCzMf6C+eF/+wQMbb5t/uepDnZX6Rf5PPw/gr7IO/
Zz2Hf4F5PvIh1lfYC+zux9JOfxDvsR/mc7yMp+ku42nrQfQP/pd28hfiMesb
GH9P/Ga8ib/EW5j4Qbxm/cv8w9/Q/3wf/pt4i3/ieegvnhemHftlfJnPfB/z
j/7Af2D/+CP00l/YB/6E+gDtxHvamf+0M/9pp79ox1/QTv/TTvylHX/rxiv8
PfGSeId+5if2D+Pv8F/Yl+u/8EfEI/wR8QC96EMv/snWfwJ68R/YC+sJ8lV3
/cD85/lY35HfMF+p/8Gsd5m/5EvMV+wLJj4xf/l78lvayVf5feobxG83H6a+
gf3y960e/HrarCYFtt5D/B7dLmdVu+0lz/9VxwONYxLyTa0paw9VL3/n+w5T
P0ibl/DHebueivU9tDShvM8+X3JO/+4hXc6ap+scXZi2q2T9lfLYlsYvbLt0
x/sGC85Ou2v0oJL3EwZe3Hk1Y2SW/b0Dz0VOSIs7ZfJ6fpt3Ynb4Hfvxc6cf
2V4Uedz8+M6HSfuuV7f1nx4FZfdXDi9n98eb9J/xrwGp1Wz9p8EbO1dWvVqy
H/zCwatLz3er6rn7nzsf2lywesBq9exvbVbMmV3hjv3HpDHL/zJ67FbV6Blv
zIX7wzx3P/Cupk/vi3pinyrqtLzP83FB2t2P+zj/RuHqTw6rNo3+nTX4oZu2
fnSke+vj2Wtq2XiyPy9nQ6+q3yviBf4jNPj6qwX1z5Tsh26d+kR0399tPvH2
yNmhc2J8dv8pMarHkMzyPrv/FNH83KTFD/ls/tohrdPljJE+uz+SPCoqNbaP
T3Vp1mfJgUeD7tg/il+SHh2/xldSr/ozvX9BqM/a66rf1vcviPBZf7gqe++D
MX/12fj288zWoXPesfUK3VXmk0qNTZwYMa+Wjdf0V9mpE26tHpJj66fzDlVI
Xpx6zu4vjRmxKzsjsqReGpjPtr9mlNn5cma9C2pmy6KEStsvGl0heVlsbq7J
nGnqh5e5bU6Gt382pOY58+gXaZ3z69fQl4aknszqm2Ny02etrZ4X4T1TvVXT
+BE+83vtUdGvPVbLe6/y8sGZr/vMq+vLd3qqXw0vuvHdkxdH+UxS0AfeyV4h
3pS4b+amVPOZnj9fjJ++ubJ3c3Nwp+j3fObNyYNmrWq0R01cc+nBmGd9puCu
m/Neq5SrGkw6PydljM8E74yJfOyFG+rxsS/MTdE+U2/Ax2E14srq1KOXm8ZX
8Jn77vv0WJvYSjr0ta2Hi9r5zPjFZyZOC62rV7Wu90fG7WzzQJehIxccuGhS
Fg1JTjtw2lQ5szDi8ZAa+mZel69jCzJNubt+GTzrTFnvUETS1naxe03e86PN
Z3ur6bfqTjibdWGzWbhy41fXcyp5F69eubq6zCrz8IJ9vhmxN1W1a5GHsx4+
rnap1mdin6rl/bsgc13s9VOqz9wVCWl5e1TSuAZDMz/MVtc75T4wa24ZPSHz
224hK8+qnuP3pM9uXMt7o9HxngUdclXV7iu+yRiaacae9E5n7M1XH/V9Oead
rlvUvJk5ZzKa5qtDe2e832BLsf+opM9kTMlXLy7peW1q27Pm5KchcQUHLpiE
pJVjqxReNTllP3klM+W8mb5g45pX3ovUGxZ0S4tam2f9wwKZH2Z5YWjQtldv
2P2sxBm37q0WGqZfGf58v4LyZ034id+aZGwLt/6/8dxv+nX+pYK3+M/esSHN
fzcvXE4afmxEeVvPZr5vE3sz93R5+ljd3SE23q+bM+TJda0i9dzJQV8klM02
U2f1yky822dS3946sKBflhk6uGb5nMMnTauvq17NyM4yLe/efe/azCtm5+Xa
iZmhp8yZpvOvN3ggwsa7wfVbzZgzpabdf2r/XUvfzMrFeo9f7VnQ6pi5OmxB
5ZMf3bb7UQt3H10ws04Z71Dul0sTNh+0+0+fi78x25YuvdUyrWQ/Cv/QSPyV
SRv+98TctJL6Sb2ebT4dNz5UX7oW2j+zzm5zoPyaLcufrOjdrrH6YlY3z/bH
VPGHZurM38Piz5fsV+GPKj/s96fmu1Vfz3smvaS+sumTjoW3plTRw5+7cSNj
5SwzsWD/k7ebBXsFrR8rWv38OqUvvtvpnvSKdv+q1fhXvfWfltejn8zZVzQp
Q911cP2GB86X7GedKKo88fN7q3sNl56psGbaftVlXcx9m9LKaNZD0yfmhU1/
7U/1SMfpH6ZEHFFF7/3UKCatZD+rzsht9zxSt6Y3ddO6WYujTlp/M03ijV0P
7ZH4pIbK+Nj9rzmzffcPWljbiz7+5PWMxWesf4qX+KayZXzt+udVmQ+qmcwH
tXbJo0nrE3+3+wV/vPrIl/8aF+wFn09LyDznU93nlfk17UJ53frZWZcyhvyu
Gsp81Z/JfFWdkhu/3HJJuHel4YgO0bvOqW1P3P7sF1Pb6/rcgdR2sy6oRWIP
dv9p9duvT848GGH3lwo6f/X18g5ZKvrpwpiQ5nmqq9ifOi72p8ourTllyD9L
9qtZT0zc9Nbnsdvzabf5ll1/SbvNZ8gniAfjxH+bgB67P71a4oF296vmiD83
3SQ+2fU/+VBFiRcl+9eB/KRwzOKOS8K+N+Qn1Kf7DDdzU4rzGZ5nZt9KzeMH
lbwvGS7x1vws43PH/jL5ymGJ33b9j17+nvoA+Uu5zv78wCN/QT/22kDyC/t+
Hc+DvT4n+Ynd7yLfxh57SH5j3zdjPYY9kn+T77BeIr9hfU4+Q/2A/CWQn9n9
MNbD2Av5N/lKsuSDtj5A/Rx7Yr5Mk/63+wfkBw3E39p8n3xrjIyvihN/fcd+
L/kD9psi808F/P8d+2XkC+h75892y2OLP0/+vO3z+bMTjuVhX7q72JfJr3Jt
26C/RGji1acZv1ZovO22uRC8vPboMzlmUu6yllf2LVKnLo/3ZYX5TMBf6Bbi
L0zA/+gPxf+YEU90mn78u3CdG7xj1OJtx81c8V/mCfFfZp/4Y50v/ljd/GRc
1ne5FXR6m+7rYp/cpOqL//ZOif9Wca83erf5ylBvXbeRsxMu7lYLJF7o3RIv
VJv9UzsE/xakr7f+4y+jnz+kHpZ44+2TeKMC8c2bKfFNrW7dv9LxipEe/muU
xFevv8RX9ZrEa5Ut8VrNLVjW5GjZOjo9OXhWws823nuBeG8C7V6g3Tj5nPmj
mz9/UIH8wQTyC50g+YUplPzDmyT5hxkm+YkZJ/mJCejVxN9APqM3Sj5jlOQ7
ppbkO6at9IcXdL+/P0ys9J9Ol/4zhdLfXqb0t5kv+ZNeK/mTuij5lTdA8itV
VM+ff+ndkn+pYMnPvALJz1RgvL0sGW/VUvI5NV7yORXI97wVku+pcZJPmmTJ
J1X7C/75ZX6T+WXz4RfFv6nHJL/1Lkh+q/ZK/quOSf6r5sp8VTkyX9Ulmc8e
/v8DyZ9VB8mfbf6O/3TWk2rcjsZPRXydZfcLqfe2/zZ1Vbtz+WaytNv9Q/b7
Au3WH2Bv+INFa7u1jU7Id9lsknzSBPJJk/RUlb0rTm82rZ7u3CSmeb7RP20v
F1SwVzG/etZ9YM7ZdusU8w//H/g9E9TzpVPZSXU0fx//6dZuH4+so/n+QLsX
aFeBdo98dqbkp14gP1Uvyu8b5v8q+X1Dvsv6K7A+V91Fv+L7l0cFjR9Z5Ygh
3+Xz+1vcm5JSrPfY7aGPztuwxdavsmo1GRBWs45m/lPf6Les0ztpXratdxF/
iU/kzzZ+y3rQvt+lZb1o659Rsp6073MlyXrTxpdEWY/a+ET+TL1ok6wH7X5q
qqwX7f5pqqwnbX0wWdabNp4NlPWo+WiTiZgfU93WFwP5oG4h+aDp+0aVOZt6
l7f7pa0ln/SmSD5p2nSNCT40JtjWG8dLPqqr3+/PR03dyMf2PHdfFbt/ulXy
V+9Wd3/+qkZ9mbO75/9U9X6+f+ygzNYrVOuiXfHzB1y19ckmku+rbZLv23oZ
+SH7r4dPVJ+d0CxfLTx633P9apw3xJeDzROWX1pTQxNPtq6/f9EPp2po1q+B
/E/fkPzPDOiZ8tgLQXU94s3aChviF91dx2P9ubPN2LRN5SO8ZQ0euZwx1mfG
9tn0j9DFtT27Hq0cUdghuaYXfC1yR1RPn3lwZfXTK3eGe6xPkz7f+bc3i/3X
6DPv+LJqFo/30eY6+1KYx3o1Je2DHz/dV8070+KepQnhxevhqOjh/7lc1WP9
OjFz8vLuWyp6YZLfmljJb722kt+aPyMyxu9dcVRN6BjTNH6Qzwz9NnF+j89P
KdbjR7MmNQ37+JKalBvVv2CYz3S7d/ntXrMuK9bno++/FvfS67dU4ohdh4vu
L54vs4dP/yWiSLFeP3zl3ZX535fVnV/6NjW2eL4WPvrQ9Nq55TXr96rPdHpx
7eTK+pce254P6esz94zbd/H1d6to1vMFkp9r9Hf/V43Lqf+oplk/Yl/Utx6Z
pyMfb3vCsD58UOaH3Y+KfGvEwLd/vGGI9zMXvFqvfIPrhnwg4nb2Kx9PrqGJ
/+yHPjGo0qaoxKNmUdsFU0Z8V10Tr3J/GP7St3Ora9aDP3b45ql1QWU97IF6
Yb8WP75ckHLQND702Z7t88p5xLc+Z2esHbmxnMf6r9NP8dM7rAjR2Av1+zL3
lQsb/cUuM2pJp4QnelXTxMNF7WtNfe52sGa9+EeX/Mo36lTysCfqwadPTcvO
ePRnEzT71+TFtSp7N8V+zLdL3utxc31lj/VhhNif3X9PFHvTfL5wlv/vNfaX
Kn+vsc+2Yt92v22M6PXIl5aJXo98qpf4C7tf31D6R5M/9Zb+0eRXAf9j99+W
yHh45FN5Mh4e+VaFVb9U/OK1QkV+tSvnWmrbj0v2+9n/f0TGV9WQ+aHIDz6Q
+aFYrzaW+aXIz5Kl/qBWSf3B1tup38XJfPVYP1aT+e7tkPmuGsp8967KfLf1
fOp9DaUe5VUVe1YF77b/uM/fK3gnxN7VMbEvr6PYl/pT7Mt7X+zLvl9AvbC+
1Lu8VeI/1Pu3myY1ahrkjRD/ot4VezZviz2rv4o9m4Ziz/Z9BOqNNaSeZh4R
f6W29m615nrKVVNJ/Jk6Jf7DTBD/oXqI/zBjxX/Y9xeoVxZKvc7cLf5Rjerb
oO9/cs6aReI/Va1Iv78y74q/UqPEX5knxV/Z9RX12mTxf5r1PfGM+m2c1A81
/f9mwbgbHTdU0YzPRPGvmv6OFf+qGQ/Wi9R/E6U+qen/+U/GLKv4YZhmfEaJ
P9f0d2/x55rxID+gfhyof2r6/8jeBvtffTpcMz5VJH5o+jsQPzTjwfqY+nOg
vqrp/3JfvPvX9mm1NOOzXeKVpr8D8UozHvZ98ED9OlC/1fR/RrXvw4a+EakZ
n0B81OTLgfioyafJb6g3B+KvR34ciL8e+TPxnHr0HInfivoL9YQp/+g8NK3e
BTM0/Z5mnSNz7fsjhVJ/Mc2k/mLrd7cKCyvPGZJjdoh+j3hIfWlX/XVBa4rz
pwrSXx7xkPXu8t7PdoouzqeOyfh4xEPq6z/9TceFRPrMApkPHvGQ/YUPPuge
F1KcPwyW+ecRD6nv9ard8cGY4vyr9aFxeypNL3nfhPXyhxUWL0kozh+b/VR4
e8mQ2YZ6Ne9Pko8OFXtS5CPU75/psiM7qzjf9MR+FfkI9bmwha/MTSnOP98T
f6HJR6gPDJu2Mymt+HnyxD9p8hH2M5LLR5VZU5yfrn/v9QmDHy95f7P2wjrT
Nj50074vk/rVwl4nr5Scj/tpycAe7VOr2fdnfl7duskD4eXsebAJn42M/ff1
kvdpAvm4R708sF9m3wfgfZve0h9qg+ix+6/0J/WR6+nfPHXuoeP2fRzzzvmQ
Nr2qe9Tfu7+xI6hx+ZLzQLyfMyklIj/j4Flb35mU6NPRXc6qroMHNNhdteT9
nU/e6pT82YXLivp9hTWVH/y9Scn7POy3D6mRUD9+Wq5qNP6rT24ev2Lft50h
6xXF+ieq+4yuWwectu+rsx7se+S32ILkPPW5/J5hPd9QPm/fX2d9+Ff5vAk8
r2a9v8gkbrs+sKZmfyBoVXrLc+3KedT7143eEv7l3y4b1vvnVl7tWi0+QlOf
HxYx9O7QVTU19fhm11rkHZoWrqkHBEu8NtTfj8wo88Xtl6p6dr0v+Y2mfj3x
XJcZvd+uoFn/Py35k0f9esTdf5x+5eUwj3rAD5KfaerX8Ynv35dUPJ+pDwTy
P4/69cXgilUP5NbyqA9s/9FvX4r6QNsXDq+ZXi9XUY+OXrYx8eEXQzzqx4WX
umyOrBikqQcc3neq6+j8Wh7r+/0jc+u3L7qhqCe/80KLuNfnR3jUh9+W/vJY
z7xUN/2foSsjNfs7fYU96jWH5Ps1+29BBf7f99hve1z0GuphefJ8mv2sgdIf
HvtZw6X/NPtZk6W/PfazDsv4aPazWsh4euxnfSPzQbGfVbjSP1809aslMp88
6le8P1CzV78haYvs+9K23u2cHzPO+THjnB8zzvkx45wfM875MeOcHzPO+TFb
f3Hvf6B+Tr3AfR8ARj+Mfhj9MPph9MPoh9Hv3v9A/R69MHrd+xRg9MLohdEL
oxdGr3N/g8f+APEVJp7CxE/Ynq8KMPERZr8N5vnd+xlgnt89P+O+385+A3ph
9MLohdELoxdGL4xemPkHo89hj/iJPhh9MPpg9MHog9Hnvh8CM99g9MLoddju
x6AXRi+MXhi9MHrd+xtg7ANGL4xeGL0O2/dd0AujF0YvjF4YvTD6YPTB6IPR
57Ddn0IfjD4YfTD63PscYOwXRi+MXhi9MHodtu8HoRdGL4xeGL0w+mD0weiD
0Qejz2H7vhL6YPTB6IPRB6MPRh+MPhh9MPoctvkw+mD0wehz36+C8dcwemH0
wuiF0Quj12H7/hZ6YfTC6IXRB6MPRh+MPhh9MPoctusH9MHoc98vg4l/MHph
9MLohdELoxdGr8N2Pxi97v0PMPEaRi+MXhi9MHph9MLohdHrsOfe/wCjD0Yf
jD4YfTD6YPTB6IPR5/Ad5y/c9wFh9MLodc+bwuiF0QujF0avcz+Fdu/DYL2J
v4aJfzDxGib/gcl/YJ4f5vlhnt+9H8N9nxBGL4xeGL0wemH0uvdLwOiF0euc
v2X9oJz74ZRzP5xy7odTzv1wyrkfTjn3wynnfjjl3A+nnPWDrafyfhz7rXY9
Hqh3ucz6g/qee98E78tRn+T7qS/C9v1i5zw5zO/B7B/C7B/Cdv8wwNRb3ff7
3PPp7vs+MPbg3ifBfg72A/N87v0RMPV19i95fve+CPYv6T+Y+j77l8wH974I
9k94fpfZH8FfwPa8qnN/hHvfBPsf+B+Y8XDvj4DZX2a/lPnv3i/h3hcBYz/u
eXveB8L+3POS7v0RvA9k9zsC7YwXzHyA2S+A8Qfu+0ju+UL3/SPqY9i7e18E
zPPyeX4f5vnddvf9Pff+Gfe+SOwXfwYz/137du9PdO+Tcdfz2BvjA+PPYeYT
bOu3Acafufbqvo8HM77u+3Uw88N9fw6mnfyXdpj5RD5n938CzHi778O592G5
89ONr7TjL2D8PUz/3PH+nDM/3fjL/GG8YM7jcF6M9xeo/3O+kvNgnJ+EOR/F
eW/Ov3CehvOQnJfhPBPnqzn/xHlpzv9w/ovzhNSz+Tzs3C/gnke1++Oc32K/
G+a8G+fD+Dznc9jf5jwO59c4/8T5Mc47cb6M893UGzlvRr0dZv+E807U993z
kNg3n+f5GC/3vCD275w/dM8Xut+nnPsZlPP9dv6456+wV95PYv8Ff4X/gKkf
8nz8PUx9DPuiHXbPb9IO04690W7jXaAd+6fd3r8UaMe/0A7TTj5AfMdfwtgX
9oB/Ip6Tr8Cc58NesGfiJ/4U5nwh9mL3LwP+ACa/Z/yZT5yPZP+S91HwB8x/
/AH2DWNvMPMb5v0HGHuBsSeY+eHeB0Z/o5f5hf3DxC/3vi+Y83fYO+NHPY7n
574bmPyO5+e8MeNJ/Qn/wv0dMPkd/pDzyTw/93cwP937vmDOV7r+h/t3mP/u
fV8w/sU9T856mvHivh7Gl/1JzovCPA/+i/kC018w/hXm/CTM+MDEH5jxhxl/
97w5+SHM/Ke/+DzxCCb+8/cwf8940w7TznyiHXbPi9MO047/ph226/PA/RLE
B+ybfBJmfcr4cV6e8YPpP+wf/4X94++xT3u+MGCfxA/aYfd8Bu38Pky+COPP
YPwdTPyHyX9gxhMmv4TpT/wF9ke+x/xw63eMB/v7zH/iFYx9kX9hz+QrPC/j
hb9kv538EWb83PvgiKfYB+edGU/yeeafy8Rf8jf+nvmIv2P9C/N57r/C37L/
gj3Tbu8/Cqwv7X3oAWa8uD+H/qK+S/5HO/bMepPxh5kf3K+FP6S+if3Qzvwm
XpLvuPfJ0P+sZ2HyVeyJ8eP7YOYD8xv7Jb6QbxIvyDfxx+STrIewP9g97814
k99i3+Qv7vlBGP9M/CMfcs8Dwvh74h35GeNBf8Hkx8QX+hd/RTvzH6Z/WS+T
j5HPuPcJ2HwvMD60Ew9pZz7QTrylnflHO89PO/GPduyb8cff/R/3GSjnPgMb
7/C/2Bvjgf3CzHf6k3gOY8/YJ/PBtU/sDX/o2hv2g3/EfvDv+CPiA4w/wr/g
L+g/5h9MvkB/0j+u/2P+01+s5xhv974V9/445i/xDiZfZz7zfPhL4pv7PMQ7
7Me9j4N8kd+nPoH9015630PpfQ+l9z2U3vdQet9D6X0Ppfc9lN73UHrfQ+l9
D6X3PZTe91B630PpfQ+l9z2U3vdQet9D6X0Ppfc9lN73UHrfQ+l9D6X3PZTe
91B630PpfQ+l9z2U3vdQet9D6X0Ppfc9/P/3PfwvkRqBPA==
    "], {{
      {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
       Opacity[0.3], EdgeForm[None], 
       GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNmnn8l9MSx59zTioqpFKkTRuyJVvXVvbCtSR7tMgaEWkRhewk61WRsmS9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          "]], PolygonBox[CompressedData["
1:eJwll3f8UFMYxu89h2QkiqIpDaUdidLQMNvSkigpFRoaKFGpKCsV2mlokIZ2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          "]]}]}, 
      {RGBColor[0.880722, 0.611041, 0.142051], AbsoluteThickness[1.6], 
       Opacity[0.3], EdgeForm[None], 
       GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNmnf8z+X6x7/43Pf9RQOVOqVB2SophJJCGlqOnHIiaae9Q4WGpH2SsooS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          "]], 
         PolygonBox[CompressedData["
1:eJwtl3n01VMUxZ9f73vPK02SMqQiQlnIGIqUCAuVKUmUqRSZkoRKmUI0URGS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          
          "]]}]}, {}, {}, {}, {}, {}}, {
      {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
       LineBox[CompressedData["
1:eJwl0bsyA2EYgOEvTnFowowIncJxRKi1CuIUScU4TS6AhmGGe0JD7UwcL8E1
kAylZ0fx7Pvvl92d3T+D1b3ybioiqtzSRS8f5Jsi5poj5pngjg2zey2yQJ4H
Ns0fdZElJnliy7ymy6xQ4Jlt8xctscoUr+yYv+k7ZY6dT2uFE+vf5Nn6wwU9
LRGX+sk6hxxxwDnfrh/VNa6sr5ll3/m43lCnwRDDjNBHjiwD9DPmngbd1pnk
O21cp30qaYdWtF3TtNGK1wuXhtsi55Ds9alm/HCWvB9f1JlJ/f8HfxHyKyA=

        "]], LineBox[CompressedData["
1:eJwl1FeQjlcYB/DXWiVDzBiL6NwpmUH0ukiQyB2yWkJssETvneglESVaRGeG
cZOZJGb0Er1G772tVe9WtMjvGRe//Z/ned/zfe+ec96vUubAtgPyJEmS5U/p
lCRJMz5ChrqqumzeJClHGUao/+QPbnKDzRRNTZK/ZC4f88K9Y2RrWY1WtGQ/
XfSrxb3GW+RoJjCebnpdqcs3fM0Verp2WdaJ+XTmEj30L8radKIjF/hO/7ys
RQcyOEem/ln5CV/RnlN017/NNk6rt8oz8l9Zk+7Gk+S38ge5k2L+5x0yixq8
dG2XnExmPFs8B9d4rVeHt8bT5X32Udxn/C3fMIPvXf9R9pGzI6lHX3U/GtCQ
Q3olzT0o/2MOQ/Tny8FyXsyhAUPVw2hCU9LjM2KePCp/iT0wHht7xg2SuF8/
j+9YLB+SQ1NS9I7LJUyMdYk14RYpNNfP555l8gn/UEp9UuZ1/Te5kiJ6K2R/
PiW/+pRcxRpW84yn3DPvbOyRvMsd8lGQ1s5prkdez++kqjvSwf3lXa9AGhXZ
pPeh78mQheNcG280vkoh43ZyUJy1OPfqK3IDO2Jv2RlnRv2BfEgO2TzmEc/j
3MV1c1vJ2Xrr5Sz5U+xtPK/6ZzmXObFnsV98HnshF7KAxSziC/2l8leWxPqx
jDb6K+RKlrOaVXwZaykLxJk3LuBZPpMD4tzpPWAGa9Ut5EzWGRd0X0uZqj4t
S6vPyObqZnFumUYLvX4sj7OunsqUeD71iZhvXjP5mEfx7LHveulxntx3k/FM
YFz8j/rHUmLjkqSxzOYBC3nneqNIrhuPZBTDY430RsjD8iNzj8jGcT+DGEj9
eKdiveOcxZrHOsRexLvIfkqYe0DW169Hb7Koq9ebmfRUz5K9Yg3k3nhnjWvH
2eQuU3kdvznyFbtJ89l75B2mRD9+e+K3It6dOHfq7bKyrEL1+I54N2IfneGi
VEje/y7/D0G7uKE=
        "]], LineBox[CompressedData["
1:eJwl0UsuQ1EcwOHTMioiIUZGxcg2Oi2licSYYRMNVoQqVb3Usw+0LAIDduBR
NsB30sGX3zn/e3t7H9mNcnErFULYpEXCH8V0CJ2RELrc0qbFqvm13nDBFZes
mJ9rkwZnJBTM63rKMSfUWDav6hEHHFJhyXxfq7oX5/rC7GgIz1omT8b+Vcec
k2HNetyspgO+zd70Q7/4ZIJ1s368H+1pXX/0lwHv9jvkrBeYYY4s82w7Nq1T
8Rm8uLZ3VdASHeumdvWOex7o0eeRJxquMelek/jf7Ma96+X9djE1/A7/2NA6
4A==
        "]]}, 
      {RGBColor[0.880722, 0.611041, 0.142051], AbsoluteThickness[1.6], 
       LineBox[{1323, 1054, 1811, 1809, 1810, 1743, 2095, 1742, 1323}], 
       LineBox[CompressedData["
1:eJwl1NdvT2EYB/BTSpuoGztGaJVeiRFqXlK0aFGiUSJFjVJ7tEZrhpLYVI2S
ICGSioREY134A+wRJLVKrdojYnzeuPj8vud53vecnt85z6+JefPGFMZEUZTg
o1NsFHWknu5xUdSDFgxrHEX9ZH/60JdU0hjC4LAvPoqa89TxcHY5Z6p8Qg3L
1UNpZs91uZt97KWIv9ylp/U7spVzRsrW6gNyoTqLCscL5HveUaJ+KzOZzzze
sFr/tRxFIXOpY5X+q3Bt5lDAS1bq18oRzGYWL1ih/1xmMJMZYY/eQM8ojSwm
ks98VrCBbVRwjCqqqWkURddkimskE+O7NSDik2s2lAn6Tbmivspl6uliLU9u
5SLd1JdkNUnhWYR3pPdeNlFfkMnqKTJR/ZdKjnCY8/pvwpo9k2S8XhznHHfS
y5Ud1b/ZH5475ZzVr6ODPTlyst4kcsM7ZycT9MuoYrv6jNwhT4fzwnOVqc6v
lTlhP1soY7zeJk6GVJ+Sm+UJ2S7Mk+wd5kzGqo/L9ups2Vb9i7WsYw1H9R/T
xp5MuZGH9FI/kpWUhOciS8OMhZmTH7nv+IN8ICNZGt6FXMRiRvMp/B39z3IJ
SxnDl3Af+l/lsjD/jOVbuDf977KIYrL5wXr9n2HmwjwyLsxrmGUOWjtEOfdo
6f7TZTHPrE9jOunkh3cWfkP2ZIS96luyh/q2/M0fbnCTPQywZxADw+9XnWJO
C8xrV9mFZDqTRGLs//8V/wA1sotT
        "]], LineBox[CompressedData["
1:eJwl1Fdsj1EYB+APnVa5EStmjCoXVsReEa4IQhMSuza1Ja7RCG1JjIiRaFF7
1d7VovbeM1ZLXBC7RDwnLp7+3vc95+T/9fy/tuGY9EHTy0VRVMOPWbFR1Ccm
ilrFR9GiuCjqTz91Xx6ry+RGWVMOlLUSoihHltO/kG31z8NcP0jW1ufK8voK
DFbXMXspN7PIbJtcKPNkBkNYrM9gKKm8MWvv3GtZV79TZso9cpncLZeQSpY+
m2EMp9Ssg7MlcpV+v1wp17CaP9QL+83r2ZcvY/Vx4by6vtkHeZB1ZhtYz18a
MMK8kT1HZKK+IiPVjc0+yqPkmOWyiRP6pYwOd6DfEvYzis9mHZ37FM7rx8lm
+nMyTz+aAvVWGWseQ6Z+LE3VX0Jaa8Jk9Wl5JnwmpzjJJPNj8jiHOcoRJobf
UR4Kd0Q+B5hgvlfuY1e483DfjDffEb6L8B1SqN8u02Rzz/JVVtUnqisSRwLx
NDefbf2pfMYTLuh/0dn6T5nNLFroy+RFuqhT7J2rbqm+JLvr29KNrswze+Ud
nuhdzuS1uonZG/mWd5RQyns+kGxfa2fbsNzeXrIHPWlHb8awwtofknx2dapx
Wf/c2hX5Qs4PzyYrW6tCJX6Hu5BJ5sXqFPUcmaxvwY9Qm00J7y/f6KT/Los4
a895WSCnykJZxLlwb2GNaebF8hIXw/Nwmenm1+R1rnKTG6Sb35Z3uMU97jLD
/IF8yP3wd88jZppfd1eFHGMPuawli4UsIJ00hjEg5v//lH9HDpo3
        "]], 
       LineBox[{1322, 1259, 1838, 1682, 1808, 1741, 2094, 1740, 
        1322}]}}}], {{}, {{}, 
     {GrayLevel[0], PointSize[0.018], AbsoluteThickness[1.6], 
      PointBox[{{-6.283185307179586, 0.}, {0., 0.}, {6.283185307179586, 
       0.}}]}, {}}, {}, {}, {{}, {}}}, 
   {GrayLevel[0], Thickness[0.003], 
    LineBox[NCache[{{(-2) Pi, -1}, {2 Pi, -1}}, {{-6.283185307179586, -1}, {
       6.283185307179586, -1}}]], 
    LineBox[NCache[{{(-2) Pi, 0}, {2 Pi, 0}}, {{-6.283185307179586, 0}, {
       6.283185307179586, 0}}]], 
    LineBox[NCache[{{(-2) Pi, 1}, {2 Pi, 1}}, {{-6.283185307179586, 1}, {
       6.283185307179586, 1}}]], 
    LineBox[NCache[{{-Pi, -2}, {-Pi, 
        2}}, {{-3.141592653589793, -2}, {-3.141592653589793, 2}}]], 
    LineBox[{{0, -2}, {0, 2}}], 
    LineBox[NCache[{{Pi, -2}, {Pi, 2}}, {{3.141592653589793, -2}, {
       3.141592653589793, 2}}]]}},
  AspectRatio->1,
  Axes->{False, False},
  AxesLabel->{None, None},
  AxesOrigin->{Automatic, Automatic},
  DisplayFunction->Identity,
  Frame->True,
  FrameLabel->{{
     FormBox["\"v\"", TraditionalForm], 
     FormBox["\"\"", TraditionalForm]}, {
     FormBox["\"\[Phi]\"", TraditionalForm], 
     FormBox[
     "\"\\!\\(\\*SubscriptBox[\\(v\\), \\(s\\)]\\) = 0,  \
\\!\\(\\*SubscriptBox[\\(v\\), \\(c\\)]\\) = 0\"", TraditionalForm]}},
  FrameStyle->Thickness[0.004],
  FrameTicks->{{Automatic, Automatic}, {{{
       NCache[(-2) Pi, -6.283185307179586], 
       FormBox[
        RowBox[{
          RowBox[{"-", "2"}], " ", "\[Pi]"}], TraditionalForm]}, {
       NCache[-Pi, -3.141592653589793], 
       FormBox[
        RowBox[{"-", "\[Pi]"}], TraditionalForm]}, {0, 
       FormBox["0", TraditionalForm]}, {
       NCache[Pi, 3.141592653589793], 
       FormBox["\[Pi]", TraditionalForm]}, {
       NCache[2 Pi, 6.283185307179586], 
       FormBox[
        RowBox[{"2", " ", "\[Pi]"}], TraditionalForm]}}, None}},
  FrameTicksStyle->GrayLevel[0],
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImageSize->Medium,
  LabelStyle->{
    GrayLevel[0], FontSize -> 14},
  Method->{
   "ScalingFunctions" -> None, "TransparentPolygonMesh" -> True, 
    "AxesInFront" -> True},
  PlotRange->
   NCache[{{(-2) Pi, 2 Pi}, {-1, 1}}, {{-6.283185307179586, 
     6.283185307179586}, {-1, 1}}],
  PlotRangeClipping->True,
  PlotRangePadding->0,
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.7172813537135677`*^9, 3.7172816775293407`*^9, 
  3.717367933768857*^9, 3.717370443152297*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"plotBasins0", "[", 
  RowBox[{"0.6", ",", "400", ",", "0.05"}], "]"}]], "Input",
 CellChangeTimes->{{3.710599826286817*^9, 3.7105998263829107`*^9}, {
   3.7106820137416573`*^9, 3.7106820217062902`*^9}, 3.717368931379377*^9, 
   3.717372938666601*^9}],

Cell[BoxData[
 GraphicsBox[{GraphicsComplexBox[CompressedData["
1:eJylnXdUFEnftpGcJYOIiJgwYMQcusy4ZgTzuooJc1oxIWLOiglzxqwoJhCR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    "], {{
      {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
       Opacity[0.3], EdgeForm[None], 
       GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNm3kcT0UXxu+duV6Ryi6tFIqSNlQiSaJC8aKihEqSpShpkYpEKGsS0itR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          "]], PolygonBox[CompressedData["
1:eJwll3m0llMYxb/vPGeZLUOZMpVSURqERJISJc2FInJTSsjUVQkNKiJjI4rS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          "]]}]}, 
      {RGBColor[0.880722, 0.611041, 0.142051], AbsoluteThickness[1.6], 
       Opacity[0.3], EdgeForm[None], 
       GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNnHn8T0UXx3/k3plrCZGlUFSWCC2kVYpEklDJkxaUIltJIpWQomhTaRMS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          "]], PolygonBox[CompressedData["
1:eJwtl3m011MUxX/qvd+9F8uQMakkpDSoZ27WoETxmmh4Uag0ChmaqKiQ5qcy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          "]]}]}, {}, {}, {}, {}, {}}, {
      {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
       LineBox[{532, 1, 585, 864, 1025, 863, 941, 1232, 940, 532}], 
       LineBox[CompressedData["
1:eJwl1Xecz3UcwPFf9t4tI07I3iQtI5HdCZV9RiXuEJGM7EoZUWaiktAwkz2S
PcqWQ6G99y7PN3+8PN+fz93v7ufz+34el5SSlpx6RSKRSPdPRmbQSXOFTIlE
RWVSEV+owspKMVdiN76tD81vsakKx571MmZkBhUzL2N3/qiVOmS9gllYgivY
iz/pXR2xXsOsLMlV7M2f9Yuu12p76/iwWpn7siX7sIVKqbV1KquxujaZj3Ej
c/KG+H0cyN/i56is1trbwkFqY36U93CWZiq3KtjbwMf4h/5URW20t41Dda/5
cd7HuZqjvKpibwtH8m8lq6q22tvOJ9TRPIqdOF8vKb9q2NvOcfw33pdqqqu9
8azBmtplPs6dLMQrNdHcnU+znWqrh3VP3ag62mfvJPfyaj4bZ8yp7M0p8f9S
HfWJc9fNukW36ib77/MgpynV3E9pejnOUoM1SC/E86Od8Xpey9s4Is6awzmb
h/WJ+VA8YzzCUzzKOfF+dc76BIvyRX6kXebbWYz1uZunuEANza+oo/lVXqd0
80Iu0mvxfq0/1nnzWZaI18R70R5zAybxDo7hQo6O1/JTXTBfiOeVn/EsP2dp
ltKd5nF8nWO5mF/Ha81fcTwnxPfF96iTvcXx3Oob8xJ+y3IsqybmiXwmPmNN
is9Pd9kvH/dU35nf5Pdx2dmZS/mGntQS68Z8SkvN+9mYZfhFnAe/5P9apH3W
jViS53iG5/lfnKv2WjdkcZ7maZ5hozi3eLbNo1iPHTRPI+N5j3sQ94ZFeIzp
PM4G8XlqWNyveO7s3a+ZGmI9NO6lZlh/oB3xjLJePA/xjGmgHlHduJ+arv7W
z3MAn+M13B/PEg+wbjzfekgPxp2x116T1Mt6Mh+I8+dV3M0T3BN3jbXiXM0p
MbOtJqhbnD0LsoAWaId1F45lZ46Je6X3zNXZRv/E86Zt9qoxXzz7mqcOGhHn
wuHxOm02V+bd+kvDtMleJeaJu6Z2aq+2GmJ/q9aby7O1ftdgrbNXjrniHsdZ
KznONH4+B8Tv0xpzGbZUPx207s8czK715qPcwF+VpnesSzNbfB5qrhZqFmdv
f61WmpPYPM5cB+IzYc94vZbHnWYzrdJh69XsoSbmpnEvVNw6M6fGZ64pmq5p
+sHXJnM5q7IoC7k2XfyRLMgCyq98yqs8yq1cyqkcyq5syqosynz52l36W3sR
UIftBw==
        "]]}, 
      {RGBColor[0.880722, 0.611041, 0.142051], AbsoluteThickness[1.6], 
       LineBox[CompressedData["
1:eJwl1Hloz2EcwPHvGLaEIgmRK5SzMAvlipKzLfewzUrmWI45RrlJJEZNlLsQ
wmSFHEsSq8kO0hCRmx3YHIXXkz9eez+fZ9tv3z3Pb+uYnpW0OCaKopY+lDeM
ol+xUdS0QRR1JpFxpJLNdg6Rz10qqCLW97WmFyOYQibryOU4+dzkHg/ZGh9F
G9nEBrawmTFxUdRVu/HRulhH62xOW68mh1GsYS1nfO5s+DzvKLI3UmdxkjLz
KT3Ba+6Zh2sKxyg1H9ejvOCueajO5DAl5iPaXtvx1PqVPtMR4bVYxUoG25vB
AbLNB3WF7tfWWqYvtVz/kMdt8yBtFb6eZSxnCfvsL9WS8GxaqsPC87GQBSTa
m84e5ptzNVN3aUst1uf6QIeEZySDuSTYm8oO0s07tYU25771Uy3SRB3INus5
2l8n85utFNrrp800L/y+pIQ7DucY7jicKzes+2oyP1nPdXt9tInuDb8z08Ld
hmcL96x3uGrdU+uoJYcr9npoY93NHpLDXdhL0hXhfCmw7q6T+Bbuhsvhfabx
eksrtFATdABZ1hO1i05gEePNi8Mczj88O/nWnbWGahZw0V4nbaBX9Yle0yrm
cd7cQWP1sj7WAq0kg3PhvaaRxnApvMe1jY4Nr88jc364N3qH+9Q+4Xxpa10v
nFc4H+Y0ct7+ttP0h9ZRy3e+8ZUaqqmiki985hMf+cB73vGW+n7GGz2v5X7G
BU3lL2lx//+f/AMu2pyL
        "]], LineBox[CompressedData["
1:eJwl1GtoT2EcwPEjzUaIkhYLGxPL1FzShFyGmQnLFso1cyub2wteGIXM/RZF
m8sYmsiyGlmjxRpt2VIuE8tlRC4vpCTK58mLz76/5zm1/c/5P2eJywtzCjpE
URTrR1JMFHUjPjaKEuKiKK1zFFXpHv2m+/UAxexjLx3p71qmzmA6+da3eG6u
1mz6cd36tq5kDc3Wq3UWidywrtG1ZJmzmclBOpFs/6au1x/cpdW6VmM1jo3m
Ft2gsxlMlXWdbmKOebPO1cMcogtD7VXrFv0ZrpMS7sPefd3KPHMeuRyjK6n2
7+g2/UUOw6mxV69FLDBv14V6khN0Jy3cg+7U3+H3M4J79hp0F4vMu3WxPtRT
2oOe4flbLw3fh+YxmmXhu9F0HUuT+ZU2aq/wLMPz1yOaH56BzmcMq8L3wXgm
0GKvTZu1QI/ruvD8KeQ0vUm3XxfuS//wl1Tr+HC/5me8Nz/VPvpc3+qLcD/0
NY/T+9qqJbzkQfgsmhA+j9bray1lirmEUs5yJpxD2lw7p2WcD/vhb9FufqMD
NJF35gadqEk6WR9pu5aTYb7ARS5RzkA+uHZZP+qVcE0HaYY26iet4DNN1lM1
ObwX4SyEcxDOCtesd2imPtYv4f1gmrmCJearOiScTb6Gs6EjGUUKWfaedIqi
Fd7XZm2glkrKOEoRa8hlEsOIpyPfveut1FNJKcVsZgkzGRPz///CP/MrjHM=

        "]]}}}], {{}, {{}, 
     {GrayLevel[0], PointSize[0.018], AbsoluteThickness[1.6], 
      PointBox[{{-5.639684198386302, 0.}, {0.6435011087932844, 0.}, {
       6.9266864159728705`, 0.}}]}, {}}, {}, {}, {{}, {}}}, 
   {GrayLevel[0], Thickness[0.003], 
    LineBox[NCache[{{(-2) Pi, -1}, {2 Pi, -1}}, {{-6.283185307179586, -1}, {
       6.283185307179586, -1}}]], 
    LineBox[NCache[{{(-2) Pi, 0}, {2 Pi, 0}}, {{-6.283185307179586, 0}, {
       6.283185307179586, 0}}]], 
    LineBox[NCache[{{(-2) Pi, 1}, {2 Pi, 1}}, {{-6.283185307179586, 1}, {
       6.283185307179586, 1}}]], 
    LineBox[NCache[{{-Pi, -2}, {-Pi, 
        2}}, {{-3.141592653589793, -2}, {-3.141592653589793, 2}}]], 
    LineBox[{{0, -2}, {0, 2}}], 
    LineBox[NCache[{{Pi, -2}, {Pi, 2}}, {{3.141592653589793, -2}, {
       3.141592653589793, 2}}]]}},
  AspectRatio->1,
  Axes->{False, False},
  AxesLabel->{None, None},
  AxesOrigin->{Automatic, Automatic},
  DisplayFunction->Identity,
  Frame->True,
  FrameLabel->{{
     FormBox["\"v\"", TraditionalForm], 
     FormBox["\"\"", TraditionalForm]}, {
     FormBox["\"\[Phi]\"", TraditionalForm], 
     FormBox[
     "\"\\!\\(\\*SubscriptBox[\\(v\\), \\(s\\)]\\) = 0.6,  \
\\!\\(\\*SubscriptBox[\\(v\\), \\(c\\)]\\) = 0\"", TraditionalForm]}},
  FrameStyle->Thickness[0.004],
  FrameTicks->{{Automatic, Automatic}, {{{
       NCache[(-2) Pi, -6.283185307179586], 
       FormBox[
        RowBox[{
          RowBox[{"-", "2"}], " ", "\[Pi]"}], TraditionalForm]}, {
       NCache[-Pi, -3.141592653589793], 
       FormBox[
        RowBox[{"-", "\[Pi]"}], TraditionalForm]}, {0, 
       FormBox["0", TraditionalForm]}, {
       NCache[Pi, 3.141592653589793], 
       FormBox["\[Pi]", TraditionalForm]}, {
       NCache[2 Pi, 6.283185307179586], 
       FormBox[
        RowBox[{"2", " ", "\[Pi]"}], TraditionalForm]}}, None}},
  FrameTicksStyle->GrayLevel[0],
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImageSize->Medium,
  LabelStyle->{
    GrayLevel[0], FontSize -> 14},
  Method->{
   "ScalingFunctions" -> None, "TransparentPolygonMesh" -> True, 
    "AxesInFront" -> True},
  PlotRange->
   NCache[{{(-2) Pi, 2 Pi}, {-1, 1}}, {{-6.283185307179586, 
     6.283185307179586}, {-1, 1}}],
  PlotRangeClipping->True,
  PlotRangePadding->0,
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.710599953390737*^9, 3.710681977736651*^9, 
  3.710682019473184*^9, 3.710682148794653*^9, 3.717370066177423*^9, 
  3.717372897682539*^9, 3.717373121172122*^9, 3.717378170920061*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"plotBasins0", "[", 
  RowBox[{"0.5", ",", "400", ",", "0.05"}], "]"}]], "Input",
 CellChangeTimes->{
  3.71059996879395*^9, {3.717380665064131*^9, 3.7173806652654743`*^9}}],

Cell[BoxData[
 GraphicsBox[{GraphicsComplexBox[CompressedData["
1:eJxknXl8D0f4x4MkiEiIHG6qoSihrqJkFlXiKuKqivuIElWUuElddV8NUlfc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    "], {{
      {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
       Opacity[0.3], EdgeForm[None], 
       GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxMnQm8VeP3xs+5955h73NuSrmVSJnHZC5jkSSZMiRSkVRCyZwpc0SZSRki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          "]], 
         PolygonBox[CompressedData["
1:eJwtnHmgjsUXxy/33ve973u7777chFCUJCKEIqSIbFlCK8m+RCWplDallKhU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          "]]}]}, 
      {RGBColor[0.880722, 0.611041, 0.142051], AbsoluteThickness[1.6], 
       Opacity[0.3], EdgeForm[None], 
       GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxMnWWYHFUThRd3192dnemZnolBsri7e3B3gru7u0Pw4G7BJbjrh7tDcHcL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          "]], PolygonBox[CompressedData["
1:eJwtnHm8zdX3xo9QfZWkyXTvuefec53xnuGGEjIPoWQoRSUhU8qsolKRkBBl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          "]]}]}, {}, {}, {}, {}, {}}, {
      {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
       LineBox[{2, 1, 26, 1245, 3383, 3782, 3780, 5109, 3781, 5110, 3382, 
        4581, 4582, 4169, 6227, 3377, 3643, 5767, 5105, 5106, 4956, 5768, 
        5769, 4170, 5107, 3767, 4957, 5770, 6228, 4171, 4889, 4890, 4820, 
        3768, 4819, 3769, 4821, 4891, 4823, 3770, 4822, 3771, 4824, 4892, 
        3378, 4826, 4827, 4825, 4829, 4828, 3379, 4583, 4584, 3773, 6347, 
        3772, 1237, 8, 1979, 7, 1976, 6, 1973, 5, 2004, 4, 3, 2}], 
       LineBox[CompressedData["
1:eJwl13eYVdUVBfCL9KFKV4ogWABBVMqg9Dr0PkMdOgxFhjKgdCMx6KcmiCZR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        "]], LineBox[CompressedData["

1:eJwl1nmUz1UYx/E7tCcztGlPRSolW4Vh7JW1RKFShlCWFi1KZUnWGevMSAsq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        "]], LineBox[CompressedData["
1:eJwl1ne8z1Ucx/FjFkURpU0qTUr93RRalEQZDS0Vrtm1aRHXNeNem3svGYV7
7ZGiMrLvvVw0UI+GItWjsv6o5+fRH6/H+/d5n8849zvO99brlNGqW7mUUkH5
lMoqpLQOKyqltKdaSm1qp9QWT+BJtMZu/uO0FVrgMbTELn7Pmimtp5PrpFS5
Rko9xN0x4JKU3qqeUn8696KUFl6Q0pVqKsnJ5PVDXyzgX86fT6+gH+vVQX1H
/HlhSg/K+YO2Fzf3u7eezWiunlPVnK2V0gnrv5j/O53CO82bTM/Qpfq1UNsS
B603UHuAPiq+3u/u+l1Hx+p3QP5+XCveL6c+vQZjrA3Wr4yXbU6+nmXyBvH2
0oF0H83jl9IB4mLan5bQ2fw9tJ94F+1Ld9NZ/FH67dO3njmjzcm0ttNaCe8q
Xob9bXbN9oqvFpfSuvQR+y9Sf0purpqTNIcet35Uz2O0l9pCORPEv4nbqXka
T5nTFm0wT01N132HGa/r2wWd8RpeDZW/TY8mch7A/Vimprr8Y/pWo8PM2Ukv
xFtqLqBvx/1Vu1/t62o2qHmNfkpnx3WVM4vWozPpDCy1n1fldMb0uB76TqNF
/Fd4L2OqOJtfpm+B+XVjpjlv4hBvCB2Kq/lT5F5FB4sn+z1KXS4t1O8lvV5E
jjiLP4ku4X9ify/wr1Q3kfc+FvPXx/PJy4/7ZU6neFZ5z9Ln8Rz28jPN2kRn
yDtf/hviPrE/fd41Zyidr99StXeoqSrnhNzzaBHvdl4hbUy/0KcRvQ23oCFu
xef8l/RcTSepPevevih+AR30729O+7im5lSRfy7axTvHf5pO55/Dq4yn4j7x
29Jp/Eq8ivH+izP52+zrjP6txW3wJDqZ85nZN8m7GTdgiT3fSDfyp9tTFXVD
5M7Tc5G1BtYGiwfhHX03yJsm71x5i6331rOUl8dbJ35G/iK1HWkHTFA3Ul2J
nNlyLle3Vt4WbEapuAQL5N1MP4jrHPPxnt4/qxunz3iMwVdqxtKf+B/qd7ea
L+V+auZBa6OtbRJ/gUnm7rN+FzaLt2JLPBv6/qW+UG5R7DeuAxZjKd6pktL3
ztWqFZ0pOOv3eXr9Y62ca1oa19vszvquoVWtnbJW3tpJWoGepufz880qQCu5
y+T+G9eP/4N9FMspwRb9fhT/hCfktY53NK6NtX3xfCKpmaXPYTlHcAiPyfsu
zkV6EC3QEkfVLlOzAsvxt5kT1W6XuwPbcJ+8nbSM7sc9uBdfq52gZiLex1G1
I9QuknuL9Y/orXGuYZw9LRR/iF5yt6pd4W9ZHO8kGsrpzf+Sv5JfyGvEm+s6
fK3vG9a2WetDt9NM+g2/X5xr4r50Z7xbav5QcxvtH98v3ir9iuLsQWP+gPje
8Vfzl/HG29vyePbsPQt3xLOlx7dxdot/oTlqcjEJUzAZv8b9iX3oNZV+S6fT
Y/yP1N+vzyHeBnN26b8bTXgz5Bzmb+Tv4eWYXxzPoFk5eEDOIvXH9ckV/0NX
qVmNlViLNTjJ/5iux7o4d/EJTvE30s/iTI4zJs4TnI5vuH5T0DTeyfhmxIx4
58yfKWdW1NlXqXgvmslrjiNxplv7jubRE+qy9RmNO63P0+twfIf0WqFuJQbK
2yN/jX6D/C72e768I/LeVneduuPi62kxxqitT6/FRrldYi+0Kz0Q91rNu/oO
i/MFF8kbTnfR3aiBmliupmk807RZPC/xfVLbBeWt58b5wxtkXtfoI6cW8uyz
m3gwP4PW5l2MfH538RB+D3oJrw4K+D3FQ/m96KW8yzCH31v8Jr8P7WpuhfhO
+F2RZoi7YYc9PCj/ITSPe2u/D8dzzJ9pj7XkruIt0O89tSNiT7yR8b+BvEex
0FqWeLhZo+K7oO/FcrJjn3Rg/J8W/xfpmRHPgX7d4pmgN1j/3ZwGtHuchXEW
6JenNh838gtoD2s943ywNif+jzJrbtyDuB+4Sd4cfb4yY5j4BzpSfhZGIBuj
8GO1//8X/Q8I4al7
        "]], LineBox[CompressedData["
1:eJwl1ne8z1Ucx/Hjuq55resOdNV1kRmirUHRkIpSSns+WrT3sOuPitbjUYnb
Mm8aVFahRbRIWberchHZq+GGnp9Hf7wf7/N5fT6fc853nd+v6NrB/QZVSSkN
y0ipW2ZKxbS5WkoHs1NampvSMvqWvqfv6AD+Nf+GvqIltJj+xcc3TKmE+jRI
aW1+SufyceJy41fqpvQzX5iT0jT1b9MacRmtplX0pdymeimVyp2jd3dBSr35
79gUbCOfyvdYazLfIJ7AJ9FE2o0/Z73n6WR9X5izG39W/Lnxi/bwGZ9vnSfV
P0Gfik9SsyA4zZNbbd5Rcifi87BPQvgq/ASs1L7WW2ukmpXYcL6Cj+AV+DD+
k3go/5Efr+c4+tg8c+ljcy3Hh8gfi8/BZkcOfxx7jGaJX7Dfdeabar1j1I1x
HaNpF/Z+7MEcb6n9Ql+F8ZuxH30r6GW9O9W9p+5sva/qG0uV2Axsi/pF6hfp
/cN4ofF6fRU0Vu9+ddPV9dX7hr7XKRP/CPtL/e/xPuj903ij8Z/69tFr8Zz1
XEV/ia/kf/Mp+nPksvNSqku1qV79lOrwhnit4OKaPJvfqe8Oqm+9erTaWnXw
GvKD8bpYNq3Ca+PV8UF4Haw2rcRr4Vn47XgtrCatwGvit8XzEDewdjU1NbCq
vDrP5PXxDJ4lPuT6qhin2DM+ybVMpivMsde1Xc4nivcYl8jv5t9aZ0PcU9ol
Hh/Pg3+D73PPKvCB+nZg2+lrfC++Dr8U32Nvl4Vjv8a7zX/jVc3zS8wpLuc7
+VqeEfed7xCv4dt5Wewb/9BcA8y1zTpLrLNNbrXcJdhWbAstjvc73h/aJB6n
r0z+Ytos7s//4BNcZ125A+oOxndP1dyjW+VvoRrWqk4/ma9Sbj9lid+KZ09z
jW9Wl6nnXXM1xuZjTcXN3d+1+or4EdQYnyhfQPOMH9DXRN37+ppiC7DDxa3U
/qKvmXFL40L8MJoc90rPo9RMfETU0wz9RXI91J5Op1J3Oi3WxU/hrc3VjR/J
T+ZteGGWc8H5WEKzaQ7Npa74V+ZcTB/qz7WXDKpKy7A8nk/j7aOv9Ut4P36G
OUeYexSNpBPifFJ/ntwravrwsbyCZsi9xF+m7voeUd+DP8qPiXuobwE9Feee
vubYdOpu3CPWUtdW/Vb7OF38tLovebGaXnLt5Hrys+hMaoF/ENdDj6n9NO4p
NoWKjI+Me0S/mq+5eCpezNvEOvQb3kLckh7X3y7urTXW4a2in4bg7fEivAJv
Hf00FG/LO8gdRevl2olLrdGed8Q60Qa8g/ht/Cj+kb0O09vReDifJZ5JLeXP
Ud+bzqY+dC61ws/nF9B51N4++sYzxy/kHcT9Yg/8orhe/GLeUdw/9sAviXcD
X2jNZ6zZGdtmX2eIe9JobICao/HteC9sDLaIt9V3mVwXuUt5Vz4wngV+RTxX
8eX8Kroy9ofPdj1zaIQ5PjNHITaNOhl3jnVoo3U6i4+mkepGUXNzdZEr5l15
s3g/4jtS83B8V/yR+N2mSXIP8ofoMPXF8U3xFryJ3Hv6Gqm/Sz6H383LaYJc
A3HDOLPjDNWzxl7qGzcw/gRvpGaq/lK6Ws9MrBr2Ov3jfNnkvNgc/zf07Re/
gVfya+L8wf92di2V+xc7QNfi19E/+JY4b/jWOHP0beeV4m1xTvEdvDq+K/7H
iHfGGcZ38xr4LHu53lyHsGXWOGj+Q3RDnMNqkmv4AU/qqtCNeAbfK7ePlsc3
L37TXJnxXrrGaXSTutnx+4O/I87lDd2TnLgvlEuNKA/Pj99D6+RFnhfwfLxJ
1IgbRz2/N357zHkPbxq9WJn1c7E8ui+eXfTiP8f5gxXQ/XghXoCXx5lpfHic
tfHbm/X/f8D/ALHMbW4=
        "]], LineBox[CompressedData["
1:eJwl0llL1FEYx/EnmJaLiBYI7yKw7mx1Zv4z4waRtkHRKyhL21zarQTbLsy6
atFuKnwFWiARZJaNldpqr6AiqPSibrrv86eLL7/zfM95nv8Z5qxu7tzbMS8i
hlMWRzzIRFQtiKheEtG9MqJhacQFWS/vLosYwK6KiJ34vSKijj9v/w7/l+uX
tVwXVyPPyc1mnZUl9WlZlGfkJv6ULKhPyESelBv5TnkcbehAOzbwR+UxHMIR
HMZ6fmx5xCpZdocb7vBMPYoG9SO+Xs65byn9PurUD/laOcuv9e0Cf11vDVfC
L34Nn/B9fJEr4Cdfyef5a3zCDZuVlz/s5fhs+rvVQ/wXZ3pRrc4hi6futs5e
i3OtaMZBHEAVv1/mfWOfzMlb+m/iG75ihxm3ZZPcjm0YNzPRe0XPVVzCFr2X
01n8lDP39eyRf9zzIt+D3eoR+zlMWt9zZsKsMorcdDrfnPl6PnNbrTPWg85V
yMfOfE/vws842yiz3tCotzSy0N0X+T+sE+9rTD7HC4zjJcqYwCu8xhtMYgrT
eIt3eI8P+IhPmMGTzP93+w9lNWIt
        "]]}, 
      {RGBColor[0.880722, 0.611041, 0.142051], AbsoluteThickness[1.6], 
       LineBox[CompressedData["
1:eJwl1WtMlnUcxvE/opaitHqBeEghJ0KGRKRNzAOCzUNiMrGAyqKtwwu1xEO9
qLVWmaWZVlutMk1TK83cbCUegAyNECRxGWBqRzOHaZpkCfS514uv1339ftd1
P//nfh4fkkvnFcyNCSHs9M+iISFcTAzhvaEhbMsMYR2tvz6EOvRNCeGLYSHs
RQWqUIlE8y43hLDH9Vr5XXQN3U1jzHfSd/kddDUtp8G8k2amhZDtdR7NCCHX
7B37Jnqj+TyzuZjAf4cjmMMny/TxmqP0MuQOOFstBpgdlfnIvoV+SDfjWvPU
viHkoAQLsQKbUIUWXEB8PznkoAQLsBwbUYlmnEfv/iGkYDyKUIZl2IAKNOFP
9Bogh3EoQmdyCHmpIbySrktX0By6ki5yxlfpBH4VzaWv0cXmCZ5TH7ztvSZ6
X33RD1O9t7Pm53AI6TrbaCOGu37E85mj34N/XreOX0LXeVYJ9qV8sX2M/VX8
es/2Kfue7h2HtXJrEG83W7ZQ9hI/X6aWL6Or+Vj7Yv52+7P8C+6zFMOdv9MZ
02kHfVh+ltyk6LPjL+NTvp2e0WvFgzI1Zg/R+53hPqTpp+I2vVtkLyKFb6ND
6Xl6WrdUZ7/uA/QevbuRbJ+EPN0R0fPCQP4cHURb6Snde3WqdWfTIr27ouds
nxh9JrpZcr8jgT8dff/oSXpSt1hnr24JLdSbiV/trok+Z91M1z/jav6X6Frn
J8ySr9K7k87QuQMn7OPlxupluH5L7jgtlBtjdoJ/1rN9DnFyLXY9aTOd6T4F
ctlyb8q9gSbzGWajzI7xz+h1k++OrvjWvkAvX2akzHRnyMe06P8nOjDCPF2u
MfrM+MO0nTbQo+6Zr1+hP51OMZ+MNlxElu4wuTpc4OvpX/Rr2qw7RWe37lT6
Ol9jPo3P1Gvin3beM/J/oBX77CdFryMzXGaVzEpUm082Szc7wj8ZfZdxSqfK
7jdaSfN0J8qlRb8J/B5s5yui3yvk2ufxqfYvu89y7IrmZkPNDvPjZXbyOXQZ
/7l9Dj/EvpEfY17Oj6Uv8dvtx/GD7Q/x2eY7+NF0Kf8itsp8gi0YYT7afqD8
YP5x7+N75z+GiXiCHylzq8yg6Dth9rHccfojfkCS+UH3XSC7EGW4SWeJ2XWy
j/Hz0Sy7PnoudBG/GFlyN+N98y/9Nmyg1TRWZj/dyO+jm+hXtGv0edIP+Bp6
ALXo5wz19CDq8A0a0N+8wTm2uN6MrUm+835/K2hvupv2ouU0jn5Ge9IeuBJX
oDu6oSti0QUxCOj096sD7biMf/EPLuFvtCX+/3fuPz1sJYw=
        "]], 
       LineBox[CompressedData["
1:eJwl13f8z+Uax/GP7BBC2Ss/40fI3jN+9s6W3YnMopAOocisQwsdJxnZKzqN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        "]], LineBox[CompressedData["
1:eJwl1ne8z1Ucx/GvUalUaBcyLuISFYouGWVz0aMlZOS6IuO6XNxr60aZl2uV
LS0z2btop7S3Stsqhfqnen4e/fF6vM/nfT7j/L7r3oq9BnUeWCRJkl1Fk+Rs
SpKsKJsk+dcnyfe1kuQIxtVMkkfF31l/Xj1JbqqTJDdiLH8Sv471Z/z64lvw
Q2qSTOQfoROiD63HX1jVvvWt2C+/jLpXok5c2vreaklSiubI7avuZfP22b+Y
9zK9hGbw9/L70H30cT1T1A+l/W9MkmflVRZXwonaSXISx3EMg/VtrO5X66Oo
JK6MS+VW57/Bm6f+dTo3zsd/zbq1c71KB8i9Xl6euXPsHzSvkFbjjeJVpbm0
v7OMpFXEw+kI5OBhfjYdhiEYiiz04w+igzEAA/EIMvkPR79YI0W/frQvP9Ps
2WYfcK7+cb34GdgvbuW8GXL6yimI66GuETaL02i6/azoLX7GfkW/swJq6VMT
qegqb6N+q2skSTHXfau8hBZFkbj/8ufqUVfuzRihVw6+VDNanKv+C+uaclNx
n5mF8ofLOaRXnv3GetwmtyGmiUfbO6vmMfFU8RnrtmrboJf6F53lJ7XtxD/S
9jRdj/X6VrvBvUEKqqIK1vEr0cq4DhVRAWv55Wh5XIOyuBZr+O3164Af9G+t
//cxT9zKuqcztKT5znfa2f5EC/EROXfSO/CovSecvbn1d/wG4mX6/hHPKv83
egq/Yym/kd4FdJjf/rb8tLgmcT/UV8R1KI+R+gxV/5acbLmz1ByK54d3kL6H
dzGTX1P9GDpY3kvyU8U18Ldn4y6/4S+apV9ntSvUvCjnQ7kbaSfeMl5Hujzu
pT5Labp4Me1Al9A8/iLaXvwkbUeforn8hXHfxAtoG7pB3/U4a+4ZDDF7vr15
OC3u7Eyj4h1whnVx3dVUd9468mpjiPgduevd/3KuxZtyrqFlcS0ayl2s/mc5
v+AnTFHztbxDen5Fu5qxSE6u+LC4pZoWaKp/E9yO2WrG2y/pWZgmvpBegF5m
9FO/Sv04+8fVF8i9X/1WXj5vqbip3Nnqllg3sU6cd4TaQWpzaEHM4TdGtngg
f4ucf/UbJv6HDqe99X0k3q8KvknlfcN8j0uUcz3VFWIu5mA+5uFzZxglf63a
dViDFH13Is+MF8SrkS13r7Otco714ir2C5z9nXgv7e2zN4yOQA4O8gfqO13u
DExDaTUz6Ta6HWvUrI1nBkXEj+m3LZ49c0fKa6ZP8zivmXfQ5fImy9kup4ve
heITfveE+BbFN0ldb3UP4aKosz9dbR/xSXkT4xsv75K4DvYupqVRCs/xW8X7
Izctngt8o2aDc3XTt4H4V8/GUUzQs5G4O78xPcY7jolxj8QP8pvQE7yTmMRv
Ku7Bb0Zbm9MG38a3zJmWmN1W/Dy91FkuQxlcgcvxAv+quF/OfGXcO/q72o/U
/kav5i3gzTAnQ//+5vSlD+jZFafkTJK7Wp9u4h20hZqWuBMr1LaiO/lT5BX1
m1fyCvUbpU8uivFay3maP5efxxtizuj4xvLbxvn4Y8RZ/LFxH8wqrm6c9Tk0
Q9wHB+LvC83EufzHzdzFG6puvNx2erWP36nfhHj2+BNpB156/Nb43yG+lzhP
fT4tEc8PXeV8HeU8QzvR3fp2N6efvdOuQyY9Q1+SP0DfP6zfN/9PujC+HWpS
UQMb1HZUm66mY8xHZ3TCRvV/ubfT1aTF8xD/H8T9l98EH+o3Ut95etxvzvvi
d8Uf0NFqvlI7Jr4zdL6cm+Ja6Lvd/jl0B11jxt1qi8c7E2eW201Ntjnn8Xby
svTMV7/ZXnd7m+iDdEv8LeRvoz3EW2lPup1O5u+kvcQ7aG+6K757cQ/iXuj7
ULzP5pQw53zs5l0QKm8Phsc3TnyP85WkNzv/HjkXWe+l9cR1sUDPb+SP1e9w
/D9IP7b/njkf0W9543lj9Kultot+N9Cmaj+xX9v6U9pc3Awr9Cvq3syIbwad
SbvHO4duOCq3GH8Wf6qePXiZevaMs6q/F8fkjDV/pV73iTfRemrqoy5uxS3Y
zG9Ib0MDNEIatvB3l/3//93/AF3+xps=
        "]], LineBox[CompressedData["
1:eJwl1mWYVVUUxvEDCtj62AUiKCEgYHf7VWUoFRQEBekSFOmGIQQFiSGHDumu
IYaU7i6luwUJf+vxw/95z3r3in3uPWff+3SlOim1syRJ0jNrkuTOmSQ5sCNX
kqzKlyT1n0+SBqiDeqiLP/k1CyXJQtq5eJLc91yS1BBXR5diSdIoP5+mFU6S
z+WXRar4XnmdaEf0szauQJKUsXY3f4s+99CxvFK8MbQ0XWDGN/pWwvWC9qL2
Gq0oru+6lln1aA/9XpT/QuxR/K+cOrQ2ulsbqN9VXjtzpupZXN4A3vO0GIpi
Cr+UvqVxTG55tUdpSXE511XN+pJ21i+Rf7NIknwhrsL/nKbyb/Cuo6z4O34Z
2ol/jfcvSou/5ZeKz4F/lXcFJcWV+en20Nwej5ibYm4JTOYVMa+//RamafQf
65cx3Wc2DbXUXxFXpzVRAxXUZqgtqWa0mhQ6it4h/3Y0NG8mvQsbzbyTVlOz
TM0v4plyK6sZbJ8zXFeKz0zf/misdqm8bvIeV/eDugbYzOsob7n8DnRZfMbW
i2COutkYrV97a+0wS9xcr03qeulVWF5LfVpgL2+MnLEYGfcQ+8ce/nA6AukY
hqHYzR9Mh8Q+MQgDsSs+U/020p5mFDKjmbgpZprfzPwZdJR9LbXftmqekzOd
Nw0j+Uv4BXm/qd+gTxs5mbxWdDFtTdfzW9CWaIrmaIZ18R6ZlUm7qn9Mn3ri
ukjT/yfz+9FB5kzX6xs1j8rpy+uDgfxp/Ir8h/lb9XiETuV9Hc8trRD70P8r
Ollcjk6i5ekifhc1D6nprd8A/SZa+9Lag7zfeb3ie+VP4H/B/zXeKfxob3Pk
PBD3Lr6f9qR17H2tvj/LbYLGMUdtfuv5MB/zYo9yC9BJdAomo4nanWrT4plG
P6xV+7K8l7AAGVgu9xW6hC7DUrRXe0jtHDVzMRsb1L4h73WslrMK493LLGsz
47wSt3YfB9X18zm8Ji9Vn044x9sr56geu+kRuoeeiWdJ7idyj8dzq99ha7us
nbWW4oysgbZYnMfZ5t3LW9RZRvPQe+gzNLu5+Wh+PIuCKIAc/L7mZzMjO25F
5bhXdLOWVXxLvJNyb9Vrifl3uc7megQ/i5ze6hPx12qG8W7E98y/ab/ZYwYy
1d1Gs8gbLudmvGdxvrmXT9UN4Z3npao7oW6f+9uPOepOik/hM3kl4nNQc8Da
3/gLF+L812udnDetr6Vv0YVoo98a8Tx58zFBv/XiDXg7vl/eRv0m8jfy3uGl
2cthPRda22RtAd1MF8X3ws+kW8SL6Va6JL43/jK6TbyUbqfv6bVdr3fjGeLt
4E0yZ5M5m/E+fwV/J38yfwuvrf1upSvjeYl3ir9N3I6/nXZxnx+o2+H6w/iO
xF1x0fxD8g/jIE7oeYRe4h+jJ8VH6Sl6nF7mp9tbih6neXPNOa3nGZTknYhn
jz+Pf5Z3DqX4J+O548/nn+ddQGn+Kf45fgb/Iu8SyvDL4jz/dHxP9Az9x+xz
9KL4bPg4jytx3ruXPWo/UrebfkwXob373yneFe9VnKVqp5q1Os5b1/3dyzH1
HdR3xKtq+vD28VqpXRGfKcbFOSj/D7V/xFnpuq+8/ZGnrjWKxlnE2xLnqNq5
8fzE76f8FfLHqE11vdJ1b3lb5TVU1whPqO3OWx5nktqB8Tsr97v4PVA3SDwY
T8qrEr87eqTzh/DSkZOfC7P5VeP5p9/HXP2qx1kjrkbn0RqxB34P856Ks443
VK+h+gxDbl5NORn8YfzhvBF4mj8y/rNYq43h1kbFeWi/o+OsdR955IxxnZc2
Fv+EbfFey++KzvF86tstnnV+d7pK/AtdTYur22ZfxWgP3hreWHPm65mBhViA
X639hnHWFolb2sNi2sa8F9Rmun6RthO3xQGzJsifiPHxGxO/L3EO8KfSafHO
YAamxxmR7///kv8BuwD1wg==
        "]], LineBox[CompressedData["
1:eJwl1WdU11Ucx/GLIxUnOHCAiAoqILht79w2bDkrrRxo2t5lZWWdTidXVppY
2VAr9UGlPavsmFqpCKJCKYjbxqMkGdrrnh68+dzv5zvu/f1/g4xp88bNTQgh
VPmTkxlCQVoIF3qH0Dg/hEbYmhvCeXFD6ynZ1v1CqMcP/Hp+A/5kfh2vFt/z
6/gJ/In8sv4hTKK1vAt5IdTQIFefZZb4nLiO/kvraR2/htaiOuZjLsb8ZTkh
/E1XmznWzKXiJTht39d7hXCKfmv/cvVlOCkeo+4EPY4tcsftc1BuNP8Y7yg2
84/xR/EKzf7LHgfUHOWV0iq6n/7J30ePiItpJS2hf/D30gpxET1MR5o1AlXm
H8E39jjE3yM/nF/Je82ZK+jXcrv5u2KveCH/jJmrnGWY2sWucRFqeGt41eac
VfudvrPW/8TfSF813tC7Vc8EnBOPpzV0uf4gl+i3b9gnhGa0Ab1H/m68Kfcj
nYZgj6k0gb6rr5FcZ/XN1HeiTekc+dnoqCYFvzhLR7kUdBAv1dMQa60L1H1g
zmok865XcwOuRRezrqNJ/GtoZ/FVtBO9mrbhf2nG42bk0pK4j9yVco/xcnjZ
KOan8B/lfSFure+KeBbeZbQ9vZy24l9K24kvpm3pJbQlfyhNFg+iQzAYLfgD
6EDkoz/6oTl/lespxCx7trfnTPq+uJ31Evm29Gfn6hD3j7PFi/lJdCe/Xdw/
XqN4ht7WtBV2yDVxjmS56fyWvBbYzr+In8S/n9+cl4if+G14reM9Ei+yR1O6
jd8qXhuaiN/iN8Bn1vfpX+msK5DI66smDznxXtgjN87if672EbV96N64j1y2
XG9xr/h8xL2w3vphdZ+a9wm68O6Ndeqn0V50vvzzeE9uB30RA/W9QAfRtfrS
5Warn4MCZMf7JPeKmqH0ZVqvrg6bcQonUYuVejfSDdjUzbvmW/YVXZjhvbQu
6uEaaDFKsA+l2I8DOIgylOM3/I5DOIwKVOIIqnAUx3AcJ3ASuc662Rn70p3x
WXCe887yqvVpmsPfQs8gz3qT2m5q1onX4yV1G3ipvBUYHO9TvNco9dsPES9Q
s5Gmyc/g9zFnOp2Fmega72+cryY/ngVP6ekXnxO6HU/gSaTqHaYnjQ6Pz6Le
kXQURmAMRsd3hf9hvKfxbOiMB/RvwzK5TuIu6lLxq3Omid/md6Vz1aTxE+2x
Sy49XjPm8bvG94i/m5/B644H+enxvePv4ffgLTerZ+zjZ6CInyl+h59FP3K2
NXhI7zpxY/7H4vb0RvU3YSxuwc3xm8C/ld6GcbgDt8dvF398/A3tfSdNpxNo
R/4k2k08MZ6BTo7fKP5dtLt4Cu1Bn3GGcmd4On5XeT15+5y3P28AnuU/h8z4
7ZXPolPjd8+sQs/QgrT//w//B/nJMqU=
        "]]}}}], {{}, {{}, 
     {GrayLevel[0], PointSize[0.018], AbsoluteThickness[1.6], 
      PointBox[{{-5.759586531581287, 0.}, {0.5235987755982989, 0.}, {
       6.806784082777885, 0.}}]}, {}}, {}, {}, {{}, {}}}, 
   {GrayLevel[0], Thickness[0.003], 
    LineBox[NCache[{{(-2) Pi, -1}, {2 Pi, -1}}, {{-6.283185307179586, -1}, {
       6.283185307179586, -1}}]], 
    LineBox[NCache[{{(-2) Pi, 0}, {2 Pi, 0}}, {{-6.283185307179586, 0}, {
       6.283185307179586, 0}}]], 
    LineBox[NCache[{{(-2) Pi, 1}, {2 Pi, 1}}, {{-6.283185307179586, 1}, {
       6.283185307179586, 1}}]], 
    LineBox[NCache[{{-Pi, -2}, {-Pi, 
        2}}, {{-3.141592653589793, -2}, {-3.141592653589793, 2}}]], 
    LineBox[{{0, -2}, {0, 2}}], 
    LineBox[NCache[{{Pi, -2}, {Pi, 2}}, {{3.141592653589793, -2}, {
       3.141592653589793, 2}}]]}},
  AspectRatio->1,
  Axes->{False, False},
  AxesLabel->{None, None},
  AxesOrigin->{Automatic, Automatic},
  DisplayFunction->Identity,
  Frame->True,
  FrameLabel->{{
     FormBox["\"v\"", TraditionalForm], 
     FormBox["\"\"", TraditionalForm]}, {
     FormBox["\"\[Phi]\"", TraditionalForm], 
     FormBox[
     "\"\\!\\(\\*SubscriptBox[\\(v\\), \\(s\\)]\\) = 0.5,  \
\\!\\(\\*SubscriptBox[\\(v\\), \\(c\\)]\\) = 0\"", TraditionalForm]}},
  FrameStyle->Thickness[0.004],
  FrameTicks->{{Automatic, Automatic}, {{{
       NCache[(-2) Pi, -6.283185307179586], 
       FormBox[
        RowBox[{
          RowBox[{"-", "2"}], " ", "\[Pi]"}], TraditionalForm]}, {
       NCache[-Pi, -3.141592653589793], 
       FormBox[
        RowBox[{"-", "\[Pi]"}], TraditionalForm]}, {0, 
       FormBox["0", TraditionalForm]}, {
       NCache[Pi, 3.141592653589793], 
       FormBox["\[Pi]", TraditionalForm]}, {
       NCache[2 Pi, 6.283185307179586], 
       FormBox[
        RowBox[{"2", " ", "\[Pi]"}], TraditionalForm]}}, None}},
  FrameTicksStyle->GrayLevel[0],
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImageSize->Medium,
  LabelStyle->{
    GrayLevel[0], FontSize -> 14},
  Method->{
   "ScalingFunctions" -> None, "TransparentPolygonMesh" -> True, 
    "AxesInFront" -> True},
  PlotRange->
   NCache[{{(-2) Pi, 2 Pi}, {-1, 1}}, {{-6.283185307179586, 
     6.283185307179586}, {-1, 1}}],
  PlotRangeClipping->True,
  PlotRangePadding->0,
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.7106000996086197`*^9, 3.7106822818975697`*^9, 
  3.717382691776017*^9},ImageCache->GraphicsData["CompressedBitmap", "\<\
eJy9PQuQXVWRj/eZN/9/JjOZzCeZTCaZDOT/I18yAmrtopQoiiKiZZlYWQzL
Ryy0oFhKWXUtEC0RqeKz+EFq3VVYEIwuGCkQdQOsSFw/iBVRSLlARfGLZ0+f
031v33P7nHfuEE3Ve5n33r2nP6e7T3efPn3//twLd7/zH869cM87zh0/9R/P
3bd7zzsuGD/lPf+ov6ocVyodt1u/zhkvwd+qVKI3828PvOEH4e/7zX8V9dGP
flS9973vNZ9uzf50ww03qEWLFvGf7jP/1dRLL72k7rjjDgCnDh48CJ9L/2ov
+S/zX109/vjjaunSpeq4445T5XJZ9fb2qoULF6pbbrmldAu/tFnNzs6qjRs3
qieffFJt375dvf/971dPPPGEmpiYUNdff/3N/OoWM9AnP/lJQ8yFF16oTj31
VPP3fffdp9ra2tRzzz1XuonfUlOLFy+GgcxlX/ziF1VfX1+pjFTOmzcPcDKf
bsxCete73qVe//rXm9ueeuopQ+1Pf/pT8xkY88EPfjALqcWQ0NXVpT71qU+Z
y+bPn69uu+029cMf/tDc/oUvfIFuuQ+pf+ihh9T4+LgaGRlR3d3dhmnNzc1q
8+bN6o9//ONNfFKa1J/+9Cf19a9/Xb3xjW80d9x7773wHfLoABIF38IY+n5i
Nv2k2WPm5Hvf+x799C38SV+t/vKXv5hPN4fF52/59zcRvV/96lcGRfiEwrYK
f7riiisUiX/VvNfV0aNHFf8HnHv1q18N0qavsfedddZZaseOHebTRvyu0XUn
mvea+tnPfqbWrl2r2tvbVX9/v9q3b19pR+QYBOtY4N2ZZQUIKky9Vg19+be+
9S39Hagr/kvk/te//rURNy2d+pP9DkgB/YBPmyKvs+xoUqeffrp63eteZ2bo
5z//uRHOL33pSzsih9l4jNFHrqzGnz7+8Y8b47B//36tpcpYqPe9733qlFNO
SRj9u9/9zkzGd77zHaQq5pqK+uUvf6kqlYp67LHHEvSuvPJKo8DwaUfEWJvn
iGeXJXMKb//2t7+tenp64KW5B+91deONN2bk6UMf+pDh8Fe/+lVtfex9Dz/8
sKrVaurFF19MSGhpaTF2BD6dUGD8RmMRqWCv4Xs+q1/72tfU4OAgY1tj3Gi8
udDVmWUfqB6YY/3S5MF7RT3zzDM54fvIRz5ihrnnnns0A1Si8gD+/vvvT65b
s2aNuvbaazMszMOocxjmX6OxiGS9mqgFCxZkcPvud79r7Psf/vCHjDkKjUeS
PBe6kIXr8KcPf/jD5nK9fuMQTWrdunXq6quvTsiDdfWtb33rlvDPhNSnP/1p
s4BzIsG5ABXQjCvtDA+ztThiqFTr8c5du3YZAwyfqvh+9913q23btoEnoYaH
h8vwQX8NXkFHR4f5SavtxkJXk8X97Gc/a5SME/zAAw+YWdWzUdpeaNQtL5uK
DssOWmCOHDmibr75ZvXnP/85Qe+mm25Sra2t4D0kaxRYaNBn/dKshndrP/Bf
wt5G123A6x588EHDghdeeCGBCwoAay982h45HknqsaKjjbOnDnqnJicn1XXX
XWcWLrDWb3/729XMzEzpKnYNuA6XXHKJ+R0Wva1bt6qLLrqodFnEOAstyNUo
xuCBn3POOWrJkiVq+fLlMAwswf+MP4N1gZ/HxsbU0NCQ+Vmv0peH70YYK81/
Ne58mX/g8X8MOaQ5mHDjn/A7vmaP2KEm2OWgvNa+wnct6uSTTzbeA/2TnCvz
w8ZGY7UaodCeRzKWxzMxv23wD9eE3zVa3s04VphL8/H3/DpZ4etkMo4Er9G6
KMGLXbgkePlFpMoXERyhpGexRACD/Mrb6yq31+J4NsisJRImjZs3i1VuFuGb
Mtw0oA7+8JmyevTRR8rqB9+8Ud/5v3ecp358++vVk7du06M9dcMSDenwZzeq
p//t1eqZu95qXv/34JV61Bce+dSwevGpb+ibALz+y3yahXcc3Px19NDtZXNL
xdwMA+kBk8E1IAMQAMML0Cir/3n4q8OAGw6u/zKfZi2+eWZcddVV6uyzz1aH
Dx/OMSNvDKvcGCbM6DYgmtR/fuO7wBHAhLOjCgiXEXdix5FvnA+0ATOA0Ikg
Q7rN5yb1xAOfg4vNjYwlCMBynlhy6N4PGkQ0QwCpiSJMAW0ECzU6OuowJWxW
ywlL2g2AqssOg6keigsG48KKIBfazeeqywEak8sDI3xFDOGkamCmQfytx6hC
lj2ltVmmtWLwqhpaGZ1r/DReuu+cZplGGgtoZPStiaFtCdKm3XNaRBLXnS8q
lYSgGg7LCCpZDCqcGh1Ohkip4a+MlGQURoceJYKI9QlyZQG5soDcliByZQG5
soDclmLIaaEBvED3YBQ9Xgan7UGcIC2h0QHLADfBzRyV7UX5lPIEhgRYO33w
tZhrBNQFZ04asARa03FSQQZYWw36DMPuEgCehACJ1n2n9ZoX0KllelYAeBLT
MOAtZnNy0E8WwO1wwBFt571hhXrX3gtPFsDtcMDhNMoUSzC3CTDhBSSaJdMD
eBsuJBwwvIClZjWMRWCrea8ZBLgsaf5aBfKisNW81wwKXIT1jJbKiSmOQuJE
hgTnvKZMMzeExIkMCTYBMIq+U0LC3P8KAYnNAidgldBDWzvnRWKzwAlYs/RI
FolKNCc2oVV3uFAPwt+EUugwoF5sEjZ4JgHobw7C3+CZBKC/uRgS69mqRpOg
h2wNwl/PtJD4ryloLQZ6nQMaWd8WBL3OAY2sbysGei2CBmNIbNeGvD0Iei2C
Bu+FOK6XjvZioNcgaFja2Ix3BEGvQdCwqrLJ7igGerUg6xp0ZxD0akHWNejO
YqBXyaC7gqBXyaC7ioFeid8x0KWeINyV+B2Dq+8oBPQE/I7Ncqk3CPQE/I5N
sb6jENDjZdEKwz1eFq2CoGeYLjPQfUHQM0yXGei+YqBXCGZEj9gfBL1CMCN6
gP5iK9i0AFpbh3lB0NMCaG2H+outW8sZaFj60G4PBEEvZ6BhpUW7PVCM4csd
hQKnYX4E3FShwFmYXwzoMkehILYYDAJd5igUxBGDxYBOsVCEtHgoCHQKv2Mi
re8oBHSpLM9huEtleZ4T6Ir63i1vMthDbLMgAq5NMcEdEEotKAZ0UpjZ4SDQ
SWFmh4sBXSLM7MIg0CXCzC4sBnTC0Vk0F2G4E47OormYE+iszo5EwM3q7Egx
oIsdJmv0S6NBoIsdJmsu6TsKAV0kMFkPF4a7SGCyHmBOoFMmg/qMRcBNmQzq
M1ZsDRoXmDweBDouMHms2OozJjM5DHdMZvJ4MSaPOeYCJHlRBNzUXIAkLyoG
dFQwF4uDQEcFc7F4bkCZqYgEyuxEUaAj+B1FRmCNJ4JAR/A7CovAGk8UA7qQ
sReXPGtvvUAXMvbiemdtenGgXFvjgHJtLQh02BEk0NbJINBhR5BAWyfnBhRy
VSRIcUBhWSdBKgh0gSBIS4NAFwiCtHRuQJlNigTKDFJRoEOCRZoKAh0SLNJU
MaCDgsosCwIdFFRmWbG1ZtChFFQmDihRCiozVWytme+ozIGrN9mAwgt0PqP0
gavG1YPXrLVBSzx7CSioDAAFlYkDSp4wqExBoAOCcZgOAh0QjMP03IBySuOA
cuNQEOg8h1IwDiuCQOc5lIJxWDE3oHw9jQPK19OCQPsFSmeCQPsFSmfmBpSb
wTig3AzmgNJWLC9EbsHvoErot7/9LX4KIdcnLAzHB5HrExaG413kaINcqpyh
yhi3yub+++83laWdnZ2qWq2qM888U/3mN78pR+HPmRuHP2euB39vHXEZSeDF
PVCrPj09rfbs2QNom6qVmZkZdf7554dJ6BWm4IQgCb3CFJzgkjCOs9+oYogq
ywBfOOPw7LPPJkUcUO6Fhy6iSOCzEEcCn4UcCf4CpmpSwIQFSlR1zWuTWpCK
H/zgBwY2HHsIUdEjTMTKIBU9wkSs9FGRL4uqJiVIWPZEVPCy2Zr5rjlT7wb/
YG4AFxyiBh+kbeQeYW7iqMqZn5ogXo0KYq141dXTTz9txFCrg9Gk22+/3RT5
aY0vhfWjW5iWVUECuoVpWeXTj0YFrjU0BQMDA8ZkwREdALZz5071i1/8Ig53
zvw43Dnzvbg3qkKtoQa86lWvUh/72MdMZZpeG6pBnLsEfq8O4twl8Hu1jHO4
LooKyj7wgQ8Y03vkyBFNF7xX1PPPP0+iX2qIO+d3HO6c3zncaTnwlDgR2lDB
DCuEfmkU4b2SHNkKot0p+CVrgmh3Cn7JGp+LwKuXuoJz3+nwD7yyOES4V5ZD
JOwgdQjUrw0C7RCoXzs3oNzTjgPKY4qCQNuFmGJdEGi7EFOsmxtQTmkcUE5p
QaBtAqXrg0DbBErXzw0oRcRAaRxQioiB0oJAWx1KIfbfEATa6lAKsf8GEag3
9m8VKI0DmqM0PvZvYZSigbBFiV6gLYxSNBC2GDKevQSUVqOkErIhUFqNkgrM
4kDJDMKAcUDJDML9BYE2C+vupiDQZmHd3TQ3oJzSOKCc0oJA64LB3xwEWhcM
/ua5AeV51zigPLVSEGiTQ+l9151ui/a8QJscSh++/hRbIFgcKOXSgdI4oJRL
B0oLAq05lILB3xIEWnMoBYO/ZW5AuRmMA8rNYEGgVcEMbg0CrQpmcOvcgHIz
GAeUm0EZqHeVIaDcOMQB5cZhS7FVpiKYwW1BoBXBDG4rxt6KQynEDXFAedxQ
ECivrSdKtweB8pp+onT73IBybzAOKPcGGwKtc6DmxQ3DDgdgnQM0L24UdhQH
xg1CY2DcGDQE1pQBxozATgdOUwYO0/2dxUAwlQ+DYJreEEQtA4LM2EnO+LXM
+GS6ToofnCuxf3CuuAUG58rqH5wraMPBTdsLrpC7nHHtBUz/dsUNydRNHpJp
lzxkzkqTMs2K2kvKsyvO+pKy+AcD5Zj1E0uYAe/gFhCnVySDvYIZLvgVxOgV
jQcDNYbLYbXLDwZqC7/CyhYxGIgLCoUwGIgJClZosFlndSoZPtJgdCaHBLpE
XA4PRoIsD0YC3GCwXShtTHhVZrxdKG1MeFXckEx45SGZ8DYY8iTUYbYaGC3N
kn4S6jBbBYzGN2ABDc6sf2BwZvVjBt/JBJzi/DLTEVouUw3a6azWIPRlpnO0
JAe0aidTBFLROKB8TSsIdIfg4FaCQHcIDm4lGqi5ZrujWPawdAxQ7uBKQAMW
cIejgNyxCwPlDm48pWWXUhgC1sZqEOh2h1JYJ6tzA8rXzDigfP0sCHSb4ODW
gkC3MUEiSmtzA8rj/DigPM4vCHSrQymsy01BoFsdSmGtbpobUO7KxwHlrnxB
oFsESutBoFsESusxQEMVDvy7Sg45bi7jkOPmMgq5xhUOcX1EUuRPFBaY5iDy
JwoLTHMM8jXkG2zG3nrrrVCvUBoy3xUqeYB/ocszZPE5iSOLz0kBsprUZZdd
ZooAoHnOm970JnXnnXcCfvOQ6tiKiPx1VX5dQmEzuh3QdQJOhwOOYwsHzVH1
GTapVBnYEqS+Gd0TaJKhP5qrFgyPwN94RitbNdgSwxlqSgGNcKDOZu/evabN
CvRa2r17tzpw4ECpD8lu1PKl6r2uyq9z2FNJWAN+lvlBf/eWM05NkF7uCAp4
ADGsqiRs4iOfdvqZyR3LHYECTyGKbVRBAmyDLp9QJ6B/JU416nhW9V6Xa2pj
4tUa8MjE9CuM8FRMowE48w+T32LeLcZAMXyahfeyWrfhxGb4C++118HBfbgX
RmrB8eBemAf4tNM2n0ippUYe0KcOepnCLje0D4VGT/v37yeq4yo+olrvpFTX
cNpQbwyCyxDpi8/ZZAh59zvfog1QQybQUKg05pJleNves2fNUJfs/js9VARP
yKRA+xuohIKmbWeccYYxgb///e/JpDQqIql6r5PbBpHOgH6EdIafiSNXvS1K
Z0A/QjrDz86RS99WZG0577zzTAczqE0ZxO8a1atUvdfJDYVaMEB1rO60YEnC
XGnBQNYxuNOC4YhiQkyxSy3imnQZ3SDMdHuQpg3CDLbHIB9V7RLR72eDMA1x
KHN+R6EsVbq0CN+l3tZ6gZ8dQeTWC/zsiEFufQ4o50gcUM6RgkDXCZR2BoGu
EyjtnBtQTmkcUE5pQaBrBWerKwh0reBQdc0NKKc0DiintCDQNQKl3UGgawRK
u+cGlHvycUC5J18Q6GohKuoJAl0tREU90UDNNauEyDoOKI+sJaCBZNQqh1KI
rHuDQFcJkXVvMfYSUF7wFweUF/wVBEpNQPjuUF8QKDUB4RmwvrkB5RmwOKA8
A1YQqNt5BE6j9QeBup1H4DRafzGgxwvGYV4Q6PGCcZg3N6C86CQOKC86KQiU
R9ekMgNBoDyCJpUZmBtQrjJxQLnKFAS6whEkUJn5QaArHEEClZlfDOi0IEiD
QaDTgiANzg0o2d6777ojEijZ3sf3X1sUKOUeuEUaCgKlnAK3SEPRQM01NniT
e4t44dpGKnJvkfi1hhq48OPWPWzugCq712TT5/DdQVYxAfHiyQ5O2aPYPUx2
gKt2H8qm1uG7F1m1hh3NOzlTzuSAlncwNtz775+hXqJ1uEBDgIOm1OcUWAJU
pHu+U87cgRHoYJPx2J2XU0NRPiA1Y4UBgZDANrGnbQyvcUZm5Xpy2t59moVl
82claShkI/WnktabMADQlRaFePrO8FpsnPBcD0/ba1CLQdn8WUk6EnGo1CIT
iA9UmCx1NBiEy5Yf5zs28rZtWAkB04y9PV1ys2VZUrsbWxid7ygJ5FBPOYQD
s48NSF0CGxRzSU1yWpBASNvCqCQw2JLSRjJyVRRABBF0qYUB07pNqc9OC1IL
mWcYhcQe+2fagEsurgIAoEhS+9NA6afUqseSnjaAJNKBi5K3X3Xk0e6LWzSo
aS+MmFZcS+1+LO1pw0qiHWREikqqju7Z/XsLldoOw4iBqm1PyyDqa+w0oJSc
4rpHPHHK0xJ+T6MhanvsNMiUPPZ6QOP07fKBA0Zmtj1Rnc2x2+RS8olbwoSu
cwjNdjaqs6l1e3FKLntLmNTA0ZXFgibXHdYjVpJr2o5Uwu3UrxM5BrenJ88W
C8pbd6QJb5Sc5nYkEG6nFp+IFtyeO6+WEkhdkFhvzQyBrGun5JF2smkkc07m
VN+eniOl3kmsHWeGQNZSVPKVO9kMkjmnwh99e+5MbUrgOAPC5KRJplFygLsD
oqoZnp4mH2djMvlvksmUvPPugKBqGcodQ0/JHBOAaF43CSjpqZa8394wmWnv
hTGBdXrMJoHRGgPJNe8Nkxlo2jAqWFiNnESmx+ntDxuetG3IqGBhNXISmR6n
vD9sduR+I2aIhbLqE5lkJVD6+6wfD6a2Rk8ASHxo8M+G0F4K9LLeNyOM4Puu
O50MCBFMJhBV29jZCrZ/xkcEJGGABWpXBIFy6wHKkYdE+v7PX+GSzhvb4kpA
fiE936IZXXOYEnLN4XftvWOgW8v1iAeOpM2WFgqW/uDte12O8M68uASS70gP
8uC4UNwBv+vQBMP0Wq7ZPTAq0MZpOE5GkFH8ZGn2IQLVBCH0880qVEE3HxBG
0kv8QQzETGrD6uFl2oxsWF41Pbzkx1qzT05IwWMwZBbnCsZCgC4yI0ceLrr9
AXYHOqEtCMul4/PYkKpZtDLsuROtggPuiE+JPzCCgqs+NGJUIuj4FeMJ1xeE
ue44Tzb8bBYNFnvyRqsQqzgKWOIPqKBAtA/tIVAneCnjfuYPyUuoh/m+GA8X
C2mbiZ8180U+ED7yRZL7OxhQpX0rh2T/wsP4BtGvtM3Fz9P5AkQIrPlayz0n
jDtH/UwfDDE922/bx3F8FIUUbjVHcDzdJPFOZtqOdTDE8WxDcR+78YkbUkza
7GV3lcu4uv+/f97AiQv0gp0vS0eNUca43opywIOL0BaNm1ySOJ6G5F4PKW0x
PF9WvxqTG0ZJKyoaj1FC+0NuVooL+KOf3pDke0Ls1vcF+hvPC4SREs+1eLQ4
t1BSwbdv0+nwnCcVeEalC00qS3lwnhuU0q7d8wLBtsR9rYYtnlt820edDvd5
Dobnn7pwBWME8rENSoHm4f1yvoL782S09CVUzsOXPU/A2OPg5UhFTtC5MUck
0sbw/XICh4cCdL++hGqF+DLnCZ97nGl3MMjJNzfgiMQ8P3N7mbCSy0IGwo1/
Eclmj0rALVLASiEO+boOct0N6EtMlWFzL5NRGowshBtEI6+bPWINt0ixPEV/
FCc4CHU3kJrEVskM7/ZwL02Q5ZanZoEuPctSODkQLdJ1H31GoNLHeHQHjIIn
OdMsyI2WfSnSHogW7rpPfgxNgSeISOknlt+uC3rLkqQ85qCFzeH5UIx8h60k
yHj6qBopkcW2AeqOPTxw9SaeQeZBHa1tDteHYiQ8vCCBlAeek9PmzCs3Lcj4
YDo4lL2VHjk5HC330kRk4z/ipZmLNmdgbnNwPoLIhoiUHsw5HK0Q0vxk424S
Y3mKuLWExRIjfjcoe5SeXeVbCLLhrubPQJL1MesbEohpH+xoLmvLwdv39jiu
CYyrHShLXi0zT6Q4lWSy+IIFKytmBdzo+Cg9VMu3VmRjYY3CQJI9M44FkoTp
M0w4etWpx3ETYVxGEp8x0qyKP+1XwdCZhfQ+KQ75cy79mU2gGs+pJPkpu41t
2wUQiUTmfdedTpu+dGAWBhqMUMteRy3tIbZUCOEIgn5pXG2mg2UFfFLveuB8
jXVlObPRVuO5ryRJ6CMcbn34+lNoj53OAMNAgxFq3OuosT3vp6+Sk55mejWG
zmN407VDeJAgl3TOCH2fa0TSNFIue2bCR6SfpNR9Im4pfV4qSt9geFnsZ9kv
Sgrxgc+cXQQnVwwymjLnycbp+iM8eJGbLC73+j53DUjTULkUp4lCkWoyN+6D
hkvpE2dR9AbDtoCn+ymBxwaWLXVfQz2W155GgSU9KbVVWIeqzD4Av5Ee95my
h+hJURHxKz6U6tJ95/Q11E95wWwUcNLTW1sFD6HK9B7UBsXSfdTuEXqQVURc
i4/mkqasJ5A90sN6Vp9OZi6FMM4IvVS43+KV6qyLOeDMVGpCK4n5hJH6kpny
ZdbQh/M4Bp3M+glBs8FFOrLQ4rVJWcdzwKGX00HrH4zU55+grkBGKFlBcjmH
joBn7kkKdkQIE8gszQ1YBRxanJvuZG66Ajm4ZPXPJSQ6AuGQJw3bEaHgfFrA
nOPQ4rR0+6fF3dPh+Uf+rOOQ2Wv3TBI6HFIeUVoWpEma53DCejx5TnQkk+Tu
qfGRkeUs1S2bvXbPlKEjIeVxpdVd2quY5xBuPZm85ejwTxnGSjbYwTnLqBPO
Gy4zOaPXLmgii66kxGNf5HS59u5J04Qkz4WWZLowXrJRHc5XRrFwznCJyVm+
dkEnWcwrpX/7IqfKNXqHTX+UPNEt/qniW/EwU8zDL0nPnG8LrNPkcvJUPT2x
WUpjuui7D4HPzlmNq5gZW0dM9voyUk5OFyBaxqgJBodznHA0lxc7wEwyr77k
ujHp4U7ZyyJPk2+j0IOtpcyyK3iwNe2f0xpXP5dYK7PkVwOiZYx6YfASnr7N
TXXdcU8B88f3X9uBAHl2nPIxnAE8zQEMkIqBhiK0MM0JZ2seSOqaLJH7Tusl
hPnu99133dGBN/NEOeVduHjyBBOIp1RSNBShaWlSOFswQpKDCKcsL/4IFRMv
lm11duI0yEoWkkkpsbcwckoWOFNCxmD/56/Q1+89e9YE82Vby514BTIeISMh
pUsXRs7CAmcWSIcP3r63lD9pfIwfE9MfYflcPfGl9MYiJyXdpu6PMEWu0Psy
o2OR7M5tOf+1Hl8TqiHUbAiJ/IjA3cUR3AWrmT5tN1RZqDkRkucRgcGLIxgM
tj735N6/1sN1GtSihsR3VGDwpMBgWj+5V59uhTYobghJ8KjA4EmBwYQAj4xy
u5zE4EbNaELP+OHhG8Y1GfGicwYhsR1OnMoKHl4q4REVeh2lZxRGuOLpXiiP
yzBszEgenUYISfRw4r1X8JhWCY+10OtReuJiRNyT2/ekKWjU5abIA4p453cq
U+RT8o0b97AMgyzoA8LiknUOq6Zug+4x+yVPmSywkxw1t+phXDskueeAVWcy
ffwRDlS/yKcPntmdZnxkfeHeMtvxyGRziQ64h9HhpDvNrXoY15xJMRNgZYTq
r/8wJ75L5clDkgHqCKhgPxuG0hM0jPGxy9hYkDhBr5IJm9iZNr4jUmNONtu+
GWeioL0Vg4BNF2c3sCh7n+428g0sT5KSrF1HQKn72TCUT6JhTPhUxqaIJL/0
stSyc4N8G4SoJZ6jRI8LtoGo5fsylLXPbUke84dolSqJy25tg0ahKkR83Kt1
d016BSPDNwrY7ovUiK7u6CWPeXAarKlBkWGOYiqkKOs1HggyjS2hk67d9VIl
gWCtiL6syoSGAnoea7g7Jr2COeIbQmznRWqkV3csKg+akGJLPIoNc06rGTbp
q2o8zme2lkKnvOy87IeYVZhVhIMNzg5bj2BbULBRVOS6PBI1KdvdnibOqpld
smRzOGtxFwniYdiRyoiOo4kQ3Jx0N816Amajl20/HHLq9EiCpO2H9jRpVs1s
fDFC+BK4SJh1I8np1LszfAwf+YYiTrMwL7xTwzdAhK0MKV3eIxhEbsFJbqZS
tlUoa5XWQvo3XfjekrBLJG1C9DjOietb4opEB330yFIkeCyeXEfJIKnCl/Pa
LRjSciLlud2EvG/HaDLJ8FJyR6qI5px1C330KNLOgZtA9229TbpZ2fBz9Xj1
rpuL87EJtwOkHLOb+eJOHTulY02MYROve3Zzaz424ShSxt7NFXLvmJ27saah
8S64zJKatEMilqS6OShfPDOa8KOvIT9q0oaTWGDqZul8kd6onxm8CJXvufhK
lx1TD/dJGVLXl/Op04KEL7x6l++X+KqTHccc7pNyy+ORarXAz6JOASqD3GBn
W8pcTjDuoHee8ZBYBVJa69DpgZMpDvMuP1KSd4LxBkOijGvKKsACFQqtqfch
1+jooakoSrKVCwUGTfnEh3w57u32JCxqTRdCuXBGM5sK06R1Y6HApCmfAJEj
zd3QHj+bPCWFVHhGbSoye8uyHZJSWyscibJt/P2xU3vCM0/1JseL6UlvwEJJ
Ob8VjojZhwX4I9h2PwPNJgI6uCx2dvUGKQxVBo0LDFwpB8w1x92yYaBVFISE
O4b6vQyOl9mPQfeVBb2uXiHBoYqscYGfK+UsRo1ZNAzsSpRnQEi416ffZfa6
0sLr4yjJxYMS2rVcJDBzHbNFvDgN4iGNYksSY7iiwEsRKSPFAwjaF14ksGYd
s4+8DhBiF410ixsPpJWwdvaSKtwhJjo4e2Q8EsvNqd3CfF2NuCmc17dDd+d3
v/MtmfQn3y5D+SUTmVhjTtOWxKCZHT48fSxN33BA3kcZghY3FuMbeNZcmLpB
Y5OykgOYpw+nHA6I7CjDF2iq8fyJTdwZA6DZWrZWJqtKMLeBh1oOsSkWHBF3
M5JacYGdbmKKXLJn9K3RaOa2nFWdsucvDzFxFtwOd3+RGnYBCF5/XLLH8a0R
aOarGSv7DD3EuUE4J+1KS4W4tF8sPSmmxldQWg5IkzJlunIJfdqfZH7YH5H2
/KX6Wdo4lh6EU+OeB62phE2mulYujg90OJkXcLZYn5F8IVsuxSW19u+UrXjV
oR+ZmnYJ8aUY0H8ZdHh62DmXwqyr9CiDTnkJrDoihNyTG4pggBVknlvm69tI
ljJEfXJmk3OOieOShHN9Yc65hbq+nXUp+9Ynpx4525jQLfGzjdcOuttRIA7k
ZPKjeb7iXil3MyhLncfjT9s68BJAd3sJBIL8cH4Ez1esK6W5BmW58wREgcYN
vFpYyp+mNURNuVgXMzNS97ARQTgkgdP4DydM4xXYUgo0LQ9qyoW7iKvUXGxE
0B1J0jSuw35GNYyTDlHHqHBiQOpCxpPLbOHwSFl6zLxhGHmEGmaFcwRSxzKe
J2a+qEfCAifII4+6cUEj/nEB0ICkXMVkyLjJ621Pwr/II2tc7oiNXE/0wFI+
ZzJk5OTVtcfPxlKFc7BkNxGbM1LIdQHXLOrxJHBTrGGbDq8VFNkilDLuNzKn
F160/wbP4gBvnrG3ZLd6mzOSynUcPQCKJwRWi3Vt0zKv2V5WLfEYeUxvFLru
53rVDmDdQuAr+McgRMOMsW5CVEqJrEzNR5WvJPDqzMZ2tDsJ+IJfDHgOM364
GVApGbQytQxVvkDAq1OM6li+IHuMcCSQ+pXSFxtSSivcHbY5gCbc/IbnIsFj
gWjzG4gcC6R5pQTOhpTICvdlbRjfZCVUInM8QJKUQZhNMj/jARSlFMmsmJsx
14wwYyeclJDC9RSPUWaOhFMJUoLBPOrV19JNDtYw7pCi7BSVhZ4AEyMsKfqX
uYJdvIIh0GQQlQVhVCaLoTIYQEWL61QQlUEBFYo7tahOFUNlwCMriMqkpHKl
ElY7G8tXFRJwGxNsBzzihNhOSopmxz8EZzX1ZVUhc7bRT1BfwFOiCvNFrsnM
HXu1/EPWloxd89SIaXJXJtT2BVwiqsdf5BrQ3OlTGbhU2KV5sdLPiphGOJ7i
FF5Xk6YwUxNeskf/bUFMBf+kLA+5RLmaKixSOpI7Vz2VcDCmLY6nvIRXxqTZ
Yfvo3xfs06cNyWZRruCflCKi5TtXGYVlZIdyh+Cn/IznJ3Td4268gpMWOSYu
JU81kvSoUr7JxBMuEcmWiYThnQIOUiXsqECTp45Iekgq35fj+eCILNaEn9Ft
DRid2fAVicwxWnoYnCcmrgkMJo9jJGFwWwMGZ7aFRVpyDJaeM+fJJ9QExlJO
f8TP2LpDcXKQ3eL94DVrk7jZ5a1bt0uxvvTgq5HEFrrPFrD3p/x1TC41FtP8
rTuEowYTCtBGh1BwWeyW5hJJ0hO3RpI1w334AkeVCOZsnu9ns92HlMp8vfur
oxFpFamkZoJ5pnwXCMTMCkndt74ZU9mVMNzG3VKNtXcndjQi/yKV4Uwwp9ix
GgnSnnXRrBRdftbXHNVCHi8S/BW2/kj5jOWOGXZy3tj7I1v1aJu82+pT+A6C
Fv3KFOOy7Y9FgpfGVnIp87M8bHARq2z1qW1xbytEf4yPRymJclt1ZWRJOHsm
VevwR5SlQfyhTDm2NYJ6oDpbi23bGGe+l4RTiVLBDn+qWpr9OJKpkLbWWg9U
Zw6MxJLJiGxY+PE9kxE5voKPEVoczi1J8X2Kz0Q4ZyblIgKPFeKK5dotjYoU
haeocPl37YceTEoWBJ7oNOaJoBCVQLSdtMD31h8FgnwJlZEAKprni4OojARQ
0bO9uBgqw2FUlgRRGQ6jsqQYKnxn2W21rFV9aRAVvj/sdj3WWr60GCp8G8Vj
20rLgvjwDSKPcUqeuRWJVH/AByBbMx1Eqj+wIJOtmS6GFC9GlvzAQ3ieZyaI
GK+ylly0I3hOZqYYcm6TXTepDdM4w3MRmIfApJ++pNUpyKjyhATctCqhwW2M
62aiYcZneGIFkyqYy9SXtDo1GVWeXYGbVvlJbXMieix+kGK6ZY5PyI+ZSamI
mh3I5AfSIp4nk/5l5PmQ57ssYUmbE7JjIYgUFC9zfD5+hk9GygxkEgBpOZMt
9+BhL3HwiQc+N+XnXt2dF1T4nCiDmEzJUZJ7ICudPUxBdLJYwtarscKOUnry
wznlZwTwEJyoyOwI1125RQsjdvjmDxYUPfcylh+RdGOmp5NFarZ2jZV3lNIz
Hs4BSyPGR+A0S3izuOyyPdTSY8oRJnS2c21EKFZsEmwFz6KSlMGhPoTbxCMZ
8jQtpVRwYnhfdnkf6rsy5WgmuuO5jiCkPk2CpeSpY1LZ/Z+/guA2uTxIhYpK
UrybgFRdl8azNg6Bg7eI0pRgnV1Kk1OkDsfH3FRyRt4zDM+dhnOsrTmdR6JI
lahQ4QdNJYVGfnDkFoVhSlilXBkD3ktpoDE3WZ0R/wzrc6fbHBNuTtuR/mPT
EMmBt3WAXCrsut4shoJUcUsmxpkBdjKpKVNKxpKe/RhV7zut1wSlUgGqdQya
xRiZqmnJZDgsTE8iYagm5Ir7bGgqSelMwG1B4sU8wuqswTUMN52yK0n9nUlt
zAQcK6RMTK6szlpHI5Kms3UlKZmT1W4aCaI1UUrRBx7xrFGeRpRpqZcS5oHH
SktITUVkawKPC9ZITUUkqQKPKJbj62DcJZUcpPhMhiM+ad8/gAoPjPmkoQRK
gXGKyoQntkHxCoTkEirjEcFFIDpO9p3DAU4gOJeQGnWmygku4vefhdhG2n8O
oCLtPzNUiu8/M1Si9p9Xmv+yfaTSnlG0J+321+O7r170aE/a7WfHt1YboceP
K8KFDz30kEWv1JLrruTtxMROgIaNRnhjm9eT+YxG1O62n6hsXyP4F2qDxI5s
elOvgSA5OW7pzSYHYvQwNXQ2N99jqMp7DCVENDoCnkSkXkoanYZPAuiXQ06+
o0+Vd/Rh0XzWDZW2/WDlPCFIEu3yhDbmYPU84eWSle+SU+VdcixhJhkYN16+
FUuVt2IRx6N2atSJRxq3UacOc+P67HhXXXWVOvvss9Xhw4dz4zXq3iCNBxIN
B9BHR0ed8cK9AsxYG7K8O3jwoKEHxqib77yH3fntS/D2F198kY5xa2c3nQ78
Z0FutPeYv/fYv2/AazXZybWb2Zj03b/Yy69HymGFmJ2dVW9729sMVRr70kY2
a6997WtNQ7vXvOY16ujRo+7tt912m/ryl79shv7EJz6hLr30Uu0zWajQQOGJ
J54wn7rw+rvuugssuLke7r3mmmtoyM+gTAF/3/zmN6v169ern/zkJ/04Gl/K
iC+5logl2x3o4osvZlArphvQBRdcYD4NCOPZq0ufxJ82bdpkNEezDYetqu3b
t6tbb71VvfTSSyBNvUiPtDpRM7sifQI1HIBw1lln4c15TMooSyDzK1euNF1H
4B90tdJY9QQwcugD6VyzZg1oUULf5Zdfrt7znvcYOdC31PBSAAbKBpdW8QYQ
cJIme3uPb0EzF0U29UuUFdj8la98JcMICWUg/JWvfKUZ6w1veEMxlL2tCC+y
vPoEsvPZZ581FuHAgQMGieeeey4RNZBUuNNeab87dOiQGVm/NHR4r6h77rkn
gU5ENurTRzDyffoqvE9fqSMCz+eff96oxV8Dzwuz7ALwvb1GO9Rpp50GRhPX
gsad80irWee8hLyXM24GxSZ1ww03qA0bjNVVjzzyiGpra4P2YSRpQDBYMv3S
jIH3ivr+97+fY0yjJnTUmSzQhA6p+5uh5DACFiEwtPTvjDPOULt37yaoIDFg
wvRLQ4X3irrzzjtzUBu1aKsgI0It2jr/tihlGFE3a9tll12WQIVL6/W6+tGP
fqQdcXt7Iy+lihR4+ol1HkNQGewrRovJXNLl5513HoEp0QLayC+q4rvT1ar7
GINB7P8DGRLyrshWNerEtCxiLDTrX8Zp8jhkBLFR96Hl4WEQ2B04GnffNgvf
4fJsPuzJ/1067v8B5ktLzA==\
\>"]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"plotBasins0", "[", 
  RowBox[{"0.9", ",", "400", ",", "0.05"}], "]"}]], "Input",
 CellChangeTimes->{3.710600204504321*^9, 3.717423449193543*^9}],

Cell[BoxData[
 GraphicsBox[{GraphicsComplexBox[CompressedData["
1:eJxlm3lYTdv/x5s0l05zcYlc4xFuGZO9TSFDxspMLgoZupnJFDIUSobooFCK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    "], {{
      {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
       Opacity[0.3], EdgeForm[None], 
       GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNmXeAV8URx3eeKCpgoRzS9OhFeq8nvTcPkKYgoKCIIIgFowbF2LCcWMAW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          "]], 
         PolygonBox[CompressedData["
1:eJwtlXmwkFMYxs97uhGlG6J9HUvTRdyxizCasmSMMYZJxlxpG8oyTJM1S8hM
ppmyNG1SVJZKmyzTYCraF0QqXWW9KRWShN/Tc/545n3e75zvO+d7z/s8p0PN
kOsH55TSCFAB3ouUBvCgK3EG+avEc8mPIx4PjoU30QvwAHeD3uRdiMN5/DLx
NPKjiQ1Bf1AHfmFsNvgAPpDxbsRZ5POJz4Af4UvBFPg28J32At6B38H8C4iv
kD9I7AeWw7eBx+H1GT8Iz5oLNoNvyTuDRVob/Aw/B4wKf0Pvvg0mwqt5vzGx
EtwFbiY/XZzxGuJP4Af4NNBX39Iz+EzQjrnPh7+lNTS2ACxLnjMSPgxshU8H
G+D7wT74JrAKPg3sgn8J/oIfCI+NB33g9VhjP7wBeIh8S7iWl4Gx8IdBLXwu
qFXtwBeqNZgBfxRshy/WO3zr0uxa6pvfMPZc+F9Us3fhNzB+MvEN8q2qJVgD
Xwj+hd8C/oD/Dt6EPwZ2wD8GPXl3D/lOeGviSeRjiHPIV4Lv4U+ByeKgivGX
yOfDV4O1WhfshX8FZsGvYU5b4sTkd2vIzyvfWE+cDvbAvwb/wP8L720SaKhe
BIe0d3AK/IVwrerAh/Abedap7FH/tiO8N/3jCvjrYHdyTVfD/wS/wTeCz1QL
8Cv8c3ChejX77E7k+UHwN5igWqvn4OdnjzUDHeANsrVwBHlH+IDw2R5Zer19
9ph6vhP8GDBP/cCzS+CziS1Ac9CGvFX22dUnvxzeOpu3kobhTcEBxo9Krs3o
8FqqkWr7ZByW9+EaS6vv6wySNStvkKakpa5Fe91Ay7AGpZ0J4V6RhvqQLyUu
Iq8m3kr+Wrg3zw57hzQvrXcpWp+jfSZrvrlqla2deuQtVYtsb6pQD2gv5OuS
13iRvHN2r6mnusOvyPamJoydIW1na1sedTX8KtWAvGnY66aGuTyvgvzi7Nqq
ZvKqZtl7kWcNIp6afRYryMcRz8zu5QXJvTMzrD31kLxzPHmjsIcuDnumvHIV
j85i/E744OQ58qZJ4b3Lo27XWWf/+6fSXNjDKotGb2Lso/DaVaW3BxJ7Jfd4
XekJ9YI8eSjxouxeVI9uJI4AU+CbwW3w6xjvWM5kO3F40aLmaK9as6rseYjq
ln03DE3uzROyvblF8YoHwlqQZ2yCPxv21i3gEPyJsHY/Sdb2mrDWpHH9S6Ns
Leuf5M1zwZJUPFo6CWtRnjqs1Ey1kgcvDK+pteTR8s5B5exqk715XdhL5NFL
wneg7r718iSNhe+qqeC+0tPqZfWQtNALtAtrojG8MvtspdlrdXdm/5vmyGt1
Z+mukufK63qHtdm21P7p8Fo6g31gLxhJviHZe5aFuTzo3qK56jJnXvhMdZaq
ke6C+8PeqjtBXrYyfPfI03pob+Rrkz18N3xXOUs9kxfsDHunPEHauzLb66XB
R4j3lFrpDpeXvxW+G+Tp/wOgxR4I
          "]]}]}, 
      {RGBColor[0.880722, 0.611041, 0.142051], AbsoluteThickness[1.6], 
       Opacity[0.3], EdgeForm[None], 
       GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNmHn81lMWx/O9F9mSLVmyhCGMpbE0lhkm+8iSfV/GGMskyhYSlURR0iJt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          "]], PolygonBox[CompressedData["
1:eJwtlXmwj1UYx39+5xFqqrHUCGPphrI0tCd7yB5XWUsIbeaqiWQYuiGXsUS2
YoxlSEm2qRHGKEuMmpZJm6nGRChqNPayfL6+7x+fe77n/d33vOc8z/d5Tq1B
wwuL8rlcrgQCSvPnr5TLtYPHoC7zJ6EX+gFojR4K/dHreLGBNPRm3gSuQ0+B
IvRLcAr+Yb6C8Tj/PwJdAsOY3wK90dWhIfpxGB3+H/32tPaBfg/Govfw/q/o
F2Eg8zlQFj1Tz9AH+f0bdFvowPxVOAF9wmuv5/c16A9gf97vLEHfCo2Sz3Q9
egy0RleH29EfwwT0RBiEPqwR+sJbzGfDNNZ7mXnh1SCyV3QzeJj5JdiBrg+H
sjX07lC4Bv03Y3voCYuZ14Q7k89QjH4dBifv6TgMUU6SY/YI+jLsRjeG8eFv
aO0hcBPzrxQjdB1oib4I25VbGKfYQo3kb0i/Fn5Xz87Cv8zfZ8xBefQN0A9d
oNzCM8yfYrwH2sg/sDT5DAXoVYppcg7XozfqG+j7dQb0ZpiMLoGK6LlQG32b
9oz+EMbpbIop+kZ5BN0WTirHzJczfkcOjjAOZN4neY3l8l7YC3fBBPREeA79
LExCJ5ie97Mf5U0YoNzqTOj/YAu6BexSvBmrwnRoxfwYLJZXkvWfjG/n/Ux7
qw33Ju9RsTmReVExOsm8MzyIXpVcO1/AjOQaWq3Yh882Jqsl1aRqcUWWG9Wg
ak85Ooq+OZzbhcneUA2pduSRs6qF8Fk2whmdj7GC9gQXVHthr2xKPvvdUCk5
BvKyeoBqX57+UntXfPPe82nVUtj7a5O91gIW5O25dei14V6gnLYP51i57QTf
olfCaPQsOID+Oey9SfIUehsUopvCR2FPyUvF8Km8DVXQU2En+r5wrqYl1/Id
4bVU07vRn4d/qwZ70HvDvWsUezyn3EFLvQsdwz1BvaArLNO74dobBe+GPSev
6QzqpQuZv5LcUxehp4Z7gZ71COdAsW8OXcI1oVroBvXQn8CjyR7ZKi9C+eSa
Ue9YGv62ekjzsMflbdX8KXS3cKzWwA/o/fIcejbsU+ygVXLNPK/aCPdS/Y9y
2yTcC5XjcujT2dl1J3zGfEc41qqJWuGepl6mnlo1fKfoLqkHPdGlwrHVN49C
pXCtF/PsYnLMFevKyd4ZDE8ke0i9pym0Se5B6gWzwr1XPaFy2MObshrMo//I
ekUPvaO1wl5TTR7Laka1oh7+DrpaeK/6Zhl033Bv053xUHhNraU9nMlqWLVb
Cg6hfw97aT4clDfCuZ0rj6N/CntVOd0Q7jnqNeqJ6u1fw5vJPf4NxS787gvJ
ven7cO7Uo9R7VTOqFfXgwzpv+Nvy7IWsJlWL8swC9LxwrxoJv6C7QvfkO3U4
uih8Fj27Fn0u86LueNXeb+G7VzV4PvOYvKUeor3PD6+tM0wOn+Hq3uH/5B6k
3qMa1V3ZPZxr3ZlXAClMD+w=
          "]]}]}, {}, {}, {}, {}, {}}, {
      {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
       LineBox[CompressedData["
1:eJwl1GWUlAUUgOGhu5GOpaRTEKSRLunullxAQKQVkO5uDLpTGpTubhWUFClB
GoXngx/PvPfembNnz5lI1zK8ZpcIoVAozEMNgnmIh5YRQ6GheoPrNOZ/3vCa
wfwXvN7rQnxGVUoQhW8894Gu1uJajMgkJhFF+cpzjahiXqVfc41mVHP7Vs+z
nrb2dXo7+N+oaR+hl/iJdvaN+hetqWUfpZf5lTbUdtuko0lpTk0qPuXv4G9Q
xzxef6Mfn5PebYLG1FjEpr29rm7XSWQwT9aMukOz6TTNqtM1u+7SPDpTc+ss
/Zn65k6aV2drfE1AQsLt93nAHsq57dby+o9W0IoUYL49v36n+2hi7q6PeMwB
Orvt1yccpIP9kC7gKF3sR/Qpx+hoP66LOUW4/aQ+4zSd7Gf0Bc/5kk/cClOI
lfYi2ltf8oqztHDrpYNYHrxn9hW6jBM0t/fUgSyhlX2pLuJw8Bmx99A/+YOF
NHX7Qv+lkrkyBfnR/rH+oHuDz7K5mw7gKt8Hn0O3rvqQMuayfMQ8ez6dq7/Q
0Bx8Ya7wO3No4NZZ71HanJNc5GCG207qmTtqPI1LHLKQmQ7u/ZlCJvtU/VAn
6l220t6+TWNodNIRRlu3vowljX2cptUxeofNwWfYvkWjaVRSkJxWbn0YSRJ7
MpIy3L6BGuYWepELDKO6W3O9xZrge2Vfq+coaS5FRCLRxO1m8L4Q3c/EU6IR
lShEJtL7n493vz1vAVVYjOE=
        "]]}, 
      {RGBColor[0.880722, 0.611041, 0.142051], AbsoluteThickness[1.6], 
       LineBox[CompressedData["
1:eJwl00lsTlEYBuDTXyuhNZRGF1j8pIaERMxjKiRIEwtN6MLYISIRQ1W7MLZ2
NcW4oBLDhmqChZAgaamptDZssBH8aASlBK3pObF48ibf/b577j333GTJhsL1
aSGENsoTIWwk2SOEElIx00N4LXfKaraxg+3sooat9GELWUxnGm20UksmB2jh
PmksYSoPmMJDinlrvaNyIEcYQA7v1Gs8337qOMtlmmjlKSk66CJdfxY5TDDf
zUTGs5jv/HKtUv6RTfImjTRzi7/qd+RkbnOPuwSqeBX3h5e8IcUqJvGD3+Yr
5KI4kxFCoVzJOL7R5Xq5fMF1bnCNsSykM95HT2+5gjF8ic+utk4+4zlXGc0V
RlFAR1xDXy+5nJF84qvaWvmEi1ziAiNYwMe4hp5lcil5fOCz2hr5mPM0cI7h
1DMv7hfz2cdeznA63tNsT5nkJMM4xVBWMyd+A+ayh92coI73ZjPkYI4xhOPk
UkZ+3GdmU8SgeFZoN1cqH3GIwxykH7PiOYvfTE9CzohngZn0JZuf9I/vp6fK
eapkMxVsSvz/X/4BRiBx7g==
        "]], LineBox[CompressedData["
1:eJwl0TsrBmAYgOGXT1FGKQwOZaLIH1CKQYQwYCSJhKSQ0XHBhhQLPguDUzHg
BxgcyqkcUhanECksrjJc3fX0PO/yZjV2VnfEhBAGaImEMB4bQm9cCBGGGWKQ
Qg5JJpUfUojj0d2DFpHGFDNMc0Qzz3YeNZ066nkxe9JiMpgjk3lKOGaRJRZY
JsoJLby6f9ZsGojnzWxFV5lgkgQ+zFu1jVJOOeeMdi5YZ4M1ttjkkjJ2yGGb
XMp558u7HdpJJVdUcE0XN9yyRx675FPFJ9/uu/VXv7SGAu6oZYRRxuihnz6a
7KfSRhKJRPj2f6/cc8EB+2wQZTb2/5//AHDdR4U=
        "]]}}}], {{}, {{}, 
     {GrayLevel[0], PointSize[0.018], AbsoluteThickness[1.6], 
      PointBox[{{-5.1634157921809525`, 0.}, {1.1197695149986342`, 0.}, {
       7.40295482217822, 0.}}]}, {}}, {}, {}, {{}, {}}}, 
   {GrayLevel[0], Thickness[0.003], 
    LineBox[NCache[{{(-2) Pi, -1}, {2 Pi, -1}}, {{-6.283185307179586, -1}, {
       6.283185307179586, -1}}]], 
    LineBox[NCache[{{(-2) Pi, 0}, {2 Pi, 0}}, {{-6.283185307179586, 0}, {
       6.283185307179586, 0}}]], 
    LineBox[NCache[{{(-2) Pi, 1}, {2 Pi, 1}}, {{-6.283185307179586, 1}, {
       6.283185307179586, 1}}]], 
    LineBox[NCache[{{-Pi, -2}, {-Pi, 
        2}}, {{-3.141592653589793, -2}, {-3.141592653589793, 2}}]], 
    LineBox[{{0, -2}, {0, 2}}], 
    LineBox[
     NCache[{{Pi, -2}, {Pi, 2}}, {{3.141592653589793, -2}, {
       3.141592653589793, 2}}]]}},
  AspectRatio->1,
  Axes->{False, False},
  AxesLabel->{None, None},
  AxesOrigin->{Automatic, Automatic},
  DisplayFunction->Identity,
  Frame->True,
  FrameLabel->{{
     FormBox["\"v\"", TraditionalForm], 
     FormBox["\"\"", TraditionalForm]}, {
     FormBox["\"\[Phi]\"", TraditionalForm], 
     FormBox[
     "\"\\!\\(\\*SubscriptBox[\\(v\\), \\(s\\)]\\) = 0.9,  \
\\!\\(\\*SubscriptBox[\\(v\\), \\(c\\)]\\) = 0\"", TraditionalForm]}},
  FrameStyle->Thickness[0.004],
  FrameTicks->{{Automatic, Automatic}, {{{
       NCache[(-2) Pi, -6.283185307179586], 
       FormBox[
        RowBox[{
          RowBox[{"-", "2"}], " ", "\[Pi]"}], TraditionalForm]}, {
       NCache[-Pi, -3.141592653589793], 
       FormBox[
        RowBox[{"-", "\[Pi]"}], TraditionalForm]}, {0, 
       FormBox["0", TraditionalForm]}, {
       NCache[Pi, 3.141592653589793], 
       FormBox["\[Pi]", TraditionalForm]}, {
       NCache[2 Pi, 6.283185307179586], 
       FormBox[
        RowBox[{"2", " ", "\[Pi]"}], TraditionalForm]}}, None}},
  FrameTicksStyle->GrayLevel[0],
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImageSize->Medium,
  LabelStyle->{
    GrayLevel[0], FontSize -> 14},
  Method->{
   "ScalingFunctions" -> None, "TransparentPolygonMesh" -> True, 
    "AxesInFront" -> True},
  PlotRange->
   NCache[{{(-2) Pi, 2 Pi}, {-1, 1}}, {{-6.283185307179586, 
     6.283185307179586}, {-1, 1}}],
  PlotRangeClipping->True,
  PlotRangePadding->0,
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.710600340211226*^9, 3.7106824677809677`*^9, 
  3.717423453724874*^9, 3.7174240597274723`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"plotBasins0", "[", 
  RowBox[{"0.95", ",", "400", ",", "0.05"}], "]"}]], "Input",
 CellChangeTimes->{{3.710600353409355*^9, 3.710600353801239*^9}, {
  3.7174242459608393`*^9, 3.717424246383812*^9}}],

Cell[BoxData[
 GraphicsBox[{GraphicsComplexBox[CompressedData["
1:eJxlfHlcTs37f/u+75KkxVrW7Ms5CMn6kBAfD0mSKKQHT9Zs2Z8i2bMTUSmF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    "], {{
      {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
       Opacity[0.3], EdgeForm[None], 
       GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNmgnY18MWx2cmSiRbQpaKuNYohShCWYtEVJIWoYU2lSgVlaSUpFLabIWQ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          "]], PolygonBox[CompressedData["
1:eJwtlnlQV1Ucxd/7ooCkuSBYYCrmVuKaioapk2VZNI6UGVkzRZla0z7V5OTU
NNNuTZtO+1Smo5bmQpJLIKJQgUAoaq5YKsIoKZi4ZPY5fd8fZ+459/7e+913
73c5abmPZz9mQRD8AFqBmxFdYoLgpTAIfkH3RLdDP4pegD7EGI+ezhiHPsP4
Mr9JYEwGHeD3gL9ZKwVl8EtBCfwwKOc3xvPTGN9Bv8naG6C9ngWL4QYKWLsI
3oVXgWtYq0J3hJeDweghoDM8GZSxZuifwUX0VMYXmEuATwOn4Fv0ncyfQk9k
jEWPhieynznoQnQ9Yxv0DMYE9CWsl4L+6HSwEL6RcR1rXRiP63f8fhZjO+Zu
YD1E52gv6H76fvQT6CXoQfpW9DPo5ei30XNBJ3Qi+FhnF63tBCfhTWCpvh30
Z/0MmMzc9+gv4Wfhq+G/gzbodaAXc70F+GmQBV+k74fngzR0EboTfAKogw9l
rge8CYyHf8XcQfhQ83ePYq4PvAVMivbUHn69+d0OZG4zOI++nTGbuZ/ghaAP
uhj9ke4Cvgx+DryHrgbDmPsNfSW8WXtCf4PeDu8OtsGPgRLmL6CnMM5Eb4Jv
Bv303+iR8I6c72x0Pvo59LPga8UqWAC/EK3tBrHoZaAbc93BXUoGsJ6hCbwO
fw201f1qT/BF5nf/o3IG/oieQaeCGPi3IAWeqWn4Hnhz4DF9C7oV+7uXuXJ0
Jnq5+X9PQNfovaAGflzfHPqc+GJwh3lMKBYawWR0NtgOXwjOs7YbnICvAX1Z
u9/8rDvonfBjoBLeADLgs8xzbRBYybOTzM9a9WCnYj30WPwL3MZaHPvPDf0d
u9BXgR36bzATPlzfDP8XTFXugt6KZdAc+jv1LsXAVtUB89ifj74J/rR5Ls9D
fwL/FMSjk9CV8EYwJvSa0AI+R69kbYVyAL0PncHYFX2AsQIchZ8GtYozUA9v
AfvgpeDPwGtEFbw133cf42fo/aqD4EjgNe1X3n0UXMfcIWnGt8xr16s6I/Mz
1tlqjw/DR4G9gceIzmKYeezoTHLgd4NaxTK43HyP2lsFSDL/Bu1dNe5G9JOq
MaHnbC/tB3428BgQ/4C5ztHcBsZc87vRGT1oXkNUO/4BRaHfme5KMf+UeQ1T
7dJ/qNbNUM4EXvMK0A+YP5sHpsMfMo+11MBjfZPuIPCY/5C1981jV3saY55T
yqX9zE0xvzPd1S4wAn2neawohgbDvzDvLRlRbBeGnruK8XTWBpjffTKYD59j
XmuT+N215jmtXNYd7IDXmPey2CjX5pn/Vjm3Sn3DfI0wCCYq10FMFEPPw2eb
1xLVpCx4qnI6iin9NsX87vTMSfhBxrFgnGLPfE5cNe+c6qz5WaqGq9a0Bl1D
rzmqJaoxqi0p0dkuQV8WnfFS+CvmvUtzY817gGq/YmqF7tq8FqvGbVBtM6+d
6hFx8FXmd7ERrDXvEeoNPZUX8NWgh85SMa/YNV/LBN/Bi6Napz3nKRfN36Vn
/u9t5r1FPa4CvtW896uHN8DrzXv1ANVY8xxTbskzjDPvwelRjuqsu4HqwM9c
vbmt+bPq0VfA/2AcHvpv6tBbVKNCz9ki856kXtQXvc28B6n36JkSi3pK4M+M
N/ccQ6IacETfZv7s6DDyLua9Tx7mhEWeJfA7v1rxbV6rVSNV+yujWqceUGz+
Tr1LPaxWd2GeCyPRBeZnrrNWD5XXUk9WL5bnWmN+R7ob9XT15rWhexH16L3m
OaLcGIF+Eb7HnKumyhvkh+51sqJcP2D+38p5eaW60HuLPJN6c17o3k89Wl5B
PUO9Qp5B3i7R3DvK48mrrI9qtzyLvM9A81ohDySvJs8oryjPJu8Qb14L5SHk
pcqi2poT1eZbzXunarR6UXVUq9WT5LXU89Tr5LnkFeQB5f3kGeT11HPVa+X5
5G3TzL2gPK687eHQvY88rryEeqR6ozyFvLF6lHqTPLK8X2Po3koeUN6xIXTv
Ig/5H6s9c/g=
          "]]}]}, 
      {RGBColor[0.880722, 0.611041, 0.142051], AbsoluteThickness[1.6], 
       Opacity[0.3], EdgeForm[None], 
       GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNmgm4l9MWxv98ex8yz4qUCqVEKUOpJEOGUkllKHNEqVCGRuWWkiiEaI4y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          "]], PolygonBox[CompressedData["
1:eJwtlnnwV1MYxr91z/uLitK+73uhspRSytJKWoWUJC1IQpKMmaRhJjIjSxNj
zW5sIYbGWNpJ2rRpo1JU0r4on2ee+8cz53nOOffec8953+c9dYeN7XtX8UKh
MAck0CQKhe1gKKIW6AuvWlQoTILvzAqF1bSV6NsA7wJugZ+mbwG8FG0vdHXQ
B36Kvh/g80FLdCv0n/APwW49S9/L8FfCc7eBIvgzoAVjXcAg+GOgHrwIdIM3
ZD0z4GuYfw36SdAI/R/6Us1lfBp6CXqLxsDN6MFgPXwduJ2xC9Fvw98C7eDt
wVPw6aAxvAl4D/4u6ADvCOrAN4KB8OtBA/goUA6+nXcepv0A3Yn2Df0vbTXW
8zDtPHQNxtaCfslraBheo9Y2BPwO3wZmZX5HS/guUAK+l76h8PNA/eS+HTqX
8F5moHf4nXqXDlRnsRr0Tj6TDaA86xlPez/vW87Yi2Cz9lJrhs8GbeBttR5Q
mfkTaWczpyZjD4Ga6P7gXHHGp8L/YnwzbUX0BNrp0oxv0r7CB9G+hn41vPcX
gV/AeHQ1nQ1zdsD/0D9njsGm8P6gOLyZzhR8jb6K9ghzivOt69AJXVf/GI5h
xW6x5L26KRw72rMr4WV4Ziz8V56fGv4Hrb0OfQ/AJ2rN6HaZY/Eb0DU5JhfB
l4Ie8HWMz4HvAbei/0FfDD+p74AD6MvQpfneGPRy9Dz0s+DnzP8wAP5o+Nv6
hwu0duY/Dv+OOZ9obWAYeh96CLw547PQe9DPo78F3fWvikl4U8ZnJudYd3RZ
9LjknH0knNPK5dr09YNPDnPt8QmdC/pfxismx3798NkpB+6F36eYYrwZmBDe
U+1ldcZ/BOPkGTpb+m7UesNnE4pJ1nI6HEvKyc7wBvRNT96TM8P/pH/pBs6B
vwBaw3vqzOBrwrGrmF4MxqIr0y6lb6XiOryWjejv4WeFveIYWAV/Kew1vfQ+
sDLMT9I3Wt4Qjp0d6FP5nmgv5qN7yk9Y73PJObOA9k76KuQeuJB2DLqSYiWz
Nz2hnEz2qGHwQnisNHoafAqYi26Abheeo7FD9LUNe6y89aA8C74bXjL5jOTN
23OvmZTnauPw2pWzFeD7acsmx7RytQV9H2XO2SO5h8g7yssvGG8VjuXJuXed
H441eVhV+AGdC9hKX1J8ws8Gy9Bbad8Pe6U87BDtltyLyuXeU1s5ntmDOsKH
64zgh+nbB/8MdEYPB6Xge2nLJMfcfsVmuDY0yrz3ekZzdQbymnci9/LMXiSP
ljfLk1RLbgjHomqKakV7dL3MNUOx2Ckc24rJY/IaxR/6NuU0/GA4NpvTNxN+
NDymGqfY6IHukzlG5DU/J9c+eY5ycQVt+8w5qVrWNew1qmkJfZR2BBipc0YX
C9eyO5RDRfYEecEodBH6WDIfnZz7A8O1Rh4gL2mNrpLZU3aHv6F3y1P+Dr9D
z8rDMvjH4VqjNci7luZ7LQ+T9wyW52T2oC/hX8g/0Ffof+ELwXH0Wu2ZYiff
q6NgE/o39BR5A+1OMCNca5UDP8HLh3P3avqahWNUsamaoNpUCwxIrlHy2rnh
b8tzN8DX007IPEfeWBKszOyRqu2qKaolqvHH4SfC3qIz+UqxEY7lKvTdAy8R
9m69Y5V8KlwrT2Su5aqJqoWq6Yvlt+HaoD1Q7Tgj7IWqIYr1LOxVinl5QxWt
KdkjnpZX0fbN3LcojwGdvfZYubwq/7Zyekm4hqp2qiZdG76j6G5yOrMXdwjn
ljxZsX53+N8U8yPgI8NzlZO7cg9Q7uuM5a2XhL1IHqtcVw1W7T0797o2YW+S
5ylXlyV7rXL2MGOXh89eNX4FvFrYO2oke7vOXGctj9fdqq5yNPmOpVx6MDxX
OaW7Wr1w7OjOJi+Sh8u75UnyxvnJtVceOUnvDt8NdWc5JR6+m+gbyu0u4VhV
jit2Xg/fTRRDitU3w3chxezn8E/DtVke9T9I72AU
          
          "]]}]}, {}, {}, {}, {}, {}}, {
      {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
       LineBox[CompressedData["
1:eJwt1HfczlUYB+DntWehSFYRooyUsgkRMsqsZDYUGWWkYRalopJR2SMpe5NR
ViUyskJmZBPJjq67jz+u93vuc+7f8/zOc87nzdu6Y/0OSYlEor0/yWSMx9NN
8RrNeYPX6c4dbKEu9ZjlgbPyTv4wPkSa5InEQbmZufxt7S7+ND5GWutH5RYW
cN5aAY4bnyKd9ZNyG4u4YK0gp+O7OENDdQN2cA/bKcxvtGaJnlHyghwpz8ui
sgi/s4tejOALdsazehZz0fhenuNZlpkbJy/LMfKSHCuXykvyfvbTl4vmRsv7
2B3vp24kS7CHfeylDd9b+1JOYiLX1CXlAzShMQ+Rye/xoHyR5Xoux0HxJGXJ
Yr2MbEs7UjCF5LFX/SuZapySd3mPitzquQpyNqnjLJnLnDhL5rOAeSxiIQfj
9+C72H+8T+wjzpaVrGIFP7CawxzhZzKyhptYS2Wyeocq8mYG8D4fRL937hh9
MknPI8av8grVyGaueuydDxnIIH7R30VukCn01DLOzmOxf/VG812Nf5Wp1XWM
c/ERJzgZ94xT8Rls5GP+ijOOuyc3xfN8wmYOmM8t85CT2qTy2ZvM7+N2dQZ1
DnkbNeNs1Out7SWrOr06W5wJnXk0es3VkM24hWTqdfo7GR+PvbKedWSmatwL
PWv07OGZuDtc5yd1B3mUY1HHO/FjfDcPx/2LWt9umhqn4984S3V7eYjFLOFb
0lKJq3HWep6WT5GGK3EXzL0cvw8zmMm0+G2YTrnYl/ctL/vTj2/4Ou6QZ3fF
2Rt/FXtncuzF3EuyVOzZs6XlO7wd72ptQtxNuZMrjI/3ky/I5ykWd81zxWUf
evOP9c9jT3J7/L9iuPqc/CzOXraSd8fd9Wwh2ZMeDGMoC/Vs5QSD1UP4lCPq
/PEdzDeuL5/gsPE5OU+2lHnJ6LPzycfZyjbe5C1m62sh5yT9f8SJlDf+X/8H
tdPIpQ==
        "]]}, 
      {RGBColor[0.880722, 0.611041, 0.142051], AbsoluteThickness[1.6], 
       LineBox[CompressedData["
1:eJwl1Gt012McAPBfdm3WLi1sExmVasulMMql0IhzQh2JEFNIs7mrzok3Vt46
R+Uy8s5LY5J7SbPpYprrOeaYY9jNama2SZvP93jx2ffy+z47v+f5P/9/SWXN
0upxSZKU+9OQmiSFKUkyJy1JTk9PkrniP3pvi++wkyNU8Zl+ppkx8W71xZyh
LhcfpEl/vDqRVzKPEvUlYg2fe36iOkW+mss5S32Z+DAHPZ+gzpTv5nnS+Zg/
6afXzAGyzV2hzuARDunl6GXJP2E749nDXwzwh5k14lUMciV/8ziHPdsvHqCZ
vHhfvtRvEnNj/+RQwSJGGOYFGtnHUJyXNS3kep+r1U/yBF/p5esVxPvyMvmx
b47FuXPUTCt55harJ3Iy3+hV+JyWsYoqNlDLc9TxOvWUmT/N+tliLc9wM+P0
losniKXibZTJbxW3sJJZ6tvFc7iL2epVYhfn8SYpesPeJ1XsVvfwFmnqEf10
sTfOmwb6OJ9T9bs8f1Z+B6XqO8V1nEuxutPzzfJbmKleIdbzBp38zm9mhpgl
74iaX5nBTRRa1+H5A/K1nM0per/oPS0fI1H/LE6nnWncGGet325ukPvVUzlJ
7yf1U/LjjPJj3G3a4jvADUwy12buPvm9TKFA7we9TfJ/+Zbv4vOM82BJfMZm
vjfzmnwHr/J13JeY1R+gKO5onBGtsR82cl3swfrrxVeoiztLS/wP6/qZJP8i
9sEG1nNN7Nm6a8WXeJEJfBqz1vTFd1W+l2we41EWxJlYt1DcxlY+4kP2W9MT
90L+ftwHPoj7xkPM50xrLxXviftIlrrZmuq4+7zLe+yK89K/SMww0yjv5oI4
V/WF4jH1KJPVx8VGd7+YopT/f9f+A2u5oCw=
        "]], LineBox[CompressedData["
1:eJwl0D0vQ2EYBuBHit/QJkh8pfyXGhxmg1XCKmGgLPQTowlVWp+bfyJoVJDG
Lo3ZddLhyn2/98mbnLyTqxvJ+lBELDI7HJFkIg5GIn71Z471I7KUqbBAfjSi
ILfYZpwXxui795rS3zjjnIv0bO/ICRpc0uTd3pVTXHFNi679Q07T5oZbPu1f
8ps77vlLN3b0nsz5x0QvsssSc7ZlOU+VGnVO+HFnT5Y4ZMb5yXvk5YNsckqd
fTZZ49H3lczg/f4BBiEwuQ==
        "]]}}}], {{}, {{}, 
     {GrayLevel[0], PointSize[0.018], AbsoluteThickness[1.6], 
      PointBox[{{-5.029949409676211, 0.}, {1.253235897503375, 0.}, {
       7.536421204682961, 0.}}]}, {}}, {}, {}, {{}, {}}}, 
   {GrayLevel[0], Thickness[0.003], 
    LineBox[NCache[{{(-2) Pi, -1}, {2 Pi, -1}}, {{-6.283185307179586, -1}, {
       6.283185307179586, -1}}]], 
    LineBox[NCache[{{(-2) Pi, 0}, {2 Pi, 0}}, {{-6.283185307179586, 0}, {
       6.283185307179586, 0}}]], 
    LineBox[NCache[{{(-2) Pi, 1}, {2 Pi, 1}}, {{-6.283185307179586, 1}, {
       6.283185307179586, 1}}]], 
    LineBox[NCache[{{-Pi, -2}, {-Pi, 
        2}}, {{-3.141592653589793, -2}, {-3.141592653589793, 2}}]], 
    LineBox[{{0, -2}, {0, 2}}], 
    LineBox[NCache[{{Pi, -2}, {Pi, 2}}, {{3.141592653589793, -2}, {
       3.141592653589793, 2}}]]}},
  AspectRatio->1,
  Axes->{False, False},
  AxesLabel->{None, None},
  AxesOrigin->{Automatic, Automatic},
  DisplayFunction->Identity,
  Frame->True,
  FrameLabel->{{
     FormBox["\"v\"", TraditionalForm], 
     FormBox["\"\"", TraditionalForm]}, {
     FormBox["\"\[Phi]\"", TraditionalForm], 
     FormBox[
     "\"\\!\\(\\*SubscriptBox[\\(v\\), \\(s\\)]\\) = 0.95,  \
\\!\\(\\*SubscriptBox[\\(v\\), \\(c\\)]\\) = 0\"", TraditionalForm]}},
  FrameStyle->Thickness[0.004],
  FrameTicks->{{Automatic, Automatic}, {{{
       NCache[(-2) Pi, -6.283185307179586], 
       FormBox[
        RowBox[{
          RowBox[{"-", "2"}], " ", "\[Pi]"}], TraditionalForm]}, {
       NCache[-Pi, -3.141592653589793], 
       FormBox[
        RowBox[{"-", "\[Pi]"}], TraditionalForm]}, {0, 
       FormBox["0", TraditionalForm]}, {
       NCache[Pi, 3.141592653589793], 
       FormBox["\[Pi]", TraditionalForm]}, {
       NCache[2 Pi, 6.283185307179586], 
       FormBox[
        RowBox[{"2", " ", "\[Pi]"}], TraditionalForm]}}, None}},
  FrameTicksStyle->GrayLevel[0],
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImageSize->Medium,
  LabelStyle->{
    GrayLevel[0], FontSize -> 14},
  Method->{
   "ScalingFunctions" -> None, "TransparentPolygonMesh" -> True, 
    "AxesInFront" -> True},
  PlotRange->
   NCache[{{(-2) Pi, 2 Pi}, {-1, 1}}, {{-6.283185307179586, 
     6.283185307179586}, {-1, 1}}],
  PlotRangeClipping->True,
  PlotRangePadding->0,
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.7106004905696507`*^9, 3.7106826075875483`*^9, 
  3.717424906392497*^9, 3.717429680854189*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["1 state attractor", "Title",
 CellChangeTimes->{{3.710703354220295*^9, 3.710703394153265*^9}, 
   3.7174423487619143`*^9}],

Cell[CellGroupData[{

Cell[TextData[{
 Cell[BoxData[
  FormBox[
   RowBox[{"(", 
    RowBox[{"v", ",", 
     SubscriptBox["v", "c"]}]}], TraditionalForm]]],
 ")"
}], "Chapter",
 CellChangeTimes->{{3.710703563186775*^9, 3.710703570961725*^9}, {
   3.710784327154557*^9, 3.710784366609646*^9}, {3.7173553879257317`*^9, 
   3.7173553931602*^9}, 3.717442767306231*^9}],

Cell[TextData[{
 "Define function that plots the 1 state attractor in ",
 Cell[BoxData[
  FormBox[
   RowBox[{"(", 
    RowBox[{"v", ",", 
     SubscriptBox["v", "c"]}], ")"}], TraditionalForm]]],
 " space for a given ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["v", "s"], TraditionalForm]]],
 " value."
}], "Text",
 CellChangeTimes->{{3.710703572705634*^9, 3.710703603640291*^9}, {
  3.710704006184936*^9, 3.71070401553522*^9}, {3.710705372231855*^9, 
  3.7107053769264307`*^9}, {3.710706106217256*^9, 3.710706120183467*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"ClearAll", "[", 
   RowBox[{
   "vS", ",", "tMax", ",", "col", ",", "Q", ",", "\[Alpha]", ",", "\[Gamma]", 
    ",", "\[Phi]E", ",", "vE", ",", "vCE", ",", "\[Phi]", ",", "v", ",", "vC",
     ",", "t", ",", "sol", ",", "endT", ",", "arrowPos"}], "]"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"plotAttractor1v", "[", 
   RowBox[{
    RowBox[{"vS_", "?", "NumericQ"}], ",", 
    RowBox[{"tMax_", "?", "NumericQ"}], ",", 
    RowBox[{"col_", "?", "ColorQ"}], ",", 
    RowBox[{"arrowPos_", "?", "NumericQ"}]}], "]"}], ":=", 
  "\[IndentingNewLine]", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"Q", "=", "1.1"}], ",", 
      RowBox[{"\[Alpha]", "=", "4.6"}], ",", 
      RowBox[{"\[Gamma]", "=", "0.05"}], ",", "\[Phi]E", ",", "vE", ",", 
      "vCE", ",", "\[Phi]", ",", "v", ",", "vC", ",", "sol", ",", "endT"}], 
     "}"}], ",", "\[IndentingNewLine]", "\[IndentingNewLine]", 
    RowBox[{"(*", " ", 
     RowBox[{"Map", " ", "initial", " ", "phase", " ", "point", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "\[Pi]"}], ",", "2", ",", "0"}], ")"}], " ", "to", " ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"\[Phi]E", ",", "vE", ",", "vCE"}], ")"}], "[", "tMax", 
       "]"}]}], " ", "*)"}], "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"{", 
       RowBox[{"\[Phi]E", ",", "vE", ",", "vCE"}], "}"}], "=", 
      RowBox[{
       RowBox[{"Reap", "[", 
        RowBox[{"NDSolve", "[", 
         RowBox[{
          RowBox[{"{", "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{
             RowBox[{"\[Phi]", "[", "0", "]"}], "\[Equal]", 
             RowBox[{"-", "\[Pi]"}]}], ",", 
            RowBox[{
             RowBox[{"v", "[", "0", "]"}], "\[Equal]", "2"}], ",", 
            RowBox[{
             RowBox[{"vC", "[", "0", "]"}], "\[Equal]", "0"}], ",", 
            "\[IndentingNewLine]", 
            RowBox[{
             RowBox[{
              RowBox[{"\[Phi]", "'"}], "[", "t", "]"}], "\[Equal]", 
             RowBox[{"v", "[", "t", "]"}]}], ",", "\[IndentingNewLine]", 
            RowBox[{
             RowBox[{
              RowBox[{"v", "'"}], "[", "t", "]"}], "\[Equal]", 
             RowBox[{
              FractionBox["1", 
               SuperscriptBox["Q", "2"]], 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"1", "+", "\[Gamma]"}], ")"}], " ", 
                 RowBox[{"(", 
                  RowBox[{"vS", "-", 
                   RowBox[{"v", "[", "t", "]"}], "-", 
                   RowBox[{"Sin", "[", 
                    RowBox[{"\[Phi]", "[", "t", "]"}], "]"}]}], ")"}]}], "-", 
                
                RowBox[{"vC", "[", "t", "]"}]}], ")"}]}]}], ",", 
            "\[IndentingNewLine]", 
            RowBox[{
             RowBox[{
              RowBox[{"vC", "'"}], "[", "t", "]"}], "\[Equal]", 
             RowBox[{
              FractionBox["\[Alpha]", 
               SuperscriptBox["Q", "2"]], 
              RowBox[{"(", 
               RowBox[{"vS", "-", 
                RowBox[{"v", "[", "t", "]"}], "-", 
                RowBox[{"vC", "[", "t", "]"}], "-", 
                RowBox[{"Sin", "[", 
                 RowBox[{"\[Phi]", "[", "t", "]"}], "]"}]}], ")"}]}]}]}], 
           "}"}], ",", "\[IndentingNewLine]", 
          RowBox[{"{", "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"t", ",", "0", ",", "tMax"}], "}"}], ",", 
          RowBox[{"Method", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{"\"\<EventLocator\>\"", ",", 
             RowBox[{"\"\<Event\>\"", "\[Rule]", 
              RowBox[{"(", 
               RowBox[{"t", "\[Equal]", "tMax"}], ")"}]}], ",", 
             "\[IndentingNewLine]", 
             RowBox[{"\"\<EventAction\>\"", "\[RuleDelayed]", 
              RowBox[{"Sow", "[", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"\[Phi]", "[", "t", "]"}], ",", 
                 RowBox[{"v", "[", "t", "]"}], ",", 
                 RowBox[{"vC", "[", "t", "]"}]}], "}"}], "]"}]}]}], "}"}]}]}],
          "]"}], "]"}], "\[LeftDoubleBracket]", 
       RowBox[{
        RowBox[{"-", "1"}], ",", "1", ",", "1"}], "\[RightDoubleBracket]"}]}],
      ";", "\[IndentingNewLine]", "\[IndentingNewLine]", 
     RowBox[{"(*", " ", 
      RowBox[{"Flow", " ", "to", " ", "1", " ", "state", " ", 
       RowBox[{"(", 
        RowBox[{
        "if", " ", "it", " ", "exists", " ", "at", " ", "given", " ", 
         SubscriptBox["v", "s"]}], ")"}], " ", "and", " ", "return", " ", 
       "subsequent", " ", "trajectory"}], " ", "*)"}], "\[IndentingNewLine]", 
     
     RowBox[{"sol", "=", 
      RowBox[{"NDSolve", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{"\[Phi]", "[", "0", "]"}], "\[Equal]", "\[Phi]E"}], ",", 
          RowBox[{
           RowBox[{"v", "[", "0", "]"}], "\[Equal]", "vE"}], ",", 
          RowBox[{
           RowBox[{"vC", "[", "0", "]"}], "\[Equal]", "vCE"}], ",", 
          "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{
            RowBox[{"\[Phi]", "'"}], "[", "t", "]"}], "\[Equal]", 
           RowBox[{"v", "[", "t", "]"}]}], ",", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{
            RowBox[{"v", "'"}], "[", "t", "]"}], "\[Equal]", 
           RowBox[{
            FractionBox["1", 
             SuperscriptBox["Q", "2"]], 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"(", 
                RowBox[{"1", "+", "\[Gamma]"}], ")"}], " ", 
               RowBox[{"(", 
                RowBox[{"vS", "-", 
                 RowBox[{"v", "[", "t", "]"}], "-", 
                 RowBox[{"Sin", "[", 
                  RowBox[{"\[Phi]", "[", "t", "]"}], "]"}]}], ")"}]}], "-", 
              RowBox[{"vC", "[", "t", "]"}]}], ")"}]}]}], ",", 
          "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{
            RowBox[{"vC", "'"}], "[", "t", "]"}], "\[Equal]", 
           RowBox[{
            FractionBox["\[Alpha]", 
             SuperscriptBox["Q", "2"]], 
            RowBox[{"(", 
             RowBox[{"vS", "-", 
              RowBox[{"v", "[", "t", "]"}], "-", 
              RowBox[{"vC", "[", "t", "]"}], "-", 
              RowBox[{"Sin", "[", 
               RowBox[{"\[Phi]", "[", "t", "]"}], "]"}]}], ")"}]}]}]}], "}"}],
         ",", "\[IndentingNewLine]", 
        RowBox[{"{", 
         RowBox[{"\[Phi]", ",", "v", ",", "vC"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"t", ",", "0", ",", "200"}], "}"}], ",", 
        RowBox[{"Method", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{"\"\<EventLocator\>\"", ",", 
           RowBox[{"\"\<Event\>\"", "\[Rule]", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"\[Phi]", "[", "t", "]"}], "\[Equal]", 
              RowBox[{"\[Phi]E", "+", 
               RowBox[{"2", "\[Pi]"}]}]}], ")"}]}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{"\"\<EventAction\>\"", "\[RuleDelayed]", 
            RowBox[{"Throw", "[", 
             RowBox[{
              RowBox[{"endT", "=", "t"}], ",", "\"\<StopIntegration\>\""}], 
             "]"}]}]}], "}"}]}]}], "]"}]}], ";", "\[IndentingNewLine]", 
     "\[IndentingNewLine]", 
     RowBox[{"(*", " ", 
      RowBox[{"Return", " ", "1", " ", "state", " ", "attractor"}], " ", 
      "*)"}], "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"ParametricPlot", "[", 
       RowBox[{
        RowBox[{"Evaluate", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"vC", "[", "t", "]"}], ",", 
            RowBox[{"v", "[", "t", "]"}]}], "}"}], "/.", "sol"}], "]"}], ",", 
        
        RowBox[{"{", 
         RowBox[{"t", ",", "0", ",", "endT"}], "}"}], ",", 
        RowBox[{"PlotStyle", "\[Rule]", "col"}]}], "]"}], "/.", 
      RowBox[{
       RowBox[{"Line", "[", "x__", "]"}], "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Arrowheads", "[", 
          RowBox[{"{", 
           RowBox[{"{", 
            RowBox[{"Automatic", ",", "arrowPos"}], "}"}], "}"}], "]"}], ",", 
         
         RowBox[{"Arrow", "[", "x", "]"}]}], "}"}]}]}]}]}], "]"}]}]}], "Input",\

 CellChangeTimes->{{3.710703612185732*^9, 3.710703613146097*^9}, {
   3.710703645087953*^9, 3.7107038250095987`*^9}, {3.7107038651203623`*^9, 
   3.710703925800755*^9}, {3.710703966836862*^9, 3.7107039711892033`*^9}, {
   3.7107040284227467`*^9, 3.710704103911132*^9}, {3.710704178547552*^9, 
   3.710704218489841*^9}, {3.710704287232888*^9, 3.710704302735257*^9}, {
   3.710704453096983*^9, 3.710704469639659*^9}, {3.7107045058389473`*^9, 
   3.710704522036879*^9}, {3.7107046199149303`*^9, 3.710705014168984*^9}, {
   3.7107050627339163`*^9, 3.710705064581814*^9}, 3.710705380970055*^9, {
   3.71070553812418*^9, 3.710705545777363*^9}, {3.710705876236657*^9, 
   3.710705974584722*^9}, {3.710708729182864*^9, 3.710708734523841*^9}, 
   3.710708917711267*^9, {3.7107765702372723`*^9, 3.710776574826092*^9}, {
   3.710776616626152*^9, 3.7107766206742764`*^9}, {3.710776666008458*^9, 
   3.7107766985264397`*^9}, {3.710784842006604*^9, 3.710784866724958*^9}, {
   3.710786067923798*^9, 3.710786094881473*^9}, {3.717282083500925*^9, 
   3.717282090324587*^9}, 3.717355908889283*^9, {3.717442430121669*^9, 
   3.7174424533615294`*^9}, 3.717442503445665*^9, {3.7174427213557377`*^9, 
   3.717442725180142*^9}, {3.717442770409978*^9, 3.7174427833453627`*^9}, 
   3.717443307660668*^9}],

Cell[TextData[{
 "\nPlot 1 state attractors for a range of ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["v", "s"], TraditionalForm]]],
 " values:"
}], "Text",
 CellChangeTimes->{{3.7107061273757668`*^9, 3.710706150158072*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"cdata", "=", 
   RowBox[{"ColorData", "[", 
    RowBox[{"97", ",", "\"\<ColorList\>\""}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"vSvals", "=", 
   RowBox[{"{", 
    RowBox[{"0.58", ",", "0.75", ",", "1", ",", "1.25", ",", "1.5"}], "}"}]}],
   ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"aPos", "=", 
   RowBox[{"{", 
    RowBox[{"0.93", ",", "0.88", ",", "0.32", ",", "0.85", ",", "0"}], 
    "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"p", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"plotAttractor1v", "[", 
      RowBox[{
       RowBox[{
       "vSvals", "\[LeftDoubleBracket]", "n", "\[RightDoubleBracket]"}], ",", 
       "6000", ",", 
       RowBox[{
       "cdata", "\[LeftDoubleBracket]", "n", "\[RightDoubleBracket]"}], ",", 
       RowBox[{
       "aPos", "\[LeftDoubleBracket]", "n", "\[RightDoubleBracket]"}]}], 
      "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"n", ",", "1", ",", "5"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"pos", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.84"}], ",", "0.28"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.83"}], ",", "0.58"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.83"}], ",", "0.84"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.85"}], ",", "1.13"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.82"}], ",", "1.4"}], "}"}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lbl", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"Graphics", "[", 
      RowBox[{"Text", "[", 
       RowBox[{
        RowBox[{"Style", "[", 
         RowBox[{
          RowBox[{
           RowBox[{
           "StringTemplate", "[", 
            "\"\<\!\(\*SubscriptBox[\(v\), \(s\)]\) = `a`\>\"", "]"}], "[", 
           RowBox[{"<|", 
            RowBox[{"\"\<a\>\"", "\[Rule]", 
             RowBox[{
             "vSvals", "\[LeftDoubleBracket]", "n", 
              "\[RightDoubleBracket]"}]}], "|>"}], "]"}], ",", 
          RowBox[{"FontSize", "\[Rule]", "14"}], ",", 
          RowBox[{"FontColor", "\[Rule]", 
           RowBox[{
           "cdata", "\[LeftDoubleBracket]", "n", 
            "\[RightDoubleBracket]"}]}]}], "]"}], ",", 
        RowBox[{
        "pos", "\[LeftDoubleBracket]", "n", "\[RightDoubleBracket]"}]}], 
       "]"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"n", ",", "1", ",", "5"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Show", "[", 
  RowBox[{
   RowBox[{"Join", "[", 
    RowBox[{"p", ",", "lbl"}], "]"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "1.2"}], ",", "1.2"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", "1.8"}], "}"}]}], "}"}]}], ",", 
   RowBox[{"AspectRatio", "\[Rule]", "Full"}], ",", 
   RowBox[{"Frame", "\[Rule]", "True"}], ",", 
   RowBox[{"FrameStyle", "\[Rule]", 
    RowBox[{"Thickness", "[", "0.003", "]"}]}], ",", 
   RowBox[{"PlotRangePadding", "\[Rule]", "0"}], ",", 
   RowBox[{"GridLines", "\[Rule]", "Automatic"}], ",", 
   RowBox[{"FrameTicks", "\[Rule]", "Automatic"}], ",", 
   RowBox[{"FrameTicksStyle", "\[Rule]", "Black"}], ",", 
   RowBox[{"LabelStyle", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"Black", ",", 
      RowBox[{"FontSize", "\[Rule]", "14"}]}], "}"}]}], ",", 
   RowBox[{"FrameLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"\"\<v\>\"", ",", "\"\<\>\""}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
       "\"\<\!\(\*SubscriptBox[\(v\), \(c\)]\)\>\"", ",", "\"\<\>\""}], 
       "}"}]}], "}"}]}], ",", 
   RowBox[{"ImageSize", "\[Rule]", "Medium"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.710706000759252*^9, 3.710706004644423*^9}, 
   3.710706037214898*^9, {3.710706143103284*^9, 3.710706259330122*^9}, {
   3.7107063065296593`*^9, 3.710706418595367*^9}, {3.7107064507159348`*^9, 
   3.710706726326672*^9}, {3.710707005876616*^9, 3.7107070822564*^9}, {
   3.7107071990043907`*^9, 3.710707224314292*^9}, {3.710707280705373*^9, 
   3.710707285672772*^9}, {3.710707329039289*^9, 3.710707352389803*^9}, {
   3.710707412748127*^9, 3.710707621553985*^9}, {3.710707658688671*^9, 
   3.710707738893084*^9}, {3.710707775188636*^9, 3.7107079329910517`*^9}, {
   3.710707983028253*^9, 3.7107081773001833`*^9}, {3.710708256281591*^9, 
   3.710708256855842*^9}, {3.710708837048049*^9, 3.710708848711232*^9}, {
   3.7107089322697077`*^9, 3.710709103158684*^9}, {3.710776721002119*^9, 
   3.71077672127882*^9}, {3.710776755477022*^9, 3.71077675607349*^9}, {
   3.710776786734151*^9, 3.710776807788189*^9}, {3.7107768476524143`*^9, 
   3.710777002594223*^9}, {3.717282160090372*^9, 3.717282214334758*^9}, {
   3.717282246253776*^9, 3.71728254034505*^9}, {3.717340072318059*^9, 
   3.717340078572639*^9}, 3.717355910744754*^9, {3.7174338912160673`*^9, 
   3.7174338961923122`*^9}, {3.7174346270671597`*^9, 
   3.7174346404667597`*^9}, {3.717441315532505*^9, 3.717441343083536*^9}, {
   3.7174417843455553`*^9, 3.7174417865131683`*^9}, {3.71744188304727*^9, 
   3.717441928499571*^9}, 3.717442073039645*^9, {3.717442464247237*^9, 
   3.717442644078425*^9}, {3.717442863238721*^9, 3.717443101764146*^9}, {
   3.717443135090444*^9, 3.717443263093379*^9}, {3.717443591897871*^9, 
   3.717443673092353*^9}}],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    TagBox[
     {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], Opacity[
      1.], FaceForm[Opacity[0.3]], 
      {Arrowheads[{{Automatic, 0.93}}], ArrowBox[CompressedData["
1:eJwV2nk4VN8bAHAliuxChKKyRJZIQl6lbBERJSkU2UoRSSlUlqi+iBBCEqFF
lkocM5YZa/Z9mTuTVJYZspf8zu8fns9z7j333Hve9z3vHyPj4mPtupaNje0K
/vP//88SD0V6izLApByIdwd6IF77IXfVdga4ys7aBhv1QG9nae4mdQZoBEjv
MLfsAZm4ozqkowxQ7bgyy3LqgZ2JKQNyoQzIeqm0/uS9HlCekRGXmmDASJER
PbaxBy5s2e8YRP4G9w+0KeQ69MLRjxRL5uXvcGtLSZFnaB9kbC82QvM/IUBf
7E0BzyAUHTDXPTo1AVc2pAfYXRiGYqnTlT8WJ4AUHFxreGkYXM1CK26xT0J9
TpeOSsAwrJ6UoEdsnoTnhu99liOGwaXlSLrCoUkYPBA+cjl/GMw0Lr4Li5+E
v6Gu5MrpYej0GtTnU5mCCvO49+9ujgA/68jciX1TcKhv7qbKvRGYKCl9/dhg
CpgOFuK5MSNA3/OORLOegk7N3ZmP0kagRJHLkxkwBc+sBIvl0Qg4ysr8KPgy
BbKjF7dWsdHAzt7cXUKfCQs2EpH6B2mw3nff5bNGTEi76X78/hEaMA6onIw9
xgRH87YOqikNaqYve1WfZcKUidLYEWsaVA7GNNveZsI78+jbYudpMNDxaKvU
ZybkuSooCN3D8xX32RuSmDAtJ7pTJpIG/7WyRuyoTEh9pu+uHEOD0SE/zyPd
TGiaC8/e94QGZ4nSygPTTDCTcN69LZsG2TFrp8iCLDjOqW+iUU2D8c99yZ83
sWCQ/Os4O4UG1z70yOWKsWBKYL/a1wYafNBpKb4gxYKIu5XHTrfTIG3n8RMu
CiyoehtleYCggdC9Hcdd9VjwwC/EWO0fDWr3mjwo0WeBc+XTk5/XEODKfePX
sgELopqzmoGDgKtNaObCERb0Lh1t1eMhoCayeazYggX3CrKv/hMn4Nf3zlmd
Myzwjf54MkWTgDPjugcqHFkQL+bpl7GPgGMj7bf2nmNBgWSPWpYOAekuj0nr
XVjQHBxyK8mAgA0F7KF7LrKgem0DxdKcgNN3yrPOu7PglYqByx5LAlpD424+
8GDBdf9IfwFrAiR64/d88mLB4zHRmcqT2A7Bfck+LBBlhZZ8cyFA0nCq9/oV
Fth3Ho3KciXAYl2Y9dGrLDAeUn/j4E6Ax86lxHZfFmgHrPSgSwRM8VnZhPvh
58dpd3heIaDj2ztv1Wss4J3U4RH0w+Pu15Od/Vkw7mewwzKQgIoMq/Rf2Fy7
k5e+BxHgW27EcA9gwU7/wKUbwQQ4bht0HsS2Dz67dUMIAavbnwsfuc6CMNdG
t9gwAmY1pWaysNk69BtF7hPQSWLMz2Gre2mbJEQQoL0/ZIt+IAv8O/b18T8g
4BNXiP1NbOX3X27cjyFgOvPK60Ls4jyjnfOPCAi6MrK+C/uyi22PcywB4wx7
r2nsTyHu0dR4Amiel1rW3mDBbN6q3q5EAlh+r3ZxYd+5mzIWnkRAFJN8Yx22
/mxz+HAKfr+3O0pn8f1/Za+LqqcR8Jh0uL8POyk9IO72cwJ0XFNoH7BPhRfM
12USMN+fWh2GfX9pUZ87G7+vS3WwEbabmN5Fkxx8/4H7XKv4/Q6t2nqF5hIw
8treuQDbuVXOuOQ1AYrjZXeOYXO/fjTPKCAgT1/s3Cj+fvfzL/nzviXg6ejU
0hVsidkXSP09ASrbSs2m8ffneyHYZvWBgAvVQuZu2NzfC156lhDgYue09BXv
X03R5/13yvD+K4gcU8HW5oqIevSJgH/dOUdC8X7/ue8Ym1SO45MteoCK4yGz
NsoirYIAJR2Z1r04XsZWBTsTSQR4hVfudMDx9F6D42l0NQGFNffW++N4e5d6
azWoloCkRy6O4ZdY8DxErsi0Hu+vrSs12JsFZZqsWYVGAvzjEws9cLzKyd9t
WdtMQM+J/b3SOJ5Duce1c1oJ2L8yHt2M47+Sz7g9oR2vP8Qp57IbC7wjFNbc
6SQgP2p4JeI8CwK+zPPp9xIgXs+/hw3nD9tExqhwPwETttblnk4ssAs4epAx
QMDZhtPlojj/qkMlr18eISAl20HxlAMLUjm5TXcRBHzkqB6ItmeBY9DE4xE6
AdkvutY02OL8PvbkstZ3AmK5rq5m4Pz+mn+dN2ECrzdO4MC1o/h7pG3ZKTlF
ALqv+Wq/KQuy6soSUpkE7D66cy7lMAv8Qmh+UTME9NqMdWgdYoGK0nD/3G8C
7i7ndtUAC0ISpx86zBFQTtbTK9PB8cbP3Sy0iF0slr5FmwWt5hdtLiwRkDnK
LuW7lwVH8x9IvF0mYM1LGe85VRaYKnWeU1shoCuxVc52Bwtqa4uuE2voIHRo
1MxMhgWxAQmlf9fSIeaXyD11aXz/LS8ZwXV04MoU1urG9VHF2M93JycdZkfX
vY3H9TN3wvXEzvV0mEw4fcAQ19eiV8320hvo0J99MyWQmwVbt96u+8NFh1Id
L49/nCxoK49QpHHTYf0ZrmMB7LieXI16VbGRDit3PpcFLjJh7fSDyfO8dJix
bhQQwfVbZLm6SJmPDhv/xWUk/GTCrcilmCls4Yjpq4b9TKDtGQlyFKCDzmfH
z1famZDT3BbNLUiH3z5KxmENTDg5fqTgHXa/de2WQDITTjUO9lsK0SGKN1HX
Gp8vvIX7RH9gp5tteC1QxIShrwtnbgjTYcvJF54f8piw6FVXyL6JDv9MVJZe
JjHhcc8xT3YROuy/V9M595gJz/oZnYHYDDcHyV0RTLjgOWE0hn2Rt7H7ED7P
uuq70TFROux5Ms5t4M+EAV1BeIv9XiwByXgzwYWdu2aDGB2sip//GXPB6z2v
eswB+3Y4ozbOngmv0pmDOdg5r7V3yloxQX/xo8849n9Cb6bJ+Hyt4vSfl99M
B2keubOmB5hgeam1yhHbO0HLr0SDCXtiKS0x2BcT/tNZv4sJ2VufbCvB1jn1
o0J/GxMuqV4p7cYW2jXDeUaUCXY9Cf9NY4ufdNl6jocJcirwlkOcDjeVJgVM
1uL7zXKEhLEv/DYaFV2cgmRDjnJx7H/L23MaJ6egSTUx9/8OeKTt6MaYgnVy
8QNC2PNL2pvGeqdg4wGtE/+fLz+qr9OiZQpyoj8J/f95/3HN5KZUT4EO1Vns
/+uJei2b2vxxCh7KfXcpxhaWMyr/XjgFAjGG89HYHFYHhL9nTYFJ3/X2M9ja
f3+8a3w6BZVTIYty2CH/FDOfxkzBYsEZj1/4e5XsIlimoVMQPLtB7hV24Qlm
Ad0f9zcv76o6YhtY7aU7e07BvcyGcJ7/f9+NE+PCNni9y8WyJ/F+LftK9xsZ
TwFL7ITHDN7f7Ijt/k66U+BeV7kmAtuh1W7SePsU7OhZp5KK44V6ze2XiNgU
0DLP1EpiqxSWtjdwT8G2AqWSRBxf7xOmsn9OT8LyR6WXATj+PmwnvbEZnYSb
vf25gzheA9e8ZmT3ToLF1ZWNetgi7k/4VionocwkeeE7Px1iL/zVDH8wCX6J
vkmTPHR4wjp3USkYXx8z3SSNLTn86NhHn0mIOeV61RTn19FysXtRJyZhRNpD
OBrn498dc8kbpXA/aZzPVsVBB/mDjiEsvkmYMQ1d+oLz/biDVkkF2yR8raMG
fGCngyVt3F7w2wQoO2dzPcT1gpGv1v88bwL6bBq+zfwl4N1KXZa32gTwNyDt
GFy/DCsTMyZkJiDJucZNdxr3F9qOavbCE1CYPCg1iutdO6fticW5cXDwJWso
TBKg8MCzw+rzOFhqvbW9NIbPax17g1swDl37eU3mcX2u/X6557jeL/jLv753
SyUBlHpF4xilX8Bu10OV/UJATMb6hRKJX1D/Tbd0x2cCQq6tXOtZ/AnbMh2f
ipcSIPVFIN62+CcMRT+cohTi87JfOM9G4Sf8cjJr1UkloC83PZGD4wdQjJrD
kv0JsBFs76xmjYGi8RvlNl8CNmf0iPgOjsHvL7cy2XF/E29Hkn/+YQys7Rc5
7D0JCFX/oQ/OY+AUxXm17izuR24o8ZR8+g4v7okmvjcioEG1WdPTaRTEzddz
LQnh82GKUvI2hg7DZC2ugXQaFPVORHVy9sOmlY6HL4xHgDtp7qnd6Rb4py/+
QGbXENxfv2FS0+cdPCR9NOFs74d1tWJLcw+KkXgahwvPh17I08uU4A1uRBtG
I0waY7qhBcUHS33sRAo9cwXbMzthI7/aoaSFPsQtFXvj0boOsFdZOGTvOYwK
tsuVzfm3wZaBmcgPgcPowfLexdArbZAauLD2X/gwyko+2SLg1QaTlP2l518M
oyEl0NJyaoOcW3m8fgPDaLFseeC5WRvuy7y25ZmMoLldfz9Nbm2DjO77Mz0b
aYix+8/tS02t0PYn/BJnLQ2tCXxSVa/cCloK50RaGmgoPk68PUa+FZySUsof
ttKQM4mcYy3bCu9fDW6eG6ChDMGcJ9/FWsFzein/wgwNjZk8d1Jlb4VyPVpH
oxSBTu1LORVR/BUsKyKXhy8TqHnNnPnQpq+Qs9Yu750fgb5/83nIv/EryKiY
/wsKJNBWLqX1xmu+wpU8qbdLoQTakfcxtXayBXrmEz89f0IgmnQe7xpKC/wW
mR6I+0igf2lpM5eDWkC4LN9R+w+BSmVeqIiONkNm9xZ90VUCjctXvREZbIYN
R9ZlTa6lo82H1jDFO5pBNrWbM4qbjoD1I0eN1AyX5rLIvuJ09FacsywxrRnu
S0ROimjR0Zunb30NTzYD647Zoc+edKSW81dVoKUJuqMs9Nou0dFh/pTbL2qb
YGS3gzH9Ch3JLziZ6FY0QYRzd+ZMAB0ZtM0fDixoguYXm4imMDpax5jPkY9u
AiUuQR2vZDr6OrNZ57RpE3Dk7zjpTaajRAnSAbb6Rrh7R3Qou4aO5v7RduaQ
GuHWq4X83jo6Uq9wK7f83AiHbvup72mko0F9tR+F+Y2wRpq8t7CDjmafxW1J
fNQIvkVqc7UMOkqP7wjZZNsI0Yvz0cWjeD4T+9uzFo3wc+hpevoYHWUeJfH3
GjXCUBXF0HWcjrhV2H7kaTdCTIjfty8zdBQk8f5QoGQjXLpWpJHExkBeQ+GH
K781wLV/6n9gLQN1ScfUdg81QMZMkw+DnYGqw1+QZrobgIgT85Zaz0ARdSI7
99Y3wAOO4+xneRnoy7iLD6OwAZyNR/Q3ieP7VwJqvl1vgKfvRrQDJRioQXvH
Yc2rDcD04ODv3cJAt6LF5CM8G+Ce0V2HaGkGunhtSGCfYwPEtt+jVG1nIO0q
NTN0qAHmkxzcPHYzkMl1HYErfA3AYsV/zVZhoGCfzkiP9Xg+Db//BlQZKD+1
iHBja4C6bAt53T0MdOr3ht2XZurB3e4eT7UWA6ltK1941V0PYkqciX37GEjv
2CaDqq/14KIfHD+uzUBy3uanB6n1kGzmu7hGl4FWOuVWtpbXQ9Q1/aZFfQZq
LfRs6HxeDwVcTLtxYCAtI4bPxuR6SCxaudJnwEDJ5Vp9R+Lw80ZjnHIPMZDw
VBqr9l49VNn1PhA0YiAH4/K1vz3qYWOO5YKwOQN9DsjQWtWsh2ZCbgMJe0ei
o8VVlXrQNy0f8rDA6/nwgWdMvh4aYw98e3OMgVyCHG4PSdRDoUVLKedxvF8v
Hdnm2eqBe+MvozjsR2fou+8vU+GFh2iJuDUDnbX9Ny82S4Wia6rakjYMxPn8
oa3JGBXO5Bmrs04wEOXpOrHOZioUn2zmcrDF++msP3uHQoWkmyF9JGyO+D1O
qiQqqD5a8bxrx0CGVQNDScVUmHvPpzGMHXnffsL6DRV8Sgb+aZ5koIQj2+8K
5FKBQ2vfm27szWW7DBOfUWH438xTmVMMdFx+n8fZBCqM7nkb6479OFdfcNdj
KtR9P5uej72AKvYvRVJBRXWu6hf2+xk1ojGMCvXbXP/utGegb7WbOLNuUeFw
a6aNI3ZZ5WjOzQAqRJZbOFdhD+49aLffkwpnlXxsf2IfVPHhuH+BCg0nDJl8
pxmId4b1seMsFW5T1NTVsd1lo3122lNBWThdygo7xGmtQpANFSIo06Ve2Hcs
thBtFlQwuBa3ehc77kFKsrIJFTbmfV9Kwv728bDVg0NUSJ47kfsaO/PGMPu4
HhVSfxryfsKevaT84dg+KlA3SSjVYHPv+32mRJ0KLZz665r+v56AhVVpZSo4
WYo+a8VWbFpJiZajgvptrpk27Af9Dcp/tlFhn8Ltjf8fp0psL760hQqT9m0/
G7BJA02qDBEquMkaPyZjO/OkpTsIUEGuYeu/UmyPLq/Vbm68/8nPtHOxk84J
HrfloMJ/fcsGidhvO1zjulcpcLg9WDwU2+v0QfLpZQrYNF2occd+KHlrhJil
wEEBlqEFdu+hqR9eTAokfD+XooLNNe8ztPiTAh1PZ+t5sGln+8ojv1HgjvdU
5xj+/lI5a+9uGaHA1sKHFQg7ZLZa/X0fBfZlCYU/wab6ztWZdlLA4kmFmhv2
B1Ofg6MtFPje2II0sdmzuDLu1lPgfmz4XjbsoOxUYkcNBaZ+/Bp6iOOjw4yX
68onCpA2bhaxwtYyeDYhXkyBd8MTuvzYFWFhb+reUIBV+sj5Ho5HjbgKqkI2
BXj+DF7Qwd5jSJIeTqfAZalxp0kcz9ftfY4lJlNA4gtx1Axbx9BBi/8xBfb/
ntOfxfngVe0/8TWKApsn9mk8w551/349/h4FviSlytNwPvkG3+XeHkQBKxGL
ICOcb0sHKtkuuFJAOE7jfS/Ox4+nnxnqOlHgV/n80kXsdMuDNiIO+HvFeNYH
4/w12JLZ2WZFgd+nvFPCLfH1+aSD3noUYA9ITVmDHfhnvsl+HwVuKZ2quIHr
gXL3RUmzPRSw66r3dcb1ovt+CbuGAgWszyz38B1loA0GQt07N1GgfOSeXoAZ
A6ncuuBziJ8C5rVbWf2meH0nNPOcuSlwRf+ceaoJA21ff3j5FRsF3FkbeFeP
MJCSrf6CzWQdnO/6In0ce2Kt8437P+pgcwM8yjjMQH4pPk8+MepAcQPj4T5D
BlIVehmr2F8HskPMg0a4Ho79rnqkQKkDNaNL1+7ieumI4iovk+vgO5eEcCWu
p8ejl+6UVdQBqU49VekAA/G86/9gVVwHVyXz+X/sZyC7vzp1mZl1UOVhwfcD
13NtyRlKxa060CMuDPxVZ6BDh/9mKQfWgauZtzo/Nl/cJFu6H57/n+EdZXwe
xPV+OxjpWQcjqRqtpkoMZCqQURV0qg50DniUCuDz5Ujkt/luzTrgf9LPNyCA
8z0qxM+NWQvMMOt3UfwMdDvYL5PyqxZuHZHM28uH13viTrbS91p42mKSe38j
A70LXSf3d7AWErichTg5cbwoMv9UNtRC8w83gwfLdHRCIkmyMacWzut90eVf
oqP1X1kK9lm18HWVKIhdoKPmw9x/fqbVQrus/uKjWTpaFng9IZxQCxYz8e5e
U3RUcYPyK/JuLUgysuwLCTzfAd1b8061UL7+RgI3jY6mnff7vjtTC4HfRi64
DtPRS9cNWy+dqoWwF6a1wgN0pKXzOnnKshZUD898senE/dHFuWVBqAWabxW3
C+431pl6F/ZJ1cJpvR61mlx8Pd/LTrehGmguO6S5mIP7j44Ci099NRDAbmW2
6yUdVas95uHrroHwD+c/RGbS0acvHvaVLTWAXy5VJYWO2K5tk9apqgGOIIVf
W6PpaEJkjJr2ogas4nUNM73wfHL1JwS9a+CLjdvGFA86GuUkTuW714DH/jje
2It0ZDVW/tjYtQYkw67V3DhPRxnrnsSHn62BnoubJLUc6Oi4GvomfbwGLtwy
v+JgRkfnjzzU/KhVA6MJKQlO8nQUmKpKjWKvgQqBlKyZHXSk+th2sxxbDaTV
M6vDZOlI2Xz4Z83fajhj/8YkTYqOTnFQ+bjnq2Fdwa/gcmE6WkpstCz6UQ1P
F+aK0nB/eesoz+6glmooTFKRXdtNoCTZQ6aMZ9XQY75D2b6DQDUX5l61JFWD
ZamE75tWAh204wn4klAN77j8Sm0aCXQ2JPjs88fV8M/2A0RVEcgqVNQm7G41
1GbdOZr5mkB+ZT5OX7yqIXeBuRoTTKA/wo9LVw5Ug80lE8nyIAIJhbvwGepW
w4Nih5yx6wT6LILePdCuhucbjq7X8yUQs+ZlxzaNagj4FyDS7kYgi1GFSHeF
ajjfZ6tcbIn7ZYO1Z1yFqyFk49tHdtsIVFL6Q0VonAxPA79vPYH7d/GcbrmM
H2S4eeqwrpUEgUTLhM+qfSfD9dVQ4cObCDRo7RF1kiDD3zbPcxIbCHR7HUdT
VQ8ZputkBMKYNHRqTKj2Xw0Z9IfTVQwraMjGdfcruUwyvLrm4mX2mYZYM7sN
ZZ6T4T/R9YFWZTS0qG/dJJVGhvXOS2vt39PQp56Al5LJZAjXZJ9yeElD7FGi
PuqxZFicK45RfEhDGh0M/bJQMtAZfTFjDjT01NS2Yc8FMsg2KNfVn6Ihh2g/
sqcLGdS2s0Ze29LQcbsNL7KdyBCf0V/qYUlD75JXJaUdydAkXbbad4iGCLUS
lrwdGcRO7T1zX5GGfhbf5HhqQgbm35gLmyZGkJ9ZnQNdhQxVsvIjHKMjqPln
9uTe3WTgXtPcNTs0gtI2d32OViKDOU+EbuPXEeR2u45TX4EMDi5kztMfRhDH
iIZLhQxez5nNfmxBI4if56aEvAgZMhUP7mzwHUFGT8/YpwuTIeq0vUus1wgK
m+1pFxPC93t9CNnsOIKcvOP8BfnJEPnzkSuXwQjiPNJ+YysXGbIcfkQHcIyg
dE3HmzkrJIgarzou/m8YKeh9dDn4lwR+0/NvP80PIx6N8HvDyyRgMrq1f48N
o/1aV69vXSTBH/axeNOGYRR0Hx9tMySgOO6XvPdoGK16Cp90+kGCHanmNE2R
YVRuvaBs20UCpy67//j4hlF+ZIerWScJnkVH6HznxPM12Mce7CDB2AvHO48X
hxDV/mXV3jYSfJz71ls/MIQ+8a6G7m0mgTR/ldZw5hBqYVQ9j6slgQDvVvLT
lCG0LXETz6saEqzGhB2zjB9CfxMeeFdUk2DqeI7Xx3tDSHrfRW4WiQQLedFV
vheHUDnPqwrvShKkO2+XjlQeQkW+zttqykjAPipMyOwcQt9frgwvlJKA/v3I
609SQ4jGxYjfja36ssKKwTeEFiWFifRiPF4rtyA9PYicgpt4kt+TwJSd5/e+
kkHkt9xOGc8nwW/vYYOiwkF0S932jz52LKkgeVcOHre4Kf/kNQnqeke8RZ4O
ItPacM/DeST4ESSU3hE4iCwLzmd+ySHBf95gOaM7iNpEgtl4skjQoDs45ac5
iGYr25JDM0mgkefz9rfyIDqlZ7JlKYMEp54LP5mUGkT57C49k89JcLMyhNmw
OoCmZ8r3T6WRoOAw+7MDiwMozjtO3A/7+a837m9YA4j9tDhjKZUE8d0SXg+I
ASRNW9Xgxdad9RdQrh5A+ZSsdrMUEvw74Nv2uHwAGfJd4RhJJoGoYkPJ9IcB
pON+a7s/tqDnnx9vswdQnaKi7KskEri6KS6JhA8g8q5t6rJPSRCUQOvyvD2A
PoRX1tQmkkB9E293RcAA6tfMPuKF3TJSZXD24gDKemsj8CWBBO8bfFCkyQBS
1MppvfaEBPWxhWUtBgOoQYfeJY8tcNGuQ2j/ADpFhDYMxuN43fLtWoLiAJLQ
Ww4zx97jWbfcITOAdNedNl6P7ZbDly0gMYDkE5X+VseR4Hpdo9M97gG0D/Zo
G2LPi+tfK187gMw8pxAHtrqOYD5ruR+xR+za3xBLAtmqzjDb8X5kWKG2xh67
/29B/4amfrRGs3fq4X8k2Nm2hku9ph+Zsi9wOWF/Uis8ffJLP2IJF23WxF5z
da17ekE/0pTZKER/jPeLlLcdZfcjpK62Uo6tfytr7XBqPwrPXx18ir3/r/cu
0Yf9iE+k+KYtNv3ykq/q/X4kfVRXdx928Q33YaNg/Hy/XJYENsGK9T7j348O
HTyeyoadnGshdeVSP/LyjNb/8YgEfP5+rFDXfsTxoqCnDdtv18BorGM/SnvO
7V6BvZB6ZuW5bT8q3/SH+Rq7JeOrVoFFP5oo7fBJwf66ZLSJ60g/iml/QX6A
PW58o/K8Xj9KpiZdDMbepK2x94tGPzomvu2cL7bO9YOBQkr9iDj8Ks8D27Lo
SoSbbD961PjM+Dy2ceJDl4/i/Sh6t9f+c9jCrRe4Ngj2I+HxsDuO2C95qm/a
buhHZ+9ZSZzFZi5e+5Sx2ode3jjI7Yz97aAx+ed8H9p2tNrSDdv/CWei2lQf
4r5hOH4JOyHtjqb/aB9Kuas6dB1bi/tOWtkgHh+f3XkP2yyirXWhow/Fq66p
i8OuJhm27G3sQ5faSBUvsJ+4ZSVcJfehNqts3jLsN7Kf5fI/9aHF3aKlTdjs
L06G0t/1Icmf98q+YYc/MX4pltuHrq09K7SKrZhtF2f2vA/pLPNRtuD9GLp9
3ORmYh/KteLo1sFObFtHyXvYh+buv4Ez2P1xFCm2W31I8NHXHTnYpg5X5uT9
+pCNs2xmC7bSw5knFp596HDLtxtL2I9f0xTjTvWh94daDtnh+HL+dFf6vWUf
spdh04zEPjft3tds1IcWzMvufsHecco9g21vH+JQbDRQxvH7sOZTvqhyH/LN
3fP2IvbFrvKbu7b3oUahvbdfYr87Z+B+VLAP7TXaZqCA88Hf38rdd7IXfbgh
72KG80n/gvKjgG+9CLJWGEnY7FMJ/oEDvejFdHLDT+wKi5AI//peNJOlQ43D
+dqaWlZw4mUvOp/5IX4NzvfDZI5Oo9RedMfa2uw8ts6Nyk9a8Xjcje5BwZ4W
Ha7kD+1FQScmRhNx/bhwZSA750wvev1Mn2aN603oJrPQi8J4/ONHW8D1TEbG
emsHdy+Kc9B+UYktGbmA9Nb2og3S8YIG6SSIiNu7nnu6B+1gDlib4vp4ukcv
I6alB7Ufpvr743qaKOgZpx7Vg8I7rhdq4vr7W/S6THBID3K3YRzuxvZUfpRf
d70H8earcwS9IoFEydwbG7ceVPI1cC01lwQvbrq72hr2oH1XK1eCcb1X8veS
W/jbjWzc0UVrfD6QfsUqy852o8CyH/WiRSTgMc7ceXS8Gwl4GzoOYb8unZ9M
7OtGZr108av4fKkLp9WKlHajp3dk/xTh88nhv1aOd5e7kfJWL1oGPr+OX5c/
Zz3chdQsrc0VW0ggF/W7NqCzC2WGX/jv6FcS4OY/P6mhC1lJ/wm+0orff6Ju
urO0C+UcWzpFbieBslOiierjLtSpKSkX3oP3L+/VIU/oQlnl6wcfEbj+V3x1
m0nrRLzd7W9eL+DzPj2jtia+E70ZX6BuXyLB/V+Fd59EdaLr1JFXz3F/4PHz
jLiyfycSE7xS9hz3E6vW7A90zTvRYTVFbRI7GbYGTPr2L3UgPbfkpAcCZAj5
5LrAb9OBzCNdUg4ok+HYrj1W+qYdSKUkVHwG90eVe7cf8IQOdFDJVSpPlQz/
pCK/flbqQLoaz0ulNchwZrHro/66DrRDnddIQYcMobplaa3F7WjHqlp6Ce6/
ltvu523a1I5an1i4ootkkN47QB9oaEXxn+oHSIVkWMf95lVKVStyV/d5L/QO
93/vPFvsSltR/vBNJbciMmj4vNajZOJx77sCImVkaC8KuxEZ2IrY7U9+jKsi
g0TxDofona3ok0DQcb5OMnAeEbMR+tOCRHcNf+RdIUNqmFiHklkTKtRfOXnx
ZDU4zLx64rGnCa3py/jv9elq+LJiYpch0YSWs6Y0ph2rYUT9Zv3ir0aU7e9e
FXmhGrglOldORDcii28z4sTVavilt8hf1tCAEk8f36z9EN/vvMaB43A9KjuX
/TCqrhrOXibpd22tQ5uvSnoKHa4Bt2q6VHQnQqox3IptJ2thrVRuWNT+96hd
yMjpcW0dsEcNp70vCUQtg/aPkwOpkOou77ryowDsBeXiL59uAIOTYi32qAo8
I/8wzUhNYLxPzMz8bgOcl9lY++3sVzjAlEdtN9uh+c7JMnmFNvB+tfL0SG4v
XDlBDuBcbofNs4tiwoPDIKXE3Uyld8Lu2F0cmYvDYDNQZ0ce74TesC3UvSIj
cEdUoQTNdgL9ZV6637ER2Jfa/r2WswvnQ5AOkEZA4lfG8OquLli/J6KO4wQN
cst+ySlc6wKfiJQE/gMErOH2UNjP1Q3aR9+mlh0l4Pfb6MxcoW4IDdXVdjlN
wB6Z2tQtkt3AH/aND10nwPd1Ki+PajfMlLe7JhYRQJLLuStq2w1nht0UixXo
wKmentqS2Q1BYUWpofvoEH40OetafjcUfYzactyIDrUcq9NSJd3A4qaLzZ+n
Q/2RZccgajeci/PmP/mcDuoesOY0sxsmL6zSNd7QYXP23A/xpW7Yef/tdaEK
OuiYPF4eXNsDbU7ryjv76ZCvFhvlLdoDmdlnbD/+pMMrL+N/2tt6YKVtLiJt
kQ5TO2yjN+zqAZHCPJN76xnQfdJZeUCjB/iXjz/8/+/dilaFhv7/e7f/AdVk
jBI=
        "]]}},
     Annotation[#, "Charting`Private`Tag$81479063#1"]& ]}, {{}, {}, 
    TagBox[
     {RGBColor[0.880722, 0.611041, 0.142051], AbsoluteThickness[1.6], Opacity[
      1.], FaceForm[Opacity[0.3]], 
      {Arrowheads[{{Automatic, 0.88}}], ArrowBox[CompressedData["
1:eJwV2nk4VF8fAPCESikiUaKsoYUoO1/ZhbKlELJHtlQ/JZKUFNEipU1CEZKy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        "]]}},
     Annotation[#, "Charting`Private`Tag$81479187#1"]& ]}, {{}, {}, 
    TagBox[
     {RGBColor[0.560181, 0.691569, 0.194885], AbsoluteThickness[1.6], Opacity[
      1.], FaceForm[Opacity[0.3]], 
      {Arrowheads[{{Automatic, 0.32}}], ArrowBox[CompressedData["
1:eJwV2Xc4lV8cAHCkYSVEiwoRqRQRwlfD6helUFmphIpKSiRJkpaSvSqZkRVF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        "]]}},
     Annotation[#, "Charting`Private`Tag$81479311#1"]& ]}, {{}, {}, 
    TagBox[
     {RGBColor[0.922526, 0.385626, 0.209179], AbsoluteThickness[1.6], Opacity[
      1.], FaceForm[Opacity[0.3]], 
      {Arrowheads[{{Automatic, 0.85}}], ArrowBox[CompressedData["
1:eJwV2Xc4VW8cAHAZKUVaSmUlESIVovElSkaJsiKRVPqhQYhsGdkyS0VWZkZJ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        "]]}},
     Annotation[#, "Charting`Private`Tag$81479435#1"]& ]}, {{}, {}, 
    TagBox[
     {RGBColor[0.528488, 0.470624, 0.701351], AbsoluteThickness[1.6], Opacity[
      1.], FaceForm[Opacity[0.3]], 
      {Arrowheads[{{Automatic, 0}}], ArrowBox[CompressedData["
1:eJwV2Hk8VO8XB3BZsmSJkkjZtaJsiXKUypqlQqgsUZYQIipLhZBIlkhZSsKv
kJTdtWSJEJEWyX7NRJaGMeObfsdf83q/7p07d557zuc8M1KOXsedWVlYWEJX
sbCsvOqYya/PCO6AnD+XD+un04ER9qmZq6ADwltV3Isy6CA63sPw/NEBQ/eO
3t2YRYfbxhHhu/d3QpXm9fqJp3RQlhx5F8HohPs6uuOReXTgNQjKqij/CAVb
KhqbS+hQoZwcz6rcDQ9ViuwOtNGhW+qdRppYLySevJD9h06HvoMl/Fp7v8P2
Zlu5HVaL0GPnfeu40SA0ccWVhr5YhLSNvIZDpcOQf1J/ZPfSIuSpWr+n8o2B
V82iiYwBA1R8Pjj/I8ehx+Afm3YUA64PFKgohk5AMNfS4q0GBrBdLK8MC58A
bfdhc9N3DLgg8/vHp+gJyKj+3S/ayIBE803jtkkTENrHGvmiiQHqAa4VQvkT
AO6zW1veM0Ds5JKoaPcEjHm+OPClkwF1lrLTfuIUONTbq279nQEhHQuMsVQK
DHzNcWibZsDOkE+p6x9TIF6HJdJyhgE7zH8e2p9JgayaBxODaFMz0zz/HAps
Zwuy+jPLAHs/taQHxRSYrV89xk9jQM+2bzGR7ylwcEojRnKRAYpfvQw2z1Gg
Wpia9OIfAzYfo212o1FAX9o7aQsLE7YqbWovXKCAbMKxljj0pcW2N3JLFLAS
Um72WsWEzVWboivZqGD58KuMPBsTgBrGHbuOCpKeMjsurmZCs3zR8AVhKoRN
ixztQuuVXQzVFKFCbbLAfTVOJmxqc2BvFaPCkKtW+RK6oMhx3X0pKnDHsuoE
czOh3CMhtFGBCqEdVryneZmgVpvKaqBEBbb72gGV6OeTKbMNu6kgYnR3UpSP
Cf0zvYKZKlSw6Eqe+oR2uvxAc1aDCu1JzUb7BZhw3ekV225NvB8P2/kE9FnX
i7vPa1EhLot4RkVPdYgWlR2gAvtxBbGktUwQ7EvfunCQCsL71xgPCDLBQYt/
avoQFTadjZNXFGKC6XQT75AuFTR0jVcHoT3OuVjmHaGCeHR2j8g6JpxQXgoK
PUqFBI5v9efQBz13Lpno4edfuf6mAP3IsGy2S5+Kdbb/+cH1TCAYNS4RBlR4
up72LAp9QqV0t7IhFX4PGud+RG8ray/wMsLvUy9caivMBEXNz46rjKlwt1y+
IQM9n8XqFI3OeiDXPYwWKc4yunmMCkforovOG5gg9mTVnll00rSHQA5aidPe
wcqEChVV/dvG0NvCVfpL0MIPkw7LiDDhOzGXyW2K69FwxdEeLWa7vtACTfFx
vPkIXcHkX52Klh1Tze5D3ztk/ewTer1FR7PgRiZ4fnaN4TDD9VrmmzJEb7cp
rVBEp2z6tO4WOtG7TMkUPTnxn1YFOrx2hHoe7Z/l5jyD7qAW/vJbOT90KU5O
lAm6iQl7rqNf1cVWWqMr7DmqAtFSmWwTMWh22rVoT7Sh1T5hAk2f9Xhkg46W
FtCdQZ9fNp89gNY94OQtKcYE+er0yI3onmGRTFM0T3erAxXvP92EuzMIPT5o
fP01mqVKZDkfHXs3rc8Xffq8tEIfuu+agu9OtFAU12nWTUxIMA00+Ybrd8Mu
L3oX+sGLeZdQNI/caJkFulRdtH4zmk84ZTwI3RJvY12Mz4Pqlr3uGTrNYbei
NprVcQLa0JyGgjp1+DzfqOm6z6B//vaN1UKfk0pMWi/OhIU/HRtfYj1ctK+o
2YuW/JsyIIzeo5g0bo1WLtD/6Yf1I9TExncNLSXYkvwF60sxWlwkFX1LtjRX
BW0Xlq3zFq0nn7P+NtZjzJobUd3oV0zZb91YrwfcH8xOodvedyxuQO9ZbA/g
2ozHL2ZdOoH1rX96g4Q02pB/68U3h7F+/YpajqOV/vLOfMP+eL92ss0VfTTz
Rvsi9k+fCd/vEHSuVzq7ALpGmlspCe01cj1pM/abZ0hPbB66xFc9VFaHCl+t
nPiq0fEpo+9kgAoz6S/zO9F+oWGn12C/kod1Ds6hi1TyCv9gP+dH+WqybmEC
abvtTA/2+w8u1eOCaFXvTc4v91HB+41/pAT61a+05mDMB+ubu3/sQl/RbQjT
30uFcEdLs33o9Jn8RzzqVBjX/zF0GH3Q/aJAoyoVPLZVxJuiA3dK/biCecNL
G7KzRtvlDXPIKFOhJN3A2BHNe6Y1qgnzyWLTuKUbOq1m1sUR82v49IsQb7TM
UZ+nC5hvRpbxTVfQNe7O+27twvphRu0MQt9+PrqDaycV/PbfKbiBTvLmDgjf
TgVRgWjTcDTboSnJpa1UOOt8jT8STb2XJ+cqTwU15ZO/otDnPltFdMpivrlw
j0ejI6MFdRVlqHBmKW55xd5yM7bhmLf3fvSrrlhDgq+rR4IKYqxjkSvXo0/f
eCK+hQq/bB8zVz6vWcDl42lxKiz8YEbdRNctfLFJwvzecW1OPRi9LP77YNNG
KlyVD1wViE5h1oZPb6DC5+5bFB90Lqe7vCDOAyVfzml3tH4Vh+xOnBf+zEVB
J3T8vfzgA4LYf7bHjtuiH/3no64vQIXkKEahOdo+sb/66BoqfPyo0KCFzrKU
iNXkpkKd1IsAJfQm2fEqeU4qZPj4GEmjywOTNCZYsf7Uf+lzrDyfjpaIahYq
uFQ+953HeoFmYfU7yxR47FhbObpSz9r3KwSYFHDTEsuuRTdG8cY30XHeBTsf
fokWFlJv85unQOhqKdZUtKfvLo/qGQoocv/t9UCL5FYHzo5TIK619ycvmvqm
Si9glAIpA0l/5rB//M4dbaUPUeC7ba3CF7Tbb5fpwX4K+EZfEM5ENy3Ot9p2
4zy/eatYDj0aEWVKq6RAvurGbVzY/0Ec2oWryylAp5dmD2L+ZJ/XbBd8SwHe
1fz6ZWgTqatHhYooMM2cZnVG87+UhKqnFDgutNawBPPPIODYWEkUBazTlWV3
YL4KSnYGnYiggOamaoF5zO8Up29D1Ju4H2AplibQ9u7f1rJfp0CRmxxhhrZk
T9026EGByCCtHlecF3mcvUo6ZhSYL3ML8cX5ZNYTKvNcgAI3/LlOj+E8XbjH
+4dtDQV6JKk3YtEP4/ovnVpNgcKgov+po//yTARP/DcBMgrRa8L4mbCfjV3s
GWUClvzes6zD+d1xkIseXzcBNnoao6t4mFCvwf5Ez30CNud+z5bF/UZE8GTl
gxwSxHlC52/PMWCeq4bbbWwMKkix7BTcX/lnHUrsiBuBOHW24aQ4BqT5yuVN
jgzCPe4BDgtDBvCmn9mifqAf4tkq1tqy4P7sEOtAe30vWGU8kut+vghS36+e
fd3dARJ2XPzGposQ+eNpfuObWjj4NSpS9hcdhjn6HQ0ckuFPlje8jqCDTV+P
NcfCa+LnsvgkbRsdWoMUUhrPNBNbWb0SpRsXgFO78oT5oy5ilzrBs9t9Ad7I
5DO6uPsI0OgGC5EFsGI3tWl07yeah/RpnvXzEGnEWM64PEj8bFCfGAichxGN
8B0594cJx5avow4q8yBEDx0VMhslSPWSXXJ0Gmz35qrfnDFGvJZhrL3cTINY
VcmIxqJx4sUNAdLxMQ1yuw9ICZaME1Pycvu/PqLB3+8OqVal48T8MXMpM/Sm
VRqSvdXjRHSF1CNIo4GdYUDY/dZxQkp7nYVcKg2UHgnGbxgZJ06oLQysSaIB
yOx7p7uWJOqPWSUcuUuDV9LKE1QhkhipkmLpiKFBGPeTiRhhkrjwn/ayJXpR
ZDm4TowkfN8mFrjdoUEmqzHrlCxJPEzLHEyJosG+c84uxzRIQv745/i1ETTw
rfn7XcWWJNxFE509QmhAM9cP23WGJAajeNbwoMcjrx2QtCOJzrKtB54H0+A/
O5WRRUeSIFVd9EaCaCC4k4/Fy40kUr4G0xyu02BoPibTM4Akir0nSwIDaVCQ
Lu268SpJVJ0h5SXQnuPLh6uvkcSlhI9yjQE0SO+S3rsYTBL5NSGtQujJ2P3c
KuEkMavXUVjiTwPN89/Dq+6RRGy98G+hyzQ41Z+WKHKfJPR/8O2p86UBZZIF
t7AkMfBBa9Ul9P7TZrprkknCm8/IoNOHBp9+bXNck0YSdXolAYneNKiNG6VI
ZKMPpJ3a50UD1TuFTruekYSeJrf3jCcNUsWD6Co5JNGfTNuQi5YQr3BWzSUJ
K16LNaJotYFD7sz/kUSYpV/yKg8aNP4mT6YVk4Q0h+LeKTcaZF0ItnN9TRI8
Bscrn6ONnMaf7ylB79w17ohuNwr+U/SGJPjSVu/+7kqDXxHCIW5lJKFBBid+
cqHBg66QGzzlJLHUF2CSgE5zdnyXjTbiUS08gfb8MMLbUkESJhw0p88XaJCj
L1H8vookFtc2ZI2cp4FPfEKdVjVJ6LROx+eiJSjy63PRd1wo2zzRw1uXb3nV
YP3IGRgtOdPAtvZXViu6XaH4cz36aqsRuyRBEn6TU1x30JeS3z4oR5fajThs
Rudzu7//i1b6mxFJOtHA1HxMZ38tSWyRUbMsRq89enX5Mpp2JLs1CJ1ZG8ya
i5b89nvMAF2QqnesFy1wckPuBvRU3vaf/6H3bBMXHD1HA/7WwLItdfj+1lVS
xei67pivmujmopa+UHTZo9JD5mhREx81M3Q2iynNAX1KhEVTEr237/nvi+i5
UN+xGUcaSDM2KPusHP/XvrceLQyzNd7ohdWCexLR7tWxSe7oG4UHus6jM8c8
3tqhT7w226iJXiPELW2CzpPSW82P7sro+aKOPlS8JW3YgQYbJg9/F0X/EO/9
XIpePtGxnY7fR1PUpfwu+qXq2LsO9Ea73kNOaL1ff19kotVyxHy10DM9McMX
0cdz1AzXodtNVp9XQSuKyLb8sqfBqrcDe2m43pFFI5Pv0EUXok8Vorfs8ClL
R/+rDWpxQhdrte8IRAtJKESuR696PKd7Es33kzelBp9vG8cg2270urPxi47o
ToUEN160IUMxf9XK8//AHUCxo0HfYgSrItbLaxON28/QV0R25FdifYll/YoM
Q39uKs3WRV8xsN7jhN7klD3XWEkS0f+CQw+jLxg7JR5Cr7tm4y+HHup3jy7H
ev3oSxHiRP/PR6l3B/pG1nZLylka1EtXuf2H9V91teRjIdqr1iL5Apo8ov4z
Cc1qK9PTXkoSuwU+BF9H59/vuX3nLUkw9+zyNkLnqfktD2M/uX2ea1BB2w81
RKqhe/ibnoujm86OfW3DfgzoipaeOYN5q+6XJYDOzAko/4a+Ka0QbIL9m/HM
fagRvfdwXEB1EUmwlVqPPkYXhywkTxWShMV6cyIaHfX9X9tG9Jk9R3cGoDez
+F6zf4n5qyP99iS6oSN14foLrLcgjl5ddPL7/qhEzIvvAj/DVNCppnuYJXkk
4dPm8WA92riX/Us15ovnmy1MDvRLrjuddc9JYsi0cop+mgYOQmF8lZhPc3rP
bv9Am9YMnizC/HKOpih0oYuF3pVmPiUJVuB0bkTbMJ+oxzwhCdUvjF0V6HX2
c10+WXh+S1V4IfqF4tbok5lYHzeNvJ6h/5i9tduTgXl8JYuShm7UKnXqf4T9
//PevWj0r69CSfmYn4PqUtU30Yv+j0Z9H5LE+4TzV6+hy/+2nNBIJYk0l9Mt
l9HLp/hG6A9Ionbrco4nOtF34H4x5vETXb0Nrmh9jVfnXJJI4qWiygYnNCWe
aSGaSBKGttU5dmg9dyW3Rsz3Ma2hZlu0QuG7zIvxWA+HHgaeQrvrKzH5cR5U
Do9UWqA7pUb9X8SSxIe75bEn0PLyp0SO3CWJW283zJmjdXRY+r/cIYljnQtj
ZmiqjXnjhWiSuG9o4bbiWfvaT7ORJFHzUCFkxXIH6jmv3CYJLeVrsivvP/mt
zYGO88j31j6b42gjmePDPmEk0c3iJHkS/YW1NYpyE+eJ+IK/JbrtXO4p2xsk
8T+DX2esV66/29G0JQTrlaHdexotYnHRczfOO9HMyX57NF+l1tuE63j9gunL
zujMY0e2zuG89Hmg+9gNnUH/W2cUSBKh7SMWl9Cfn36LyLxCElwNben+aOED
Zv4zfiRxmbpwJQi9s+DTPa3LmM9v7YfC0GNDXz/f8CGJ7BT27zHotQ19+g2X
SGI/+4BTEnpeI7Z4rweul47E9tyV++mEYl13kvCiyB99jR5cm8Bp6Ir57B/P
S6DjHX3eHHHGecwZkPQFzW8WqsQ4TRLrPzYlr8P6zT+dOdVnQxLT0tLLMmg1
lfurX53Cfr+Rxa+GFmD/n9HxkzjP/iN3WKPfpU+rmRthv0knmeahy5z6f7Aa
kIQEr9C/GnRSqNh4wVGSmFd3s+pFs4Yaii0cJAkzym1WduzvLM4y2YO4nzFk
Bh50RRtHVdm2ypDEg9RDNicwb7yG9tpKS2H/5ysl+KIvPWdrurwF8/j8+cuJ
aA5d40EuUZIQCYhR+rJyXHpQ8zcfSaTqVN2+gPlY1sUhXbAwTiwplZQ+w3xO
LHdp4Hw3TsSy8nVm4PxKafgdTNaOE8oNCr5d6O1XTL3rcX/3evtgLhvOS2V2
lb+uuP/7VtHV4oq+8/lGQ0j+OHGnsOPrfpzHLQ57HzbFjRNcs857l3Ges2i3
TjdajhOT+hUPp9xp8FQ1iPPV5zGCcoYj+bofzkudx43GOaNEiI1s+stYGpyN
fRZlLzBCZJ3dp3DpNQ36TcSfWpoOEVHihkrGAzTglP9l9kR/gLjuzXPrqfA8
mGvYnIsK/0roaAkf9T05D/+erotxfdFDXJQfZPAnz4PAj5gyD4EOQnbuk7/k
6DwYrjet302tJ84P9EVVKS+Ao9/Zz5E7CwjWJO0O87AFyFPRflgfmw02r099
ax9cgIifmnGHpevgYKeC8ct9dPjClGinWtVBjhwxekCLDgfrqbn37tZBRlxu
Usd+OgiHXWN+W6yDW6uLtGeADu83x+u5dNbDQ+uWTNWjdDBiNKVaXX8H+xx6
teuO0+HeJ6VM0d5mwDYvGnenQ45ueU0iTwvwPFLwDvSgwxoe0SA+nRYw6VvS
4vXC87MWEun5LbB3rn5yjw8d0gIPn30R+h5kqgNeBgXQQWFSoz5qZxu8SwuG
DeF0YPGz5+izb4OelHGHPPy9wfgg+UMyuQ26eQwj9kfSYZKjgTOf5QNohwl/
crxDhzK7af97vR/AxkjbqzCeDhmyEFPL0w7nPFclHkqgQ9BMb9EktMMz39G3
vYl0WCpTGtPIb4drtuLzSw/okKKb/unUTzzf+qpAXCodDGfzYy+v74Bdl3jk
pdPo8DvyfxwxBh0QomCu8eYRHW51zW9d+b+fQ+LTkZX/+/8PuZV8Zw==
        "]]}},
     Annotation[#, "Charting`Private`Tag$81479559#1"]& ]}, InsetBox[
    StyleBox["\<\"\\!\\(\\*SubscriptBox[\\(v\\), \\(s\\)]\\) = 0.58\"\>",
     StripOnInput->False,
     FontSize->14,
     FontColor->RGBColor[0.368417, 0.506779, 0.709798]], {-0.84, 0.28}], 
   InsetBox[
    StyleBox["\<\"\\!\\(\\*SubscriptBox[\\(v\\), \\(s\\)]\\) = 0.75\"\>",
     StripOnInput->False,
     FontSize->14,
     FontColor->RGBColor[0.880722, 0.611041, 0.142051]], {-0.83, 0.58}], 
   InsetBox[
    StyleBox["\<\"\\!\\(\\*SubscriptBox[\\(v\\), \\(s\\)]\\) = 1\"\>",
     StripOnInput->False,
     FontSize->14,
     FontColor->RGBColor[0.560181, 0.691569, 0.194885]], {-0.83, 0.84}], 
   InsetBox[
    StyleBox["\<\"\\!\\(\\*SubscriptBox[\\(v\\), \\(s\\)]\\) = 1.25\"\>",
     StripOnInput->False,
     FontSize->14,
     FontColor->RGBColor[0.922526, 0.385626, 0.209179]], {-0.85, 1.13}], 
   InsetBox[
    StyleBox["\<\"\\!\\(\\*SubscriptBox[\\(v\\), \\(s\\)]\\) = 1.5\"\>",
     StripOnInput->False,
     FontSize->14,
     FontColor->RGBColor[0.528488, 0.470624, 0.701351]], {-0.82, 1.4}]},
  AspectRatio->Full,
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0.13715714193480064`},
  DisplayFunction->Identity,
  Frame->True,
  FrameLabel->{{
     FormBox["\"v\"", TraditionalForm], 
     FormBox["\"\"", TraditionalForm]}, {
     FormBox[
     "\"\\!\\(\\*SubscriptBox[\\(v\\), \\(c\\)]\\)\"", TraditionalForm], 
     FormBox["\"\"", TraditionalForm]}},
  FrameStyle->Thickness[0.003],
  FrameTicks->Automatic,
  FrameTicksStyle->GrayLevel[0],
  GridLines->Automatic,
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImageSize->Medium,
  LabelStyle->{
    GrayLevel[0], FontSize -> 14},
  Method->{"ScalingFunctions" -> None},
  PlotRange->{{-1.2, 1.2}, {0, 1.8}},
  PlotRangeClipping->True,
  PlotRangePadding->0,
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{{3.7107767445100718`*^9, 3.710776759497746*^9}, {
   3.710776792670054*^9, 3.710776811992856*^9}, {3.710776851640917*^9, 
   3.710777006197586*^9}, {3.710784846943346*^9, 3.7107848712382393`*^9}, 
   3.710804356651207*^9, 3.7172821009985027`*^9, {3.717282163036861*^9, 
   3.717282216635345*^9}, {3.717282250955653*^9, 3.717282542218686*^9}, {
   3.717340074174336*^9, 3.717340080642988*^9}, 3.717355918238657*^9, 
   3.717356354101462*^9, 3.7174338981457233`*^9, {3.717434631138466*^9, 
   3.717434642696228*^9}, {3.717441317628764*^9, 3.717441344808694*^9}, 
   3.71744180184556*^9, {3.717441888454382*^9, 3.717441930810644*^9}, 
   3.717442083259508*^9, {3.717442478304658*^9, 3.717442646378222*^9}, 
   3.71744281440766*^9, {3.71744286535532*^9, 3.717442900113096*^9}, {
   3.717442934916471*^9, 3.717443105920891*^9}, {3.7174431402679663`*^9, 
   3.717443270385292*^9}, 3.717443318052894*^9, {3.717443595741189*^9, 
   3.717443677060916*^9}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 Cell[BoxData[
  FormBox[
   RowBox[{"(", 
    RowBox[{"\[Phi]", ",", "v"}]}], TraditionalForm]]],
 ")"
}], "Chapter",
 CellChangeTimes->{{3.710703563186775*^9, 3.710703570961725*^9}, {
   3.710784327154557*^9, 3.710784366609646*^9}, {3.7173553879257317`*^9, 
   3.7173554049345703`*^9}, {3.717355871594673*^9, 3.717355871594757*^9}, 
   3.717443288324864*^9}],

Cell[TextData[{
 "Define function that plots the 1 state attractor in ",
 Cell[BoxData[
  FormBox[
   RowBox[{"(", 
    RowBox[{"\[Phi]", ",", "v"}], ")"}], TraditionalForm]]],
 " space for a given ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["v", "s"], TraditionalForm]]],
 " value."
}], "Text",
 CellChangeTimes->{{3.710703572705634*^9, 3.710703603640291*^9}, {
  3.710704006184936*^9, 3.71070401553522*^9}, {3.710705372231855*^9, 
  3.7107053769264307`*^9}, {3.710706106217256*^9, 3.710706120183467*^9}, {
  3.717355407934894*^9, 3.717355409590053*^9}, {3.717355874337154*^9, 
  3.717355874963213*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"ClearAll", "[", 
   RowBox[{
   "vS", ",", "tMax", ",", "col", ",", "Q", ",", "\[Alpha]", ",", "\[Gamma]", 
    ",", "\[Phi]E", ",", "\[Phi]Em", ",", "vE", ",", "vCE", ",", "\[Phi]", 
    ",", "v", ",", "vC", ",", "t", ",", "sol", ",", "endT", ",", "arrowPos"}],
    "]"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"plotAttractor1\[Phi]", "[", 
   RowBox[{
    RowBox[{"vS_", "?", "NumericQ"}], ",", 
    RowBox[{"tMax_", "?", "NumericQ"}], ",", 
    RowBox[{"col_", "?", "ColorQ"}], ",", 
    RowBox[{"arrowPos_", "?", "NumericQ"}]}], "]"}], ":=", 
  "\[IndentingNewLine]", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"Q", "=", "1.1"}], ",", 
      RowBox[{"\[Alpha]", "=", "4.6"}], ",", 
      RowBox[{"\[Gamma]", "=", "0.05"}], ",", "\[Phi]E", ",", "\[Phi]Em", ",",
       "vE", ",", "vCE", ",", "\[Phi]", ",", "v", ",", "vC", ",", "sol", ",", 
      "endT"}], "}"}], ",", "\[IndentingNewLine]", "\[IndentingNewLine]", 
    RowBox[{"(*", " ", 
     RowBox[{"Map", " ", "initial", " ", "phase", " ", "point", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "\[Pi]"}], ",", "2", ",", "0"}], ")"}], " ", "to", " ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"\[Phi]E", ",", "vE", ",", "vCE"}], ")"}], "[", "tMax", 
       "]"}]}], " ", "*)"}], "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"{", 
       RowBox[{"\[Phi]E", ",", "vE", ",", "vCE"}], "}"}], "=", 
      RowBox[{
       RowBox[{"Reap", "[", 
        RowBox[{"NDSolve", "[", 
         RowBox[{
          RowBox[{"{", "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{
             RowBox[{"\[Phi]", "[", "0", "]"}], "\[Equal]", 
             RowBox[{"-", "\[Pi]"}]}], ",", 
            RowBox[{
             RowBox[{"v", "[", "0", "]"}], "\[Equal]", "2"}], ",", 
            RowBox[{
             RowBox[{"vC", "[", "0", "]"}], "\[Equal]", "0"}], ",", 
            "\[IndentingNewLine]", 
            RowBox[{
             RowBox[{
              RowBox[{"\[Phi]", "'"}], "[", "t", "]"}], "\[Equal]", 
             RowBox[{"v", "[", "t", "]"}]}], ",", "\[IndentingNewLine]", 
            RowBox[{
             RowBox[{
              RowBox[{"v", "'"}], "[", "t", "]"}], "\[Equal]", 
             RowBox[{
              FractionBox["1", 
               SuperscriptBox["Q", "2"]], 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"1", "+", "\[Gamma]"}], ")"}], " ", 
                 RowBox[{"(", 
                  RowBox[{"vS", "-", 
                   RowBox[{"v", "[", "t", "]"}], "-", 
                   RowBox[{"Sin", "[", 
                    RowBox[{"\[Phi]", "[", "t", "]"}], "]"}]}], ")"}]}], "-", 
                
                RowBox[{"vC", "[", "t", "]"}]}], ")"}]}]}], ",", 
            "\[IndentingNewLine]", 
            RowBox[{
             RowBox[{
              RowBox[{"vC", "'"}], "[", "t", "]"}], "\[Equal]", 
             RowBox[{
              FractionBox["\[Alpha]", 
               SuperscriptBox["Q", "2"]], 
              RowBox[{"(", 
               RowBox[{"vS", "-", 
                RowBox[{"v", "[", "t", "]"}], "-", 
                RowBox[{"vC", "[", "t", "]"}], "-", 
                RowBox[{"Sin", "[", 
                 RowBox[{"\[Phi]", "[", "t", "]"}], "]"}]}], ")"}]}]}]}], 
           "}"}], ",", "\[IndentingNewLine]", 
          RowBox[{"{", "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"t", ",", "0", ",", "tMax"}], "}"}], ",", 
          RowBox[{"Method", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{"\"\<EventLocator\>\"", ",", 
             RowBox[{"\"\<Event\>\"", "\[Rule]", 
              RowBox[{"(", 
               RowBox[{"t", "\[Equal]", "tMax"}], ")"}]}], ",", 
             "\[IndentingNewLine]", 
             RowBox[{"\"\<EventAction\>\"", "\[RuleDelayed]", 
              RowBox[{"Sow", "[", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"\[Phi]", "[", "t", "]"}], ",", 
                 RowBox[{"v", "[", "t", "]"}], ",", 
                 RowBox[{"vC", "[", "t", "]"}]}], "}"}], "]"}]}]}], "}"}]}]}],
          "]"}], "]"}], "\[LeftDoubleBracket]", 
       RowBox[{
        RowBox[{"-", "1"}], ",", "1", ",", "1"}], "\[RightDoubleBracket]"}]}],
      ";", "\[IndentingNewLine]", "\[IndentingNewLine]", 
     RowBox[{"(*", " ", 
      RowBox[{"Flow", " ", "to", " ", "1", " ", "state", " ", 
       RowBox[{"(", 
        RowBox[{
        "if", " ", "it", " ", "exists", " ", "at", " ", "given", " ", 
         SubscriptBox["v", "s"]}], ")"}], " ", "and", " ", "return", " ", 
       "subsequent", " ", "trajectory"}], " ", "*)"}], "\[IndentingNewLine]", 
     
     RowBox[{"\[Phi]Em", "=", 
      RowBox[{
       RowBox[{"Mod", "[", 
        RowBox[{"\[Phi]E", ",", 
         RowBox[{"2", "\[Pi]"}]}], "]"}], "-", 
       RowBox[{"2", "\[Pi]"}]}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"sol", "=", 
      RowBox[{"NDSolve", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{"\[Phi]", "[", "0", "]"}], "\[Equal]", "\[Phi]Em"}], ",", 
          RowBox[{
           RowBox[{"v", "[", "0", "]"}], "\[Equal]", "vE"}], ",", 
          RowBox[{
           RowBox[{"vC", "[", "0", "]"}], "\[Equal]", "vCE"}], ",", 
          "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{
            RowBox[{"\[Phi]", "'"}], "[", "t", "]"}], "\[Equal]", 
           RowBox[{"v", "[", "t", "]"}]}], ",", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{
            RowBox[{"v", "'"}], "[", "t", "]"}], "\[Equal]", 
           RowBox[{
            FractionBox["1", 
             SuperscriptBox["Q", "2"]], 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"(", 
                RowBox[{"1", "+", "\[Gamma]"}], ")"}], " ", 
               RowBox[{"(", 
                RowBox[{"vS", "-", 
                 RowBox[{"v", "[", "t", "]"}], "-", 
                 RowBox[{"Sin", "[", 
                  RowBox[{"\[Phi]", "[", "t", "]"}], "]"}]}], ")"}]}], "-", 
              RowBox[{"vC", "[", "t", "]"}]}], ")"}]}]}], ",", 
          "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{
            RowBox[{"vC", "'"}], "[", "t", "]"}], "\[Equal]", 
           RowBox[{
            FractionBox["\[Alpha]", 
             SuperscriptBox["Q", "2"]], 
            RowBox[{"(", 
             RowBox[{"vS", "-", 
              RowBox[{"v", "[", "t", "]"}], "-", 
              RowBox[{"vC", "[", "t", "]"}], "-", 
              RowBox[{"Sin", "[", 
               RowBox[{"\[Phi]", "[", "t", "]"}], "]"}]}], ")"}]}]}]}], "}"}],
         ",", "\[IndentingNewLine]", 
        RowBox[{"{", 
         RowBox[{"\[Phi]", ",", "v", ",", "vC"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"t", ",", "0", ",", "200"}], "}"}], ",", 
        RowBox[{"Method", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{"\"\<EventLocator\>\"", ",", 
           RowBox[{"\"\<Event\>\"", "\[Rule]", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"\[Phi]", "[", "t", "]"}], "\[Equal]", 
              RowBox[{"\[Phi]Em", "+", 
               RowBox[{"8", "\[Pi]"}]}]}], ")"}]}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{"\"\<EventAction\>\"", "\[RuleDelayed]", 
            RowBox[{"Throw", "[", 
             RowBox[{
              RowBox[{"endT", "=", "t"}], ",", "\"\<StopIntegration\>\""}], 
             "]"}]}]}], "}"}]}]}], "]"}]}], ";", "\[IndentingNewLine]", 
     "\[IndentingNewLine]", 
     RowBox[{"(*", " ", 
      RowBox[{"Return", " ", "1", " ", "state", " ", "attractor"}], " ", 
      "*)"}], "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"ParametricPlot", "[", 
       RowBox[{
        RowBox[{"Evaluate", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"\[Phi]", "[", "t", "]"}], ",", 
            RowBox[{"v", "[", "t", "]"}]}], "}"}], "/.", "sol"}], "]"}], ",", 
        
        RowBox[{"{", 
         RowBox[{"t", ",", "0", ",", "endT"}], "}"}], ",", 
        RowBox[{"PlotStyle", "\[Rule]", "col"}]}], "]"}], "/.", 
      RowBox[{
       RowBox[{"Line", "[", "x__", "]"}], "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Arrowheads", "[", 
          RowBox[{"{", 
           RowBox[{"{", 
            RowBox[{"Automatic", ",", "arrowPos"}], "}"}], "}"}], "]"}], ",", 
         
         RowBox[{"Arrow", "[", "x", "]"}]}], "}"}]}]}]}]}], "]"}]}]}], "Input",\

 CellChangeTimes->{{3.710703612185732*^9, 3.710703613146097*^9}, {
   3.710703645087953*^9, 3.7107038250095987`*^9}, {3.7107038651203623`*^9, 
   3.710703925800755*^9}, {3.710703966836862*^9, 3.7107039711892033`*^9}, {
   3.7107040284227467`*^9, 3.710704103911132*^9}, {3.710704178547552*^9, 
   3.710704218489841*^9}, {3.710704287232888*^9, 3.710704302735257*^9}, {
   3.710704453096983*^9, 3.710704469639659*^9}, {3.7107045058389473`*^9, 
   3.710704522036879*^9}, {3.7107046199149303`*^9, 3.710705014168984*^9}, {
   3.7107050627339163`*^9, 3.710705064581814*^9}, 3.710705380970055*^9, {
   3.71070553812418*^9, 3.710705545777363*^9}, {3.710705876236657*^9, 
   3.710705974584722*^9}, {3.710708729182864*^9, 3.710708734523841*^9}, 
   3.710708917711267*^9, {3.7107765702372723`*^9, 3.710776574826092*^9}, {
   3.710776616626152*^9, 3.7107766206742764`*^9}, {3.710776666008458*^9, 
   3.7107766985264397`*^9}, {3.710784842006604*^9, 3.710784866724958*^9}, {
   3.710786067923798*^9, 3.710786094881473*^9}, {3.717282083500925*^9, 
   3.717282090324587*^9}, {3.717355468814692*^9, 3.717355483758181*^9}, {
   3.717355535860203*^9, 3.717355540611265*^9}, {3.7173556696380253`*^9, 
   3.717355671100561*^9}, {3.717355712122838*^9, 3.717355726928789*^9}, 
   3.717355783527965*^9, {3.7173558883679028`*^9, 3.717355973334732*^9}, 
   3.717356043773108*^9, {3.717356221638586*^9, 3.717356358548705*^9}, {
   3.717433585046125*^9, 3.717433691073043*^9}, {3.717433793078725*^9, 
   3.717433797141006*^9}, 3.717433832523905*^9, {3.717434059939434*^9, 
   3.71743419880486*^9}, {3.717434263187112*^9, 3.71743428409692*^9}, {
   3.717434328888208*^9, 3.717434442603376*^9}, {3.717434504521278*^9, 
   3.717434530185054*^9}, {3.71744329458046*^9, 3.717443348330874*^9}, {
   3.717443698462014*^9, 3.7174436995574207`*^9}}],

Cell[TextData[{
 "\nPlot 1 state attractors for a range of ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["v", "s"], TraditionalForm]]],
 " values:"
}], "Text",
 CellChangeTimes->{{3.7107061273757668`*^9, 3.710706150158072*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"cdata", "=", 
   RowBox[{"ColorData", "[", 
    RowBox[{"97", ",", "\"\<ColorList\>\""}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"vSvals", "=", 
   RowBox[{"{", 
    RowBox[{"0.58", ",", "0.75", ",", "1", ",", "1.25", ",", "1.5"}], "}"}]}],
   ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"aPos", "=", 
   RowBox[{"{", 
    RowBox[{"0.44", ",", "0.395", ",", "0.33", ",", "0.49", ",", "0.345"}], 
    "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"p", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"plotAttractor1\[Phi]", "[", 
      RowBox[{
       RowBox[{
       "vSvals", "\[LeftDoubleBracket]", "n", "\[RightDoubleBracket]"}], ",", 
       "4001.8", ",", 
       RowBox[{
       "cdata", "\[LeftDoubleBracket]", "n", "\[RightDoubleBracket]"}], ",", 
       RowBox[{
       "aPos", "\[LeftDoubleBracket]", "n", "\[RightDoubleBracket]"}]}], 
      "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"n", ",", "1", ",", "5"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"pos", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2.1", ",", "0.35"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1.95", ",", "0.63"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "0.86"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "1.19"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "1.42"}], "}"}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lbl", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"Graphics", "[", 
      RowBox[{"Text", "[", 
       RowBox[{
        RowBox[{"Style", "[", 
         RowBox[{
          RowBox[{
           RowBox[{
           "StringTemplate", "[", 
            "\"\<\!\(\*SubscriptBox[\(v\), \(s\)]\) = `a`\>\"", "]"}], "[", 
           RowBox[{"<|", 
            RowBox[{"\"\<a\>\"", "\[Rule]", 
             RowBox[{
             "vSvals", "\[LeftDoubleBracket]", "n", 
              "\[RightDoubleBracket]"}]}], "|>"}], "]"}], ",", 
          RowBox[{"FontSize", "\[Rule]", "14"}], ",", 
          RowBox[{"FontColor", "\[Rule]", 
           RowBox[{
           "cdata", "\[LeftDoubleBracket]", "n", 
            "\[RightDoubleBracket]"}]}]}], "]"}], ",", 
        RowBox[{
        "pos", "\[LeftDoubleBracket]", "n", "\[RightDoubleBracket]"}]}], 
       "]"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"n", ",", "1", ",", "5"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Show", "[", 
  RowBox[{
   RowBox[{"Join", "[", 
    RowBox[{"p", ",", "lbl"}], "]"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"0", ",", 
        RowBox[{"4", "\[Pi]"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", "1.8"}], "}"}]}], "}"}]}], ",", 
   RowBox[{"AspectRatio", "\[Rule]", "Full"}], ",", 
   RowBox[{"Frame", "\[Rule]", "True"}], ",", 
   RowBox[{"FrameStyle", "\[Rule]", 
    RowBox[{"Thickness", "[", "0.003", "]"}]}], ",", 
   RowBox[{"PlotRangePadding", "\[Rule]", "0"}], ",", 
   RowBox[{"FrameTicks", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"Automatic", ",", "Automatic"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", 
          RowBox[{"4", "\[Pi]"}], ",", "\[Pi]"}], "]"}], ",", "None"}], 
       "}"}]}], "}"}]}], ",", 
   RowBox[{"GridLines", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"Range", "[", 
       RowBox[{"0", ",", 
        RowBox[{"4", "\[Pi]"}], ",", "\[Pi]"}], "]"}], ",", "Automatic"}], 
     "}"}]}], ",", 
   RowBox[{"FrameTicksStyle", "\[Rule]", "Black"}], ",", 
   RowBox[{"LabelStyle", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"Black", ",", 
      RowBox[{"FontSize", "\[Rule]", "14"}]}], "}"}]}], ",", 
   RowBox[{"FrameLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"\"\<v\>\"", ",", "\"\<\>\""}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"\"\<\[Phi]\>\"", ",", "\"\<\>\""}], "}"}]}], "}"}]}], ",", 
   RowBox[{"ImageSize", "\[Rule]", "Medium"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.717433729040492*^9, 3.717433755996726*^9}, {
   3.717433807731358*^9, 3.7174338743693943`*^9}, {3.7174345361912317`*^9, 
   3.717434574892231*^9}, {3.717441118942371*^9, 3.717441279501512*^9}, {
   3.71744135965873*^9, 3.717441447446579*^9}, {3.717441487749619*^9, 
   3.717441717492236*^9}, {3.717441769690042*^9, 3.717441774073914*^9}, {
   3.717441816632433*^9, 3.7174418314882507`*^9}, {3.717441936396121*^9, 
   3.7174420233918133`*^9}, {3.717442089538162*^9, 3.71744211247666*^9}, {
   3.7174421428673897`*^9, 3.7174421560026293`*^9}, {3.71744219064924*^9, 
   3.717442224136559*^9}, {3.717442292053636*^9, 3.7174422926760406`*^9}, {
   3.7174433773694563`*^9, 3.7174435415536346`*^9}, 3.717443686502015*^9, {
   3.7174437222105017`*^9, 3.7174437589931307`*^9}, {3.7174438318473587`*^9, 
   3.717443870100254*^9}}],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    TagBox[
     {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], Opacity[
      1.], FaceForm[Opacity[0.3]], 
      {Arrowheads[{{Automatic, 0.44}}], ArrowBox[CompressedData["
1:eJwVmXc81d8fx21l7xFxke2al1LyfpNCtL4NWkZGQylKEimlSFQkSkahgVJk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        "]]}},
     Annotation[#, "Charting`Private`Tag$81489021#1"]& ]}, {{}, {}, 
    TagBox[
     {RGBColor[0.880722, 0.611041, 0.142051], AbsoluteThickness[1.6], Opacity[
      1.], FaceForm[Opacity[0.3]], 
      {Arrowheads[{{Automatic, 0.395}}], ArrowBox[CompressedData["
1:eJwVnHc8VX8Yx21JZO9x7T0uFxl5HiShRUpW2qmsiqaWUhENpCRJqWREShS5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        "]]}},
     Annotation[#, "Charting`Private`Tag$81489145#1"]& ]}, {{}, {}, 
    TagBox[
     {RGBColor[0.560181, 0.691569, 0.194885], AbsoluteThickness[1.6], Opacity[
      1.], FaceForm[Opacity[0.3]], 
      {Arrowheads[{{Automatic, 0.33}}], ArrowBox[CompressedData["
1:eJwVnHk8lF0UgK2VSnZZwti3sQxjV/eIpIX0hZA1lKSkhdBCsi8RFWWNECVC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        "]]}},
     Annotation[#, "Charting`Private`Tag$81489269#1"]& ]}, {{}, {}, 
    TagBox[
     {RGBColor[0.922526, 0.385626, 0.209179], AbsoluteThickness[1.6], Opacity[
      1.], FaceForm[Opacity[0.3]], 
      {Arrowheads[{{Automatic, 0.49}}], ArrowBox[CompressedData["
1:eJwVnHc8VW8YwJEG2SOSuPa6xkX1q+h9ZEYaki2SSiGVQspKRpsyyigVDRWJ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        "]]}},
     Annotation[#, "Charting`Private`Tag$81489393#1"]& ]}, {{}, {}, 
    TagBox[
     {RGBColor[0.528488, 0.470624, 0.701351], AbsoluteThickness[1.6], Opacity[
      1.], FaceForm[Opacity[0.3]], 
      {Arrowheads[{{Automatic, 0.345}}], ArrowBox[CompressedData["
1:eJwVnHk4VG0UwIns+76EscuWYRCl94QspX2jhCxpUQlRPktCSkSSpEQpZF8T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        "]]}},
     Annotation[#, "Charting`Private`Tag$81489517#1"]& ]}, InsetBox[
    StyleBox["\<\"\\!\\(\\*SubscriptBox[\\(v\\), \\(s\\)]\\) = 0.58\"\>",
     StripOnInput->False,
     FontSize->14,
     FontColor->RGBColor[0.368417, 0.506779, 0.709798]], {2.1, 0.35}], 
   InsetBox[
    StyleBox["\<\"\\!\\(\\*SubscriptBox[\\(v\\), \\(s\\)]\\) = 0.75\"\>",
     StripOnInput->False,
     FontSize->14,
     FontColor->RGBColor[0.880722, 0.611041, 0.142051]], {1.95, 0.63}], 
   InsetBox[
    StyleBox["\<\"\\!\\(\\*SubscriptBox[\\(v\\), \\(s\\)]\\) = 1\"\>",
     StripOnInput->False,
     FontSize->14,
     FontColor->RGBColor[0.560181, 0.691569, 0.194885]], {2, 0.86}], 
   InsetBox[
    StyleBox["\<\"\\!\\(\\*SubscriptBox[\\(v\\), \\(s\\)]\\) = 1.25\"\>",
     StripOnInput->False,
     FontSize->14,
     FontColor->RGBColor[0.922526, 0.385626, 0.209179]], {2, 1.19}], 
   InsetBox[
    StyleBox["\<\"\\!\\(\\*SubscriptBox[\\(v\\), \\(s\\)]\\) = 1.5\"\>",
     StripOnInput->False,
     FontSize->14,
     FontColor->RGBColor[0.528488, 0.470624, 0.701351]], {2, 1.42}]},
  AspectRatio->Full,
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0.13715731643640663`},
  DisplayFunction->Identity,
  Frame->True,
  FrameLabel->{{
     FormBox["\"v\"", TraditionalForm], 
     FormBox["\"\"", TraditionalForm]}, {
     FormBox["\"\[Phi]\"", TraditionalForm], 
     FormBox["\"\"", TraditionalForm]}},
  FrameStyle->Thickness[0.003],
  FrameTicks->{{Automatic, Automatic}, {{{0, 
       FormBox["0", TraditionalForm]}, {
       NCache[Pi, 3.141592653589793], 
       FormBox["\[Pi]", TraditionalForm]}, {
       NCache[2 Pi, 6.283185307179586], 
       FormBox[
        RowBox[{"2", " ", "\[Pi]"}], TraditionalForm]}, {
       NCache[3 Pi, 9.42477796076938], 
       FormBox[
        RowBox[{"3", " ", "\[Pi]"}], TraditionalForm]}, {
       NCache[4 Pi, 12.566370614359172`], 
       FormBox[
        RowBox[{"4", " ", "\[Pi]"}], TraditionalForm]}}, None}},
  FrameTicksStyle->GrayLevel[0],
  GridLines->
   NCache[{{0, Pi, 2 Pi, 3 Pi, 4 Pi}, Automatic}, {{
     0, 3.141592653589793, 6.283185307179586, 9.42477796076938, 
      12.566370614359172`}, Automatic}],
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImageSize->Medium,
  LabelStyle->{
    GrayLevel[0], FontSize -> 14},
  Method->{"ScalingFunctions" -> None},
  PlotRange->
   NCache[{{0, 4 Pi}, {0, 1.8}}, {{0, 12.566370614359172`}, {0, 1.8}}],
  PlotRangeClipping->True,
  PlotRangePadding->0,
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{{3.717433773296947*^9, 3.717433811200652*^9}, 
   3.717433842368272*^9, 3.7174338768097067`*^9, {3.717434094091977*^9, 
   3.7174341834967203`*^9}, {3.717434269700963*^9, 3.717434288192966*^9}, {
   3.71743435274162*^9, 3.717434447517768*^9}, {3.717434554743972*^9, 
   3.717434576868005*^9}, {3.717441121085411*^9, 3.717441281778709*^9}, {
   3.717441363477622*^9, 3.717441449490122*^9}, {3.7174414927645206`*^9, 
   3.7174417198292217`*^9}, {3.717441771735805*^9, 3.717441776151491*^9}, {
   3.717441818792039*^9, 3.717441834296788*^9}, {3.717441941687922*^9, 
   3.717442025676672*^9}, {3.717442092354024*^9, 3.717442115093585*^9}, {
   3.717442146053355*^9, 3.717442159320788*^9}, {3.717442196786564*^9, 
   3.717442226757389*^9}, 3.717442295079501*^9, {3.717443364108713*^9, 
   3.7174435444452047`*^9}, {3.717443689939766*^9, 3.717443761831851*^9}, {
   3.717443836601392*^9, 3.717443874567606*^9}}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
WindowSize->{1075, 1287},
WindowMargins->{{Automatic, 354}, {Automatic, 0}},
PrintingCopies->1,
PrintingPageRange->{1, Automatic},
FrontEndVersion->"11.0 for Mac OS X x86 (32-bit, 64-bit Kernel) (September \
21, 2016)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[580, 22, 390, 9, 93, "Title"],
Cell[CellGroupData[{
Cell[995, 35, 150, 2, 65, "Chapter"],
Cell[1148, 39, 477, 11, 87, "Text"],
Cell[1628, 52, 14714, 337, 891, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[16379, 394, 479, 15, 111, "Chapter"],
Cell[CellGroupData[{
Cell[16883, 413, 652, 10, 32, "Input"],
Cell[17538, 425, 39299, 678, 366, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[56874, 1108, 274, 5, 32, "Input"],
Cell[57151, 1115, 54681, 927, 366, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[111869, 2047, 196, 4, 32, "Input"],
Cell[112068, 2053, 307862, 5085, 366, 292072, 4825, "CachedBoxData", \
"BoxData", "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[419967, 7143, 168, 3, 32, "Input"],
Cell[420138, 7148, 30144, 526, 366, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[450319, 7679, 222, 4, 32, "Input"],
Cell[450544, 7685, 37506, 646, 366, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[488111, 8338, 128, 2, 92, "Title"],
Cell[CellGroupData[{
Cell[488264, 8344, 342, 10, 66, "Chapter"],
Cell[488609, 8356, 527, 15, 32, "Text"],
Cell[489139, 8373, 9634, 228, 664, "Input"],
Cell[498776, 8603, 226, 7, 51, "Text"],
Cell[CellGroupData[{
Cell[499027, 8614, 5507, 138, 243, "Input"],
Cell[504537, 8754, 50951, 864, 447, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[555537, 9624, 376, 10, 66, "Chapter"],
Cell[555916, 9636, 605, 16, 32, "Text"],
Cell[556524, 9654, 10431, 241, 685, "Input"],
Cell[566958, 9897, 226, 7, 51, "Text"],
Cell[CellGroupData[{
Cell[567209, 9908, 5029, 136, 264, "Input"],
Cell[572241, 10046, 114116, 1904, 447, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

